Class: Algolia::Abtesting::ABTest

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/abtesting/ab_test.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ABTest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/algolia/models/abtesting/ab_test.rb', line 119

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::ABTest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::ABTest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:ab_test_id)
    self.ab_test_id = attributes[:ab_test_id]
  else
    self.ab_test_id = nil
  end

  if attributes.key?(:click_significance)
    self.click_significance = attributes[:click_significance]
  else
    self.click_significance = nil
  end

  if attributes.key?(:conversion_significance)
    self.conversion_significance = attributes[:conversion_significance]
  else
    self.conversion_significance = nil
  end

  if attributes.key?(:add_to_cart_significance)
    self.add_to_cart_significance = attributes[:add_to_cart_significance]
  else
    self.add_to_cart_significance = nil
  end

  if attributes.key?(:purchase_significance)
    self.purchase_significance = attributes[:purchase_significance]
  else
    self.purchase_significance = nil
  end

  if attributes.key?(:revenue_significance)
    if (value = attributes[:revenue_significance]).is_a?(Hash)
      self.revenue_significance = value
    end
  else
    self.revenue_significance = nil
  end

  if attributes.key?(:updated_at)
    self.updated_at = attributes[:updated_at]
  else
    self.updated_at = nil
  end

  if attributes.key?(:created_at)
    self.created_at = attributes[:created_at]
  else
    self.created_at = nil
  end

  if attributes.key?(:end_at)
    self.end_at = attributes[:end_at]
  else
    self.end_at = nil
  end

  if attributes.key?(:name)
    self.name = attributes[:name]
  else
    self.name = nil
  end

  if attributes.key?(:status)
    self.status = attributes[:status]
  else
    self.status = nil
  end

  if attributes.key?(:variants)
    if (value = attributes[:variants]).is_a?(Array)
      self.variants = value
    end
  else
    self.variants = nil
  end

  if attributes.key?(:configuration)
    self.configuration = attributes[:configuration]
  end
end

Instance Attribute Details

#ab_test_idObject

Unique A/B test identifier.



10
11
12
# File 'lib/algolia/models/abtesting/ab_test.rb', line 10

def ab_test_id
  @ab_test_id
end

#add_to_cart_significanceObject

Returns the value of attribute add_to_cart_significance.



16
17
18
# File 'lib/algolia/models/abtesting/ab_test.rb', line 16

def add_to_cart_significance
  @add_to_cart_significance
end

#click_significanceObject

Returns the value of attribute click_significance.



12
13
14
# File 'lib/algolia/models/abtesting/ab_test.rb', line 12

def click_significance
  @click_significance
end

#configurationObject

Returns the value of attribute configuration.



39
40
41
# File 'lib/algolia/models/abtesting/ab_test.rb', line 39

def configuration
  @configuration
end

#conversion_significanceObject

Returns the value of attribute conversion_significance.



14
15
16
# File 'lib/algolia/models/abtesting/ab_test.rb', line 14

def conversion_significance
  @conversion_significance
end

#created_atObject

Date and time when the A/B test was created, in RFC 3339 format.



26
27
28
# File 'lib/algolia/models/abtesting/ab_test.rb', line 26

def created_at
  @created_at
end

#end_atObject

End date and time of the A/B test, in RFC 3339 format.



29
30
31
# File 'lib/algolia/models/abtesting/ab_test.rb', line 29

def end_at
  @end_at
end

#nameObject

A/B test name.



32
33
34
# File 'lib/algolia/models/abtesting/ab_test.rb', line 32

def name
  @name
end

#purchase_significanceObject

Returns the value of attribute purchase_significance.



18
19
20
# File 'lib/algolia/models/abtesting/ab_test.rb', line 18

def purchase_significance
  @purchase_significance
end

#revenue_significanceObject

Returns the value of attribute revenue_significance.



20
21
22
# File 'lib/algolia/models/abtesting/ab_test.rb', line 20

def revenue_significance
  @revenue_significance
end

#statusObject

Returns the value of attribute status.



34
35
36
# File 'lib/algolia/models/abtesting/ab_test.rb', line 34

def status
  @status
end

#updated_atObject

Date and time when the A/B test was last updated, in RFC 3339 format.



23
24
25
# File 'lib/algolia/models/abtesting/ab_test.rb', line 23

def updated_at
  @updated_at
end

#variantsObject

A/B test variants. The first variant is your control index, typically your production index. The second variant is an index with changed settings that you want to test against the control.



37
38
39
# File 'lib/algolia/models/abtesting/ab_test.rb', line 37

def variants
  @variants
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/algolia/models/abtesting/ab_test.rb', line 277

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Abtesting.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/algolia/models/abtesting/ab_test.rb', line 83

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/algolia/models/abtesting/ab_test.rb', line 64

def self.attribute_map
  {
    :ab_test_id => :abTestID,
    :click_significance => :clickSignificance,
    :conversion_significance => :conversionSignificance,
    :add_to_cart_significance => :addToCartSignificance,
    :purchase_significance => :purchaseSignificance,
    :revenue_significance => :revenueSignificance,
    :updated_at => :updatedAt,
    :created_at => :createdAt,
    :end_at => :endAt,
    :name => :name,
    :status => :status,
    :variants => :variants,
    :configuration => :configuration
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/algolia/models/abtesting/ab_test.rb', line 252

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
111
112
113
114
115
# File 'lib/algolia/models/abtesting/ab_test.rb', line 107

def self.openapi_nullable
  Set.new([
            :click_significance,
            :conversion_significance,
            :add_to_cart_significance,
            :purchase_significance,
            :revenue_significance
          ])
end

.types_mappingObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/algolia/models/abtesting/ab_test.rb', line 88

def self.types_mapping
  {
    :ab_test_id => :Integer,
    :click_significance => :Float,
    :conversion_significance => :Float,
    :add_to_cart_significance => :Float,
    :purchase_significance => :Float,
    :revenue_significance => :'Hash<String, Float>',
    :updated_at => :String,
    :created_at => :String,
    :end_at => :String,
    :name => :String,
    :status => :Status,
    :variants => :'Array<Variant>',
    :configuration => :ABTestConfiguration
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/algolia/models/abtesting/ab_test.rb', line 217

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    ab_test_id == other.ab_test_id &&
    click_significance == other.click_significance &&
    conversion_significance == other.conversion_significance &&
    add_to_cart_significance == other.add_to_cart_significance &&
    purchase_significance == other.purchase_significance &&
    revenue_significance == other.revenue_significance &&
    updated_at == other.updated_at &&
    created_at == other.created_at &&
    end_at == other.end_at &&
    name == other.name &&
    status == other.status &&
    variants == other.variants &&
    configuration == other.configuration
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/algolia/models/abtesting/ab_test.rb', line 352

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


238
239
240
# File 'lib/algolia/models/abtesting/ab_test.rb', line 238

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



244
245
246
247
# File 'lib/algolia/models/abtesting/ab_test.rb', line 244

def hash
  [ab_test_id, click_significance, conversion_significance, add_to_cart_significance, purchase_significance, revenue_significance, updated_at, created_at, end_at, name,
   status, variants, configuration].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



324
325
326
# File 'lib/algolia/models/abtesting/ab_test.rb', line 324

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/algolia/models/abtesting/ab_test.rb', line 334

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*_args) ⇒ Object



328
329
330
# File 'lib/algolia/models/abtesting/ab_test.rb', line 328

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



318
319
320
# File 'lib/algolia/models/abtesting/ab_test.rb', line 318

def to_s
  to_hash.to_s
end