Class: Algolia::Abtesting::ABTestResponse
- Inherits:
-
Object
- Object
- Algolia::Abtesting::ABTestResponse
- Defined in:
- lib/algolia/models/abtesting/ab_test_response.rb
Instance Attribute Summary collapse
-
#ab_test_id ⇒ Object
Unique A/B test ID.
-
#index ⇒ Object
A/B test index.
-
#task_id ⇒ Object
Unique identifier of a task.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ABTestResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ABTestResponse
Initializes the object
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 48 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::ABTestResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::ABTestResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:index) self.index = attributes[:index] else self.index = nil end if attributes.key?(:ab_test_id) self.ab_test_id = attributes[:ab_test_id] else self.ab_test_id = nil end if attributes.key?(:task_id) self.task_id = attributes[:task_id] else self.task_id = nil end end |
Instance Attribute Details
#ab_test_id ⇒ Object
Unique A/B test ID.
13 14 15 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 13 def ab_test_id @ab_test_id end |
#index ⇒ Object
A/B test index.
10 11 12 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 10 def index @index end |
#task_id ⇒ Object
Unique identifier of a task. A successful API response means that a task was added to a queue. It might not run immediately. You can check the task’s progress with the ‘task` operation and this `taskID`.
16 17 18 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 16 def task_id @task_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 133 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Abtesting.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
28 29 30 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 28 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
19 20 21 22 23 24 25 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 19 def self.attribute_map { :index => :index, :ab_test_id => :abTestID, :task_id => :taskID } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 108 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
42 43 44 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 42 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
33 34 35 36 37 38 39 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 33 def self.types_mapping { :index => :String, :ab_test_id => :Integer, :task_id => :Integer } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
84 85 86 87 88 89 90 91 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 84 def ==(other) return true if equal?(other) self.class == other.class && index == other.index && ab_test_id == other.ab_test_id && task_id == other.task_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 208 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
95 96 97 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 95 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
101 102 103 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 101 def hash [index, ab_test_id, task_id].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
180 181 182 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 180 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 190 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
184 185 186 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 184 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
174 175 176 |
# File 'lib/algolia/models/abtesting/ab_test_response.rb', line 174 def to_s to_hash.to_s end |