Class: Algolia::Abtesting::Variant

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/abtesting/variant.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Variant

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/algolia/models/abtesting/variant.rb', line 127

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::Variant` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::Variant`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:add_to_cart_count)
    self.add_to_cart_count = attributes[:add_to_cart_count]
  else
    self.add_to_cart_count = nil
  end

  if attributes.key?(:add_to_cart_rate)
    self.add_to_cart_rate = attributes[:add_to_cart_rate]
  else
    self.add_to_cart_rate = nil
  end

  if attributes.key?(:average_click_position)
    self.average_click_position = attributes[:average_click_position]
  else
    self.average_click_position = nil
  end

  if attributes.key?(:click_count)
    self.click_count = attributes[:click_count]
  else
    self.click_count = nil
  end

  if attributes.key?(:click_through_rate)
    self.click_through_rate = attributes[:click_through_rate]
  else
    self.click_through_rate = nil
  end

  if attributes.key?(:conversion_count)
    self.conversion_count = attributes[:conversion_count]
  else
    self.conversion_count = nil
  end

  if attributes.key?(:conversion_rate)
    self.conversion_rate = attributes[:conversion_rate]
  else
    self.conversion_rate = nil
  end

  if attributes.key?(:currencies)
    if (value = attributes[:currencies]).is_a?(Hash)
      self.currencies = value
    end
  else
    self.currencies = nil
  end

  if attributes.key?(:description)
    self.description = attributes[:description]
  else
    self.description = nil
  end

  if attributes.key?(:filter_effects)
    self.filter_effects = attributes[:filter_effects]
  end

  if attributes.key?(:index)
    self.index = attributes[:index]
  else
    self.index = nil
  end

  if attributes.key?(:no_result_count)
    self.no_result_count = attributes[:no_result_count]
  else
    self.no_result_count = nil
  end

  if attributes.key?(:purchase_count)
    self.purchase_count = attributes[:purchase_count]
  else
    self.purchase_count = nil
  end

  if attributes.key?(:purchase_rate)
    self.purchase_rate = attributes[:purchase_rate]
  else
    self.purchase_rate = nil
  end

  if attributes.key?(:search_count)
    self.search_count = attributes[:search_count]
  else
    self.search_count = nil
  end

  if attributes.key?(:tracked_search_count)
    self.tracked_search_count = attributes[:tracked_search_count]
  else
    self.tracked_search_count = nil
  end

  if attributes.key?(:traffic_percentage)
    self.traffic_percentage = attributes[:traffic_percentage]
  else
    self.traffic_percentage = nil
  end

  if attributes.key?(:user_count)
    self.user_count = attributes[:user_count]
  else
    self.user_count = nil
  end

  if attributes.key?(:tracked_user_count)
    self.tracked_user_count = attributes[:tracked_user_count]
  else
    self.tracked_user_count = nil
  end
end

Instance Attribute Details

#add_to_cart_countObject

Number of add-to-cart events for this variant.



10
11
12
# File 'lib/algolia/models/abtesting/variant.rb', line 10

def add_to_cart_count
  @add_to_cart_count
end

#add_to_cart_rateObject



13
14
15
# File 'lib/algolia/models/abtesting/variant.rb', line 13

def add_to_cart_rate
  @add_to_cart_rate
end

#average_click_positionObject



16
17
18
# File 'lib/algolia/models/abtesting/variant.rb', line 16

def average_click_position
  @average_click_position
end

#click_countObject

Number of click events for this variant.



19
20
21
# File 'lib/algolia/models/abtesting/variant.rb', line 19

def click_count
  @click_count
end

#click_through_rateObject



22
23
24
# File 'lib/algolia/models/abtesting/variant.rb', line 22

def click_through_rate
  @click_through_rate
end

#conversion_countObject

Number of click events for this variant.



25
26
27
# File 'lib/algolia/models/abtesting/variant.rb', line 25

def conversion_count
  @conversion_count
end

#conversion_rateObject



28
29
30
# File 'lib/algolia/models/abtesting/variant.rb', line 28

def conversion_rate
  @conversion_rate
end

#currenciesObject

A/B test currencies.



31
32
33
# File 'lib/algolia/models/abtesting/variant.rb', line 31

def currencies
  @currencies
end

#descriptionObject

A/B test description.



34
35
36
# File 'lib/algolia/models/abtesting/variant.rb', line 34

def description
  @description
end

#filter_effectsObject

Returns the value of attribute filter_effects.



36
37
38
# File 'lib/algolia/models/abtesting/variant.rb', line 36

def filter_effects
  @filter_effects
end

#indexObject

A/B test index.



39
40
41
# File 'lib/algolia/models/abtesting/variant.rb', line 39

def index
  @index
end

#no_result_countObject

Number of [searches without results](www.algolia.com/doc/guides/search-analytics/concepts/metrics/#searches-without-results) for that variant.



42
43
44
# File 'lib/algolia/models/abtesting/variant.rb', line 42

def no_result_count
  @no_result_count
end

#purchase_countObject

Number of purchase events for this variant.



45
46
47
# File 'lib/algolia/models/abtesting/variant.rb', line 45

def purchase_count
  @purchase_count
end

#purchase_rateObject



48
49
50
# File 'lib/algolia/models/abtesting/variant.rb', line 48

def purchase_rate
  @purchase_rate
end

#search_countObject

Number of searches carried out during the A/B test.



51
52
53
# File 'lib/algolia/models/abtesting/variant.rb', line 51

def search_count
  @search_count
end

#tracked_search_countObject

Number of tracked searches. This is the number of search requests where the ‘clickAnalytics` parameter is `true`.



54
55
56
# File 'lib/algolia/models/abtesting/variant.rb', line 54

def tracked_search_count
  @tracked_search_count
end

#tracked_user_countObject

Number of users that performed a tracked search during the A/B test.



63
64
65
# File 'lib/algolia/models/abtesting/variant.rb', line 63

def tracked_user_count
  @tracked_user_count
end

#traffic_percentageObject

A/B test traffic percentage.



57
58
59
# File 'lib/algolia/models/abtesting/variant.rb', line 57

def traffic_percentage
  @traffic_percentage
end

#user_countObject

Number of users during the A/B test.



60
61
62
# File 'lib/algolia/models/abtesting/variant.rb', line 60

def user_count
  @user_count
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/algolia/models/abtesting/variant.rb', line 325

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Abtesting.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/algolia/models/abtesting/variant.rb', line 91

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/algolia/models/abtesting/variant.rb', line 66

def self.attribute_map
  {
    :add_to_cart_count => :addToCartCount,
    :add_to_cart_rate => :addToCartRate,
    :average_click_position => :averageClickPosition,
    :click_count => :clickCount,
    :click_through_rate => :clickThroughRate,
    :conversion_count => :conversionCount,
    :conversion_rate => :conversionRate,
    :currencies => :currencies,
    :description => :description,
    :filter_effects => :filterEffects,
    :index => :index,
    :no_result_count => :noResultCount,
    :purchase_count => :purchaseCount,
    :purchase_rate => :purchaseRate,
    :search_count => :searchCount,
    :tracked_search_count => :trackedSearchCount,
    :traffic_percentage => :trafficPercentage,
    :user_count => :userCount,
    :tracked_user_count => :trackedUserCount
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/algolia/models/abtesting/variant.rb', line 300

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
# File 'lib/algolia/models/abtesting/variant.rb', line 121

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/algolia/models/abtesting/variant.rb', line 96

def self.types_mapping
  {
    :add_to_cart_count => :Integer,
    :add_to_cart_rate => :Float,
    :average_click_position => :Integer,
    :click_count => :Integer,
    :click_through_rate => :Float,
    :conversion_count => :Integer,
    :conversion_rate => :Float,
    :currencies => :'Hash<String, CurrenciesValue>',
    :description => :String,
    :filter_effects => :FilterEffects,
    :index => :String,
    :no_result_count => :Integer,
    :purchase_count => :Integer,
    :purchase_rate => :Float,
    :search_count => :Integer,
    :tracked_search_count => :Integer,
    :traffic_percentage => :Integer,
    :user_count => :Integer,
    :tracked_user_count => :Integer
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/algolia/models/abtesting/variant.rb', line 259

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    add_to_cart_count == other.add_to_cart_count &&
    add_to_cart_rate == other.add_to_cart_rate &&
    average_click_position == other.average_click_position &&
    click_count == other.click_count &&
    click_through_rate == other.click_through_rate &&
    conversion_count == other.conversion_count &&
    conversion_rate == other.conversion_rate &&
    currencies == other.currencies &&
    description == other.description &&
    filter_effects == other.filter_effects &&
    index == other.index &&
    no_result_count == other.no_result_count &&
    purchase_count == other.purchase_count &&
    purchase_rate == other.purchase_rate &&
    search_count == other.search_count &&
    tracked_search_count == other.tracked_search_count &&
    traffic_percentage == other.traffic_percentage &&
    user_count == other.user_count &&
    tracked_user_count == other.tracked_user_count
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/algolia/models/abtesting/variant.rb', line 400

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


286
287
288
# File 'lib/algolia/models/abtesting/variant.rb', line 286

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



292
293
294
295
# File 'lib/algolia/models/abtesting/variant.rb', line 292

def hash
  [add_to_cart_count, add_to_cart_rate, average_click_position, click_count, click_through_rate, conversion_count, conversion_rate, currencies, description, filter_effects,
   index, no_result_count, purchase_count, purchase_rate, search_count, tracked_search_count, traffic_percentage, user_count, tracked_user_count].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



372
373
374
# File 'lib/algolia/models/abtesting/variant.rb', line 372

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/algolia/models/abtesting/variant.rb', line 382

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*_args) ⇒ Object



376
377
378
# File 'lib/algolia/models/abtesting/variant.rb', line 376

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



366
367
368
# File 'lib/algolia/models/abtesting/variant.rb', line 366

def to_s
  to_hash.to_s
end