Class: Algolia::AbtestingV3::ABTest

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/abtesting-v3/ab_test.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ABTest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::ABTest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      raise(
        ArgumentError,
        "`#{k}` is not a valid attribute in `Algolia::ABTest`. Please check the name to make sure it's valid. List of attributes: " +
          self.class.attribute_map.keys.inspect
      )
    end

    h[k.to_sym] = v
  }

  if attributes.key?(:ab_test_id)
    self.ab_test_id = attributes[:ab_test_id]
  else
    self.ab_test_id = nil
  end

  if attributes.key?(:updated_at)
    self.updated_at = attributes[:updated_at]
  else
    self.updated_at = nil
  end

  if attributes.key?(:created_at)
    self.created_at = attributes[:created_at]
  else
    self.created_at = nil
  end

  if attributes.key?(:end_at)
    self.end_at = attributes[:end_at]
  else
    self.end_at = nil
  end

  if attributes.key?(:stopped_at)
    self.stopped_at = attributes[:stopped_at]
  end

  if attributes.key?(:name)
    self.name = attributes[:name]
  else
    self.name = nil
  end

  if attributes.key?(:status)
    self.status = attributes[:status]
  else
    self.status = nil
  end

  if attributes.key?(:variants)
    if (value = attributes[:variants]).is_a?(Array)
      self.variants = value
    end
  else
    self.variants = nil
  end

  if attributes.key?(:configuration)
    self.configuration = attributes[:configuration]
  end

  if attributes.key?(:migrated_ab_test_id)
    self.migrated_ab_test_id = attributes[:migrated_ab_test_id]
  end

  if attributes.key?(:decision)
    self.decision = attributes[:decision]
  end
end

Instance Attribute Details

#ab_test_idObject

Unique A/B test identifier.



12
13
14
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 12

def ab_test_id
  @ab_test_id
end

#configurationObject

Returns the value of attribute configuration.



34
35
36
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 34

def configuration
  @configuration
end

#created_atObject

Date and time when the A/B test was created, in RFC 3339 format.



18
19
20
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 18

def created_at
  @created_at
end

#decisionObject

Returns the value of attribute decision.



39
40
41
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 39

def decision
  @decision
end

#end_atObject

End date and time of the A/B test, in RFC 3339 format.



21
22
23
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 21

def end_at
  @end_at
end

#migrated_ab_test_idObject

Unique migrated A/B test identifier.



37
38
39
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 37

def migrated_ab_test_id
  @migrated_ab_test_id
end

#nameObject

A/B test name.



27
28
29
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 27

def name
  @name
end

#statusObject

Returns the value of attribute status.



29
30
31
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 29

def status
  @status
end

#stopped_atObject

Date and time when the A/B test was stopped, in RFC 3339 format.



24
25
26
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 24

def stopped_at
  @stopped_at
end

#updated_atObject

Date and time when the A/B test was last updated, in RFC 3339 format.



15
16
17
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 15

def updated_at
  @updated_at
end

#variantsObject

A/B test variants. The first variant is your control index, typically your production index. All of the additional variants are indexes with changed settings that you want to test against the control.



32
33
34
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 32

def variants
  @variants
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 237

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end

  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
    # model
  else
    # models (e.g. Pet) or oneOf
    klass = Algolia::AbtestingV3.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass
      .build_from_hash(value)
  end
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 42

def self.attribute_map
  {
    :ab_test_id => :abTestID,
    :updated_at => :updatedAt,
    :created_at => :createdAt,
    :end_at => :endAt,
    :stopped_at => :stoppedAt,
    :name => :name,
    :status => :status,
    :variants => :variants,
    :configuration => :configuration,
    :migrated_ab_test_id => :migratedAbTestID,
    :decision => :decision
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 210

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v|
          _deserialize(::Regexp.last_match(1), v)
        }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end

  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
81
82
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 76

def self.openapi_nullable
  Set.new(
    [
      :stopped_at
    ]
  )
end

.types_mappingObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 59

def self.types_mapping
  {
    :ab_test_id => :"Integer",
    :updated_at => :"String",
    :created_at => :"String",
    :end_at => :"String",
    :stopped_at => :"String",
    :name => :"String",
    :status => :"Status",
    :variants => :"Array<Variant>",
    :configuration => :"ABTestConfiguration",
    :migrated_ab_test_id => :"Integer",
    :decision => :"Decision"
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 167

def ==(other)
  return true if self.equal?(other)
  self.class == other.class &&
    ab_test_id == other.ab_test_id &&
    updated_at == other.updated_at &&
    created_at == other.created_at &&
    end_at == other.end_at &&
    stopped_at == other.stopped_at &&
    name == other.name &&
    status == other.status &&
    variants == other.variants &&
    configuration == other.configuration &&
    migrated_ab_test_id == other.migrated_ab_test_id &&
    decision == other.decision
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 316

def _to_hash(value)
  if value.is_a?(Array)
    value.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to?(:to_hash)
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


185
186
187
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 185

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 191

def hash
  [
    ab_test_id,
    updated_at,
    created_at,
    end_at,
    stopped_at,
    name,
    status,
    variants,
    configuration,
    migrated_ab_test_id,
    decision
  ].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 287

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 297

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end

  hash
end

#to_json(*_args) ⇒ Object



291
292
293
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 291

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



281
282
283
# File 'lib/algolia/models/abtesting-v3/ab_test.rb', line 281

def to_s
  to_hash.to_s
end