Class: Algolia::AgentStudio::AlgoliaDisplayResultsToolConfig
- Inherits:
-
Object
- Object
- Algolia::AgentStudio::AlgoliaDisplayResultsToolConfig
- Defined in:
- lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb
Overview
Configuration for the algolia_display_results tool.
Instance Attribute Summary collapse
-
#max_groups ⇒ Object
Returns the value of attribute max_groups.
-
#max_results_per_group ⇒ Object
Returns the value of attribute max_results_per_group.
-
#min_groups ⇒ Object
Returns the value of attribute min_groups.
-
#min_results_per_group ⇒ Object
Returns the value of attribute min_results_per_group.
-
#name ⇒ Object
Returns the value of attribute name.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AlgoliaDisplayResultsToolConfig
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AlgoliaDisplayResultsToolConfig
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 57 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise( ArgumentError, "The input argument (attributes) must be a hash in `Algolia::AlgoliaDisplayResultsToolConfig` initialize method" ) end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) raise( ArgumentError, "`#{k}` is not a valid attribute in `Algolia::AlgoliaDisplayResultsToolConfig`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect ) end h[k.to_sym] = v } if attributes.key?(:name) self.name = attributes[:name] end if attributes.key?(:type) self.type = attributes[:type] else self.type = nil end if attributes.key?(:min_groups) self.min_groups = attributes[:min_groups] end if attributes.key?(:max_groups) self.max_groups = attributes[:max_groups] end if attributes.key?(:min_results_per_group) self.min_results_per_group = attributes[:min_results_per_group] end if attributes.key?(:max_results_per_group) self.max_results_per_group = attributes[:max_results_per_group] end end |
Instance Attribute Details
#max_groups ⇒ Object
Returns the value of attribute max_groups.
18 19 20 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 18 def max_groups @max_groups end |
#max_results_per_group ⇒ Object
Returns the value of attribute max_results_per_group.
22 23 24 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 22 def max_results_per_group @max_results_per_group end |
#min_groups ⇒ Object
Returns the value of attribute min_groups.
16 17 18 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 16 def min_groups @min_groups end |
#min_results_per_group ⇒ Object
Returns the value of attribute min_results_per_group.
20 21 22 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 20 def min_results_per_group @min_results_per_group end |
#name ⇒ Object
Returns the value of attribute name.
12 13 14 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 12 def name @name end |
#type ⇒ Object
Returns the value of attribute type.
14 15 16 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 14 def type @type end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 160 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end # model else # models (e.g. Pet) or oneOf klass = Algolia::AgentStudio.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass .build_from_hash(value) end end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 33 34 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 25 def self.attribute_map { :name => :name, :type => :type, :min_groups => :minGroups, :max_groups => :maxGroups, :min_results_per_group => :minResultsPerGroup, :max_results_per_group => :maxResultsPerGroup } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 133 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
49 50 51 52 53 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 49 def self.openapi_nullable Set.new( [] ) end |
.types_mapping ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 37 def self.types_mapping { :name => :"String", :type => :"String", :min_groups => :"Integer", :max_groups => :"Integer", :min_results_per_group => :"Integer", :max_results_per_group => :"Integer" } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
107 108 109 110 111 112 113 114 115 116 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 107 def ==(other) return true if self.equal?(other) self.class == other.class && name == other.name && type == other.type && min_groups == other.min_groups && max_groups == other.max_groups && min_results_per_group == other.min_results_per_group && max_results_per_group == other.max_results_per_group end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 239 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to?(:to_hash) value.to_hash else value end end |
#eql?(other) ⇒ Boolean
120 121 122 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 120 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
126 127 128 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 126 def hash [name, type, min_groups, max_groups, min_results_per_group, max_results_per_group].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
210 211 212 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 210 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 220 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
214 215 216 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 214 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
204 205 206 |
# File 'lib/algolia/models/agent-studio/algolia_display_results_tool_config.rb', line 204 def to_s to_hash.to_s end |