Class: Algolia::AgentStudio::ConversationFullResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/agent-studio/conversation_full_response.rb

Overview

Response model for a conversation with all its messages.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConversationFullResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise(
      ArgumentError,
      "The input argument (attributes) must be a hash in `Algolia::ConversationFullResponse` initialize method"
    )
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      raise(
        ArgumentError,
        "`#{k}` is not a valid attribute in `Algolia::ConversationFullResponse`. Please check the name to make sure it's valid. List of attributes: " +
          self.class.attribute_map.keys.inspect
      )
    end

    h[k.to_sym] = v
  }

  if attributes.key?(:id)
    self.id = attributes[:id]
  else
    self.id = nil
  end

  if attributes.key?(:agent_id)
    self.agent_id = attributes[:agent_id]
  else
    self.agent_id = nil
  end

  if attributes.key?(:title)
    self.title = attributes[:title]
  end

  if attributes.key?(:created_at)
    self.created_at = attributes[:created_at]
  else
    self.created_at = nil
  end

  if attributes.key?(:updated_at)
    self.updated_at = attributes[:updated_at]
  else
    self.updated_at = nil
  end

  if attributes.key?(:last_activity_at)
    self.last_activity_at = attributes[:last_activity_at]
  end

  if attributes.key?(:user_token)
    self.user_token = attributes[:user_token]
  end

  if attributes.key?(:is_from_dashboard)
    self.is_from_dashboard = attributes[:is_from_dashboard]
  end

  if attributes.key?(:message_count)
    self.message_count = attributes[:message_count]
  end

  if attributes.key?(:total_input_tokens)
    self.total_input_tokens = attributes[:total_input_tokens]
  end

  if attributes.key?(:total_output_tokens)
    self.total_output_tokens = attributes[:total_output_tokens]
  end

  if attributes.key?(:total_tokens)
    self.total_tokens = attributes[:total_tokens]
  end

  if attributes.key?(:conversation_metadata)
    self. = attributes[:conversation_metadata]
  end

  if attributes.key?(:feedback)
    if (value = attributes[:feedback]).is_a?(Array)
      self.feedback = value
    end
  end

  if attributes.key?(:messages)
    if (value = attributes[:messages]).is_a?(Array)
      self.messages = value
    end
  else
    self.messages = nil
  end
end

Instance Attribute Details

#agent_idObject

Returns the value of attribute agent_id.



14
15
16
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 14

def agent_id
  @agent_id
end

#conversation_metadataObject

Returns the value of attribute conversation_metadata.



36
37
38
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 36

def 
  @conversation_metadata
end

#created_atObject

Returns the value of attribute created_at.



18
19
20
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 18

def created_at
  @created_at
end

#feedbackObject

Returns the value of attribute feedback.



38
39
40
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 38

def feedback
  @feedback
end

#idObject

Returns the value of attribute id.



12
13
14
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 12

def id
  @id
end

#is_from_dashboardObject

Returns the value of attribute is_from_dashboard.



26
27
28
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 26

def is_from_dashboard
  @is_from_dashboard
end

#last_activity_atObject

Returns the value of attribute last_activity_at.



22
23
24
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 22

def last_activity_at
  @last_activity_at
end

#message_countObject

Returns the value of attribute message_count.



28
29
30
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 28

def message_count
  @message_count
end

#messagesObject

Returns the value of attribute messages.



40
41
42
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 40

def messages
  @messages
end

#titleObject

Returns the value of attribute title.



16
17
18
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 16

def title
  @title
end

#total_input_tokensObject

Returns the value of attribute total_input_tokens.



30
31
32
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 30

def total_input_tokens
  @total_input_tokens
end

#total_output_tokensObject

Returns the value of attribute total_output_tokens.



32
33
34
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 32

def total_output_tokens
  @total_output_tokens
end

#total_tokensObject

Returns the value of attribute total_tokens.



34
35
36
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 34

def total_tokens
  @total_tokens
end

#updated_atObject

Returns the value of attribute updated_at.



20
21
22
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 20

def updated_at
  @updated_at
end

#user_tokenObject

Returns the value of attribute user_token.



24
25
26
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 24

def user_token
  @user_token
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 275

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end

  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
    # model
  else
    # models (e.g. Pet) or oneOf
    klass = Algolia::AgentStudio.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass
      .build_from_hash(value)
  end
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 43

def self.attribute_map
  {
    :id => :id,
    :agent_id => :agentId,
    :title => :title,
    :created_at => :createdAt,
    :updated_at => :updatedAt,
    :last_activity_at => :lastActivityAt,
    :user_token => :userToken,
    :is_from_dashboard => :isFromDashboard,
    :message_count => :messageCount,
    :total_input_tokens => :totalInputTokens,
    :total_output_tokens => :totalOutputTokens,
    :total_tokens => :totalTokens,
    :conversation_metadata => :conversationMetadata,
    :feedback => :feedback,
    :messages => :messages
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 248

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v|
          _deserialize(::Regexp.last_match(1), v)
        }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end

  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 85

def self.openapi_nullable
  Set.new(
    [
      :title,
      :last_activity_at,
      :user_token,
      :conversation_metadata,
      :feedback
    ]
  )
end

.types_mappingObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 64

def self.types_mapping
  {
    :id => :"String",
    :agent_id => :"String",
    :title => :"String",
    :created_at => :"String",
    :updated_at => :"String",
    :last_activity_at => :"String",
    :user_token => :"String",
    :is_from_dashboard => :"Boolean",
    :message_count => :"Integer",
    :total_input_tokens => :"Integer",
    :total_output_tokens => :"Integer",
    :total_tokens => :"Integer",
    :conversation_metadata => :"ConversationMetadata",
    :feedback => :"Array<FeedbackResponse>",
    :messages => :"Array<MessageResponse>"
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 197

def ==(other)
  return true if self.equal?(other)
  self.class == other.class &&
    id == other.id &&
    agent_id == other.agent_id &&
    title == other.title &&
    created_at == other.created_at &&
    updated_at == other.updated_at &&
    last_activity_at == other.last_activity_at &&
    user_token == other.user_token &&
    is_from_dashboard == other.is_from_dashboard &&
    message_count == other.message_count &&
    total_input_tokens == other.total_input_tokens &&
    total_output_tokens == other.total_output_tokens &&
    total_tokens == other.total_tokens &&
     == other. &&
    feedback == other.feedback &&
    messages == other.messages
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 354

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to?(:to_hash)
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 219

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 225

def hash
  [
    id,
    agent_id,
    title,
    created_at,
    updated_at,
    last_activity_at,
    user_token,
    is_from_dashboard,
    message_count,
    total_input_tokens,
    total_output_tokens,
    total_tokens,
    ,
    feedback,
    messages
  ].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



325
326
327
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 325

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 335

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end

  hash
end

#to_json(*_args) ⇒ Object



329
330
331
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 329

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



319
320
321
# File 'lib/algolia/models/agent-studio/conversation_full_response.rb', line 319

def to_s
  to_hash.to_s
end