Class: Algolia::AgentStudio::FeedbackResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/agent-studio/feedback_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FeedbackResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise(
      ArgumentError,
      "The input argument (attributes) must be a hash in `Algolia::FeedbackResponse` initialize method"
    )
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      raise(
        ArgumentError,
        "`#{k}` is not a valid attribute in `Algolia::FeedbackResponse`. Please check the name to make sure it's valid. List of attributes: " +
          self.class.attribute_map.keys.inspect
      )
    end

    h[k.to_sym] = v
  }

  if attributes.key?(:id)
    self.id = attributes[:id]
  else
    self.id = nil
  end

  if attributes.key?(:agent_id)
    self.agent_id = attributes[:agent_id]
  else
    self.agent_id = nil
  end

  if attributes.key?(:message_id)
    self.message_id = attributes[:message_id]
  else
    self.message_id = nil
  end

  if attributes.key?(:vote)
    self.vote = attributes[:vote]
  else
    self.vote = nil
  end

  if attributes.key?(:tags)
    if (value = attributes[:tags]).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:notes)
    self.notes = attributes[:notes]
  end

  if attributes.key?(:model)
    self.model = attributes[:model]
  end

  if attributes.key?(:created_at)
    self.created_at = attributes[:created_at]
  else
    self.created_at = nil
  end

  if attributes.key?(:updated_at)
    self.updated_at = attributes[:updated_at]
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#agent_idObject

Returns the value of attribute agent_id.



13
14
15
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 13

def agent_id
  @agent_id
end

#created_atObject

Returns the value of attribute created_at.



25
26
27
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 25

def created_at
  @created_at
end

#idObject

Returns the value of attribute id.



11
12
13
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 11

def id
  @id
end

#message_idObject

Returns the value of attribute message_id.



15
16
17
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 15

def message_id
  @message_id
end

#modelObject

Returns the value of attribute model.



23
24
25
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 23

def model
  @model
end

#notesObject

Returns the value of attribute notes.



21
22
23
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 21

def notes
  @notes
end

#tagsObject

Returns the value of attribute tags.



19
20
21
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 19

def tags
  @tags
end

#updated_atObject

Returns the value of attribute updated_at.



27
28
29
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 27

def updated_at
  @updated_at
end

#voteObject

Returns the value of attribute vote.



17
18
19
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 17

def vote
  @vote
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 203

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end

  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
    # model
  else
    # models (e.g. Pet) or oneOf
    klass = Algolia::AgentStudio.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass
      .build_from_hash(value)
  end
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
38
39
40
41
42
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 30

def self.attribute_map
  {
    :id => :id,
    :agent_id => :agentId,
    :message_id => :messageId,
    :vote => :vote,
    :tags => :tags,
    :notes => :notes,
    :model => :model,
    :created_at => :createdAt,
    :updated_at => :updatedAt
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 176

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v|
          _deserialize(::Regexp.last_match(1), v)
        }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end

  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
64
65
66
67
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 60

def self.openapi_nullable
  Set.new(
    [
      :notes,
      :model
    ]
  )
end

.types_mappingObject

Attribute type mapping.



45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 45

def self.types_mapping
  {
    :id => :"String",
    :agent_id => :"String",
    :message_id => :"String",
    :vote => :"Integer",
    :tags => :"Array<String>",
    :notes => :"String",
    :model => :"String",
    :created_at => :"String",
    :updated_at => :"String"
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 147

def ==(other)
  return true if self.equal?(other)
  self.class == other.class &&
    id == other.id &&
    agent_id == other.agent_id &&
    message_id == other.message_id &&
    vote == other.vote &&
    tags == other.tags &&
    notes == other.notes &&
    model == other.model &&
    created_at == other.created_at &&
    updated_at == other.updated_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 282

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to?(:to_hash)
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


163
164
165
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 163

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



169
170
171
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 169

def hash
  [id, agent_id, message_id, vote, tags, notes, model, created_at, updated_at].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



253
254
255
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 253

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 263

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end

  hash
end

#to_json(*_args) ⇒ Object



257
258
259
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 257

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



247
248
249
# File 'lib/algolia/models/agent-studio/feedback_response.rb', line 247

def to_s
  to_hash.to_s
end