Class: Algolia::AgentStudio::MemoryRecord

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/agent-studio/memory_record.rb

Overview

Universal storage model for all memory types (semantic, episodic). This is the ONLY model that touches storage (Algolia). Domain models (SemanticMemory, EpisodicMemory) are used for LLM extraction and converted to MemoryRecord before saving. See langchain-ai.github.io/langmem/concepts/conceptual_guide/#memory-types for memory type definitions.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MemoryRecord

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise(
      ArgumentError,
      "The input argument (attributes) must be a hash in `Algolia::MemoryRecord` initialize method"
    )
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      raise(
        ArgumentError,
        "`#{k}` is not a valid attribute in `Algolia::MemoryRecord`. Please check the name to make sure it's valid. List of attributes: " +
          self.class.attribute_map.keys.inspect
      )
    end

    h[k.to_sym] = v
  }

  if attributes.key?(:memory_type)
    self.memory_type = attributes[:memory_type]
  end

  if attributes.key?(:episode)
    self.episode = attributes[:episode]
  end

  if attributes.key?(:text)
    self.text = attributes[:text]
  else
    self.text = nil
  end

  if attributes.key?(:raw_extract)
    self.raw_extract = attributes[:raw_extract]
  else
    self.raw_extract = nil
  end

  if attributes.key?(:keywords)
    if (value = attributes[:keywords]).is_a?(Array)
      self.keywords = value
    end
  end

  if attributes.key?(:topics)
    if (value = attributes[:topics]).is_a?(Array)
      self.topics = value
    end
  end

  if attributes.key?(:_tags)
    if (value = attributes[:_tags]).is_a?(Array)
      self._tags = value
    end
  end

  if attributes.key?(:recall_triggers)
    if (value = attributes[:recall_triggers]).is_a?(Array)
      self.recall_triggers = value
    end
  end

  if attributes.key?(:algolia_object_id)
    self.algolia_object_id = attributes[:algolia_object_id]
  end

  if attributes.key?(:app_id)
    self.app_id = attributes[:app_id]
  end

  if attributes.key?(:agent_ids)
    if (value = attributes[:agent_ids]).is_a?(Array)
      self.agent_ids = value
    end
  end

  if attributes.key?(:user_id)
    self.user_id = attributes[:user_id]
  end

  if attributes.key?(:created_at)
    self.created_at = attributes[:created_at]
  end

  if attributes.key?(:updated_at)
    self.updated_at = attributes[:updated_at]
  end
end

Instance Attribute Details

#_tagsObject

Arbitrary labels/themes for flexible categorization (e.g., ‘Q1-goals’, ‘paris-trip’, ‘vip-customer’).



29
30
31
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 29

def _tags
  @_tags
end

#agent_idsObject

Agent IDs with access: [‘agent1’], [‘*’] for all, [‘*’, ‘-agent1’] to exclude.



41
42
43
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 41

def agent_ids
  @agent_ids
end

#algolia_object_idObject

ObjectID of existing memory to update. Leave empty for new memory.



35
36
37
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 35

def algolia_object_id
  @algolia_object_id
end

#app_idObject

Application ID.



38
39
40
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 38

def app_id
  @app_id
end

#created_atObject

Epoch seconds.



47
48
49
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 47

def created_at
  @created_at
end

#episodeObject

Returns the value of attribute episode.



14
15
16
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 14

def episode
  @episode
end

#keywordsObject

5-20 free-form keywords: entities, context, search terms (any words).



23
24
25
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 23

def keywords
  @keywords
end

#memory_typeObject

Returns the value of attribute memory_type.



12
13
14
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 12

def memory_type
  @memory_type
end

#raw_extractObject

Verbatim conversation extract, not paraphrased.



20
21
22
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 20

def raw_extract
  @raw_extract
end

#recall_triggersObject

3-5 natural phrases that should trigger this memory.



32
33
34
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 32

def recall_triggers
  @recall_triggers
end

#textObject

Self-contained, first-person memory for long-term recall.



17
18
19
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 17

def text
  @text
end

#topicsObject

2-4 topics ONLY from this list: [complaints, entertainment, family, feedback, finance, food, goals, health, history, hobbies, learning, praise, preferences, schedule, shopping, technical, travel, work].



26
27
28
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 26

def topics
  @topics
end

#updated_atObject

Epoch seconds.



50
51
52
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 50

def updated_at
  @updated_at
end

#user_idObject

User ID.



44
45
46
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 44

def user_id
  @user_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 274

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end

  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
    # model
  else
    # models (e.g. Pet) or oneOf
    klass = Algolia::AgentStudio.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass
      .build_from_hash(value)
  end
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 53

def self.attribute_map
  {
    :memory_type => :memoryType,
    :episode => :episode,
    :text => :text,
    :raw_extract => :rawExtract,
    :keywords => :keywords,
    :topics => :topics,
    :_tags => :_tags,
    :recall_triggers => :recallTriggers,
    :algolia_object_id => :objectID,
    :app_id => :appId,
    :agent_ids => :agentIDs,
    :user_id => :userID,
    :created_at => :createdAt,
    :updated_at => :updatedAt
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 247

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v|
          _deserialize(::Regexp.last_match(1), v)
        }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end

  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
98
99
100
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 93

def self.openapi_nullable
  Set.new(
    [
      :episode,
      :algolia_object_id
    ]
  )
end

.types_mappingObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 73

def self.types_mapping
  {
    :memory_type => :"MemoryType",
    :episode => :"Episode",
    :text => :"String",
    :raw_extract => :"String",
    :keywords => :"Array<String>",
    :topics => :"Array<String>",
    :_tags => :"Array<String>",
    :recall_triggers => :"Array<String>",
    :algolia_object_id => :"String",
    :app_id => :"String",
    :agent_ids => :"Array<String>",
    :user_id => :"String",
    :created_at => :"Integer",
    :updated_at => :"Integer"
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 198

def ==(other)
  return true if self.equal?(other)
  self.class == other.class &&
    memory_type == other.memory_type &&
    episode == other.episode &&
    text == other.text &&
    raw_extract == other.raw_extract &&
    keywords == other.keywords &&
    topics == other.topics &&
    _tags == other._tags &&
    recall_triggers == other.recall_triggers &&
    algolia_object_id == other.algolia_object_id &&
    app_id == other.app_id &&
    agent_ids == other.agent_ids &&
    user_id == other.user_id &&
    created_at == other.created_at &&
    updated_at == other.updated_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 353

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to?(:to_hash)
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 219

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 225

def hash
  [
    memory_type,
    episode,
    text,
    raw_extract,
    keywords,
    topics,
    _tags,
    recall_triggers,
    algolia_object_id,
    app_id,
    agent_ids,
    user_id,
    created_at,
    updated_at
  ].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



324
325
326
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 324

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 334

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end

  hash
end

#to_json(*_args) ⇒ Object



328
329
330
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 328

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



318
319
320
# File 'lib/algolia/models/agent-studio/memory_record.rb', line 318

def to_s
  to_hash.to_s
end