Class: Algolia::AgentStudio::ProviderAuthenticationResponse
- Inherits:
-
Object
- Object
- Algolia::AgentStudio::ProviderAuthenticationResponse
- Defined in:
- lib/algolia/models/agent-studio/provider_authentication_response.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#input ⇒ Object
Returns the value of attribute input.
-
#last_used_at ⇒ Object
Returns the value of attribute last_used_at.
-
#name ⇒ Object
Returns the value of attribute name.
-
#provider_name ⇒ Object
Returns the value of attribute provider_name.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProviderAuthenticationResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ProviderAuthenticationResponse
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise( ArgumentError, "The input argument (attributes) must be a hash in `Algolia::ProviderAuthenticationResponse` initialize method" ) end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) raise( ArgumentError, "`#{k}` is not a valid attribute in `Algolia::ProviderAuthenticationResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect ) end h[k.to_sym] = v } if attributes.key?(:id) self.id = attributes[:id] else self.id = nil end if attributes.key?(:name) self.name = attributes[:name] else self.name = nil end if attributes.key?(:provider_name) self.provider_name = attributes[:provider_name] else self.provider_name = nil end if attributes.key?(:input) self.input = attributes[:input] else self.input = nil end if attributes.key?(:created_at) self.created_at = attributes[:created_at] else self.created_at = nil end if attributes.key?(:updated_at) self.updated_at = attributes[:updated_at] else self.updated_at = nil end if attributes.key?(:last_used_at) self.last_used_at = attributes[:last_used_at] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
19 20 21 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 19 def created_at @created_at end |
#id ⇒ Object
Returns the value of attribute id.
11 12 13 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 11 def id @id end |
#input ⇒ Object
Returns the value of attribute input.
17 18 19 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 17 def input @input end |
#last_used_at ⇒ Object
Returns the value of attribute last_used_at.
23 24 25 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 23 def last_used_at @last_used_at end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 13 def name @name end |
#provider_name ⇒ Object
Returns the value of attribute provider_name.
15 16 17 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 15 def provider_name @provider_name end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
21 22 23 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 21 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 180 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end # model else # models (e.g. Pet) or oneOf klass = Algolia::AgentStudio.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass .build_from_hash(value) end end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 26 def self.attribute_map { :id => :id, :name => :name, :provider_name => :providerName, :input => :input, :created_at => :createdAt, :updated_at => :updatedAt, :last_used_at => :lastUsedAt } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 153 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 56 57 58 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 52 def self.openapi_nullable Set.new( [ :last_used_at ] ) end |
.types_mapping ⇒ Object
Attribute type mapping.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 39 def self.types_mapping { :id => :"String", :name => :"String", :provider_name => :"String", :input => :"ProviderInput", :created_at => :"String", :updated_at => :"String", :last_used_at => :"String" } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 126 def ==(other) return true if self.equal?(other) self.class == other.class && id == other.id && name == other.name && provider_name == other.provider_name && input == other.input && created_at == other.created_at && updated_at == other.updated_at && last_used_at == other.last_used_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 259 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to?(:to_hash) value.to_hash else value end end |
#eql?(other) ⇒ Boolean
140 141 142 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 140 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 146 def hash [id, name, provider_name, input, created_at, updated_at, last_used_at].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
230 231 232 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 230 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 240 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
234 235 236 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 234 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
224 225 226 |
# File 'lib/algolia/models/agent-studio/provider_authentication_response.rb', line 224 def to_s to_hash.to_s end |