Class: Algolia::AgentStudio::SearchParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/agent-studio/search_parameters.rb

Overview

Algolia Search API parameters that can be predefined for the search tool. Reference: www.algolia.com/doc/api-reference/search-api-parameters/ The parameters that seemed irrelevant for the search tool have been commented out. Uses types from algoliasearch.search.models for better type safety.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SearchParameters

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 364

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise(
      ArgumentError,
      "The input argument (attributes) must be a hash in `Algolia::SearchParameters` initialize method"
    )
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      raise(
        ArgumentError,
        "`#{k}` is not a valid attribute in `Algolia::SearchParameters`. Please check the name to make sure it's valid. List of attributes: " +
          self.class.attribute_map.keys.inspect
      )
    end

    h[k.to_sym] = v
  }

  if attributes.key?(:query_type)
    self.query_type = attributes[:query_type]
  end

  if attributes.key?(:similar_query)
    self.similar_query = attributes[:similar_query]
  end

  if attributes.key?(:query_languages)
    if (value = attributes[:query_languages]).is_a?(Array)
      self.query_languages = value
    end
  end

  if attributes.key?(:advanced_syntax)
    self.advanced_syntax = attributes[:advanced_syntax]
  end

  if attributes.key?(:advanced_syntax_features)
    if (value = attributes[:advanced_syntax_features]).is_a?(Array)
      self.advanced_syntax_features = value
    end
  end

  if attributes.key?(:alternatives_as_exact)
    if (value = attributes[:alternatives_as_exact]).is_a?(Array)
      self.alternatives_as_exact = value
    end
  end

  if attributes.key?(:decompound_query)
    self.decompound_query = attributes[:decompound_query]
  end

  if attributes.key?(:typo_tolerance)
    self.typo_tolerance = attributes[:typo_tolerance]
  end

  if attributes.key?(:allow_typos_on_numeric_tokens)
    self.allow_typos_on_numeric_tokens = attributes[:allow_typos_on_numeric_tokens]
  end

  if attributes.key?(:min_word_size_for1_typo)
    self.min_word_size_for1_typo = attributes[:min_word_size_for1_typo]
  end

  if attributes.key?(:min_word_size_for2_typos)
    self.min_word_size_for2_typos = attributes[:min_word_size_for2_typos]
  end

  if attributes.key?(:disable_typo_tolerance_on_attributes)
    if (value = attributes[:disable_typo_tolerance_on_attributes]).is_a?(Array)
      self.disable_typo_tolerance_on_attributes = value
    end
  end

  if attributes.key?(:filters)
    self.filters = attributes[:filters]
  end

  if attributes.key?(:facet_filters)
    self.facet_filters = attributes[:facet_filters]
  end

  if attributes.key?(:facets)
    self.facets = attributes[:facets]
  end

  if attributes.key?(:max_values_per_facet)
    self.max_values_per_facet = attributes[:max_values_per_facet]
  end

  if attributes.key?(:max_facet_hits)
    self.max_facet_hits = attributes[:max_facet_hits]
  end

  if attributes.key?(:faceting_after_distinct)
    self.faceting_after_distinct = attributes[:faceting_after_distinct]
  end

  if attributes.key?(:sort_facet_values_by)
    self.sort_facet_values_by = attributes[:sort_facet_values_by]
  end

  if attributes.key?(:numeric_filters)
    self.numeric_filters = attributes[:numeric_filters]
  end

  if attributes.key?(:tag_filters)
    self.tag_filters = attributes[:tag_filters]
  end

  if attributes.key?(:sum_or_filters_scores)
    self.sum_or_filters_scores = attributes[:sum_or_filters_scores]
  end

  if attributes.key?(:around_lat_lng)
    self.around_lat_lng = attributes[:around_lat_lng]
  end

  if attributes.key?(:around_lat_lng_via_ip)
    self.around_lat_lng_via_ip = attributes[:around_lat_lng_via_ip]
  end

  if attributes.key?(:around_radius)
    self.around_radius = attributes[:around_radius]
  end

  if attributes.key?(:around_precision)
    self.around_precision = attributes[:around_precision]
  end

  if attributes.key?(:minimum_around_radius)
    self.minimum_around_radius = attributes[:minimum_around_radius]
  end

  if attributes.key?(:inside_bounding_box)
    self.inside_bounding_box = attributes[:inside_bounding_box]
  end

  if attributes.key?(:inside_polygon)
    self.inside_polygon = attributes[:inside_polygon]
  end

  if attributes.key?(:attributes_to_retrieve)
    if (value = attributes[:attributes_to_retrieve]).is_a?(Array)
      self.attributes_to_retrieve = value
    end
  end

  if attributes.key?(:attributes_to_snippet)
    if (value = attributes[:attributes_to_snippet]).is_a?(Array)
      self.attributes_to_snippet = value
    end
  end

  if attributes.key?(:snippet_ellipsis_text)
    self.snippet_ellipsis_text = attributes[:snippet_ellipsis_text]
  end

  if attributes.key?(:restrict_highlight_and_snippet_arrays)
    self.restrict_highlight_and_snippet_arrays = attributes[:restrict_highlight_and_snippet_arrays]
  end

  if attributes.key?(:page)
    self.page = attributes[:page]
  end

  if attributes.key?(:offset)
    self.offset = attributes[:offset]
  end

  if attributes.key?(:hits_per_page)
    self.hits_per_page = attributes[:hits_per_page]
  end

  if attributes.key?(:length)
    self.length = attributes[:length]
  end

  if attributes.key?(:get_ranking_info)
    self.get_ranking_info = attributes[:get_ranking_info]
  end

  if attributes.key?(:relevancy_strictness)
    self.relevancy_strictness = attributes[:relevancy_strictness]
  end

  if attributes.key?(:min_proximity)
    self.min_proximity = attributes[:min_proximity]
  end

  if attributes.key?(:attribute_criteria_computed_by_min_proximity)
    self.attribute_criteria_computed_by_min_proximity = attributes[:attribute_criteria_computed_by_min_proximity]
  end

  if attributes.key?(:distinct)
    self.distinct = attributes[:distinct]
  end

  if attributes.key?(:enable_rules)
    self.enable_rules = attributes[:enable_rules]
  end

  if attributes.key?(:enable_personalization)
    self.enable_personalization = attributes[:enable_personalization]
  end

  if attributes.key?(:personalization_impact)
    self.personalization_impact = attributes[:personalization_impact]
  end

  if attributes.key?(:enable_ab_test)
    self.enable_ab_test = attributes[:enable_ab_test]
  end

  if attributes.key?(:enable_re_ranking)
    self.enable_re_ranking = attributes[:enable_re_ranking]
  end

  if attributes.key?(:re_ranking_apply_filter)
    self.re_ranking_apply_filter = attributes[:re_ranking_apply_filter]
  end

  if attributes.key?(:rule_contexts)
    if (value = attributes[:rule_contexts]).is_a?(Array)
      self.rule_contexts = value
    end
  end

  if attributes.key?(:remove_stop_words)
    self.remove_stop_words = attributes[:remove_stop_words]
  end

  if attributes.key?(:ignore_plurals)
    self.ignore_plurals = attributes[:ignore_plurals]
  end

  if attributes.key?(:remove_words_if_no_results)
    self.remove_words_if_no_results = attributes[:remove_words_if_no_results]
  end

  if attributes.key?(:optional_words)
    self.optional_words = attributes[:optional_words]
  end

  if attributes.key?(:optional_filters)
    self.optional_filters = attributes[:optional_filters]
  end

  if attributes.key?(:synonyms)
    self.synonyms = attributes[:synonyms]
  end

  if attributes.key?(:replace_synonyms_in_highlight)
    self.replace_synonyms_in_highlight = attributes[:replace_synonyms_in_highlight]
  end

  if attributes.key?(:analytics)
    self.analytics = attributes[:analytics]
  end

  if attributes.key?(:analytics_tags)
    if (value = attributes[:analytics_tags]).is_a?(Array)
      self.analytics_tags = value
    end
  end

  if attributes.key?(:click_analytics)
    self.click_analytics = attributes[:click_analytics]
  end

  if attributes.key?(:user_token)
    self.user_token = attributes[:user_token]
  end

  if attributes.key?(:restrict_searchable_attributes)
    if (value = attributes[:restrict_searchable_attributes]).is_a?(Array)
      self.restrict_searchable_attributes = value
    end
  end

  if attributes.key?(:disable_exact_on_attributes)
    if (value = attributes[:disable_exact_on_attributes]).is_a?(Array)
      self.disable_exact_on_attributes = value
    end
  end

  if attributes.key?(:exact_on_single_word_query)
    self.exact_on_single_word_query = attributes[:exact_on_single_word_query]
  end

  if attributes.key?(:natural_languages)
    if (value = attributes[:natural_languages]).is_a?(Array)
      self.natural_languages = value
    end
  end

  if attributes.key?(:percentile_computation)
    self.percentile_computation = attributes[:percentile_computation]
  end

  if attributes.key?(:explain)
    if (value = attributes[:explain]).is_a?(Array)
      self.explain = value
    end
  end
end

Instance Attribute Details

#advanced_syntaxObject

Returns the value of attribute advanced_syntax.



18
19
20
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 18

def advanced_syntax
  @advanced_syntax
end

#advanced_syntax_featuresObject

Returns the value of attribute advanced_syntax_features.



20
21
22
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 20

def advanced_syntax_features
  @advanced_syntax_features
end

#allow_typos_on_numeric_tokensObject

Returns the value of attribute allow_typos_on_numeric_tokens.



28
29
30
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 28

def allow_typos_on_numeric_tokens
  @allow_typos_on_numeric_tokens
end

#alternatives_as_exactObject

Returns the value of attribute alternatives_as_exact.



22
23
24
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 22

def alternatives_as_exact
  @alternatives_as_exact
end

#analyticsObject

Returns the value of attribute analytics.



124
125
126
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 124

def analytics
  @analytics
end

#analytics_tagsObject

Returns the value of attribute analytics_tags.



126
127
128
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 126

def analytics_tags
  @analytics_tags
end

#around_lat_lngObject

Returns the value of attribute around_lat_lng.



56
57
58
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 56

def around_lat_lng
  @around_lat_lng
end

#around_lat_lng_via_ipObject

Returns the value of attribute around_lat_lng_via_ip.



58
59
60
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 58

def around_lat_lng_via_ip
  @around_lat_lng_via_ip
end

#around_precisionObject

Returns the value of attribute around_precision.



62
63
64
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 62

def around_precision
  @around_precision
end

#around_radiusObject

Returns the value of attribute around_radius.



60
61
62
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 60

def around_radius
  @around_radius
end

#attribute_criteria_computed_by_min_proximityObject

Returns the value of attribute attribute_criteria_computed_by_min_proximity.



92
93
94
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 92

def attribute_criteria_computed_by_min_proximity
  @attribute_criteria_computed_by_min_proximity
end

#attributes_to_retrieveObject

Returns the value of attribute attributes_to_retrieve.



70
71
72
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 70

def attributes_to_retrieve
  @attributes_to_retrieve
end

#attributes_to_snippetObject

Returns the value of attribute attributes_to_snippet.



72
73
74
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 72

def attributes_to_snippet
  @attributes_to_snippet
end

#click_analyticsObject

Returns the value of attribute click_analytics.



128
129
130
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 128

def click_analytics
  @click_analytics
end

#decompound_queryObject

Returns the value of attribute decompound_query.



24
25
26
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 24

def decompound_query
  @decompound_query
end

#disable_exact_on_attributesObject

Returns the value of attribute disable_exact_on_attributes.



134
135
136
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 134

def disable_exact_on_attributes
  @disable_exact_on_attributes
end

#disable_typo_tolerance_on_attributesObject

Returns the value of attribute disable_typo_tolerance_on_attributes.



34
35
36
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 34

def disable_typo_tolerance_on_attributes
  @disable_typo_tolerance_on_attributes
end

#distinctObject

Returns the value of attribute distinct.



94
95
96
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 94

def distinct
  @distinct
end

#enable_ab_testObject

Returns the value of attribute enable_ab_test.



102
103
104
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 102

def enable_ab_test
  @enable_ab_test
end

#enable_personalizationObject

Returns the value of attribute enable_personalization.



98
99
100
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 98

def enable_personalization
  @enable_personalization
end

#enable_re_rankingObject

Returns the value of attribute enable_re_ranking.



104
105
106
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 104

def enable_re_ranking
  @enable_re_ranking
end

#enable_rulesObject

Returns the value of attribute enable_rules.



96
97
98
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 96

def enable_rules
  @enable_rules
end

#exact_on_single_word_queryObject

Returns the value of attribute exact_on_single_word_query.



136
137
138
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 136

def exact_on_single_word_query
  @exact_on_single_word_query
end

#explainObject

Returns the value of attribute explain.



142
143
144
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 142

def explain
  @explain
end

#facet_filtersObject

Returns the value of attribute facet_filters.



38
39
40
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 38

def facet_filters
  @facet_filters
end

#faceting_after_distinctObject

Returns the value of attribute faceting_after_distinct.



46
47
48
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 46

def faceting_after_distinct
  @faceting_after_distinct
end

#facetsObject

Returns the value of attribute facets.



40
41
42
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 40

def facets
  @facets
end

#filtersObject

Returns the value of attribute filters.



36
37
38
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 36

def filters
  @filters
end

#get_ranking_infoObject

Returns the value of attribute get_ranking_info.



86
87
88
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 86

def get_ranking_info
  @get_ranking_info
end

#hits_per_pageObject

Returns the value of attribute hits_per_page.



82
83
84
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 82

def hits_per_page
  @hits_per_page
end

#ignore_pluralsObject

Returns the value of attribute ignore_plurals.



112
113
114
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 112

def ignore_plurals
  @ignore_plurals
end

#inside_bounding_boxObject

Returns the value of attribute inside_bounding_box.



66
67
68
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 66

def inside_bounding_box
  @inside_bounding_box
end

#inside_polygonObject

Returns the value of attribute inside_polygon.



68
69
70
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 68

def inside_polygon
  @inside_polygon
end

#lengthObject

Returns the value of attribute length.



84
85
86
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 84

def length
  @length
end

#max_facet_hitsObject

Returns the value of attribute max_facet_hits.



44
45
46
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 44

def max_facet_hits
  @max_facet_hits
end

#max_values_per_facetObject

Returns the value of attribute max_values_per_facet.



42
43
44
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 42

def max_values_per_facet
  @max_values_per_facet
end

#min_proximityObject

Returns the value of attribute min_proximity.



90
91
92
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 90

def min_proximity
  @min_proximity
end

#min_word_size_for1_typoObject

Returns the value of attribute min_word_size_for1_typo.



30
31
32
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 30

def min_word_size_for1_typo
  @min_word_size_for1_typo
end

#min_word_size_for2_typosObject

Returns the value of attribute min_word_size_for2_typos.



32
33
34
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 32

def min_word_size_for2_typos
  @min_word_size_for2_typos
end

#minimum_around_radiusObject

Returns the value of attribute minimum_around_radius.



64
65
66
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 64

def minimum_around_radius
  @minimum_around_radius
end

#natural_languagesObject

Returns the value of attribute natural_languages.



138
139
140
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 138

def natural_languages
  @natural_languages
end

#numeric_filtersObject

Returns the value of attribute numeric_filters.



50
51
52
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 50

def numeric_filters
  @numeric_filters
end

#offsetObject

Returns the value of attribute offset.



80
81
82
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 80

def offset
  @offset
end

#optional_filtersObject

Returns the value of attribute optional_filters.



118
119
120
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 118

def optional_filters
  @optional_filters
end

#optional_wordsObject

Returns the value of attribute optional_words.



116
117
118
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 116

def optional_words
  @optional_words
end

#pageObject

Returns the value of attribute page.



78
79
80
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 78

def page
  @page
end

#percentile_computationObject

Returns the value of attribute percentile_computation.



140
141
142
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 140

def percentile_computation
  @percentile_computation
end

#personalization_impactObject

Returns the value of attribute personalization_impact.



100
101
102
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 100

def personalization_impact
  @personalization_impact
end

#query_languagesObject

Returns the value of attribute query_languages.



16
17
18
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 16

def query_languages
  @query_languages
end

#query_typeObject

Returns the value of attribute query_type.



12
13
14
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 12

def query_type
  @query_type
end

#re_ranking_apply_filterObject

Returns the value of attribute re_ranking_apply_filter.



106
107
108
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 106

def re_ranking_apply_filter
  @re_ranking_apply_filter
end

#relevancy_strictnessObject

Returns the value of attribute relevancy_strictness.



88
89
90
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 88

def relevancy_strictness
  @relevancy_strictness
end

#remove_stop_wordsObject

Returns the value of attribute remove_stop_words.



110
111
112
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 110

def remove_stop_words
  @remove_stop_words
end

#remove_words_if_no_resultsObject

Returns the value of attribute remove_words_if_no_results.



114
115
116
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 114

def remove_words_if_no_results
  @remove_words_if_no_results
end

#replace_synonyms_in_highlightObject

Returns the value of attribute replace_synonyms_in_highlight.



122
123
124
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 122

def replace_synonyms_in_highlight
  @replace_synonyms_in_highlight
end

#restrict_highlight_and_snippet_arraysObject

Returns the value of attribute restrict_highlight_and_snippet_arrays.



76
77
78
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 76

def restrict_highlight_and_snippet_arrays
  @restrict_highlight_and_snippet_arrays
end

#restrict_searchable_attributesObject

Returns the value of attribute restrict_searchable_attributes.



132
133
134
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 132

def restrict_searchable_attributes
  @restrict_searchable_attributes
end

#rule_contextsObject

Returns the value of attribute rule_contexts.



108
109
110
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 108

def rule_contexts
  @rule_contexts
end

#similar_queryObject

Returns the value of attribute similar_query.



14
15
16
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 14

def similar_query
  @similar_query
end

#snippet_ellipsis_textObject

Returns the value of attribute snippet_ellipsis_text.



74
75
76
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 74

def snippet_ellipsis_text
  @snippet_ellipsis_text
end

#sort_facet_values_byObject

Returns the value of attribute sort_facet_values_by.



48
49
50
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 48

def sort_facet_values_by
  @sort_facet_values_by
end

#sum_or_filters_scoresObject

Returns the value of attribute sum_or_filters_scores.



54
55
56
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 54

def sum_or_filters_scores
  @sum_or_filters_scores
end

#synonymsObject

Returns the value of attribute synonyms.



120
121
122
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 120

def synonyms
  @synonyms
end

#tag_filtersObject

Returns the value of attribute tag_filters.



52
53
54
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 52

def tag_filters
  @tag_filters
end

#typo_toleranceObject

Returns the value of attribute typo_tolerance.



26
27
28
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 26

def typo_tolerance
  @typo_tolerance
end

#user_tokenObject

Returns the value of attribute user_token.



130
131
132
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 130

def user_token
  @user_token
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 856

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end

  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
    # model
  else
    # models (e.g. Pet) or oneOf
    klass = Algolia::AgentStudio.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass
      .build_from_hash(value)
  end
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 145

def self.attribute_map
  {
    :query_type => :queryType,
    :similar_query => :similarQuery,
    :query_languages => :queryLanguages,
    :advanced_syntax => :advancedSyntax,
    :advanced_syntax_features => :advancedSyntaxFeatures,
    :alternatives_as_exact => :alternativesAsExact,
    :decompound_query => :decompoundQuery,
    :typo_tolerance => :typoTolerance,
    :allow_typos_on_numeric_tokens => :allowTyposOnNumericTokens,
    :min_word_size_for1_typo => :minWordSizeFor1Typo,
    :min_word_size_for2_typos => :minWordSizeFor2Typos,
    :disable_typo_tolerance_on_attributes => :disableTypoToleranceOnAttributes,
    :filters => :filters,
    :facet_filters => :facetFilters,
    :facets => :facets,
    :max_values_per_facet => :maxValuesPerFacet,
    :max_facet_hits => :maxFacetHits,
    :faceting_after_distinct => :facetingAfterDistinct,
    :sort_facet_values_by => :sortFacetValuesBy,
    :numeric_filters => :numericFilters,
    :tag_filters => :tagFilters,
    :sum_or_filters_scores => :sumOrFiltersScores,
    :around_lat_lng => :aroundLatLng,
    :around_lat_lng_via_ip => :aroundLatLngViaIp,
    :around_radius => :aroundRadius,
    :around_precision => :aroundPrecision,
    :minimum_around_radius => :minimumAroundRadius,
    :inside_bounding_box => :insideBoundingBox,
    :inside_polygon => :insidePolygon,
    :attributes_to_retrieve => :attributesToRetrieve,
    :attributes_to_snippet => :attributesToSnippet,
    :snippet_ellipsis_text => :snippetEllipsisText,
    :restrict_highlight_and_snippet_arrays => :restrictHighlightAndSnippetArrays,
    :page => :page,
    :offset => :offset,
    :hits_per_page => :hitsPerPage,
    :length => :length,
    :get_ranking_info => :getRankingInfo,
    :relevancy_strictness => :relevancyStrictness,
    :min_proximity => :minProximity,
    :attribute_criteria_computed_by_min_proximity => :attributeCriteriaComputedByMinProximity,
    :distinct => :distinct,
    :enable_rules => :enableRules,
    :enable_personalization => :enablePersonalization,
    :personalization_impact => :personalizationImpact,
    :enable_ab_test => :enableAbTest,
    :enable_re_ranking => :enableReRanking,
    :re_ranking_apply_filter => :reRankingApplyFilter,
    :rule_contexts => :ruleContexts,
    :remove_stop_words => :removeStopWords,
    :ignore_plurals => :ignorePlurals,
    :remove_words_if_no_results => :removeWordsIfNoResults,
    :optional_words => :optionalWords,
    :optional_filters => :optionalFilters,
    :synonyms => :synonyms,
    :replace_synonyms_in_highlight => :replaceSynonymsInHighlight,
    :analytics => :analytics,
    :analytics_tags => :analyticsTags,
    :click_analytics => :clickAnalytics,
    :user_token => :userToken,
    :restrict_searchable_attributes => :restrictSearchableAttributes,
    :disable_exact_on_attributes => :disableExactOnAttributes,
    :exact_on_single_word_query => :exactOnSingleWordQuery,
    :natural_languages => :naturalLanguages,
    :percentile_computation => :percentileComputation,
    :explain => :explain
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 829

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v|
          _deserialize(::Regexp.last_match(1), v)
        }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end

  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 289

def self.openapi_nullable
  Set.new(
    [
      :query_type,
      :similar_query,
      :query_languages,
      :advanced_syntax,
      :advanced_syntax_features,
      :alternatives_as_exact,
      :decompound_query,
      :typo_tolerance,
      :allow_typos_on_numeric_tokens,
      :min_word_size_for1_typo,
      :min_word_size_for2_typos,
      :disable_typo_tolerance_on_attributes,
      :filters,
      :facet_filters,
      :facets,
      :max_values_per_facet,
      :max_facet_hits,
      :faceting_after_distinct,
      :sort_facet_values_by,
      :numeric_filters,
      :tag_filters,
      :sum_or_filters_scores,
      :around_lat_lng,
      :around_lat_lng_via_ip,
      :around_radius,
      :around_precision,
      :minimum_around_radius,
      :inside_bounding_box,
      :inside_polygon,
      :attributes_to_retrieve,
      :attributes_to_snippet,
      :snippet_ellipsis_text,
      :restrict_highlight_and_snippet_arrays,
      :page,
      :offset,
      :hits_per_page,
      :length,
      :get_ranking_info,
      :relevancy_strictness,
      :min_proximity,
      :attribute_criteria_computed_by_min_proximity,
      :distinct,
      :enable_rules,
      :enable_personalization,
      :personalization_impact,
      :enable_ab_test,
      :enable_re_ranking,
      :re_ranking_apply_filter,
      :rule_contexts,
      :remove_stop_words,
      :ignore_plurals,
      :remove_words_if_no_results,
      :optional_words,
      :optional_filters,
      :synonyms,
      :replace_synonyms_in_highlight,
      :analytics,
      :analytics_tags,
      :click_analytics,
      :user_token,
      :restrict_searchable_attributes,
      :disable_exact_on_attributes,
      :exact_on_single_word_query,
      :natural_languages,
      :percentile_computation,
      :explain
    ]
  )
end

.types_mappingObject

Attribute type mapping.



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 217

def self.types_mapping
  {
    :query_type => :"QueryType",
    :similar_query => :"String",
    :query_languages => :"Array<SupportedLanguage>",
    :advanced_syntax => :"Boolean",
    :advanced_syntax_features => :"Array<AdvancedSyntaxFeatures>",
    :alternatives_as_exact => :"Array<AlternativesAsExact>",
    :decompound_query => :"Boolean",
    :typo_tolerance => :"TypoToleranceUnion",
    :allow_typos_on_numeric_tokens => :"Boolean",
    :min_word_size_for1_typo => :"Integer",
    :min_word_size_for2_typos => :"Integer",
    :disable_typo_tolerance_on_attributes => :"Array<String>",
    :filters => :"String",
    :facet_filters => :"FacetFiltersUnion",
    :facets => :"FacetsUnion",
    :max_values_per_facet => :"Integer",
    :max_facet_hits => :"Integer",
    :faceting_after_distinct => :"Boolean",
    :sort_facet_values_by => :"String",
    :numeric_filters => :"NumericFiltersUnion",
    :tag_filters => :"TagFiltersUnion",
    :sum_or_filters_scores => :"Boolean",
    :around_lat_lng => :"String",
    :around_lat_lng_via_ip => :"Boolean",
    :around_radius => :"AroundRadiusUnion",
    :around_precision => :"AroundPrecisionUnion",
    :minimum_around_radius => :"Integer",
    :inside_bounding_box => :"InsideBoundingBoxUnion",
    :inside_polygon => :"InsidePolygonUnion",
    :attributes_to_retrieve => :"Array<String>",
    :attributes_to_snippet => :"Array<String>",
    :snippet_ellipsis_text => :"String",
    :restrict_highlight_and_snippet_arrays => :"Boolean",
    :page => :"Integer",
    :offset => :"Integer",
    :hits_per_page => :"Integer",
    :length => :"Integer",
    :get_ranking_info => :"Boolean",
    :relevancy_strictness => :"Integer",
    :min_proximity => :"Integer",
    :attribute_criteria_computed_by_min_proximity => :"Boolean",
    :distinct => :"DistinctUnion",
    :enable_rules => :"Boolean",
    :enable_personalization => :"Boolean",
    :personalization_impact => :"Integer",
    :enable_ab_test => :"Boolean",
    :enable_re_ranking => :"Boolean",
    :re_ranking_apply_filter => :"ReRankingApplyFilterUnion",
    :rule_contexts => :"Array<String>",
    :remove_stop_words => :"RemoveStopWordsUnion",
    :ignore_plurals => :"IgnorePluralsUnion",
    :remove_words_if_no_results => :"RemoveWordsIfNoResults",
    :optional_words => :"OptionalWordsUnion",
    :optional_filters => :"OptionalFiltersUnion",
    :synonyms => :"Boolean",
    :replace_synonyms_in_highlight => :"Boolean",
    :analytics => :"Boolean",
    :analytics_tags => :"Array<String>",
    :click_analytics => :"Boolean",
    :user_token => :"String",
    :restrict_searchable_attributes => :"Array<String>",
    :disable_exact_on_attributes => :"Array<String>",
    :exact_on_single_word_query => :"ExactOnSingleWordQuery",
    :natural_languages => :"Array<SupportedLanguage>",
    :percentile_computation => :"Boolean",
    :explain => :"Array<String>"
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 676

def ==(other)
  return true if self.equal?(other)
  self.class == other.class &&
    query_type == other.query_type &&
    similar_query == other.similar_query &&
    query_languages == other.query_languages &&
    advanced_syntax == other.advanced_syntax &&
    advanced_syntax_features == other.advanced_syntax_features &&
    alternatives_as_exact == other.alternatives_as_exact &&
    decompound_query == other.decompound_query &&
    typo_tolerance == other.typo_tolerance &&
    allow_typos_on_numeric_tokens == other.allow_typos_on_numeric_tokens &&
    min_word_size_for1_typo == other.min_word_size_for1_typo &&
    min_word_size_for2_typos == other.min_word_size_for2_typos &&
    disable_typo_tolerance_on_attributes == other.disable_typo_tolerance_on_attributes &&
    filters == other.filters &&
    facet_filters == other.facet_filters &&
    facets == other.facets &&
    max_values_per_facet == other.max_values_per_facet &&
    max_facet_hits == other.max_facet_hits &&
    faceting_after_distinct == other.faceting_after_distinct &&
    sort_facet_values_by == other.sort_facet_values_by &&
    numeric_filters == other.numeric_filters &&
    tag_filters == other.tag_filters &&
    sum_or_filters_scores == other.sum_or_filters_scores &&
    around_lat_lng == other.around_lat_lng &&
    around_lat_lng_via_ip == other.around_lat_lng_via_ip &&
    around_radius == other.around_radius &&
    around_precision == other.around_precision &&
    minimum_around_radius == other.minimum_around_radius &&
    inside_bounding_box == other.inside_bounding_box &&
    inside_polygon == other.inside_polygon &&
    attributes_to_retrieve == other.attributes_to_retrieve &&
    attributes_to_snippet == other.attributes_to_snippet &&
    snippet_ellipsis_text == other.snippet_ellipsis_text &&
    restrict_highlight_and_snippet_arrays == other.restrict_highlight_and_snippet_arrays &&
    page == other.page &&
    offset == other.offset &&
    hits_per_page == other.hits_per_page &&
    length == other.length &&
    get_ranking_info == other.get_ranking_info &&
    relevancy_strictness == other.relevancy_strictness &&
    min_proximity == other.min_proximity &&
    attribute_criteria_computed_by_min_proximity == other.attribute_criteria_computed_by_min_proximity &&
    distinct == other.distinct &&
    enable_rules == other.enable_rules &&
    enable_personalization == other.enable_personalization &&
    personalization_impact == other.personalization_impact &&
    enable_ab_test == other.enable_ab_test &&
    enable_re_ranking == other.enable_re_ranking &&
    re_ranking_apply_filter == other.re_ranking_apply_filter &&
    rule_contexts == other.rule_contexts &&
    remove_stop_words == other.remove_stop_words &&
    ignore_plurals == other.ignore_plurals &&
    remove_words_if_no_results == other.remove_words_if_no_results &&
    optional_words == other.optional_words &&
    optional_filters == other.optional_filters &&
    synonyms == other.synonyms &&
    replace_synonyms_in_highlight == other.replace_synonyms_in_highlight &&
    analytics == other.analytics &&
    analytics_tags == other.analytics_tags &&
    click_analytics == other.click_analytics &&
    user_token == other.user_token &&
    restrict_searchable_attributes == other.restrict_searchable_attributes &&
    disable_exact_on_attributes == other.disable_exact_on_attributes &&
    exact_on_single_word_query == other.exact_on_single_word_query &&
    natural_languages == other.natural_languages &&
    percentile_computation == other.percentile_computation &&
    explain == other.explain
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



935
936
937
938
939
940
941
942
943
944
945
946
947
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 935

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to?(:to_hash)
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


749
750
751
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 749

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 755

def hash
  [
    query_type,
    similar_query,
    query_languages,
    advanced_syntax,
    advanced_syntax_features,
    alternatives_as_exact,
    decompound_query,
    typo_tolerance,
    allow_typos_on_numeric_tokens,
    min_word_size_for1_typo,
    min_word_size_for2_typos,
    disable_typo_tolerance_on_attributes,
    filters,
    facet_filters,
    facets,
    max_values_per_facet,
    max_facet_hits,
    faceting_after_distinct,
    sort_facet_values_by,
    numeric_filters,
    tag_filters,
    sum_or_filters_scores,
    around_lat_lng,
    around_lat_lng_via_ip,
    around_radius,
    around_precision,
    minimum_around_radius,
    inside_bounding_box,
    inside_polygon,
    attributes_to_retrieve,
    attributes_to_snippet,
    snippet_ellipsis_text,
    restrict_highlight_and_snippet_arrays,
    page,
    offset,
    hits_per_page,
    length,
    get_ranking_info,
    relevancy_strictness,
    min_proximity,
    attribute_criteria_computed_by_min_proximity,
    distinct,
    enable_rules,
    enable_personalization,
    personalization_impact,
    enable_ab_test,
    enable_re_ranking,
    re_ranking_apply_filter,
    rule_contexts,
    remove_stop_words,
    ignore_plurals,
    remove_words_if_no_results,
    optional_words,
    optional_filters,
    synonyms,
    replace_synonyms_in_highlight,
    analytics,
    analytics_tags,
    click_analytics,
    user_token,
    restrict_searchable_attributes,
    disable_exact_on_attributes,
    exact_on_single_word_query,
    natural_languages,
    percentile_computation,
    explain
  ].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



906
907
908
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 906

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



916
917
918
919
920
921
922
923
924
925
926
927
928
929
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 916

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end

  hash
end

#to_json(*_args) ⇒ Object



910
911
912
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 910

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



900
901
902
# File 'lib/algolia/models/agent-studio/search_parameters.rb', line 900

def to_s
  to_hash.to_s
end