Class: Algolia::Analytics::ClickPositionsInner
- Inherits:
-
Object
- Object
- Algolia::Analytics::ClickPositionsInner
- Defined in:
- lib/algolia/models/analytics/click_positions_inner.rb
Overview
Click position.
Instance Attribute Summary collapse
-
#click_count ⇒ Object
Number of times this search has been clicked at that position.
-
#position ⇒ Object
Range of positions in the search results, using the pattern ‘[start,end]`.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClickPositionsInner
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ClickPositionsInner
Initializes the object
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 44 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::ClickPositionsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::ClickPositionsInner`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:position) if (value = attributes[:position]).is_a?(Array) self.position = value end end if attributes.key?(:click_count) self.click_count = attributes[:click_count] end end |
Instance Attribute Details
#click_count ⇒ Object
Number of times this search has been clicked at that position.
14 15 16 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 14 def click_count @click_count end |
#position ⇒ Object
Range of positions in the search results, using the pattern ‘[start,end]`. For positions 11 and up, click events are summed over the specified range. `-1` indicates the end of the list of search results.
11 12 13 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 11 def position @position end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 152 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Analytics.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
25 26 27 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 25 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
17 18 19 20 21 22 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 17 def self.attribute_map { :position => :position, :click_count => :clickCount } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 127 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
38 39 40 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 38 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
30 31 32 33 34 35 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 30 def self.types_mapping { :position => :'Array<Integer>', :click_count => :Integer } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
104 105 106 107 108 109 110 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 104 def ==(other) return true if equal?(other) self.class == other.class && position == other.position && click_count == other.click_count end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 227 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
114 115 116 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 114 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
120 121 122 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 120 def hash [position, click_count].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
199 200 201 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 199 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 209 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
203 204 205 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 203 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
193 194 195 |
# File 'lib/algolia/models/analytics/click_positions_inner.rb', line 193 def to_s to_hash.to_s end |