Class: Algolia::Analytics::GetNoClickRateResponse
- Inherits:
-
Object
- Object
- Algolia::Analytics::GetNoClickRateResponse
- Defined in:
- lib/algolia/models/analytics/get_no_click_rate_response.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
Number of tracked searches.
-
#dates ⇒ Object
Daily no click rates.
-
#no_click_count ⇒ Object
Number of times this search was returned as a result without any click.
-
#rate ⇒ Object
No click rate, calculated as number of tracked searches without any click divided by the number of tracked searches.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetNoClickRateResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ GetNoClickRateResponse
Initializes the object
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 53 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::GetNoClickRateResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::GetNoClickRateResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:rate) self.rate = attributes[:rate] else self.rate = nil end if attributes.key?(:count) self.count = attributes[:count] else self.count = nil end if attributes.key?(:no_click_count) self.no_click_count = attributes[:no_click_count] else self.no_click_count = nil end if attributes.key?(:dates) if (value = attributes[:dates]).is_a?(Array) self.dates = value end else self.dates = nil end end |
Instance Attribute Details
#count ⇒ Object
Number of tracked searches. Tracked searches are search requests where the ‘clickAnalytics` parameter is true.
13 14 15 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 13 def count @count end |
#dates ⇒ Object
Daily no click rates.
19 20 21 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 19 def dates @dates end |
#no_click_count ⇒ Object
Number of times this search was returned as a result without any click.
16 17 18 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 16 def no_click_count @no_click_count end |
#rate ⇒ Object
No click rate, calculated as number of tracked searches without any click divided by the number of tracked searches.
10 11 12 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 10 def rate @rate end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 179 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Analytics.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
32 33 34 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 32 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
22 23 24 25 26 27 28 29 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 22 def self.attribute_map { :rate => :rate, :count => :count, :no_click_count => :noClickCount, :dates => :dates } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 154 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
47 48 49 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 47 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 43 44 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 37 def self.types_mapping { :rate => :Float, :count => :Integer, :no_click_count => :Integer, :dates => :'Array<DailyNoClickRates>' } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
129 130 131 132 133 134 135 136 137 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 129 def ==(other) return true if equal?(other) self.class == other.class && rate == other.rate && count == other.count && no_click_count == other.no_click_count && dates == other.dates end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 254 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
141 142 143 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 141 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
147 148 149 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 147 def hash [rate, count, no_click_count, dates].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
226 227 228 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 226 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
230 231 232 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 230 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
220 221 222 |
# File 'lib/algolia/models/analytics/get_no_click_rate_response.rb', line 220 def to_s to_hash.to_s end |