Class: Algolia::Analytics::TopHitWithRevenueAnalytics
- Inherits:
-
Object
- Object
- Algolia::Analytics::TopHitWithRevenueAnalytics
- Defined in:
- lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb
Instance Attribute Summary collapse
-
#add_to_cart_count ⇒ Object
Number of add-to-cart events from this search.
-
#add_to_cart_rate ⇒ Object
Add-to-cart rate, calculated as number of tracked searches with at least one add-to-cart event divided by the number of tracked searches.
-
#click_count ⇒ Object
Number of clicks associated with this search.
-
#click_through_rate ⇒ Object
Click-through rate, calculated as number of tracked searches with at least one click event divided by the number of tracked searches.
-
#conversion_count ⇒ Object
Number of conversions from this search.
-
#conversion_rate ⇒ Object
Conversion rate, calculated as number of tracked searches with at least one conversion event divided by the number of tracked searches.
-
#count ⇒ Object
Number of occurrences.
-
#currencies ⇒ Object
Revenue associated with this search, broken-down by currencies.
-
#hit ⇒ Object
Object ID of a record that’s returned as a search result.
-
#purchase_count ⇒ Object
Number of purchase events from this search.
-
#purchase_rate ⇒ Object
Purchase rate, calculated as number of tracked searches with at least one purchase event divided by the number of tracked searches.
-
#tracked_hit_count ⇒ Object
Number of tracked searches.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TopHitWithRevenueAnalytics
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TopHitWithRevenueAnalytics
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 98 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::TopHitWithRevenueAnalytics` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::TopHitWithRevenueAnalytics`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:hit) self.hit = attributes[:hit] else self.hit = nil end if attributes.key?(:count) self.count = attributes[:count] else self.count = nil end if attributes.key?(:click_through_rate) self.click_through_rate = attributes[:click_through_rate] else self.click_through_rate = nil end if attributes.key?(:conversion_rate) self.conversion_rate = attributes[:conversion_rate] else self.conversion_rate = nil end if attributes.key?(:tracked_hit_count) self.tracked_hit_count = attributes[:tracked_hit_count] else self.tracked_hit_count = nil end if attributes.key?(:click_count) self.click_count = attributes[:click_count] else self.click_count = nil end if attributes.key?(:conversion_count) self.conversion_count = attributes[:conversion_count] else self.conversion_count = nil end if attributes.key?(:add_to_cart_rate) self.add_to_cart_rate = attributes[:add_to_cart_rate] else self.add_to_cart_rate = nil end if attributes.key?(:add_to_cart_count) self.add_to_cart_count = attributes[:add_to_cart_count] else self.add_to_cart_count = nil end if attributes.key?(:purchase_rate) self.purchase_rate = attributes[:purchase_rate] else self.purchase_rate = nil end if attributes.key?(:purchase_count) self.purchase_count = attributes[:purchase_count] else self.purchase_count = nil end if attributes.key?(:currencies) if (value = attributes[:currencies]).is_a?(Hash) self.currencies = value end else self.currencies = nil end end |
Instance Attribute Details
#add_to_cart_count ⇒ Object
Number of add-to-cart events from this search.
34 35 36 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 34 def add_to_cart_count @add_to_cart_count end |
#add_to_cart_rate ⇒ Object
Add-to-cart rate, calculated as number of tracked searches with at least one add-to-cart event divided by the number of tracked searches. If null, Algolia didn’t receive any search requests with ‘clickAnalytics` set to true.
31 32 33 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 31 def add_to_cart_rate @add_to_cart_rate end |
#click_count ⇒ Object
Number of clicks associated with this search.
25 26 27 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 25 def click_count @click_count end |
#click_through_rate ⇒ Object
Click-through rate, calculated as number of tracked searches with at least one click event divided by the number of tracked searches. If null, Algolia didn’t receive any search requests with ‘clickAnalytics` set to true.
16 17 18 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 16 def click_through_rate @click_through_rate end |
#conversion_count ⇒ Object
Number of conversions from this search.
28 29 30 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 28 def conversion_count @conversion_count end |
#conversion_rate ⇒ Object
Conversion rate, calculated as number of tracked searches with at least one conversion event divided by the number of tracked searches. If null, Algolia didn’t receive any search requests with ‘clickAnalytics` set to true.
19 20 21 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 19 def conversion_rate @conversion_rate end |
#count ⇒ Object
Number of occurrences.
13 14 15 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 13 def count @count end |
#currencies ⇒ Object
Revenue associated with this search, broken-down by currencies.
43 44 45 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 43 def currencies @currencies end |
#hit ⇒ Object
Object ID of a record that’s returned as a search result.
10 11 12 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 10 def hit @hit end |
#purchase_count ⇒ Object
Number of purchase events from this search.
40 41 42 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 40 def purchase_count @purchase_count end |
#purchase_rate ⇒ Object
Purchase rate, calculated as number of tracked searches with at least one purchase event divided by the number of tracked searches. If null, Algolia didn’t receive any search requests with ‘clickAnalytics` set to true.
37 38 39 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 37 def purchase_rate @purchase_rate end |
#tracked_hit_count ⇒ Object
Number of tracked searches. Tracked searches are search requests where the ‘clickAnalytics` parameter is true.
22 23 24 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 22 def tracked_hit_count @tracked_hit_count end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 347 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Analytics.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 64 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 46 def self.attribute_map { :hit => :hit, :count => :count, :click_through_rate => :clickThroughRate, :conversion_rate => :conversionRate, :tracked_hit_count => :trackedHitCount, :click_count => :clickCount, :conversion_count => :conversionCount, :add_to_cart_rate => :addToCartRate, :add_to_cart_count => :addToCartCount, :purchase_rate => :purchaseRate, :purchase_count => :purchaseCount, :currencies => :currencies } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 322 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 91 92 93 94 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 87 def self.openapi_nullable Set.new([ :click_through_rate, :conversion_rate, :add_to_cart_rate, :purchase_rate ]) end |
.types_mapping ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 69 def self.types_mapping { :hit => :String, :count => :Integer, :click_through_rate => :Float, :conversion_rate => :Float, :tracked_hit_count => :Integer, :click_count => :Integer, :conversion_count => :Integer, :add_to_cart_rate => :Float, :add_to_cart_count => :Integer, :purchase_rate => :Float, :purchase_count => :Integer, :currencies => :'Hash<String, CurrenciesValue>' } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 288 def ==(other) return true if equal?(other) self.class == other.class && hit == other.hit && count == other.count && click_through_rate == other.click_through_rate && conversion_rate == other.conversion_rate && tracked_hit_count == other.tracked_hit_count && click_count == other.click_count && conversion_count == other.conversion_count && add_to_cart_rate == other.add_to_cart_rate && add_to_cart_count == other.add_to_cart_count && purchase_rate == other.purchase_rate && purchase_count == other.purchase_count && currencies == other.currencies end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 422 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
308 309 310 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 308 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
314 315 316 317 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 314 def hash [hit, count, click_through_rate, conversion_rate, tracked_hit_count, click_count, conversion_count, add_to_cart_rate, add_to_cart_count, purchase_rate, purchase_count, currencies].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
394 395 396 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 394 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 404 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
398 399 400 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 398 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
388 389 390 |
# File 'lib/algolia/models/analytics/top_hit_with_revenue_analytics.rb', line 388 def to_s to_hash.to_s end |