Method: Algolia::AnalyticsClient#get_status

Defined in:
lib/algolia/api/analytics_client.rb

#get_status(index, request_options = {}) ⇒ GetStatusResponse

Retrieves the time when the Analytics data for the specified index was last updated. The Analytics data is updated every 5 minutes.

Required API Key ACLs:

- analytics

Parameters:

  • index (String)

    Index name. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (GetStatusResponse)


1018
1019
1020
1021
# File 'lib/algolia/api/analytics_client.rb', line 1018

def get_status(index, request_options = {})
  response = get_status_with_http_info(index, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "Analytics::GetStatusResponse")
end