Class: Algolia::Composition::Composition
- Inherits:
-
Object
- Object
- Algolia::Composition::Composition
- Defined in:
- lib/algolia/models/composition/composition.rb
Instance Attribute Summary collapse
-
#algolia_object_id ⇒ Object
Composition unique identifier.
-
#behavior ⇒ Object
Returns the value of attribute behavior.
-
#description ⇒ Object
Composition description.
-
#name ⇒ Object
Composition name.
-
#sorting_strategy ⇒ Object
A mapping of sorting labels to the indices (or replicas) that implement those sorting rules.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Composition
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Composition
Initializes the object
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/algolia/models/composition/composition.rb', line 56 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise( ArgumentError, "The input argument (attributes) must be a hash in `Algolia::Composition` initialize method" ) end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) raise( ArgumentError, "`#{k}` is not a valid attribute in `Algolia::Composition`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect ) end h[k.to_sym] = v } if attributes.key?(:algolia_object_id) self.algolia_object_id = attributes[:algolia_object_id] else self.algolia_object_id = nil end if attributes.key?(:name) self.name = attributes[:name] else self.name = nil end if attributes.key?(:description) self.description = attributes[:description] end if attributes.key?(:behavior) self.behavior = attributes[:behavior] else self.behavior = nil end if attributes.key?(:sorting_strategy) if (value = attributes[:sorting_strategy]).is_a?(Hash) self.sorting_strategy = value end end end |
Instance Attribute Details
#algolia_object_id ⇒ Object
Composition unique identifier.
12 13 14 |
# File 'lib/algolia/models/composition/composition.rb', line 12 def algolia_object_id @algolia_object_id end |
#behavior ⇒ Object
Returns the value of attribute behavior.
20 21 22 |
# File 'lib/algolia/models/composition/composition.rb', line 20 def behavior @behavior end |
#description ⇒ Object
Composition description.
18 19 20 |
# File 'lib/algolia/models/composition/composition.rb', line 18 def description @description end |
#name ⇒ Object
Composition name.
15 16 17 |
# File 'lib/algolia/models/composition/composition.rb', line 15 def name @name end |
#sorting_strategy ⇒ Object
A mapping of sorting labels to the indices (or replicas) that implement those sorting rules. The sorting indices MUST be related to the associated main targeted index in the composition. Each key is the label your frontend sends at runtime (for example, "Price (asc)"), and each value is the name of the index that should be queried when that label is selected. When a request includes a "sortBy" parameter, the platform looks up the corresponding index in this mapping and uses it to execute the query. The main targeted index is replaced with the sorting strategy index it is mapped to. Up to 20 sorting strategies can be defined.
23 24 25 |
# File 'lib/algolia/models/composition/composition.rb', line 23 def sorting_strategy @sorting_strategy end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/algolia/models/composition/composition.rb', line 160 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end # model else # models (e.g. Pet) or oneOf klass = Algolia::Composition.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass .build_from_hash(value) end end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 33 34 |
# File 'lib/algolia/models/composition/composition.rb', line 26 def self.attribute_map { :algolia_object_id => :objectID, :name => :name, :description => :description, :behavior => :behavior, :sorting_strategy => :sortingStrategy } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/algolia/models/composition/composition.rb', line 133 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
48 49 50 51 52 |
# File 'lib/algolia/models/composition/composition.rb', line 48 def self.openapi_nullable Set.new( [] ) end |
.types_mapping ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 43 44 45 |
# File 'lib/algolia/models/composition/composition.rb', line 37 def self.types_mapping { :algolia_object_id => :"String", :name => :"String", :description => :"String", :behavior => :"CompositionBehavior", :sorting_strategy => :"Hash<String, String>" } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
108 109 110 111 112 113 114 115 116 |
# File 'lib/algolia/models/composition/composition.rb', line 108 def ==(other) return true if self.equal?(other) self.class == other.class && algolia_object_id == other.algolia_object_id && name == other.name && description == other.description && behavior == other.behavior && sorting_strategy == other.sorting_strategy end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/algolia/models/composition/composition.rb', line 239 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to?(:to_hash) value.to_hash else value end end |
#eql?(other) ⇒ Boolean
120 121 122 |
# File 'lib/algolia/models/composition/composition.rb', line 120 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
126 127 128 |
# File 'lib/algolia/models/composition/composition.rb', line 126 def hash [algolia_object_id, name, description, behavior, sorting_strategy].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
210 211 212 |
# File 'lib/algolia/models/composition/composition.rb', line 210 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/algolia/models/composition/composition.rb', line 220 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
214 215 216 |
# File 'lib/algolia/models/composition/composition.rb', line 214 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
204 205 206 |
# File 'lib/algolia/models/composition/composition.rb', line 204 def to_s to_hash.to_s end |