Class: Algolia::Ingestion::AuthOAuth
- Inherits:
-
Object
- Object
- Algolia::Ingestion::AuthOAuth
- Defined in:
- lib/algolia/models/ingestion/auth_o_auth.rb
Overview
Credentials for authenticating with OAuth 2.0.
Instance Attribute Summary collapse
-
#client_id ⇒ Object
Client ID.
-
#client_secret ⇒ Object
Client secret.
-
#scope ⇒ Object
OAuth scope.
-
#url ⇒ Object
URL for the OAuth endpoint.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.discriminator_attributes ⇒ Object
Returns the keys that uniquely identify this oneOf variant when present.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuthOAuth
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AuthOAuth
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 60 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise( ArgumentError, "The input argument (attributes) must be a hash in `Algolia::AuthOAuth` initialize method" ) end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) raise( ArgumentError, "`#{k}` is not a valid attribute in `Algolia::AuthOAuth`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect ) end h[k.to_sym] = v } if attributes.key?(:url) self.url = attributes[:url] else self.url = nil end if attributes.key?(:client_id) self.client_id = attributes[:client_id] else self.client_id = nil end if attributes.key?(:client_secret) self.client_secret = attributes[:client_secret] else self.client_secret = nil end if attributes.key?(:scope) self.scope = attributes[:scope] end end |
Instance Attribute Details
#client_id ⇒ Object
Client ID.
14 15 16 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 14 def client_id @client_id end |
#client_secret ⇒ Object
Client secret. This field is ‘null` in the API response.
17 18 19 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 17 def client_secret @client_secret end |
#scope ⇒ Object
OAuth scope.
20 21 22 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 20 def scope @scope end |
#url ⇒ Object
URL for the OAuth endpoint.
11 12 13 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 11 def url @url end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 157 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end # model else # models (e.g. Pet) or oneOf klass = Algolia::Ingestion.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass .build_from_hash(value) end end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 23 def self.attribute_map { :url => :url, :client_id => :client_id, :client_secret => :client_secret, :scope => :scope } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 130 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.discriminator_attributes ⇒ Object
Returns the keys that uniquely identify this oneOf variant when present
33 34 35 36 37 38 39 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 33 def self.discriminator_attributes [ :url, :client_id, :client_secret ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 56 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 52 def self.openapi_nullable Set.new( [] ) end |
.types_mapping ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 49 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 42 def self.types_mapping { :url => :"String", :client_id => :"String", :client_secret => :"String", :scope => :"String" } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
106 107 108 109 110 111 112 113 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 106 def ==(other) return true if self.equal?(other) self.class == other.class && url == other.url && client_id == other.client_id && client_secret == other.client_secret && scope == other.scope end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 236 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to?(:to_hash) value.to_hash else value end end |
#eql?(other) ⇒ Boolean
117 118 119 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 117 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
123 124 125 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 123 def hash [url, client_id, client_secret, scope].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
207 208 209 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 207 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 217 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
211 212 213 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 211 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
201 202 203 |
# File 'lib/algolia/models/ingestion/auth_o_auth.rb', line 201 def to_s to_hash.to_s end |