Class: Algolia::Ingestion::Event
- Inherits:
-
Object
- Object
- Algolia::Ingestion::Event
- Defined in:
- lib/algolia/models/ingestion/event.rb
Overview
An event describe a step of the task execution flow..
Instance Attribute Summary collapse
-
#batch_size ⇒ Object
The extracted record batch size.
-
#data ⇒ Object
Returns the value of attribute data.
-
#event_id ⇒ Object
Universally unique identifier (UUID) of an event.
-
#parent_id ⇒ Object
The parent event, the cause of this event.
-
#published_at ⇒ Object
Date of publish RFC 3339 format.
-
#run_id ⇒ Object
Universally unique identifier (UUID) of a task run.
-
#status ⇒ Object
Returns the value of attribute status.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Event
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Event
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/algolia/models/ingestion/event.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::Event` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) raise( ArgumentError, "`#{k}` is not a valid attribute in `Algolia::Event`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect ) end h[k.to_sym] = v } if attributes.key?(:event_id) self.event_id = attributes[:event_id] else self.event_id = nil end if attributes.key?(:run_id) self.run_id = attributes[:run_id] else self.run_id = nil end if attributes.key?(:parent_id) self.parent_id = attributes[:parent_id] end if attributes.key?(:status) self.status = attributes[:status] else self.status = nil end if attributes.key?(:type) self.type = attributes[:type] else self.type = nil end if attributes.key?(:batch_size) self.batch_size = attributes[:batch_size] else self.batch_size = nil end if attributes.key?(:data) if (value = attributes[:data]).is_a?(Hash) self.data = value end end if attributes.key?(:published_at) self.published_at = attributes[:published_at] else self.published_at = nil end end |
Instance Attribute Details
#batch_size ⇒ Object
The extracted record batch size.
24 25 26 |
# File 'lib/algolia/models/ingestion/event.rb', line 24 def batch_size @batch_size end |
#data ⇒ Object
Returns the value of attribute data.
26 27 28 |
# File 'lib/algolia/models/ingestion/event.rb', line 26 def data @data end |
#event_id ⇒ Object
Universally unique identifier (UUID) of an event.
11 12 13 |
# File 'lib/algolia/models/ingestion/event.rb', line 11 def event_id @event_id end |
#parent_id ⇒ Object
The parent event, the cause of this event.
17 18 19 |
# File 'lib/algolia/models/ingestion/event.rb', line 17 def parent_id @parent_id end |
#published_at ⇒ Object
Date of publish RFC 3339 format.
29 30 31 |
# File 'lib/algolia/models/ingestion/event.rb', line 29 def published_at @published_at end |
#run_id ⇒ Object
Universally unique identifier (UUID) of a task run.
14 15 16 |
# File 'lib/algolia/models/ingestion/event.rb', line 14 def run_id @run_id end |
#status ⇒ Object
Returns the value of attribute status.
19 20 21 |
# File 'lib/algolia/models/ingestion/event.rb', line 19 def status @status end |
#type ⇒ Object
Returns the value of attribute type.
21 22 23 |
# File 'lib/algolia/models/ingestion/event.rb', line 21 def type @type end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/algolia/models/ingestion/event.rb', line 209 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end # model else # models (e.g. Pet) or oneOf klass = Algolia::Ingestion.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass .build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/algolia/models/ingestion/event.rb', line 46 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/algolia/models/ingestion/event.rb', line 32 def self.attribute_map { :event_id => :eventID, :run_id => :runID, :parent_id => :parentID, :status => :status, :type => :type, :batch_size => :batchSize, :data => :data, :published_at => :publishedAt } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/algolia/models/ingestion/event.rb', line 182 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 69 |
# File 'lib/algolia/models/ingestion/event.rb', line 65 def self.openapi_nullable Set.new( [] ) end |
.types_mapping ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/algolia/models/ingestion/event.rb', line 51 def self.types_mapping { :event_id => :"String", :run_id => :"String", :parent_id => :"String", :status => :"EventStatus", :type => :"EventType", :batch_size => :"Integer", :data => :"Hash<String, Object>", :published_at => :"String" } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/algolia/models/ingestion/event.rb', line 154 def ==(other) return true if self.equal?(other) self.class == other.class && event_id == other.event_id && run_id == other.run_id && parent_id == other.parent_id && status == other.status && type == other.type && batch_size == other.batch_size && data == other.data && published_at == other.published_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/algolia/models/ingestion/event.rb', line 288 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to?(:to_hash) value.to_hash else value end end |
#eql?(other) ⇒ Boolean
169 170 171 |
# File 'lib/algolia/models/ingestion/event.rb', line 169 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/algolia/models/ingestion/event.rb', line 175 def hash [event_id, run_id, parent_id, status, type, batch_size, data, published_at].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
259 260 261 |
# File 'lib/algolia/models/ingestion/event.rb', line 259 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/algolia/models/ingestion/event.rb', line 269 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
263 264 265 |
# File 'lib/algolia/models/ingestion/event.rb', line 263 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
253 254 255 |
# File 'lib/algolia/models/ingestion/event.rb', line 253 def to_s to_hash.to_s end |