Class: Algolia::Ingestion::PushTaskRecords
- Inherits:
-
Object
- Object
- Algolia::Ingestion::PushTaskRecords
- Defined in:
- lib/algolia/models/ingestion/push_task_records.rb
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#object_id ⇒ Object
Unique record identifier.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PushTaskRecords
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PushTaskRecords
Initializes the object
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 42 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise( ArgumentError, "The input argument (attributes) must be a hash in `Algolia::PushTaskRecords` initialize method" ) end if attributes.key?(:object_id) self.object_id = attributes[:object_id] else self.object_id = nil end # add extra attribute to additional_properties self.additional_properties ||= {} self.additional_properties.merge!(attributes.reject { |k, _| self.class.attribute_map.key?(k.to_sym) }) end |
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
12 13 14 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 12 def additional_properties @additional_properties end |
#object_id ⇒ Object
Unique record identifier.
10 11 12 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 10 def object_id @object_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 113 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end # model else # models (e.g. Pet) or oneOf klass = Algolia::Ingestion.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass .build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
22 23 24 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 22 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
15 16 17 18 19 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 15 def self.attribute_map { :object_id => :objectID } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 84 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end # add extra attribute to transformed_hash transformed_hash.merge!(attributes.reject { |k, _| attribute_map.key?(k.to_sym) }) new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
34 35 36 37 38 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 34 def self.openapi_nullable Set.new( [] ) end |
.types_mapping ⇒ Object
Attribute type mapping.
27 28 29 30 31 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 27 def self.types_mapping { :object_id => :"String" } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
63 64 65 66 67 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 63 def ==(other) return true if self.equal?(other) self.class == other.class && object_id == other.object_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 197 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to?(:to_hash) value.to_hash else value end end |
#eql?(other) ⇒ Boolean
71 72 73 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 71 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
77 78 79 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 77 def hash [object_id].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
163 164 165 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 163 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 173 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end # also add attributes from additional_properties to hash self.additional_properties&.each_pair do |k, v| hash[k.to_sym] = _to_hash(v) end hash end |
#to_json(*_args) ⇒ Object
167 168 169 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 167 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
157 158 159 |
# File 'lib/algolia/models/ingestion/push_task_records.rb', line 157 def to_s to_hash.to_s end |