Class: Algolia::Ingestion::SourceBigCommerce
- Inherits:
-
Object
- Object
- Algolia::Ingestion::SourceBigCommerce
- Defined in:
- lib/algolia/models/ingestion/source_big_commerce.rb
Instance Attribute Summary collapse
-
#channel ⇒ Object
Returns the value of attribute channel.
-
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
-
#product_metafields ⇒ Object
Returns the value of attribute product_metafields.
-
#store_hash ⇒ Object
The store hash identifying the store the shopper is signing in to.
-
#variant_metafields ⇒ Object
Returns the value of attribute variant_metafields.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SourceBigCommerce
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SourceBigCommerce
Initializes the object
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 54 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::SourceBigCommerce` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::SourceBigCommerce`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:store_hash) self.store_hash = attributes[:store_hash] end if attributes.key?(:channel) self.channel = attributes[:channel] end if attributes.key?(:custom_fields) if (value = attributes[:custom_fields]).is_a?(Array) self.custom_fields = value end end if attributes.key?(:product_metafields) if (value = attributes[:product_metafields]).is_a?(Array) self. = value end end if attributes.key?(:variant_metafields) if (value = attributes[:variant_metafields]).is_a?(Array) self. = value end end end |
Instance Attribute Details
#channel ⇒ Object
Returns the value of attribute channel.
12 13 14 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 12 def channel @channel end |
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
14 15 16 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 14 def custom_fields @custom_fields end |
#product_metafields ⇒ Object
Returns the value of attribute product_metafields.
16 17 18 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 16 def @product_metafields end |
#store_hash ⇒ Object
The store hash identifying the store the shopper is signing in to.
10 11 12 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 10 def store_hash @store_hash end |
#variant_metafields ⇒ Object
Returns the value of attribute variant_metafields.
18 19 20 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 18 def @variant_metafields end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 149 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Ingestion.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
32 33 34 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 32 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
21 22 23 24 25 26 27 28 29 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 21 def self.attribute_map { :store_hash => :storeHash, :channel => :channel, :custom_fields => :customFields, :product_metafields => :productMetafields, :variant_metafields => :variantMetafields } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 124 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
48 49 50 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 48 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 43 44 45 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 37 def self.types_mapping { :store_hash => :String, :channel => :BigCommerceChannel, :custom_fields => :'Array<String>', :product_metafields => :'Array<BigCommerceMetafield>', :variant_metafields => :'Array<BigCommerceMetafield>' } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 104 105 106 107 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 98 def ==(other) return true if equal?(other) self.class == other.class && store_hash == other.store_hash && channel == other.channel && custom_fields == other.custom_fields && == other. && == other. end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 224 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
111 112 113 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 111 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
117 118 119 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 117 def hash [store_hash, channel, custom_fields, , ].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
196 197 198 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 196 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
200 201 202 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 200 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
190 191 192 |
# File 'lib/algolia/models/ingestion/source_big_commerce.rb', line 190 def to_s to_hash.to_s end |