Class: Algolia::Ingestion::SourceBigQuery

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/ingestion/source_big_query.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SourceBigQuery

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 89

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::SourceBigQuery` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::SourceBigQuery`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:project_id)
    self.project_id = attributes[:project_id]
  else
    self.project_id = nil
  end

  if attributes.key?(:dataset_id)
    self.dataset_id = attributes[:dataset_id]
  else
    self.dataset_id = nil
  end

  if attributes.key?(:data_type)
    self.data_type = attributes[:data_type]
  end

  if attributes.key?(:table)
    self.table = attributes[:table]
  end

  if attributes.key?(:table_prefix)
    self.table_prefix = attributes[:table_prefix]
  end

  if attributes.key?(:custom_sql_request)
    self.custom_sql_request = attributes[:custom_sql_request]
  end

  if attributes.key?(:unique_id_column)
    self.unique_id_column = attributes[:unique_id_column]
  end
end

Instance Attribute Details

#custom_sql_requestObject

Custom SQL request to extract data from the BigQuery table.



24
25
26
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 24

def custom_sql_request
  @custom_sql_request
end

#data_typeObject

Returns the value of attribute data_type.



15
16
17
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 15

def data_type
  @data_type
end

#dataset_idObject

Dataset ID of the BigQuery Source.



13
14
15
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 13

def dataset_id
  @dataset_id
end

#project_idObject

Project ID of the BigQuery Source.



10
11
12
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 10

def project_id
  @project_id
end

#tableObject

Table name (for default BQ).



18
19
20
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 18

def table
  @table
end

#table_prefixObject

Table prefix (for Google Analytics).



21
22
23
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 21

def table_prefix
  @table_prefix
end

#unique_id_columnObject

The name of the column that contains the unique ID, used as ‘objectID` in Algolia.



27
28
29
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 27

def unique_id_column
  @unique_id_column
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 192

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Ingestion.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 65

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 52

def self.attribute_map
  {
    :project_id => :projectID,
    :dataset_id => :datasetID,
    :data_type => :dataType,
    :table => :table,
    :table_prefix => :tablePrefix,
    :custom_sql_request => :customSQLRequest,
    :unique_id_column => :uniqueIDColumn
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 167

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_s] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_s] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_s] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 83

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 70

def self.types_mapping
  {
    :project_id => :String,
    :dataset_id => :String,
    :data_type => :BigQueryDataType,
    :table => :String,
    :table_prefix => :String,
    :custom_sql_request => :String,
    :unique_id_column => :String
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 139

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    project_id == other.project_id &&
    dataset_id == other.dataset_id &&
    data_type == other.data_type &&
    table == other.table &&
    table_prefix == other.table_prefix &&
    custom_sql_request == other.custom_sql_request &&
    unique_id_column == other.unique_id_column
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 263

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


154
155
156
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 154

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



160
161
162
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 160

def hash
  [project_id, dataset_id, data_type, table, table_prefix, custom_sql_request, unique_id_column].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 239

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 245

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



233
234
235
# File 'lib/algolia/models/ingestion/source_big_query.rb', line 233

def to_s
  to_hash.to_s
end