Class: Algolia::Ingestion::SourceShopify

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/ingestion/source_shopify.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SourceShopify

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 81

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::SourceShopify` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::SourceShopify`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:collection_id_indexing)
    self.collection_id_indexing = attributes[:collection_id_indexing]
  end

  if attributes.key?(:increase_product_collection_limit)
    self.increase_product_collection_limit = attributes[:increase_product_collection_limit]
  end

  if attributes.key?(:default_price_ratio_as_one)
    self.default_price_ratio_as_one = attributes[:default_price_ratio_as_one]
  end

  if attributes.key?(:exclude_oos_variants_for_price_at_trs)
    self.exclude_oos_variants_for_price_at_trs = attributes[:exclude_oos_variants_for_price_at_trs]
  end

  if attributes.key?(:include_variants_inventory)
    self.include_variants_inventory = attributes[:include_variants_inventory]
  end

  if attributes.key?(:has_collection_search_page)
    self.has_collection_search_page = attributes[:has_collection_search_page]
  end

  if attributes.key?(:product_named_tags)
    self.product_named_tags = attributes[:product_named_tags]
  end

  if attributes.key?(:shop_url)
    self.shop_url = attributes[:shop_url]
  else
    self.shop_url = nil
  end
end

Instance Attribute Details

#collection_id_indexingObject

Whether to index collection IDs. If your store has ‘has_collection_search_page` set to true, collection IDs will be indexed even if `collectionIDIndexing` is false.



10
11
12
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 10

def collection_id_indexing
  @collection_id_indexing
end

#default_price_ratio_as_oneObject

Whether to set the default price ratio to 1 if no sale price is present. The price ratio is determined by the ratio: ‘sale_price` / `regular_price`. If no sale price is present, the price ratio would be 0. If `defaultPriceRatioAsOne` is true, the price ratio is indexed as 1 instead.



16
17
18
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 16

def default_price_ratio_as_one
  @default_price_ratio_as_one
end

#exclude_oos_variants_for_price_at_trsObject

Whether to exclude out-of-stock variants when determining the ‘max_variant_price` and `min_variant_price` attributes.



19
20
21
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 19

def exclude_oos_variants_for_price_at_trs
  @exclude_oos_variants_for_price_at_trs
end

#has_collection_search_pageObject

Whether to include collection IDs and handles in the product records.



25
26
27
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 25

def has_collection_search_page
  @has_collection_search_page
end

#include_variants_inventoryObject

Whether to include an inventory with every variant for every product record.



22
23
24
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 22

def include_variants_inventory
  @include_variants_inventory
end

#increase_product_collection_limitObject

Whether to increase the number of indexed collections per product. If true, Algolia indexes 200 collections per product. If false, 100 collections per product are indexed.



13
14
15
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 13

def increase_product_collection_limit
  @increase_product_collection_limit
end

#product_named_tagsObject

Whether to convert tags on products to named tags. To learn more, see [Named tags](www.algolia.com/doc/integration/shopify/sending-and-managing-data/named-tags).



28
29
30
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 28

def product_named_tags
  @product_named_tags
end

#shop_urlObject

URL of the Shopify store.



31
32
33
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 31

def shop_url
  @shop_url
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 188

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Ingestion.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 48

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
45
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 34

def self.attribute_map
  {
    :collection_id_indexing => :collectionIDIndexing,
    :increase_product_collection_limit => :increaseProductCollectionLimit,
    :default_price_ratio_as_one => :defaultPriceRatioAsOne,
    :exclude_oos_variants_for_price_at_trs => :excludeOOSVariantsForPriceAtTRS,
    :include_variants_inventory => :includeVariantsInventory,
    :has_collection_search_page => :hasCollectionSearchPage,
    :product_named_tags => :productNamedTags,
    :shop_url => :shopURL
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 163

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



72
73
74
75
76
77
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 72

def self.openapi_all_of
  [
    :SourceShopifyBase,
    :SourceUpdateShopify
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 67

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 53

def self.types_mapping
  {
    :collection_id_indexing => :Boolean,
    :increase_product_collection_limit => :Boolean,
    :default_price_ratio_as_one => :Boolean,
    :exclude_oos_variants_for_price_at_trs => :Boolean,
    :include_variants_inventory => :Boolean,
    :has_collection_search_page => :Boolean,
    :product_named_tags => :Boolean,
    :shop_url => :String
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 133

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    collection_id_indexing == other.collection_id_indexing &&
    increase_product_collection_limit == other.increase_product_collection_limit &&
    default_price_ratio_as_one == other.default_price_ratio_as_one &&
    exclude_oos_variants_for_price_at_trs == other.exclude_oos_variants_for_price_at_trs &&
    include_variants_inventory == other.include_variants_inventory &&
    has_collection_search_page == other.has_collection_search_page &&
    product_named_tags == other.product_named_tags &&
    shop_url == other.shop_url
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 263

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


149
150
151
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 149

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



155
156
157
158
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 155

def hash
  [collection_id_indexing, increase_product_collection_limit, default_price_ratio_as_one, exclude_oos_variants_for_price_at_trs, include_variants_inventory,
   has_collection_search_page, product_named_tags, shop_url].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



235
236
237
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 235

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 245

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*_args) ⇒ Object



239
240
241
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 239

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



229
230
231
# File 'lib/algolia/models/ingestion/source_shopify.rb', line 229

def to_s
  to_hash.to_s
end