Class: Algolia::Ingestion::SourceUpdateDocker

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/ingestion/source_update_docker.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SourceUpdateDocker

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 74

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::SourceUpdateDocker` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::SourceUpdateDocker`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:registry)
    self.registry = attributes[:registry]
  end

  if attributes.key?(:image)
    self.image = attributes[:image]
  end

  if attributes.key?(:version)
    self.version = attributes[:version]
  end

  if attributes.key?(:configuration)
    self.configuration = attributes[:configuration]
  else
    self.configuration = nil
  end
end

Instance Attribute Details

#configurationObject

The configuration of the spec.



18
19
20
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 18

def configuration
  @configuration
end

#imageObject

The name of the image to pull.



12
13
14
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 12

def image
  @image
end

#registryObject

Returns the value of attribute registry.



9
10
11
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 9

def registry
  @registry
end

#versionObject

The version of the image, defaults to ‘latest`.



15
16
17
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 15

def version
  @version
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 160

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Ingestion.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 53

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 43

def self.attribute_map
  {
    :registry => :registry,
    :image => :image,
    :version => :version,
    :configuration => :configuration
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 135

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_s] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_s] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_s] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



68
69
70
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 68

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



58
59
60
61
62
63
64
65
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 58

def self.types_mapping
  {
    :registry => :DockerRegistry,
    :image => :String,
    :version => :String,
    :configuration => :Object
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



110
111
112
113
114
115
116
117
118
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 110

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    registry == other.registry &&
    image == other.image &&
    version == other.version &&
    configuration == other.configuration
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 231

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


122
123
124
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 122

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



128
129
130
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 128

def hash
  [registry, image, version, configuration].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



207
208
209
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 207

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



201
202
203
# File 'lib/algolia/models/ingestion/source_update_docker.rb', line 201

def to_s
  to_hash.to_s
end