Class: Algolia::Ingestion::TaskCreate

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/ingestion/task_create.rb

Overview

API request body for creating a task.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TaskCreate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/algolia/models/ingestion/task_create.rb', line 93

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::TaskCreate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::TaskCreate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:source_id)
    self.source_id = attributes[:source_id]
  else
    self.source_id = nil
  end

  if attributes.key?(:destination_id)
    self.destination_id = attributes[:destination_id]
  else
    self.destination_id = nil
  end

  if attributes.key?(:trigger)
    self.trigger = attributes[:trigger]
  else
    self.trigger = nil
  end

  if attributes.key?(:action)
    self.action = attributes[:action]
  else
    self.action = nil
  end

  if attributes.key?(:enabled)
    self.enabled = attributes[:enabled]
  end

  if attributes.key?(:failure_threshold)
    self.failure_threshold = attributes[:failure_threshold]
  end

  if attributes.key?(:input)
    self.input = attributes[:input]
  end

  if attributes.key?(:cursor)
    self.cursor = attributes[:cursor]
  end
end

Instance Attribute Details

#actionObject

Returns the value of attribute action.



18
19
20
# File 'lib/algolia/models/ingestion/task_create.rb', line 18

def action
  @action
end

#cursorObject

Date of the last cursor in RFC 3339 format.



29
30
31
# File 'lib/algolia/models/ingestion/task_create.rb', line 29

def cursor
  @cursor
end

#destination_idObject

Universally unique identifier (UUID) of a destination resource.



14
15
16
# File 'lib/algolia/models/ingestion/task_create.rb', line 14

def destination_id
  @destination_id
end

#enabledObject

Whether the task is enabled.



21
22
23
# File 'lib/algolia/models/ingestion/task_create.rb', line 21

def enabled
  @enabled
end

#failure_thresholdObject

Maximum accepted percentage of failures for a task run to finish successfully.



24
25
26
# File 'lib/algolia/models/ingestion/task_create.rb', line 24

def failure_threshold
  @failure_threshold
end

#inputObject

Returns the value of attribute input.



26
27
28
# File 'lib/algolia/models/ingestion/task_create.rb', line 26

def input
  @input
end

#source_idObject

Universally uniqud identifier (UUID) of a source.



11
12
13
# File 'lib/algolia/models/ingestion/task_create.rb', line 11

def source_id
  @source_id
end

#triggerObject

Returns the value of attribute trigger.



16
17
18
# File 'lib/algolia/models/ingestion/task_create.rb', line 16

def trigger
  @trigger
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/algolia/models/ingestion/task_create.rb', line 223

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Ingestion.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/algolia/models/ingestion/task_create.rb', line 68

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/algolia/models/ingestion/task_create.rb', line 54

def self.attribute_map
  {
    :source_id => :sourceID,
    :destination_id => :destinationID,
    :trigger => :trigger,
    :action => :action,
    :enabled => :enabled,
    :failure_threshold => :failureThreshold,
    :input => :input,
    :cursor => :cursor
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/algolia/models/ingestion/task_create.rb', line 198

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
# File 'lib/algolia/models/ingestion/task_create.rb', line 87

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/algolia/models/ingestion/task_create.rb', line 73

def self.types_mapping
  {
    :source_id => :String,
    :destination_id => :String,
    :trigger => :TaskCreateTrigger,
    :action => :ActionType,
    :enabled => :Boolean,
    :failure_threshold => :Integer,
    :input => :TaskInput,
    :cursor => :String
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/algolia/models/ingestion/task_create.rb', line 169

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    source_id == other.source_id &&
    destination_id == other.destination_id &&
    trigger == other.trigger &&
    action == other.action &&
    enabled == other.enabled &&
    failure_threshold == other.failure_threshold &&
    input == other.input &&
    cursor == other.cursor
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/algolia/models/ingestion/task_create.rb', line 298

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


185
186
187
# File 'lib/algolia/models/ingestion/task_create.rb', line 185

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



191
192
193
# File 'lib/algolia/models/ingestion/task_create.rb', line 191

def hash
  [source_id, destination_id, trigger, action, enabled, failure_threshold, input, cursor].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



270
271
272
# File 'lib/algolia/models/ingestion/task_create.rb', line 270

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/algolia/models/ingestion/task_create.rb', line 280

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*_args) ⇒ Object



274
275
276
# File 'lib/algolia/models/ingestion/task_create.rb', line 274

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



264
265
266
# File 'lib/algolia/models/ingestion/task_create.rb', line 264

def to_s
  to_hash.to_s
end