Method: Algolia::IngestionClient#run_source

Defined in:
lib/algolia/api/ingestion_client.rb

#run_source(source_id, run_source_payload = nil, request_options = {}) ⇒ RunSourceResponse

Runs all tasks linked to a source, only available for Shopify, BigCommerce and commercetools sources. Creates one run per task.

Required API Key ACLs:

- addObject
- deleteIndex
- editSettings

Parameters:

  • source_id (String)

    Unique identifier of a source. (required)

  • run_source_payload (RunSourcePayload) (defaults to: nil)
  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (RunSourceResponse)


2426
2427
2428
2429
# File 'lib/algolia/api/ingestion_client.rb', line 2426

def run_source(source_id, run_source_payload = nil, request_options = {})
  response = run_source_with_http_info(source_id, run_source_payload, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "Ingestion::RunSourceResponse")
end