Class: Algolia::Insights::ConvertedObjectIDs

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/insights/converted_object_ids.rb

Overview

Use this event to track when users convert on items unrelated to a previous Algolia request. For example, if you don’t use Algolia to build your category pages, use this event. To track conversion events related to Algolia requests, use the "Converted object IDs after search" event.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConvertedObjectIDs

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise(
      ArgumentError,
      "The input argument (attributes) must be a hash in `Algolia::ConvertedObjectIDs` initialize method"
    )
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      raise(
        ArgumentError,
        "`#{k}` is not a valid attribute in `Algolia::ConvertedObjectIDs`. Please check the name to make sure it's valid. List of attributes: " +
          self.class.attribute_map.keys.inspect
      )
    end

    h[k.to_sym] = v
  }

  if attributes.key?(:event_name)
    self.event_name = attributes[:event_name]
  else
    self.event_name = nil
  end

  if attributes.key?(:event_type)
    self.event_type = attributes[:event_type]
  else
    self.event_type = nil
  end

  if attributes.key?(:index)
    self.index = attributes[:index]
  else
    self.index = nil
  end

  if attributes.key?(:object_ids)
    if (value = attributes[:object_ids]).is_a?(Array)
      self.object_ids = value
    end
  else
    self.object_ids = nil
  end

  if attributes.key?(:user_token)
    self.user_token = attributes[:user_token]
  else
    self.user_token = nil
  end

  if attributes.key?(:authenticated_user_token)
    self.authenticated_user_token = attributes[:authenticated_user_token]
  end

  if attributes.key?(:timestamp)
    self.timestamp = attributes[:timestamp]
  end
end

Instance Attribute Details

#authenticated_user_tokenObject

Identifier for authenticated users. When the user signs in, you can get an identifier from your system and send it as ‘authenticatedUserToken`. This lets you keep using the `userToken` from before the user signed in, while providing a reliable way to identify users across sessions. Don’t use personally identifiable information in user tokens. For more information, see [User token](www.algolia.com/doc/guides/sending-events/concepts/usertoken/).



25
26
27
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 25

def authenticated_user_token
  @authenticated_user_token
end

#event_nameObject

Event name, up to 64 ASCII characters. Consider naming events consistently—for example, by adopting Segment’s [object-action](segment.com/academy/collecting-data/naming-conventions-for-clean-data/#the-object-action-framework) framework.



11
12
13
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 11

def event_name
  @event_name
end

#event_typeObject

Returns the value of attribute event_type.



13
14
15
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 13

def event_type
  @event_type
end

#indexObject

Index name (case-sensitive) to which the event’s items belong.



16
17
18
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 16

def index
  @index
end

#object_idsObject

Object IDs of the records that are part of the event.



19
20
21
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 19

def object_ids
  @object_ids
end

#timestampObject

Timestamp of the event, measured in milliseconds since the Unix epoch. By default, the Insights API uses the time it receives an event as its timestamp.



28
29
30
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 28

def timestamp
  @timestamp
end

#user_tokenObject

Anonymous or pseudonymous user identifier. Don’t use personally identifiable information in user tokens. For more information, see [User token](www.algolia.com/doc/guides/sending-events/concepts/usertoken/).



22
23
24
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 22

def user_token
  @user_token
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 293

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end

  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
    # model
  else
    # models (e.g. Pet) or oneOf
    klass = Algolia::Insights.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass
      .build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



44
45
46
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 44

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
41
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 31

def self.attribute_map
  {
    :event_name => :eventName,
    :event_type => :eventType,
    :index => :index,
    :object_ids => :objectIDs,
    :user_token => :userToken,
    :authenticated_user_token => :authenticatedUserToken,
    :timestamp => :timestamp
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 266

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v|
          _deserialize(::Regexp.last_match(1), v)
        }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end

  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
66
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 62

def self.openapi_nullable
  Set.new(
    []
  )
end

.types_mappingObject

Attribute type mapping.



49
50
51
52
53
54
55
56
57
58
59
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 49

def self.types_mapping
  {
    :event_name => :"String",
    :event_type => :"ConversionEvent",
    :index => :"String",
    :object_ids => :"Array<String>",
    :user_token => :"String",
    :authenticated_user_token => :"String",
    :timestamp => :"Integer"
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



239
240
241
242
243
244
245
246
247
248
249
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 239

def ==(other)
  return true if self.equal?(other)
  self.class == other.class &&
    event_name == other.event_name &&
    event_type == other.event_type &&
    index == other.index &&
    object_ids == other.object_ids &&
    user_token == other.user_token &&
    authenticated_user_token == other.authenticated_user_token &&
    timestamp == other.timestamp
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 372

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to?(:to_hash)
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


253
254
255
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 253

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



259
260
261
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 259

def hash
  [event_name, event_type, index, object_ids, user_token, authenticated_user_token, timestamp].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



343
344
345
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 343

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 353

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end

  hash
end

#to_json(*_args) ⇒ Object



347
348
349
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 347

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



337
338
339
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 337

def to_s
  to_hash.to_s
end