Method: Algolia::Insights::ConvertedObjectIDs#authenticated_user_token

Defined in:
lib/algolia/models/insights/converted_object_ids.rb

#authenticated_user_tokenObject

Identifier for authenticated users. When the user signs in, you can get an identifier from your system and send it as authenticatedUserToken. This lets you keep using the userToken from before the user signed in, while providing a reliable way to identify users across sessions. Don’t use personally identifiable information in user tokens. For more information, see [User token](www.algolia.com/doc/guides/sending-events/concepts/usertoken).



27
28
29
# File 'lib/algolia/models/insights/converted_object_ids.rb', line 27

def authenticated_user_token
  @authenticated_user_token
end