Class: Algolia::Insights::ConvertedObjectIDsAfterSearch
- Inherits:
-
Object
- Object
- Algolia::Insights::ConvertedObjectIDsAfterSearch
- Defined in:
- lib/algolia/models/insights/converted_object_ids_after_search.rb
Overview
Use this event to track when users convert after a previous Algolia request. For example, a user clicks on an item in the search results to view the product detail page. Then, the user adds the item to their shopping cart. If you’re building your category pages with Algolia, you’ll also use this event.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#authenticated_user_token ⇒ Object
An identifier for authenticated users.
-
#event_name ⇒ Object
The name of the event, up to 64 ASCII characters.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#index ⇒ Object
The name of an Algolia index.
-
#object_ids ⇒ Object
The object IDs of the records that are part of the event.
-
#query_id ⇒ Object
Unique identifier for a search query.
-
#timestamp ⇒ Object
The timestamp of the event in milliseconds in [Unix epoch time](wikipedia.org/wiki/Unix_time).
-
#user_token ⇒ Object
An anonymous or pseudonymous user identifier.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConvertedObjectIDsAfterSearch
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ConvertedObjectIDsAfterSearch
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 95 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::ConvertedObjectIDsAfterSearch` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::ConvertedObjectIDsAfterSearch`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:event_name) self.event_name = attributes[:event_name] else self.event_name = nil end if attributes.key?(:event_type) self.event_type = attributes[:event_type] else self.event_type = nil end if attributes.key?(:index) self.index = attributes[:index] else self.index = nil end if attributes.key?(:object_ids) if (value = attributes[:object_ids]).is_a?(Array) self.object_ids = value end else self.object_ids = nil end if attributes.key?(:query_id) self.query_id = attributes[:query_id] else self.query_id = nil end if attributes.key?(:user_token) self.user_token = attributes[:user_token] else self.user_token = nil end if attributes.key?(:authenticated_user_token) self.authenticated_user_token = attributes[:authenticated_user_token] end if attributes.key?(:timestamp) self. = attributes[:timestamp] end end |
Instance Attribute Details
#authenticated_user_token ⇒ Object
An identifier for authenticated users. > Note: Never include personally identifiable information in user tokens.
28 29 30 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 28 def authenticated_user_token @authenticated_user_token end |
#event_name ⇒ Object
The name of the event, up to 64 ASCII characters. Consider naming events consistently—for example, by adopting Segment’s [object-action](segment.com/academy/collecting-data/naming-conventions-for-clean-data/#the-object-action-framework) framework.
11 12 13 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 11 def event_name @event_name end |
#event_type ⇒ Object
Returns the value of attribute event_type.
13 14 15 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 13 def event_type @event_type end |
#index ⇒ Object
The name of an Algolia index.
16 17 18 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 16 def index @index end |
#object_ids ⇒ Object
The object IDs of the records that are part of the event.
19 20 21 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 19 def object_ids @object_ids end |
#query_id ⇒ Object
Unique identifier for a search query. The query ID is required for events related to search or browse requests. If you add ‘clickAnalytics: true` as a search request parameter, the query ID is included in the API response.
22 23 24 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 22 def query_id @query_id end |
#timestamp ⇒ Object
The timestamp of the event in milliseconds in [Unix epoch time](wikipedia.org/wiki/Unix_time). By default, the Insights API uses the time it receives an event as its timestamp.
31 32 33 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 31 def @timestamp end |
#user_token ⇒ Object
An anonymous or pseudonymous user identifier. > Note: Never include personally identifiable information in user tokens.
25 26 27 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 25 def user_token @user_token end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 323 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Insights.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 70 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 56 def self.attribute_map { :event_name => :eventName, :event_type => :eventType, :index => :index, :object_ids => :objectIDs, :query_id => :queryID, :user_token => :userToken, :authenticated_user_token => :authenticatedUserToken, :timestamp => :timestamp } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 298 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_s] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 89 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 75 def self.types_mapping { :event_name => :String, :event_type => :ConversionEvent, :index => :String, :object_ids => :'Array<String>', :query_id => :String, :user_token => :String, :authenticated_user_token => :String, :timestamp => :Integer } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 269 def ==(other) return true if equal?(other) self.class == other.class && event_name == other.event_name && event_type == other.event_type && index == other.index && object_ids == other.object_ids && query_id == other.query_id && user_token == other.user_token && authenticated_user_token == other.authenticated_user_token && == other. end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 394 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
285 286 287 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 285 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
291 292 293 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 291 def hash [event_name, event_type, index, object_ids, query_id, user_token, authenticated_user_token, ].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
370 371 372 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 370 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 376 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
364 365 366 |
# File 'lib/algolia/models/insights/converted_object_ids_after_search.rb', line 364 def to_s to_hash.to_s end |