Class: Algolia::Insights::PurchasedObjectIDsAfterSearch
- Inherits:
-
Object
- Object
- Algolia::Insights::PurchasedObjectIDsAfterSearch
- Defined in:
- lib/algolia/models/insights/purchased_object_ids_after_search.rb
Overview
Use this event to track when users make a purchase after a previous Algolia request. If you’re building your category pages with Algolia, you’ll also use this event.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#authenticated_user_token ⇒ Object
User token for authenticated users.
-
#currency ⇒ Object
If you include pricing information in the ‘objectData` parameter, you must also specify the currency as ISO-4217 currency code, such as USD or EUR.
-
#event_name ⇒ Object
Can contain up to 64 ASCII characters.
-
#event_subtype ⇒ Object
Returns the value of attribute event_subtype.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#index ⇒ Object
Name of the Algolia index.
-
#object_data ⇒ Object
Extra information about the records involved in the event—for example, to add price and quantities of purchased products.
-
#object_ids ⇒ Object
List of object identifiers for items of an Algolia index.
-
#query_id ⇒ Object
Unique identifier for a search query.
-
#timestamp ⇒ Object
Time of the event in milliseconds in [Unix epoch time](wikipedia.org/wiki/Unix_time).
-
#user_token ⇒ Object
Anonymous or pseudonymous user identifier.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PurchasedObjectIDsAfterSearch
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PurchasedObjectIDsAfterSearch
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 109 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::PurchasedObjectIDsAfterSearch` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::PurchasedObjectIDsAfterSearch`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:event_name) self.event_name = attributes[:event_name] else self.event_name = nil end if attributes.key?(:event_type) self.event_type = attributes[:event_type] else self.event_type = nil end if attributes.key?(:event_subtype) self.event_subtype = attributes[:event_subtype] else self.event_subtype = nil end if attributes.key?(:index) self.index = attributes[:index] else self.index = nil end if attributes.key?(:query_id) self.query_id = attributes[:query_id] else self.query_id = nil end if attributes.key?(:object_ids) if (value = attributes[:object_ids]).is_a?(Array) self.object_ids = value end else self.object_ids = nil end if attributes.key?(:object_data) if (value = attributes[:object_data]).is_a?(Array) self.object_data = value end end if attributes.key?(:currency) self.currency = attributes[:currency] end if attributes.key?(:user_token) self.user_token = attributes[:user_token] else self.user_token = nil end if attributes.key?(:timestamp) self. = attributes[:timestamp] end if attributes.key?(:authenticated_user_token) self.authenticated_user_token = attributes[:authenticated_user_token] end end |
Instance Attribute Details
#authenticated_user_token ⇒ Object
User token for authenticated users.
39 40 41 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 39 def authenticated_user_token @authenticated_user_token end |
#currency ⇒ Object
If you include pricing information in the ‘objectData` parameter, you must also specify the currency as ISO-4217 currency code, such as USD or EUR.
30 31 32 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 30 def currency @currency end |
#event_name ⇒ Object
Can contain up to 64 ASCII characters. Consider naming events consistently—for example, by adopting Segment’s [object-action](segment.com/academy/collecting-data/naming-conventions-for-clean-data/#the-object-action-framework) framework.
11 12 13 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 11 def event_name @event_name end |
#event_subtype ⇒ Object
Returns the value of attribute event_subtype.
15 16 17 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 15 def event_subtype @event_subtype end |
#event_type ⇒ Object
Returns the value of attribute event_type.
13 14 15 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 13 def event_type @event_type end |
#index ⇒ Object
Name of the Algolia index.
18 19 20 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 18 def index @index end |
#object_data ⇒ Object
Extra information about the records involved in the event—for example, to add price and quantities of purchased products. If provided, must be the same length as ‘objectIDs`.
27 28 29 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 27 def object_data @object_data end |
#object_ids ⇒ Object
List of object identifiers for items of an Algolia index.
24 25 26 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 24 def object_ids @object_ids end |
#query_id ⇒ Object
Unique identifier for a search query. The query ID is required for events related to search or browse requests. If you add ‘clickAnalytics: true` as a search request parameter, the query ID is included in the API response.
21 22 23 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 21 def query_id @query_id end |
#timestamp ⇒ Object
Time of the event in milliseconds in [Unix epoch time](wikipedia.org/wiki/Unix_time). By default, the Insights API uses the time it receives an event as its timestamp.
36 37 38 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 36 def @timestamp end |
#user_token ⇒ Object
Anonymous or pseudonymous user identifier. > Note: Never include personally identifiable information in user tokens.
33 34 35 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 33 def user_token @user_token end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 333 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Insights.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 81 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 64 def self.attribute_map { :event_name => :eventName, :event_type => :eventType, :event_subtype => :eventSubtype, :index => :index, :query_id => :queryID, :object_ids => :objectIDs, :object_data => :objectData, :currency => :currency, :user_token => :userToken, :timestamp => :timestamp, :authenticated_user_token => :authenticatedUserToken } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 308 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_s] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 103 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 86 def self.types_mapping { :event_name => :String, :event_type => :ConversionEvent, :event_subtype => :PurchaseEvent, :index => :String, :query_id => :String, :object_ids => :'Array<String>', :object_data => :'Array<ObjectDataAfterSearch>', :currency => :String, :user_token => :String, :timestamp => :Integer, :authenticated_user_token => :String } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 276 def ==(other) return true if equal?(other) self.class == other.class && event_name == other.event_name && event_type == other.event_type && event_subtype == other.event_subtype && index == other.index && query_id == other.query_id && object_ids == other.object_ids && object_data == other.object_data && currency == other.currency && user_token == other.user_token && == other. && authenticated_user_token == other.authenticated_user_token end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 404 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
295 296 297 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 295 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
301 302 303 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 301 def hash [event_name, event_type, event_subtype, index, query_id, object_ids, object_data, currency, user_token, , authenticated_user_token].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
380 381 382 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 380 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 386 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
374 375 376 |
# File 'lib/algolia/models/insights/purchased_object_ids_after_search.rb', line 374 def to_s to_hash.to_s end |