Class: Algolia::Monitoring::LatencyResponse
- Inherits:
-
Object
- Object
- Algolia::Monitoring::LatencyResponse
- Defined in:
- lib/algolia/models/monitoring/latency_response.rb
Instance Attribute Summary collapse
-
#metrics ⇒ Object
Returns the value of attribute metrics.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LatencyResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ LatencyResponse
Initializes the object
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 37 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::LatencyResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::LatencyResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:metrics) self.metrics = attributes[:metrics] end end |
Instance Attribute Details
#metrics ⇒ Object
Returns the value of attribute metrics.
9 10 11 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 9 def metrics @metrics end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 106 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Monitoring.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
19 20 21 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 19 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
12 13 14 15 16 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 12 def self.attribute_map { :metrics => :metrics } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 81 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
31 32 33 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 31 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
24 25 26 27 28 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 24 def self.types_mapping { :metrics => :LatencyResponseMetrics } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
59 60 61 62 63 64 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 59 def ==(other) return true if equal?(other) self.class == other.class && metrics == other.metrics end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 181 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
68 69 70 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 68 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
74 75 76 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 74 def hash [metrics].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
153 154 155 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 153 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
157 158 159 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 157 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
147 148 149 |
# File 'lib/algolia/models/monitoring/latency_response.rb', line 147 def to_s to_hash.to_s end |