Class: Algolia::Monitoring::Server

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/monitoring/server.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Server

Initializes the object



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/algolia/models/monitoring/server.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::Server` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      raise(
        ArgumentError,
        "`#{k}` is not a valid attribute in `Algolia::Server`. Please check the name to make sure it's valid. List of attributes: " +
          self.class.attribute_map.keys.inspect
      )
    end

    h[k.to_sym] = v
  }

  if attributes.key?(:name)
    self.name = attributes[:name]
  end

  if attributes.key?(:region)
    self.region = attributes[:region]
  end

  if attributes.key?(:is_slave)
    self.is_slave = attributes[:is_slave]
  end

  if attributes.key?(:is_replica)
    self.is_replica = attributes[:is_replica]
  end

  if attributes.key?(:cluster)
    self.cluster = attributes[:cluster]
  end

  if attributes.key?(:status)
    self.status = attributes[:status]
  end

  if attributes.key?(:type)
    self.type = attributes[:type]
  end
end

Instance Attribute Details

#clusterObject

Name of the cluster to which this server belongs.



21
22
23
# File 'lib/algolia/models/monitoring/server.rb', line 21

def cluster
  @cluster
end

#is_replicaObject

Whether this server is a replica of another server.



18
19
20
# File 'lib/algolia/models/monitoring/server.rb', line 18

def is_replica
  @is_replica
end

#is_slaveObject

Included to support legacy applications. Use is_replica instead.



15
16
17
# File 'lib/algolia/models/monitoring/server.rb', line 15

def is_slave
  @is_slave
end

#nameObject

Server name.



10
11
12
# File 'lib/algolia/models/monitoring/server.rb', line 10

def name
  @name
end

#regionObject

Returns the value of attribute region.



12
13
14
# File 'lib/algolia/models/monitoring/server.rb', line 12

def region
  @region
end

#statusObject

Returns the value of attribute status.



23
24
25
# File 'lib/algolia/models/monitoring/server.rb', line 23

def status
  @status
end

#typeObject

Returns the value of attribute type.



25
26
27
# File 'lib/algolia/models/monitoring/server.rb', line 25

def type
  @type
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/algolia/models/monitoring/server.rb', line 170

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end

  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
    # model
  else
    # models (e.g. Pet) or oneOf
    klass = Algolia::Monitoring.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass
      .build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



41
42
43
# File 'lib/algolia/models/monitoring/server.rb', line 41

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
35
36
37
38
# File 'lib/algolia/models/monitoring/server.rb', line 28

def self.attribute_map
  {
    :name => :name,
    :region => :region,
    :is_slave => :is_slave,
    :is_replica => :is_replica,
    :cluster => :cluster,
    :status => :status,
    :type => :type
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/algolia/models/monitoring/server.rb', line 143

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v|
          _deserialize(::Regexp.last_match(1), v)
        }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end

  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



59
60
61
62
63
# File 'lib/algolia/models/monitoring/server.rb', line 59

def self.openapi_nullable
  Set.new(
    []
  )
end

.types_mappingObject

Attribute type mapping.



46
47
48
49
50
51
52
53
54
55
56
# File 'lib/algolia/models/monitoring/server.rb', line 46

def self.types_mapping
  {
    :name => :"String",
    :region => :"Region",
    :is_slave => :"Boolean",
    :is_replica => :"Boolean",
    :cluster => :"String",
    :status => :"ServerStatus",
    :type => :"Type"
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.



116
117
118
119
120
121
122
123
124
125
126
# File 'lib/algolia/models/monitoring/server.rb', line 116

def ==(other)
  return true if self.equal?(other)
  self.class == other.class &&
    name == other.name &&
    region == other.region &&
    is_slave == other.is_slave &&
    is_replica == other.is_replica &&
    cluster == other.cluster &&
    status == other.status &&
    type == other.type
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/algolia/models/monitoring/server.rb', line 249

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to?(:to_hash)
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

See Also:

  • `==` method


130
131
132
# File 'lib/algolia/models/monitoring/server.rb', line 130

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.



136
137
138
# File 'lib/algolia/models/monitoring/server.rb', line 136

def hash
  [name, region, is_slave, is_replica, cluster, status, type].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



220
221
222
# File 'lib/algolia/models/monitoring/server.rb', line 220

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/algolia/models/monitoring/server.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end

  hash
end

#to_json(*_args) ⇒ Object



224
225
226
# File 'lib/algolia/models/monitoring/server.rb', line 224

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object



214
215
216
# File 'lib/algolia/models/monitoring/server.rb', line 214

def to_s
  to_hash.to_s
end