Method: Algolia::MonitoringClient#get_latency

Defined in:
lib/algolia/api/monitoring_client.rb

#get_latency(clusters, request_options = {}) ⇒ LatencyResponse

Parameters:

  • clusters (String)

    Subset of clusters, separated by commas. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (LatencyResponse)


421
422
423
424
# File 'lib/algolia/api/monitoring_client.rb', line 421

def get_latency(clusters, request_options = {})
  response = get_latency_with_http_info(clusters, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "Monitoring::LatencyResponse")
end