Class: Algolia::QuerySuggestions::GetConfigStatus200Response
- Inherits:
-
Object
- Object
- Algolia::QuerySuggestions::GetConfigStatus200Response
- Defined in:
- lib/algolia/models/query-suggestions/get_config_status200_response.rb
Instance Attribute Summary collapse
-
#index_name ⇒ Object
Query Suggestions index name.
-
#is_running ⇒ Object
Indicates whether the creation or update of the Query Suggestions is in progress.
-
#last_built_at ⇒ Object
Timestamp in [ISO-8601](wikipedia.org/wiki/ISO_8601) format when the Query Suggestions index was last built.
-
#last_successful_build_duration ⇒ Object
Duration of the last successful build in seconds.
-
#last_successful_built_at ⇒ Object
Timestamp in [ISO-8601](wikipedia.org/wiki/ISO_8601) format when the Query Suggestions index was last updated successfully.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetConfigStatus200Response
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ GetConfigStatus200Response
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 58 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::GetConfigStatus200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::GetConfigStatus200Response`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:index_name) self.index_name = attributes[:index_name] end if attributes.key?(:is_running) self.is_running = attributes[:is_running] end if attributes.key?(:last_built_at) self.last_built_at = attributes[:last_built_at] end if attributes.key?(:last_successful_built_at) self.last_successful_built_at = attributes[:last_successful_built_at] end if attributes.key?(:last_successful_build_duration) self.last_successful_build_duration = attributes[:last_successful_build_duration] end end |
Instance Attribute Details
#index_name ⇒ Object
Query Suggestions index name.
10 11 12 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 10 def index_name @index_name end |
#is_running ⇒ Object
Indicates whether the creation or update of the Query Suggestions is in progress.
13 14 15 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 13 def is_running @is_running end |
#last_built_at ⇒ Object
Timestamp in [ISO-8601](wikipedia.org/wiki/ISO_8601) format when the Query Suggestions index was last built.
16 17 18 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 16 def last_built_at @last_built_at end |
#last_successful_build_duration ⇒ Object
Duration of the last successful build in seconds.
22 23 24 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 22 def last_successful_build_duration @last_successful_build_duration end |
#last_successful_built_at ⇒ Object
Timestamp in [ISO-8601](wikipedia.org/wiki/ISO_8601) format when the Query Suggestions index was last updated successfully.
19 20 21 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 19 def last_successful_built_at @last_successful_built_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 147 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::QuerySuggestions.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
36 37 38 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 36 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 31 32 33 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 25 def self.attribute_map { :index_name => :indexName, :is_running => :isRunning, :last_built_at => :lastBuiltAt, :last_successful_built_at => :lastSuccessfulBuiltAt, :last_successful_build_duration => :lastSuccessfulBuildDuration } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 122 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_s] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 52 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 41 def self.types_mapping { :index_name => :String, :is_running => :Boolean, :last_built_at => :String, :last_successful_built_at => :String, :last_successful_build_duration => :String } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
96 97 98 99 100 101 102 103 104 105 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 96 def ==(other) return true if equal?(other) self.class == other.class && index_name == other.index_name && is_running == other.is_running && last_built_at == other.last_built_at && last_successful_built_at == other.last_successful_built_at && last_successful_build_duration == other.last_successful_build_duration end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 218 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
109 110 111 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 109 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
115 116 117 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 115 def hash [index_name, is_running, last_built_at, last_successful_built_at, last_successful_build_duration].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
194 195 196 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 194 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
188 189 190 |
# File 'lib/algolia/models/query-suggestions/get_config_status200_response.rb', line 188 def to_s to_hash.to_s end |