Class: Algolia::QuerySuggestions::SourceIndex

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/query-suggestions/source_index.rb

Overview

Configuration of an Algolia index for Query Suggestions.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SourceIndex

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise(
      ArgumentError,
      "The input argument (attributes) must be a hash in `Algolia::SourceIndex` initialize method"
    )
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      raise(
        ArgumentError,
        "`#{k}` is not a valid attribute in `Algolia::SourceIndex`. Please check the name to make sure it's valid. List of attributes: " +
          self.class.attribute_map.keys.inspect
      )
    end

    h[k.to_sym] = v
  }

  if attributes.key?(:index_name)
    self.index_name = attributes[:index_name]
  else
    self.index_name = nil
  end

  if attributes.key?(:replicas)
    self.replicas = attributes[:replicas]
  end

  if attributes.key?(:analytics_tags)
    if (value = attributes[:analytics_tags]).is_a?(Array)
      self.analytics_tags = value
    end
  end

  if attributes.key?(:facets)
    if (value = attributes[:facets]).is_a?(Array)
      self.facets = value
    end
  end

  if attributes.key?(:min_hits)
    self.min_hits = attributes[:min_hits]
  end

  if attributes.key?(:min_letters)
    self.min_letters = attributes[:min_letters]
  end

  if attributes.key?(:generate)
    if (value = attributes[:generate]).is_a?(Array)
      self.generate = value
    end
  end

  if attributes.key?(:external)
    if (value = attributes[:external]).is_a?(Array)
      self.external = value
    end
  end
end

Instance Attribute Details

#analytics_tagsObject

Analytics tags for filtering the popular searches. For more information, see [Segment your analytics data](www.algolia.com/doc/guides/search-analytics/guides/segments).



19
20
21
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 19

def analytics_tags
  @analytics_tags
end

#externalObject

Algolia indices with popular searches to use as query suggestions. Records of these indices must have these attributes: - ‘query`: search query which will be added as a suggestion - `count`: measure of popularity of that search query For example, you can export popular searches from an external analytics provider, such as Google Analytics or Adobe Analytics, and feed this data into an Algolia index. You can use this index to generate query suggestions until your Algolia Analytics has collected enough data.



34
35
36
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 34

def external
  @external
end

#facetsObject

Facets to use as top categories with your suggestions. If provided, Query Suggestions adds the top facet values to each suggestion.



22
23
24
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 22

def facets
  @facets
end

#generateObject

Facets used for generating query suggestions from facet values. For example, if you set ‘generate: ["color", "brand"]`, combinations from the facet values are added as query suggestions, such as "blue adidas", "red adidas", "blue nike", "red nike", etc. You can include nested lists.



31
32
33
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 31

def generate
  @generate
end

#index_nameObject

Name of the Algolia index (case-sensitive) to use as source for query suggestions.



13
14
15
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 13

def index_name
  @index_name
end

#min_hitsObject

Minimum number of hits required to be included as a suggestion. A search query must at least generate ‘minHits` search results to be included in the Query Suggestions index.



25
26
27
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 25

def min_hits
  @min_hits
end

#min_lettersObject

Minimum letters required to be included as a suggestion. A search query must be at least ‘minLetters` long to be included in the Query Suggestions index.



28
29
30
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 28

def min_letters
  @min_letters
end

#replicasObject

If true, Query Suggestions uses all replica indices to find popular searches. If false, only the primary index is used.



16
17
18
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 16

def replicas
  @replicas
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 199

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end

  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
    # model
  else
    # models (e.g. Pet) or oneOf
    klass = Algolia::QuerySuggestions.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass
      .build_from_hash(value)
  end
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 37

def self.attribute_map
  {
    :index_name => :indexName,
    :replicas => :replicas,
    :analytics_tags => :analyticsTags,
    :facets => :facets,
    :min_hits => :minHits,
    :min_letters => :minLetters,
    :generate => :generate,
    :external => :external
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 172

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v|
          _deserialize(::Regexp.last_match(1), v)
        }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end

  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
69
70
71
72
73
74
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 65

def self.openapi_nullable
  Set.new(
    [
      :analytics_tags,
      :facets,
      :generate,
      :external
    ]
  )
end

.types_mappingObject

Attribute type mapping.



51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 51

def self.types_mapping
  {
    :index_name => :"String",
    :replicas => :"Boolean",
    :analytics_tags => :"Array<String>",
    :facets => :"Array<Facet>",
    :min_hits => :"Integer",
    :min_letters => :"Integer",
    :generate => :"Array<Array<String>>",
    :external => :"Array<String>"
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 144

def ==(other)
  return true if self.equal?(other)
  self.class == other.class &&
    index_name == other.index_name &&
    replicas == other.replicas &&
    analytics_tags == other.analytics_tags &&
    facets == other.facets &&
    min_hits == other.min_hits &&
    min_letters == other.min_letters &&
    generate == other.generate &&
    external == other.external
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 278

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to?(:to_hash)
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


159
160
161
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 159

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



165
166
167
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 165

def hash
  [index_name, replicas, analytics_tags, facets, min_hits, min_letters, generate, external].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



249
250
251
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 249

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 259

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end

  hash
end

#to_json(*_args) ⇒ Object



253
254
255
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 253

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



243
244
245
# File 'lib/algolia/models/query-suggestions/source_index.rb', line 243

def to_s
  to_hash.to_s
end