Class: Algolia::Recommend::BaseRecommendRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/recommend/base_recommend_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BaseRecommendRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 52

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::BaseRecommendRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::BaseRecommendRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:index_name)
    self.index_name = attributes[:index_name]
  else
    self.index_name = nil
  end

  if attributes.key?(:threshold)
    self.threshold = attributes[:threshold]
  else
    self.threshold = nil
  end

  if attributes.key?(:max_recommendations)
    self.max_recommendations = attributes[:max_recommendations]
  end

  if attributes.key?(:query_parameters)
    self.query_parameters = attributes[:query_parameters]
  end
end

Instance Attribute Details

#index_nameObject

Index name (case-sensitive).



10
11
12
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 10

def index_name
  @index_name
end

#max_recommendationsObject

Maximum number of recommendations to retrieve. By default, all recommendations are returned and no fallback request is made. Depending on the available recommendations and the other request parameters, the actual number of recommendations may be lower than this value.



16
17
18
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 16

def max_recommendations
  @max_recommendations
end

#query_parametersObject

Returns the value of attribute query_parameters.



18
19
20
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 18

def query_parameters
  @query_parameters
end

#thresholdObject

Minimum score a recommendation must have to be included in the response.



13
14
15
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 13

def threshold
  @threshold
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 176

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Recommend.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



31
32
33
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 31

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



21
22
23
24
25
26
27
28
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 21

def self.attribute_map
  {
    :index_name => :indexName,
    :threshold => :threshold,
    :max_recommendations => :maxRecommendations,
    :query_parameters => :queryParameters
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 151

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



46
47
48
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 46

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



36
37
38
39
40
41
42
43
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 36

def self.types_mapping
  {
    :index_name => :String,
    :threshold => :Float,
    :max_recommendations => :Integer,
    :query_parameters => :SearchParams
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



126
127
128
129
130
131
132
133
134
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 126

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    index_name == other.index_name &&
    threshold == other.threshold &&
    max_recommendations == other.max_recommendations &&
    query_parameters == other.query_parameters
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 251

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


138
139
140
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 138

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



144
145
146
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 144

def hash
  [index_name, threshold, max_recommendations, query_parameters].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



223
224
225
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 223

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 233

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*_args) ⇒ Object



227
228
229
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 227

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



217
218
219
# File 'lib/algolia/models/recommend/base_recommend_request.rb', line 217

def to_s
  to_hash.to_s
end