Class: Algolia::Recommend::BaseTrendingItemsQuery

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/recommend/base_trending_items_query.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BaseTrendingItemsQuery

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 77

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::BaseTrendingItemsQuery` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::BaseTrendingItemsQuery`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:facet_name)
    self.facet_name = attributes[:facet_name]
  end

  if attributes.key?(:facet_value)
    self.facet_value = attributes[:facet_value]
  end

  if attributes.key?(:model)
    self.model = attributes[:model]
  end

  if attributes.key?(:query_parameters)
    self.query_parameters = attributes[:query_parameters]
  end

  if attributes.key?(:fallback_parameters)
    self.fallback_parameters = attributes[:fallback_parameters]
  end
end

Instance Attribute Details

#facet_nameObject

Facet name for trending models.



10
11
12
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 10

def facet_name
  @facet_name
end

#facet_valueObject

Facet value for trending models.



13
14
15
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 13

def facet_value
  @facet_value
end

#fallback_parametersObject

Returns the value of attribute fallback_parameters.



19
20
21
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 19

def fallback_parameters
  @fallback_parameters
end

#modelObject

Returns the value of attribute model.



15
16
17
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 15

def model
  @model
end

#query_parametersObject

Returns the value of attribute query_parameters.



17
18
19
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 17

def query_parameters
  @query_parameters
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 166

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Recommend.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 55

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 44

def self.attribute_map
  {
    :facet_name => :facetName,
    :facet_value => :facetValue,
    :model => :model,
    :query_parameters => :queryParameters,
    :fallback_parameters => :fallbackParameters
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 141

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_s] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_s] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_s] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 71

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 60

def self.types_mapping
  {
    :facet_name => :String,
    :facet_value => :String,
    :model => :TrendingItemsModel,
    :query_parameters => :SearchParamsObject,
    :fallback_parameters => :SearchParamsObject
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



115
116
117
118
119
120
121
122
123
124
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 115

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    facet_name == other.facet_name &&
    facet_value == other.facet_value &&
    model == other.model &&
    query_parameters == other.query_parameters &&
    fallback_parameters == other.fallback_parameters
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 237

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


128
129
130
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 128

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



134
135
136
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 134

def hash
  [facet_name, facet_value, model, query_parameters, fallback_parameters].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 213

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



207
208
209
# File 'lib/algolia/models/recommend/base_trending_items_query.rb', line 207

def to_s
  to_hash.to_s
end