Class: Algolia::Recommend::Condition

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/recommend/condition.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Condition

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/algolia/models/recommend/condition.rb', line 79

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::Condition` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::Condition`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:pattern)
    self.pattern = attributes[:pattern]
  end

  if attributes.key?(:anchoring)
    self.anchoring = attributes[:anchoring]
  end

  if attributes.key?(:alternatives)
    self.alternatives = attributes[:alternatives]
  end

  if attributes.key?(:context)
    self.context = attributes[:context]
  end

  if attributes.key?(:filters)
    self.filters = attributes[:filters]
  end
end

Instance Attribute Details

#alternativesObject

Whether the pattern should match plurals, synonyms, and typos.



15
16
17
# File 'lib/algolia/models/recommend/condition.rb', line 15

def alternatives
  @alternatives
end

#anchoringObject

Returns the value of attribute anchoring.



12
13
14
# File 'lib/algolia/models/recommend/condition.rb', line 12

def anchoring
  @anchoring
end

#contextObject

An additional restriction that only triggers the rule, when the search has the same value as ‘ruleContexts` parameter. For example, if `context: mobile`, the rule is only triggered when the search request has a matching `ruleContexts: mobile`. A rule context must only contain alphanumeric characters.



18
19
20
# File 'lib/algolia/models/recommend/condition.rb', line 18

def context
  @context
end

#filtersObject

Filters that trigger the rule. You can add add filters using the syntax ‘facet:value` so that the rule is triggered, when the specific filter is selected. You can use `filters` on its own or combine it with the `pattern` parameter.



21
22
23
# File 'lib/algolia/models/recommend/condition.rb', line 21

def filters
  @filters
end

#patternObject

Query pattern that triggers the rule. You can use either a literal string, or a special pattern ‘facet:ATTRIBUTE`, where `ATTRIBUTE` is a facet name. The rule is triggered if the query matches the literal string or a value of the specified facet. For example, with `pattern: facet:genre`, the rule is triggered when users search for a genre, such as "comedy".



10
11
12
# File 'lib/algolia/models/recommend/condition.rb', line 10

def pattern
  @pattern
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/algolia/models/recommend/condition.rb', line 183

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Recommend.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/algolia/models/recommend/condition.rb', line 57

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
# File 'lib/algolia/models/recommend/condition.rb', line 46

def self.attribute_map
  {
    :pattern => :pattern,
    :anchoring => :anchoring,
    :alternatives => :alternatives,
    :context => :context,
    :filters => :filters
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/algolia/models/recommend/condition.rb', line 158

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
# File 'lib/algolia/models/recommend/condition.rb', line 73

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
# File 'lib/algolia/models/recommend/condition.rb', line 62

def self.types_mapping
  {
    :pattern => :String,
    :anchoring => :Anchoring,
    :alternatives => :Boolean,
    :context => :String,
    :filters => :String
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



132
133
134
135
136
137
138
139
140
141
# File 'lib/algolia/models/recommend/condition.rb', line 132

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    pattern == other.pattern &&
    anchoring == other.anchoring &&
    alternatives == other.alternatives &&
    context == other.context &&
    filters == other.filters
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/algolia/models/recommend/condition.rb', line 258

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


145
146
147
# File 'lib/algolia/models/recommend/condition.rb', line 145

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



151
152
153
# File 'lib/algolia/models/recommend/condition.rb', line 151

def hash
  [pattern, anchoring, alternatives, context, filters].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
# File 'lib/algolia/models/recommend/condition.rb', line 230

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/algolia/models/recommend/condition.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*_args) ⇒ Object



234
235
236
# File 'lib/algolia/models/recommend/condition.rb', line 234

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



224
225
226
# File 'lib/algolia/models/recommend/condition.rb', line 224

def to_s
  to_hash.to_s
end