Class: Algolia::Recommend::ParamsConsequence
- Inherits:
-
Object
- Object
- Algolia::Recommend::ParamsConsequence
- Defined in:
- lib/algolia/models/recommend/params_consequence.rb
Overview
Filter or boost recommendations matching a facet filter.
Instance Attribute Summary collapse
-
#automatic_facet_filters ⇒ Object
Filter recommendations that match or don’t match the same ‘facet:facet_value` combination as the viewed item.
-
#filters ⇒ Object
Filter expression to only include items that match the filter criteria in the response.
-
#optional_filters ⇒ Object
Filters to promote or demote records in the search results.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ParamsConsequence
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ ParamsConsequence
Initializes the object
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 49 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::ParamsConsequence` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::ParamsConsequence`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:automatic_facet_filters) if (value = attributes[:automatic_facet_filters]).is_a?(Array) self.automatic_facet_filters = value end end if attributes.key?(:filters) self.filters = attributes[:filters] end if attributes.key?(:optional_filters) if (value = attributes[:optional_filters]).is_a?(Array) self.optional_filters = value end end end |
Instance Attribute Details
#automatic_facet_filters ⇒ Object
Filter recommendations that match or don’t match the same ‘facet:facet_value` combination as the viewed item.
11 12 13 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 11 def automatic_facet_filters @automatic_facet_filters end |
#filters ⇒ Object
Filter expression to only include items that match the filter criteria in the response. You can use these filter expressions: - **Numeric filters.** ‘<facet> <op> <number>`, where `<op>` is one of `<`, `<=`, `=`, `!=`, `>`, `>=`. - Ranges. `<facet>:<lower> TO <upper>` where `<lower>` and `<upper>` are the lower and upper limits of the range (inclusive). - **Facet filters.** `<facet>:<value>` where `<facet>` is a facet attribute (case-sensitive) and `<value>` a facet value. - **Tag filters.** `_tags:<value>` or just `<value>` (case-sensitive). - **Boolean filters.** `<facet>: true | false`. You can combine filters with `AND`, `OR`, and `NOT` operators with the following restrictions: - You can only combine filters of the same type with `OR`. **Not supported:** `facet:value OR num > 3`. - You can’t use ‘NOT` with combinations of filters. **Not supported:** `NOT(facet:value OR facet:value)` - You can’t combine conjunctions (‘AND`) with `OR`. **Not supported:** `facet:value OR (facet:value AND facet:value)` Use quotes around your filters, if the facet attribute name or facet value has spaces, keywords (`OR`, `AND`, `NOT`), or quotes. If a facet attribute is an array, the filter matches if it matches at least one element of the array. For more information, see [Filters](www.algolia.com/doc/guides/managing-results/refine-results/filtering/).
14 15 16 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 14 def filters @filters end |
#optional_filters ⇒ Object
Filters to promote or demote records in the search results. Optional filters work like facet filters, but they don’t exclude records from the search results. Records that match the optional filter rank before records that don’t match. Matches with higher weights (‘<score=N>`) rank before matches with lower weights. If you’re using a negative filter ‘facet:-value`, matching records rank after records that don’t match.
17 18 19 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 17 def optional_filters @optional_filters end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 132 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Recommend.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
29 30 31 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 29 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
20 21 22 23 24 25 26 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 20 def self.attribute_map { :automatic_facet_filters => :automaticFacetFilters, :filters => :filters, :optional_filters => :optionalFilters } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 107 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
43 44 45 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 43 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
34 35 36 37 38 39 40 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 34 def self.types_mapping { :automatic_facet_filters => :'Array<AutoFacetFilter>', :filters => :String, :optional_filters => :'Array<String>' } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
83 84 85 86 87 88 89 90 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 83 def ==(other) return true if equal?(other) self.class == other.class && automatic_facet_filters == other.automatic_facet_filters && filters == other.filters && optional_filters == other.optional_filters end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 207 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
94 95 96 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 94 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
100 101 102 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 100 def hash [automatic_facet_filters, filters, optional_filters].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
179 180 181 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 179 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
183 184 185 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 183 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
173 174 175 |
# File 'lib/algolia/models/recommend/params_consequence.rb', line 173 def to_s to_hash.to_s end |