Class: Algolia::Recommend::PromoteObjectIDs
- Inherits:
-
Object
- Object
- Algolia::Recommend::PromoteObjectIDs
- Defined in:
- lib/algolia/models/recommend/promote_object_ids.rb
Overview
Records to promote.
Instance Attribute Summary collapse
-
#object_ids ⇒ Object
Unique identifiers of the records to promote.
-
#position ⇒ Object
The position to promote the records to.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PromoteObjectIDs
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ PromoteObjectIDs
Initializes the object
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 44 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::PromoteObjectIDs` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::PromoteObjectIDs`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:object_ids) if (value = attributes[:object_ids]).is_a?(Array) self.object_ids = value end else self.object_ids = nil end if attributes.key?(:position) self.position = attributes[:position] else self.position = nil end end |
Instance Attribute Details
#object_ids ⇒ Object
Unique identifiers of the records to promote.
11 12 13 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 11 def object_ids @object_ids end |
#position ⇒ Object
The position to promote the records to. If you pass objectIDs, the records are placed at this position as a group. For example, if you pronmote four objectIDs to position 0, the records take the first four positions.
14 15 16 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 14 def position @position end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 124 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Recommend.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
25 26 27 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 25 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
17 18 19 20 21 22 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 17 def self.attribute_map { :object_ids => :objectIDs, :position => :position } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 99 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_s] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
38 39 40 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 38 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
30 31 32 33 34 35 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 30 def self.types_mapping { :object_ids => :'Array<String>', :position => :Integer } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
76 77 78 79 80 81 82 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 76 def ==(other) return true if equal?(other) self.class == other.class && object_ids == other.object_ids && position == other.position end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 195 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
86 87 88 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 86 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
92 93 94 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 92 def hash [object_ids, position].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
171 172 173 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 171 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 177 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
165 166 167 |
# File 'lib/algolia/models/recommend/promote_object_ids.rb', line 165 def to_s to_hash.to_s end |