Class: Algolia::Recommend::RankingInfo

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/recommend/ranking_info.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RankingInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/algolia/models/recommend/ranking_info.rb', line 96

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::RankingInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::RankingInfo`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:filters)
    self.filters = attributes[:filters]
  else
    self.filters = nil
  end

  if attributes.key?(:first_matched_word)
    self.first_matched_word = attributes[:first_matched_word]
  else
    self.first_matched_word = nil
  end

  if attributes.key?(:geo_distance)
    self.geo_distance = attributes[:geo_distance]
  else
    self.geo_distance = nil
  end

  if attributes.key?(:geo_precision)
    self.geo_precision = attributes[:geo_precision]
  end

  if attributes.key?(:matched_geo_location)
    self.matched_geo_location = attributes[:matched_geo_location]
  end

  if attributes.key?(:personalization)
    self.personalization = attributes[:personalization]
  end

  if attributes.key?(:nb_exact_words)
    self.nb_exact_words = attributes[:nb_exact_words]
  else
    self.nb_exact_words = nil
  end

  if attributes.key?(:nb_typos)
    self.nb_typos = attributes[:nb_typos]
  else
    self.nb_typos = nil
  end

  if attributes.key?(:promoted)
    self.promoted = attributes[:promoted]
  else
    self.promoted = nil
  end

  if attributes.key?(:proximity_distance)
    self.proximity_distance = attributes[:proximity_distance]
  end

  if attributes.key?(:user_score)
    self.user_score = attributes[:user_score]
  else
    self.user_score = nil
  end

  if attributes.key?(:words)
    self.words = attributes[:words]
  else
    self.words = nil
  end

  if attributes.key?(:promoted_by_re_ranking)
    self.promoted_by_re_ranking = attributes[:promoted_by_re_ranking]
  end
end

Instance Attribute Details

#filtersObject

This field is reserved for advanced usage.



10
11
12
# File 'lib/algolia/models/recommend/ranking_info.rb', line 10

def filters
  @filters
end

#first_matched_wordObject

Position of the most important matched attribute in the attributes to index list.



13
14
15
# File 'lib/algolia/models/recommend/ranking_info.rb', line 13

def first_matched_word
  @first_matched_word
end

#geo_distanceObject

Distance between the geo location in the search query and the best matching geo location in the record, divided by the geo precision (in meters).



16
17
18
# File 'lib/algolia/models/recommend/ranking_info.rb', line 16

def geo_distance
  @geo_distance
end

#geo_precisionObject

Precision used when computing the geo distance, in meters.



19
20
21
# File 'lib/algolia/models/recommend/ranking_info.rb', line 19

def geo_precision
  @geo_precision
end

#matched_geo_locationObject

Returns the value of attribute matched_geo_location.



21
22
23
# File 'lib/algolia/models/recommend/ranking_info.rb', line 21

def matched_geo_location
  @matched_geo_location
end

#nb_exact_wordsObject

Number of exactly matched words.



26
27
28
# File 'lib/algolia/models/recommend/ranking_info.rb', line 26

def nb_exact_words
  @nb_exact_words
end

#nb_typosObject

Number of typos encountered when matching the record.



29
30
31
# File 'lib/algolia/models/recommend/ranking_info.rb', line 29

def nb_typos
  @nb_typos
end

#personalizationObject

Returns the value of attribute personalization.



23
24
25
# File 'lib/algolia/models/recommend/ranking_info.rb', line 23

def personalization
  @personalization
end

Present and set to true if a Rule promoted the hit.



32
33
34
# File 'lib/algolia/models/recommend/ranking_info.rb', line 32

def promoted
  @promoted
end

Wether the record are promoted by the re-ranking strategy.



44
45
46
# File 'lib/algolia/models/recommend/ranking_info.rb', line 44

def promoted_by_re_ranking
  @promoted_by_re_ranking
end

#proximity_distanceObject

When the query contains more than one word, the sum of the distances between matched words (in meters).



35
36
37
# File 'lib/algolia/models/recommend/ranking_info.rb', line 35

def proximity_distance
  @proximity_distance
end

#user_scoreObject

Custom ranking for the object, expressed as a single integer value.



38
39
40
# File 'lib/algolia/models/recommend/ranking_info.rb', line 38

def user_score
  @user_score
end

#wordsObject

Number of matched words, including prefixes and typos.



41
42
43
# File 'lib/algolia/models/recommend/ranking_info.rb', line 41

def words
  @words
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/algolia/models/recommend/ranking_info.rb', line 242

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Recommend.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/algolia/models/recommend/ranking_info.rb', line 66

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/algolia/models/recommend/ranking_info.rb', line 47

def self.attribute_map
  {
    :filters => :filters,
    :first_matched_word => :firstMatchedWord,
    :geo_distance => :geoDistance,
    :geo_precision => :geoPrecision,
    :matched_geo_location => :matchedGeoLocation,
    :personalization => :personalization,
    :nb_exact_words => :nbExactWords,
    :nb_typos => :nbTypos,
    :promoted => :promoted,
    :proximity_distance => :proximityDistance,
    :user_score => :userScore,
    :words => :words,
    :promoted_by_re_ranking => :promotedByReRanking
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/algolia/models/recommend/ranking_info.rb', line 217

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
# File 'lib/algolia/models/recommend/ranking_info.rb', line 90

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/algolia/models/recommend/ranking_info.rb', line 71

def self.types_mapping
  {
    :filters => :Integer,
    :first_matched_word => :Integer,
    :geo_distance => :Integer,
    :geo_precision => :Integer,
    :matched_geo_location => :MatchedGeoLocation,
    :personalization => :Personalization,
    :nb_exact_words => :Integer,
    :nb_typos => :Integer,
    :promoted => :Boolean,
    :proximity_distance => :Integer,
    :user_score => :Integer,
    :words => :Integer,
    :promoted_by_re_ranking => :Boolean
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/algolia/models/recommend/ranking_info.rb', line 182

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    filters == other.filters &&
    first_matched_word == other.first_matched_word &&
    geo_distance == other.geo_distance &&
    geo_precision == other.geo_precision &&
    matched_geo_location == other.matched_geo_location &&
    personalization == other.personalization &&
    nb_exact_words == other.nb_exact_words &&
    nb_typos == other.nb_typos &&
    promoted == other.promoted &&
    proximity_distance == other.proximity_distance &&
    user_score == other.user_score &&
    words == other.words &&
    promoted_by_re_ranking == other.promoted_by_re_ranking
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/algolia/models/recommend/ranking_info.rb', line 317

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


203
204
205
# File 'lib/algolia/models/recommend/ranking_info.rb', line 203

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



209
210
211
212
# File 'lib/algolia/models/recommend/ranking_info.rb', line 209

def hash
  [filters, first_matched_word, geo_distance, geo_precision, matched_geo_location, personalization, nb_exact_words, nb_typos, promoted, proximity_distance, user_score, words,
   promoted_by_re_ranking].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



289
290
291
# File 'lib/algolia/models/recommend/ranking_info.rb', line 289

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/algolia/models/recommend/ranking_info.rb', line 299

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*_args) ⇒ Object



293
294
295
# File 'lib/algolia/models/recommend/ranking_info.rb', line 293

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



283
284
285
# File 'lib/algolia/models/recommend/ranking_info.rb', line 283

def to_s
  to_hash.to_s
end