Class: Algolia::Recommend::RecommendHit

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/recommend/recommend_hit.rb

Overview

Recommend hit.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RecommendHit

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 64

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::RecommendHit` initialize method"
  end

  if attributes.key?(:object_id)
    self.object_id = attributes[:object_id]
  else
    self.object_id = nil
  end

  if attributes.key?(:_highlight_result)
    if (value = attributes[:_highlight_result]).is_a?(Hash)
      self._highlight_result = value
    end
  end

  if attributes.key?(:_snippet_result)
    if (value = attributes[:_snippet_result]).is_a?(Hash)
      self._snippet_result = value
    end
  end

  if attributes.key?(:_ranking_info)
    self._ranking_info = attributes[:_ranking_info]
  end

  if attributes.key?(:_distinct_seq_id)
    self._distinct_seq_id = attributes[:_distinct_seq_id]
  end

  if attributes.key?(:_score)
    self._score = attributes[:_score]
  else
    self._score = nil
  end

  # add extra attribute to additional_properties
  self.additional_properties ||= {}
  self.additional_properties.merge!(attributes.reject { |k, _| self.class.attribute_map.key?(k.to_sym) })
end

Instance Attribute Details

#_distinct_seq_idObject

Returns the value of attribute _distinct_seq_id.



21
22
23
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 21

def _distinct_seq_id
  @_distinct_seq_id
end

#_highlight_resultObject

Surround words that match the query with HTML tags for highlighting.



14
15
16
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 14

def _highlight_result
  @_highlight_result
end

#_ranking_infoObject

Returns the value of attribute _ranking_info.



19
20
21
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 19

def _ranking_info
  @_ranking_info
end

#_scoreObject

Recommendation score.



24
25
26
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 24

def _score
  @_score
end

#_snippet_resultObject

Snippets that show the context around a matching search query.



17
18
19
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 17

def _snippet_result
  @_snippet_result
end

#additional_propertiesObject

Returns the value of attribute additional_properties.



26
27
28
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 26

def additional_properties
  @additional_properties
end

#object_idObject

Unique record identifier.



11
12
13
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 11

def object_id
  @object_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 185

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Recommend.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



41
42
43
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 41

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
38
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 29

def self.attribute_map
  {
    :object_id => :objectID,
    :_highlight_result => :_highlightResult,
    :_snippet_result => :_snippetResult,
    :_ranking_info => :_rankingInfo,
    :_distinct_seq_id => :_distinctSeqID,
    :_score => :_score
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 153

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end

  # merge additional_properties into transformed_hash
  unless @additional_properties.nil?
    @additional_properties.each_pair do |k, v|
      transformed_hash[k.to_sym] = v
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



58
59
60
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 58

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



46
47
48
49
50
51
52
53
54
55
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 46

def self.types_mapping
  {
    :object_id => :String,
    :_highlight_result => :'Hash<String, HighlightResult>',
    :_snippet_result => :'Hash<String, SnippetResult>',
    :_ranking_info => :RankingInfo,
    :_distinct_seq_id => :Integer,
    :_score => :Float
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



126
127
128
129
130
131
132
133
134
135
136
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 126

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    object_id == other.object_id &&
    _highlight_result == other._highlight_result &&
    _snippet_result == other._snippet_result &&
    _ranking_info == other._ranking_info &&
    _distinct_seq_id == other._distinct_seq_id &&
    _score == other._score
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 265

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


140
141
142
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 140

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



146
147
148
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 146

def hash
  [object_id, _highlight_result, _snippet_result, _ranking_info, _distinct_seq_id, _score].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



232
233
234
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 232

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 242

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end

  # also add attributes from additional_properties to hash
  self.additional_properties&.each_pair do |k, v|
    hash[k.to_sym] = _to_hash(v)
  end
  hash
end

#to_json(*_args) ⇒ Object



236
237
238
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 236

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



226
227
228
# File 'lib/algolia/models/recommend/recommend_hit.rb', line 226

def to_s
  to_hash.to_s
end