Method: Algolia::Recommend::RelatedQuery#max_recommendations
- Defined in:
- lib/algolia/models/recommend/related_query.rb
#max_recommendations ⇒ Object
Maximum number of recommendations to retrieve. By default, all recommendations are returned and no fallback request is made. Depending on the available recommendations and the other request parameters, the actual number of recommendations may be lower than this value.
18 19 20 |
# File 'lib/algolia/models/recommend/related_query.rb', line 18 def max_recommendations @max_recommendations end |