Class: Algolia::Recommend::SearchRecommendRulesParams
- Inherits:
-
Object
- Object
- Algolia::Recommend::SearchRecommendRulesParams
- Defined in:
- lib/algolia/models/recommend/search_recommend_rules_params.rb
Overview
Recommend rules parameters.
Instance Attribute Summary collapse
-
#context ⇒ Object
Only search for rules with matching context.
-
#enabled ⇒ Object
Whether to only show rules where the value of their ‘enabled` property matches this parameter.
-
#facets ⇒ Object
Include facets and facet values in the response.
-
#filters ⇒ Object
Filter expression.
-
#hits_per_page ⇒ Object
Maximum number of hits per page.
-
#max_values_per_facet ⇒ Object
Maximum number of values to return for each facet.
-
#page ⇒ Object
Requested page of the API response.
-
#query ⇒ Object
Search query.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SearchRecommendRulesParams
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SearchRecommendRulesParams
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 74 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::SearchRecommendRulesParams` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::SearchRecommendRulesParams`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:query) self.query = attributes[:query] end if attributes.key?(:context) self.context = attributes[:context] end if attributes.key?(:page) self.page = attributes[:page] end if attributes.key?(:hits_per_page) self.hits_per_page = attributes[:hits_per_page] end if attributes.key?(:enabled) self.enabled = attributes[:enabled] end if attributes.key?(:filters) self.filters = attributes[:filters] end if attributes.key?(:facets) if (value = attributes[:facets]).is_a?(Array) self.facets = value end end if attributes.key?(:max_values_per_facet) self.max_values_per_facet = attributes[:max_values_per_facet] end end |
Instance Attribute Details
#context ⇒ Object
Only search for rules with matching context.
14 15 16 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 14 def context @context end |
#enabled ⇒ Object
Whether to only show rules where the value of their ‘enabled` property matches this parameter. If absent, show all rules, regardless of their `enabled` property.
23 24 25 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 23 def enabled @enabled end |
#facets ⇒ Object
Include facets and facet values in the response. Use ‘[’*‘]` to include all facets.
29 30 31 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 29 def facets @facets end |
#filters ⇒ Object
Filter expression. This only searches for rules matching the filter expression.
26 27 28 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 26 def filters @filters end |
#hits_per_page ⇒ Object
Maximum number of hits per page.
20 21 22 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 20 def hits_per_page @hits_per_page end |
#max_values_per_facet ⇒ Object
Maximum number of values to return for each facet.
32 33 34 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 32 def max_values_per_facet @max_values_per_facet end |
#page ⇒ Object
Requested page of the API response.
17 18 19 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 17 def page @page end |
#query ⇒ Object
Search query.
11 12 13 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 11 def query @query end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 230 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Recommend.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 49 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 35 def self.attribute_map { :query => :query, :context => :context, :page => :page, :hits_per_page => :hitsPerPage, :enabled => :enabled, :filters => :filters, :facets => :facets, :max_values_per_facet => :maxValuesPerFacet } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 205 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
68 69 70 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 68 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 54 def self.types_mapping { :query => :String, :context => :String, :page => :Integer, :hits_per_page => :Integer, :enabled => :Boolean, :filters => :String, :facets => :'Array<String>', :max_values_per_facet => :Integer } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 176 def ==(other) return true if equal?(other) self.class == other.class && query == other.query && context == other.context && page == other.page && hits_per_page == other.hits_per_page && enabled == other.enabled && filters == other.filters && facets == other.facets && max_values_per_facet == other.max_values_per_facet end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 305 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
192 193 194 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 192 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
198 199 200 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 198 def hash [query, context, page, hits_per_page, enabled, filters, facets, max_values_per_facet].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
277 278 279 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 277 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 287 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
281 282 283 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 281 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
271 272 273 |
# File 'lib/algolia/models/recommend/search_recommend_rules_params.rb', line 271 def to_s to_hash.to_s end |