Class: Algolia::Search::ApiKey

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/search/api_key.rb

Overview

API key object.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApiKey

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/algolia/models/search/api_key.rb', line 74

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::ApiKey` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::ApiKey`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:acl)
    if (value = attributes[:acl]).is_a?(Array)
      self.acl = value
    end
  else
    self.acl = nil
  end

  if attributes.key?(:description)
    self.description = attributes[:description]
  end

  if attributes.key?(:indexes)
    if (value = attributes[:indexes]).is_a?(Array)
      self.indexes = value
    end
  end

  if attributes.key?(:max_hits_per_query)
    self.max_hits_per_query = attributes[:max_hits_per_query]
  end

  if attributes.key?(:max_queries_per_ip_per_hour)
    self.max_queries_per_ip_per_hour = attributes[:max_queries_per_ip_per_hour]
  end

  if attributes.key?(:query_parameters)
    self.query_parameters = attributes[:query_parameters]
  end

  if attributes.key?(:referers)
    if (value = attributes[:referers]).is_a?(Array)
      self.referers = value
    end
  end

  if attributes.key?(:validity)
    self.validity = attributes[:validity]
  end
end

Instance Attribute Details

#aclObject



11
12
13
# File 'lib/algolia/models/search/api_key.rb', line 11

def acl
  @acl
end

#descriptionObject

Description of an API key for you and your team members.



14
15
16
# File 'lib/algolia/models/search/api_key.rb', line 14

def description
  @description
end

#indexesObject

Restricts this API key to a list of indices or index patterns. If the list is empty, all indices are allowed. Specify either an exact index name or a pattern with a leading or trailing wildcard character (or both). For example: - ‘dev_*` matches all indices starting with "dev_" - `*_dev` matches all indices ending with "_dev" - `products` matches all indices containing "products".



17
18
19
# File 'lib/algolia/models/search/api_key.rb', line 17

def indexes
  @indexes
end

#max_hits_per_queryObject

Maximum number of hits this API key can retrieve in one query. If zero, no limit is enforced. > Note: Use this parameter to protect you from third-party attempts to retrieve your entire content by massively querying the index.



20
21
22
# File 'lib/algolia/models/search/api_key.rb', line 20

def max_hits_per_query
  @max_hits_per_query
end

#max_queries_per_ip_per_hourObject

Maximum number of API calls per hour allowed from a given IP address or [user token](www.algolia.com/doc/guides/sending-events/concepts/usertoken/). Each time an API call is performed with this key, a check is performed. If there were more than the specified number of calls within the last hour, the API returns an error with the status code ‘429` (Too Many Requests). > Note: Use this parameter to protect you from third-party attempts to retrieve your entire content by massively querying the index.



23
24
25
# File 'lib/algolia/models/search/api_key.rb', line 23

def max_queries_per_ip_per_hour
  @max_queries_per_ip_per_hour
end

#query_parametersObject

Force some [query parameters](www.algolia.com/doc/api-reference/api-parameters/) to be applied for each query made with this API key. It’s a URL-encoded query string.



26
27
28
# File 'lib/algolia/models/search/api_key.rb', line 26

def query_parameters
  @query_parameters
end

#referersObject

Restrict this API key to specific [referrers](www.algolia.com/doc/guides/security/api-keys/in-depth/api-key-restrictions/#http-referrers). If empty, all referrers are allowed. For example: - ‘algolia.com/*` matches all referrers starting with "algolia.com/" - `*.algolia.com` matches all referrers ending with ".algolia.com" - `algolia.com` allows everything in the domain "algolia.com".



29
30
31
# File 'lib/algolia/models/search/api_key.rb', line 29

def referers
  @referers
end

#validityObject

Validity duration of a key (in seconds). The key will automatically be removed after this time has expired. The default value of 0 never expires. Short-lived API keys are useful to grant temporary access to your data. For example, in mobile apps, you can’t [control when users update your app](www.algolia.com/doc/guides/security/security-best-practices/#use-secured-api-keys-in-mobile-apps). So instead of encoding keys into your app as you would for a web app, you should dynamically fetch them from your mobile app’s backend.



32
33
34
# File 'lib/algolia/models/search/api_key.rb', line 32

def validity
  @validity
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/algolia/models/search/api_key.rb', line 186

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Search.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/algolia/models/search/api_key.rb', line 49

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/algolia/models/search/api_key.rb', line 35

def self.attribute_map
  {
    :acl => :acl,
    :description => :description,
    :indexes => :indexes,
    :max_hits_per_query => :maxHitsPerQuery,
    :max_queries_per_ip_per_hour => :maxQueriesPerIPPerHour,
    :query_parameters => :queryParameters,
    :referers => :referers,
    :validity => :validity
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/algolia/models/search/api_key.rb', line 161

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



68
69
70
# File 'lib/algolia/models/search/api_key.rb', line 68

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/algolia/models/search/api_key.rb', line 54

def self.types_mapping
  {
    :acl => :'Array<Acl>',
    :description => :String,
    :indexes => :'Array<String>',
    :max_hits_per_query => :Integer,
    :max_queries_per_ip_per_hour => :Integer,
    :query_parameters => :String,
    :referers => :'Array<String>',
    :validity => :Integer
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/algolia/models/search/api_key.rb', line 132

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    acl == other.acl &&
    description == other.description &&
    indexes == other.indexes &&
    max_hits_per_query == other.max_hits_per_query &&
    max_queries_per_ip_per_hour == other.max_queries_per_ip_per_hour &&
    query_parameters == other.query_parameters &&
    referers == other.referers &&
    validity == other.validity
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/algolia/models/search/api_key.rb', line 261

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


148
149
150
# File 'lib/algolia/models/search/api_key.rb', line 148

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



154
155
156
# File 'lib/algolia/models/search/api_key.rb', line 154

def hash
  [acl, description, indexes, max_hits_per_query, max_queries_per_ip_per_hour, query_parameters, referers, validity].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
# File 'lib/algolia/models/search/api_key.rb', line 233

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/algolia/models/search/api_key.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*_args) ⇒ Object



237
238
239
# File 'lib/algolia/models/search/api_key.rb', line 237

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



227
228
229
# File 'lib/algolia/models/search/api_key.rb', line 227

def to_s
  to_hash.to_s
end