Class: Algolia::Search::BaseSearchResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/search/base_search_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BaseSearchResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/algolia/models/search/base_search_response.rb', line 154

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise(
      ArgumentError,
      "The input argument (attributes) must be a hash in `Algolia::BaseSearchResponse` initialize method"
    )
  end

  if attributes.key?(:ab_test_id)
    self.ab_test_id = attributes[:ab_test_id]
  end

  if attributes.key?(:ab_test_variant_id)
    self.ab_test_variant_id = attributes[:ab_test_variant_id]
  end

  if attributes.key?(:around_lat_lng)
    self.around_lat_lng = attributes[:around_lat_lng]
  end

  if attributes.key?(:automatic_radius)
    self.automatic_radius = attributes[:automatic_radius]
  end

  if attributes.key?(:exhaustive)
    self.exhaustive = attributes[:exhaustive]
  end

  if attributes.key?(:exhaustive_facets_count)
    self.exhaustive_facets_count = attributes[:exhaustive_facets_count]
  end

  if attributes.key?(:exhaustive_nb_hits)
    self.exhaustive_nb_hits = attributes[:exhaustive_nb_hits]
  end

  if attributes.key?(:exhaustive_typo)
    self.exhaustive_typo = attributes[:exhaustive_typo]
  end

  if attributes.key?(:facets)
    if (value = attributes[:facets]).is_a?(Hash)
      self.facets = value
    end
  end

  if attributes.key?(:facets_stats)
    if (value = attributes[:facets_stats]).is_a?(Hash)
      self.facets_stats = value
    end
  end

  if attributes.key?(:index)
    self.index = attributes[:index]
  end

  if attributes.key?(:index_used)
    self.index_used = attributes[:index_used]
  end

  if attributes.key?(:message)
    self.message = attributes[:message]
  end

  if attributes.key?(:nb_sorted_hits)
    self.nb_sorted_hits = attributes[:nb_sorted_hits]
  end

  if attributes.key?(:parsed_query)
    self.parsed_query = attributes[:parsed_query]
  end

  if attributes.key?(:processing_time_ms)
    self.processing_time_ms = attributes[:processing_time_ms]
  else
    self.processing_time_ms = nil
  end

  if attributes.key?(:processing_timings_ms)
    self.processing_timings_ms = attributes[:processing_timings_ms]
  end

  if attributes.key?(:query_after_removal)
    self.query_after_removal = attributes[:query_after_removal]
  end

  if attributes.key?(:redirect)
    self.redirect = attributes[:redirect]
  end

  if attributes.key?(:rendering_content)
    self.rendering_content = attributes[:rendering_content]
  end

  if attributes.key?(:server_time_ms)
    self.server_time_ms = attributes[:server_time_ms]
  end

  if attributes.key?(:server_used)
    self.server_used = attributes[:server_used]
  end

  if attributes.key?(:user_data)
    self.user_data = attributes[:user_data]
  end

  if attributes.key?(:query_id)
    self.query_id = attributes[:query_id]
  end

  # add extra attribute to additional_properties
  self.additional_properties ||= {}
  self.additional_properties.merge!(attributes.reject { |k, _| self.class.attribute_map.key?(k.to_sym) })
end

Instance Attribute Details

#ab_test_idObject

A/B test ID. This is only included in the response for indices that are part of an A/B test.



10
11
12
# File 'lib/algolia/models/search/base_search_response.rb', line 10

def ab_test_id
  @ab_test_id
end

#ab_test_variant_idObject

Variant ID. This is only included in the response for indices that are part of an A/B test.



13
14
15
# File 'lib/algolia/models/search/base_search_response.rb', line 13

def ab_test_variant_id
  @ab_test_variant_id
end

#additional_propertiesObject

Returns the value of attribute additional_properties.



78
79
80
# File 'lib/algolia/models/search/base_search_response.rb', line 78

def additional_properties
  @additional_properties
end

#around_lat_lngObject

Computed geographical location.



16
17
18
# File 'lib/algolia/models/search/base_search_response.rb', line 16

def around_lat_lng
  @around_lat_lng
end

#automatic_radiusObject

Distance from a central coordinate provided by ‘aroundLatLng`.



19
20
21
# File 'lib/algolia/models/search/base_search_response.rb', line 19

def automatic_radius
  @automatic_radius
end

#exhaustiveObject

Returns the value of attribute exhaustive.



21
22
23
# File 'lib/algolia/models/search/base_search_response.rb', line 21

def exhaustive
  @exhaustive
end

#exhaustive_facets_countObject

See the ‘facetsCount` field of the `exhaustive` object in the response.



24
25
26
# File 'lib/algolia/models/search/base_search_response.rb', line 24

def exhaustive_facets_count
  @exhaustive_facets_count
end

#exhaustive_nb_hitsObject

See the ‘nbHits` field of the `exhaustive` object in the response.



27
28
29
# File 'lib/algolia/models/search/base_search_response.rb', line 27

def exhaustive_nb_hits
  @exhaustive_nb_hits
end

#exhaustive_typoObject

See the ‘typo` field of the `exhaustive` object in the response.



30
31
32
# File 'lib/algolia/models/search/base_search_response.rb', line 30

def exhaustive_typo
  @exhaustive_typo
end

#facetsObject

Facet counts.



33
34
35
# File 'lib/algolia/models/search/base_search_response.rb', line 33

def facets
  @facets
end

#facets_statsObject

Statistics for numerical facets.



36
37
38
# File 'lib/algolia/models/search/base_search_response.rb', line 36

def facets_stats
  @facets_stats
end

#indexObject

Index name used for the query.



39
40
41
# File 'lib/algolia/models/search/base_search_response.rb', line 39

def index
  @index
end

#index_usedObject

Index name used for the query. During A/B testing, the targeted index isn’t always the index used by the query.



42
43
44
# File 'lib/algolia/models/search/base_search_response.rb', line 42

def index_used
  @index_used
end

#messageObject

Warnings about the query.



45
46
47
# File 'lib/algolia/models/search/base_search_response.rb', line 45

def message
  @message
end

#nb_sorted_hitsObject

Number of hits selected and sorted by the relevant sort algorithm.



48
49
50
# File 'lib/algolia/models/search/base_search_response.rb', line 48

def nb_sorted_hits
  @nb_sorted_hits
end

#parsed_queryObject



51
52
53
# File 'lib/algolia/models/search/base_search_response.rb', line 51

def parsed_query
  @parsed_query
end

#processing_time_msObject

Time the server took to process the request, in milliseconds.



54
55
56
# File 'lib/algolia/models/search/base_search_response.rb', line 54

def processing_time_ms
  @processing_time_ms
end

#processing_timings_msObject

Experimental. List of processing steps and their times, in milliseconds. You can use this list to investigate performance issues.



57
58
59
# File 'lib/algolia/models/search/base_search_response.rb', line 57

def processing_timings_ms
  @processing_timings_ms
end

#query_after_removalObject

Markup text indicating which parts of the original query have been removed to retrieve a non-empty result set.



60
61
62
# File 'lib/algolia/models/search/base_search_response.rb', line 60

def query_after_removal
  @query_after_removal
end

#query_idObject

Unique identifier for the query. This is used for [click analytics](www.algolia.com/doc/guides/analytics/click-analytics/).



76
77
78
# File 'lib/algolia/models/search/base_search_response.rb', line 76

def query_id
  @query_id
end

#redirectObject

Returns the value of attribute redirect.



62
63
64
# File 'lib/algolia/models/search/base_search_response.rb', line 62

def redirect
  @redirect
end

#rendering_contentObject

Returns the value of attribute rendering_content.



64
65
66
# File 'lib/algolia/models/search/base_search_response.rb', line 64

def rendering_content
  @rendering_content
end

#server_time_msObject

Time the server took to process the request, in milliseconds.



67
68
69
# File 'lib/algolia/models/search/base_search_response.rb', line 67

def server_time_ms
  @server_time_ms
end

#server_usedObject

Host name of the server that processed the request.



70
71
72
# File 'lib/algolia/models/search/base_search_response.rb', line 70

def server_used
  @server_used
end

#user_dataObject

An object with custom data. You can store up to 32kB as custom data.



73
74
75
# File 'lib/algolia/models/search/base_search_response.rb', line 73

def user_data
  @user_data
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/algolia/models/search/base_search_response.rb', line 398

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end

  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
    # model
  else
    # models (e.g. Pet) or oneOf
    klass = Algolia::Search.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass
      .build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



111
112
113
# File 'lib/algolia/models/search/base_search_response.rb', line 111

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/algolia/models/search/base_search_response.rb', line 81

def self.attribute_map
  {
    :ab_test_id => :abTestID,
    :ab_test_variant_id => :abTestVariantID,
    :around_lat_lng => :aroundLatLng,
    :automatic_radius => :automaticRadius,
    :exhaustive => :exhaustive,
    :exhaustive_facets_count => :exhaustiveFacetsCount,
    :exhaustive_nb_hits => :exhaustiveNbHits,
    :exhaustive_typo => :exhaustiveTypo,
    :facets => :facets,
    :facets_stats => :facets_stats,
    :index => :index,
    :index_used => :indexUsed,
    :message => :message,
    :nb_sorted_hits => :nbSortedHits,
    :parsed_query => :parsedQuery,
    :processing_time_ms => :processingTimeMS,
    :processing_timings_ms => :processingTimingsMS,
    :query_after_removal => :queryAfterRemoval,
    :redirect => :redirect,
    :rendering_content => :renderingContent,
    :server_time_ms => :serverTimeMS,
    :server_used => :serverUsed,
    :user_data => :userData,
    :query_id => :queryID
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/algolia/models/search/base_search_response.rb', line 369

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v|
          _deserialize(::Regexp.last_match(1), v)
        }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end

  # add extra attribute to transformed_hash
  transformed_hash.merge!(attributes.reject { |k, _| attribute_map.key?(k.to_sym) })
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



146
147
148
149
150
# File 'lib/algolia/models/search/base_search_response.rb', line 146

def self.openapi_nullable
  Set.new(
    []
  )
end

.types_mappingObject

Attribute type mapping.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/algolia/models/search/base_search_response.rb', line 116

def self.types_mapping
  {
    :ab_test_id => :"Integer",
    :ab_test_variant_id => :"Integer",
    :around_lat_lng => :"String",
    :automatic_radius => :"String",
    :exhaustive => :"Exhaustive",
    :exhaustive_facets_count => :"Boolean",
    :exhaustive_nb_hits => :"Boolean",
    :exhaustive_typo => :"Boolean",
    :facets => :"Hash<String, Hash<String, Integer>>",
    :facets_stats => :"Hash<String, FacetsStats>",
    :index => :"String",
    :index_used => :"String",
    :message => :"String",
    :nb_sorted_hits => :"Integer",
    :parsed_query => :"String",
    :processing_time_ms => :"Integer",
    :processing_timings_ms => :"Object",
    :query_after_removal => :"String",
    :redirect => :"Redirect",
    :rendering_content => :"RenderingContent",
    :server_time_ms => :"Integer",
    :server_used => :"String",
    :user_data => :"Object",
    :query_id => :"String"
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/algolia/models/search/base_search_response.rb', line 300

def ==(other)
  return true if self.equal?(other)
  self.class == other.class &&
    ab_test_id == other.ab_test_id &&
    ab_test_variant_id == other.ab_test_variant_id &&
    around_lat_lng == other.around_lat_lng &&
    automatic_radius == other.automatic_radius &&
    exhaustive == other.exhaustive &&
    exhaustive_facets_count == other.exhaustive_facets_count &&
    exhaustive_nb_hits == other.exhaustive_nb_hits &&
    exhaustive_typo == other.exhaustive_typo &&
    facets == other.facets &&
    facets_stats == other.facets_stats &&
    index == other.index &&
    index_used == other.index_used &&
    message == other.message &&
    nb_sorted_hits == other.nb_sorted_hits &&
    parsed_query == other.parsed_query &&
    processing_time_ms == other.processing_time_ms &&
    processing_timings_ms == other.processing_timings_ms &&
    query_after_removal == other.query_after_removal &&
    redirect == other.redirect &&
    rendering_content == other.rendering_content &&
    server_time_ms == other.server_time_ms &&
    server_used == other.server_used &&
    user_data == other.user_data &&
    query_id == other.query_id
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



482
483
484
485
486
487
488
489
490
491
492
493
494
# File 'lib/algolia/models/search/base_search_response.rb', line 482

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to?(:to_hash)
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


331
332
333
# File 'lib/algolia/models/search/base_search_response.rb', line 331

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/algolia/models/search/base_search_response.rb', line 337

def hash
  [
    ab_test_id,
    ab_test_variant_id,
    around_lat_lng,
    automatic_radius,
    exhaustive,
    exhaustive_facets_count,
    exhaustive_nb_hits,
    exhaustive_typo,
    facets,
    facets_stats,
    index,
    index_used,
    message,
    nb_sorted_hits,
    parsed_query,
    processing_time_ms,
    processing_timings_ms,
    query_after_removal,
    redirect,
    rendering_content,
    server_time_ms,
    server_used,
    user_data,
    query_id
  ].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



448
449
450
# File 'lib/algolia/models/search/base_search_response.rb', line 448

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/algolia/models/search/base_search_response.rb', line 458

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end

  # also add attributes from additional_properties to hash
  self.additional_properties&.each_pair do |k, v|
    hash[k.to_sym] = _to_hash(v)
  end

  hash
end

#to_json(*_args) ⇒ Object



452
453
454
# File 'lib/algolia/models/search/base_search_response.rb', line 452

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



442
443
444
# File 'lib/algolia/models/search/base_search_response.rb', line 442

def to_s
  to_hash.to_s
end