Class: Algolia::Search::BrowsePagination
- Inherits:
-
Object
- Object
- Algolia::Search::BrowsePagination
- Defined in:
- lib/algolia/models/search/browse_pagination.rb
Instance Attribute Summary collapse
-
#hits_per_page ⇒ Object
Number of hits per page.
-
#nb_hits ⇒ Object
Number of results (hits).
-
#nb_pages ⇒ Object
Number of pages of results.
-
#page ⇒ Object
Page of search results to retrieve.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BrowsePagination
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ BrowsePagination
Initializes the object
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 55 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise( ArgumentError, "The input argument (attributes) must be a hash in `Algolia::BrowsePagination` initialize method" ) end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) raise( ArgumentError, "`#{k}` is not a valid attribute in `Algolia::BrowsePagination`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect ) end h[k.to_sym] = v } if attributes.key?(:page) self.page = attributes[:page] end if attributes.key?(:nb_hits) self.nb_hits = attributes[:nb_hits] end if attributes.key?(:nb_pages) self.nb_pages = attributes[:nb_pages] end if attributes.key?(:hits_per_page) self.hits_per_page = attributes[:hits_per_page] end end |
Instance Attribute Details
#hits_per_page ⇒ Object
Number of hits per page.
19 20 21 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 19 def hits_per_page @hits_per_page end |
#nb_hits ⇒ Object
Number of results (hits).
13 14 15 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 13 def nb_hits @nb_hits end |
#nb_pages ⇒ Object
Number of pages of results.
16 17 18 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 16 def nb_pages @nb_pages end |
#page ⇒ Object
Page of search results to retrieve.
10 11 12 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 10 def page @page end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 178 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end # model else # models (e.g. Pet) or oneOf klass = Algolia::Search.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass .build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
32 33 34 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 32 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
22 23 24 25 26 27 28 29 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 22 def self.attribute_map { :page => :page, :nb_hits => :nbHits, :nb_pages => :nbPages, :hits_per_page => :hitsPerPage } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 151 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
47 48 49 50 51 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 47 def self.openapi_nullable Set.new( [] ) end |
.types_mapping ⇒ Object
Attribute type mapping.
37 38 39 40 41 42 43 44 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 37 def self.types_mapping { :page => :"Integer", :nb_hits => :"Integer", :nb_pages => :"Integer", :hits_per_page => :"Integer" } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 133 134 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 127 def ==(other) return true if self.equal?(other) self.class == other.class && page == other.page && nb_hits == other.nb_hits && nb_pages == other.nb_pages && hits_per_page == other.hits_per_page end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 257 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to?(:to_hash) value.to_hash else value end end |
#eql?(other) ⇒ Boolean
138 139 140 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 138 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 144 def hash [page, nb_hits, nb_pages, hits_per_page].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
228 229 230 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 228 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 238 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
232 233 234 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 232 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
222 223 224 |
# File 'lib/algolia/models/search/browse_pagination.rb', line 222 def to_s to_hash.to_s end |