Class: Algolia::Search::BrowseParamsObject

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/search/browse_params_object.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BrowseParamsObject

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
# File 'lib/algolia/models/search/browse_params_object.rb', line 443

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::BrowseParamsObject` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::BrowseParamsObject`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:query)
    self.query = attributes[:query]
  end

  if attributes.key?(:similar_query)
    self.similar_query = attributes[:similar_query]
  end

  if attributes.key?(:filters)
    self.filters = attributes[:filters]
  end

  if attributes.key?(:facet_filters)
    self.facet_filters = attributes[:facet_filters]
  end

  if attributes.key?(:optional_filters)
    self.optional_filters = attributes[:optional_filters]
  end

  if attributes.key?(:numeric_filters)
    self.numeric_filters = attributes[:numeric_filters]
  end

  if attributes.key?(:tag_filters)
    self.tag_filters = attributes[:tag_filters]
  end

  if attributes.key?(:sum_or_filters_scores)
    self.sum_or_filters_scores = attributes[:sum_or_filters_scores]
  end

  if attributes.key?(:restrict_searchable_attributes)
    if (value = attributes[:restrict_searchable_attributes]).is_a?(Array)
      self.restrict_searchable_attributes = value
    end
  end

  if attributes.key?(:facets)
    if (value = attributes[:facets]).is_a?(Array)
      self.facets = value
    end
  end

  if attributes.key?(:faceting_after_distinct)
    self.faceting_after_distinct = attributes[:faceting_after_distinct]
  end

  if attributes.key?(:page)
    self.page = attributes[:page]
  end

  if attributes.key?(:offset)
    self.offset = attributes[:offset]
  end

  if attributes.key?(:length)
    self.length = attributes[:length]
  end

  if attributes.key?(:around_lat_lng)
    self.around_lat_lng = attributes[:around_lat_lng]
  end

  if attributes.key?(:around_lat_lng_via_ip)
    self.around_lat_lng_via_ip = attributes[:around_lat_lng_via_ip]
  end

  if attributes.key?(:around_radius)
    self.around_radius = attributes[:around_radius]
  end

  if attributes.key?(:around_precision)
    self.around_precision = attributes[:around_precision]
  end

  if attributes.key?(:minimum_around_radius)
    self.minimum_around_radius = attributes[:minimum_around_radius]
  end

  if attributes.key?(:inside_bounding_box)
    if (value = attributes[:inside_bounding_box]).is_a?(Array)
      self.inside_bounding_box = value
    end
  end

  if attributes.key?(:inside_polygon)
    if (value = attributes[:inside_polygon]).is_a?(Array)
      self.inside_polygon = value
    end
  end

  if attributes.key?(:natural_languages)
    if (value = attributes[:natural_languages]).is_a?(Array)
      self.natural_languages = value
    end
  end

  if attributes.key?(:rule_contexts)
    if (value = attributes[:rule_contexts]).is_a?(Array)
      self.rule_contexts = value
    end
  end

  if attributes.key?(:personalization_impact)
    self.personalization_impact = attributes[:personalization_impact]
  end

  if attributes.key?(:user_token)
    self.user_token = attributes[:user_token]
  end

  if attributes.key?(:get_ranking_info)
    self.get_ranking_info = attributes[:get_ranking_info]
  end

  if attributes.key?(:explain)
    if (value = attributes[:explain]).is_a?(Array)
      self.explain = value
    end
  end

  if attributes.key?(:synonyms)
    self.synonyms = attributes[:synonyms]
  end

  if attributes.key?(:click_analytics)
    self.click_analytics = attributes[:click_analytics]
  end

  if attributes.key?(:analytics)
    self.analytics = attributes[:analytics]
  end

  if attributes.key?(:analytics_tags)
    if (value = attributes[:analytics_tags]).is_a?(Array)
      self.analytics_tags = value
    end
  end

  if attributes.key?(:percentile_computation)
    self.percentile_computation = attributes[:percentile_computation]
  end

  if attributes.key?(:enable_ab_test)
    self.enable_ab_test = attributes[:enable_ab_test]
  end

  if attributes.key?(:attributes_for_faceting)
    if (value = attributes[:attributes_for_faceting]).is_a?(Array)
      self.attributes_for_faceting = value
    end
  end

  if attributes.key?(:attributes_to_retrieve)
    if (value = attributes[:attributes_to_retrieve]).is_a?(Array)
      self.attributes_to_retrieve = value
    end
  end

  if attributes.key?(:ranking)
    if (value = attributes[:ranking]).is_a?(Array)
      self.ranking = value
    end
  end

  if attributes.key?(:custom_ranking)
    if (value = attributes[:custom_ranking]).is_a?(Array)
      self.custom_ranking = value
    end
  end

  if attributes.key?(:relevancy_strictness)
    self.relevancy_strictness = attributes[:relevancy_strictness]
  end

  if attributes.key?(:attributes_to_highlight)
    if (value = attributes[:attributes_to_highlight]).is_a?(Array)
      self.attributes_to_highlight = value
    end
  end

  if attributes.key?(:attributes_to_snippet)
    if (value = attributes[:attributes_to_snippet]).is_a?(Array)
      self.attributes_to_snippet = value
    end
  end

  if attributes.key?(:highlight_pre_tag)
    self.highlight_pre_tag = attributes[:highlight_pre_tag]
  end

  if attributes.key?(:highlight_post_tag)
    self. = attributes[:highlight_post_tag]
  end

  if attributes.key?(:snippet_ellipsis_text)
    self.snippet_ellipsis_text = attributes[:snippet_ellipsis_text]
  end

  if attributes.key?(:restrict_highlight_and_snippet_arrays)
    self.restrict_highlight_and_snippet_arrays = attributes[:restrict_highlight_and_snippet_arrays]
  end

  if attributes.key?(:hits_per_page)
    self.hits_per_page = attributes[:hits_per_page]
  end

  if attributes.key?(:min_word_sizefor1_typo)
    self.min_word_sizefor1_typo = attributes[:min_word_sizefor1_typo]
  end

  if attributes.key?(:min_word_sizefor2_typos)
    self.min_word_sizefor2_typos = attributes[:min_word_sizefor2_typos]
  end

  if attributes.key?(:typo_tolerance)
    self.typo_tolerance = attributes[:typo_tolerance]
  end

  if attributes.key?(:allow_typos_on_numeric_tokens)
    self.allow_typos_on_numeric_tokens = attributes[:allow_typos_on_numeric_tokens]
  end

  if attributes.key?(:disable_typo_tolerance_on_attributes)
    if (value = attributes[:disable_typo_tolerance_on_attributes]).is_a?(Array)
      self.disable_typo_tolerance_on_attributes = value
    end
  end

  if attributes.key?(:ignore_plurals)
    self.ignore_plurals = attributes[:ignore_plurals]
  end

  if attributes.key?(:remove_stop_words)
    self.remove_stop_words = attributes[:remove_stop_words]
  end

  if attributes.key?(:keep_diacritics_on_characters)
    self.keep_diacritics_on_characters = attributes[:keep_diacritics_on_characters]
  end

  if attributes.key?(:query_languages)
    if (value = attributes[:query_languages]).is_a?(Array)
      self.query_languages = value
    end
  end

  if attributes.key?(:decompound_query)
    self.decompound_query = attributes[:decompound_query]
  end

  if attributes.key?(:enable_rules)
    self.enable_rules = attributes[:enable_rules]
  end

  if attributes.key?(:enable_personalization)
    self.enable_personalization = attributes[:enable_personalization]
  end

  if attributes.key?(:query_type)
    self.query_type = attributes[:query_type]
  end

  if attributes.key?(:remove_words_if_no_results)
    self.remove_words_if_no_results = attributes[:remove_words_if_no_results]
  end

  if attributes.key?(:mode)
    self.mode = attributes[:mode]
  end

  if attributes.key?(:semantic_search)
    self.semantic_search = attributes[:semantic_search]
  end

  if attributes.key?(:advanced_syntax)
    self.advanced_syntax = attributes[:advanced_syntax]
  end

  if attributes.key?(:optional_words)
    if (value = attributes[:optional_words]).is_a?(Array)
      self.optional_words = value
    end
  end

  if attributes.key?(:disable_exact_on_attributes)
    if (value = attributes[:disable_exact_on_attributes]).is_a?(Array)
      self.disable_exact_on_attributes = value
    end
  end

  if attributes.key?(:exact_on_single_word_query)
    self.exact_on_single_word_query = attributes[:exact_on_single_word_query]
  end

  if attributes.key?(:alternatives_as_exact)
    if (value = attributes[:alternatives_as_exact]).is_a?(Array)
      self.alternatives_as_exact = value
    end
  end

  if attributes.key?(:advanced_syntax_features)
    if (value = attributes[:advanced_syntax_features]).is_a?(Array)
      self.advanced_syntax_features = value
    end
  end

  if attributes.key?(:distinct)
    self.distinct = attributes[:distinct]
  end

  if attributes.key?(:replace_synonyms_in_highlight)
    self.replace_synonyms_in_highlight = attributes[:replace_synonyms_in_highlight]
  end

  if attributes.key?(:min_proximity)
    self.min_proximity = attributes[:min_proximity]
  end

  if attributes.key?(:response_fields)
    if (value = attributes[:response_fields]).is_a?(Array)
      self.response_fields = value
    end
  end

  if attributes.key?(:max_facet_hits)
    self.max_facet_hits = attributes[:max_facet_hits]
  end

  if attributes.key?(:max_values_per_facet)
    self.max_values_per_facet = attributes[:max_values_per_facet]
  end

  if attributes.key?(:sort_facet_values_by)
    self.sort_facet_values_by = attributes[:sort_facet_values_by]
  end

  if attributes.key?(:attribute_criteria_computed_by_min_proximity)
    self.attribute_criteria_computed_by_min_proximity = attributes[:attribute_criteria_computed_by_min_proximity]
  end

  if attributes.key?(:rendering_content)
    self.rendering_content = attributes[:rendering_content]
  end

  if attributes.key?(:enable_re_ranking)
    self.enable_re_ranking = attributes[:enable_re_ranking]
  end

  if attributes.key?(:re_ranking_apply_filter)
    self.re_ranking_apply_filter = attributes[:re_ranking_apply_filter]
  end

  if attributes.key?(:cursor)
    self.cursor = attributes[:cursor]
  end
end

Instance Attribute Details

#advanced_syntaxObject



180
181
182
# File 'lib/algolia/models/search/browse_params_object.rb', line 180

def advanced_syntax
  @advanced_syntax
end

#advanced_syntax_featuresObject

Allows you to specify which advanced syntax features are active when ‘advancedSyntax` is enabled.



194
195
196
# File 'lib/algolia/models/search/browse_params_object.rb', line 194

def advanced_syntax_features
  @advanced_syntax_features
end

#allow_typos_on_numeric_tokensObject

Whether to allow typos on numbers ("numeric tokens") in the query string.



147
148
149
# File 'lib/algolia/models/search/browse_params_object.rb', line 147

def allow_typos_on_numeric_tokens
  @allow_typos_on_numeric_tokens
end

#alternatives_as_exactObject



191
192
193
# File 'lib/algolia/models/search/browse_params_object.rb', line 191

def alternatives_as_exact
  @alternatives_as_exact
end

#analyticsObject

Indicates whether this query will be included in [analytics](www.algolia.com/doc/guides/search-analytics/guides/exclude-queries/).



91
92
93
# File 'lib/algolia/models/search/browse_params_object.rb', line 91

def analytics
  @analytics
end

#analytics_tagsObject

Tags to apply to the query for [segmenting analytics data](www.algolia.com/doc/guides/search-analytics/guides/segments/).



94
95
96
# File 'lib/algolia/models/search/browse_params_object.rb', line 94

def analytics_tags
  @analytics_tags
end

#around_lat_lngObject

Search for entries [around a central location](www.algolia.com/doc/guides/managing-results/refine-results/geolocation/#filter-around-a-central-point), enabling a geographical search within a circular area.



48
49
50
# File 'lib/algolia/models/search/browse_params_object.rb', line 48

def around_lat_lng
  @around_lat_lng
end

#around_lat_lng_via_ipObject

Search for entries around a location. The location is automatically computed from the requester’s IP address.



51
52
53
# File 'lib/algolia/models/search/browse_params_object.rb', line 51

def around_lat_lng_via_ip
  @around_lat_lng_via_ip
end

#around_precisionObject

Returns the value of attribute around_precision.



55
56
57
# File 'lib/algolia/models/search/browse_params_object.rb', line 55

def around_precision
  @around_precision
end

#around_radiusObject

Returns the value of attribute around_radius.



53
54
55
# File 'lib/algolia/models/search/browse_params_object.rb', line 53

def around_radius
  @around_radius
end

#attribute_criteria_computed_by_min_proximityObject

When the [Attribute criterion is ranked above Proximity](www.algolia.com/doc/guides/managing-results/relevance-overview/in-depth/ranking-criteria/#attribute-and-proximity-combinations) in your ranking formula, Proximity is used to select which searchable attribute is matched in the Attribute ranking stage.



217
218
219
# File 'lib/algolia/models/search/browse_params_object.rb', line 217

def attribute_criteria_computed_by_min_proximity
  @attribute_criteria_computed_by_min_proximity
end

#attributes_for_facetingObject

Attributes used for [faceting](www.algolia.com/doc/guides/managing-results/refine-results/faceting/) and the [modifiers](www.algolia.com/doc/api-reference/api-parameters/attributesForFaceting/#modifiers) that can be applied: ‘filterOnly`, `searchable`, and `afterDistinct`.



103
104
105
# File 'lib/algolia/models/search/browse_params_object.rb', line 103

def attributes_for_faceting
  @attributes_for_faceting
end

#attributes_to_highlightObject

Attributes to highlight. Strings that match the search query in the attributes are highlighted by surrounding them with HTML tags (‘highlightPreTag` and `highlightPostTag`).



118
119
120
# File 'lib/algolia/models/search/browse_params_object.rb', line 118

def attributes_to_highlight
  @attributes_to_highlight
end

#attributes_to_retrieveObject

Attributes to include in the API response. To reduce the size of your response, you can retrieve only some of the attributes. By default, the response includes all attributes.



106
107
108
# File 'lib/algolia/models/search/browse_params_object.rb', line 106

def attributes_to_retrieve
  @attributes_to_retrieve
end

#attributes_to_snippetObject

Attributes to snippet. ‘Snippeting’ is shortening the attribute to a certain number of words. If not specified, the attribute is shortened to the 10 words around the matching string but you can specify the number. For example: ‘body:20`.



121
122
123
# File 'lib/algolia/models/search/browse_params_object.rb', line 121

def attributes_to_snippet
  @attributes_to_snippet
end

#click_analyticsObject

Indicates whether a query ID parameter is included in the search response. This is required for [tracking click and conversion events](www.algolia.com/doc/guides/sending-events/concepts/event-types/#events-related-to-algolia-requests).



88
89
90
# File 'lib/algolia/models/search/browse_params_object.rb', line 88

def click_analytics
  @click_analytics
end

#cursorObject

Cursor indicating the location to resume browsing from. Must match the value returned by the previous call. Pass this value to the subsequent browse call to get the next page of results. When the end of the index has been reached, ‘cursor` is absent from the response.



227
228
229
# File 'lib/algolia/models/search/browse_params_object.rb', line 227

def cursor
  @cursor
end

#custom_rankingObject

Specifies the [Custom ranking criterion](www.algolia.com/doc/guides/managing-results/must-do/custom-ranking/). Use the ‘asc` and `desc` modifiers to specify the ranking order: ascending or descending.



112
113
114
# File 'lib/algolia/models/search/browse_params_object.rb', line 112

def custom_ranking
  @custom_ranking
end

#decompound_queryObject



163
164
165
# File 'lib/algolia/models/search/browse_params_object.rb', line 163

def decompound_query
  @decompound_query
end

#disable_exact_on_attributesObject



186
187
188
# File 'lib/algolia/models/search/browse_params_object.rb', line 186

def disable_exact_on_attributes
  @disable_exact_on_attributes
end

#disable_typo_tolerance_on_attributesObject

Attributes for which you want to turn off [typo tolerance](www.algolia.com/doc/guides/managing-results/optimize-search-results/typo-tolerance/).



150
151
152
# File 'lib/algolia/models/search/browse_params_object.rb', line 150

def disable_typo_tolerance_on_attributes
  @disable_typo_tolerance_on_attributes
end

#distinctObject

Returns the value of attribute distinct.



196
197
198
# File 'lib/algolia/models/search/browse_params_object.rb', line 196

def distinct
  @distinct
end

#enable_ab_testObject

Incidates whether this search will be considered in A/B testing.



100
101
102
# File 'lib/algolia/models/search/browse_params_object.rb', line 100

def enable_ab_test
  @enable_ab_test
end

#enable_personalizationObject

Incidates whether [Personalization](www.algolia.com/doc/guides/personalization/what-is-personalization/) is enabled.



169
170
171
# File 'lib/algolia/models/search/browse_params_object.rb', line 169

def enable_personalization
  @enable_personalization
end

#enable_re_rankingObject

Indicates whether this search will use [Dynamic Re-Ranking](www.algolia.com/doc/guides/algolia-ai/re-ranking/).



222
223
224
# File 'lib/algolia/models/search/browse_params_object.rb', line 222

def enable_re_ranking
  @enable_re_ranking
end

#enable_rulesObject

Incidates whether [Rules](www.algolia.com/doc/guides/managing-results/rules/rules-overview/) are enabled.



166
167
168
# File 'lib/algolia/models/search/browse_params_object.rb', line 166

def enable_rules
  @enable_rules
end

#exact_on_single_word_queryObject

Returns the value of attribute exact_on_single_word_query.



188
189
190
# File 'lib/algolia/models/search/browse_params_object.rb', line 188

def exact_on_single_word_query
  @exact_on_single_word_query
end

#explainObject

Enriches the API’s response with information about how the query was processed.



82
83
84
# File 'lib/algolia/models/search/browse_params_object.rb', line 82

def explain
  @explain
end

#facet_filtersObject

Returns the value of attribute facet_filters.



18
19
20
# File 'lib/algolia/models/search/browse_params_object.rb', line 18

def facet_filters
  @facet_filters
end

#faceting_after_distinctObject

Forces faceting to be applied after [de-duplication](www.algolia.com/doc/guides/managing-results/refine-results/grouping/) (with the distinct feature). Alternatively, the ‘afterDistinct` [modifier](www.algolia.com/doc/api-reference/api-parameters/attributesForFaceting/#modifiers) of `attributesForFaceting` allows for more granular control.



36
37
38
# File 'lib/algolia/models/search/browse_params_object.rb', line 36

def faceting_after_distinct
  @faceting_after_distinct
end

#facetsObject

Returns [facets](www.algolia.com/doc/guides/managing-results/refine-results/faceting/#contextual-facet-values-and-counts), their facet values, and the number of matching facet values.



33
34
35
# File 'lib/algolia/models/search/browse_params_object.rb', line 33

def facets
  @facets
end

#filtersObject

[Filter](www.algolia.com/doc/guides/managing-results/refine-results/filtering/) the query with numeric, facet, or tag filters.



16
17
18
# File 'lib/algolia/models/search/browse_params_object.rb', line 16

def filters
  @filters
end

#get_ranking_infoObject



79
80
81
# File 'lib/algolia/models/search/browse_params_object.rb', line 79

def get_ranking_info
  @get_ranking_info
end

#highlight_post_tagObject

HTML string to insert after the highlighted parts in all highlight and snippet results.



127
128
129
# File 'lib/algolia/models/search/browse_params_object.rb', line 127

def 
  @highlight_post_tag
end

#highlight_pre_tagObject

HTML string to insert before the highlighted parts in all highlight and snippet results.



124
125
126
# File 'lib/algolia/models/search/browse_params_object.rb', line 124

def highlight_pre_tag
  @highlight_pre_tag
end

#hits_per_pageObject

Number of hits per page.



136
137
138
# File 'lib/algolia/models/search/browse_params_object.rb', line 136

def hits_per_page
  @hits_per_page
end

#ignore_pluralsObject

Returns the value of attribute ignore_plurals.



152
153
154
# File 'lib/algolia/models/search/browse_params_object.rb', line 152

def ignore_plurals
  @ignore_plurals
end

#inside_bounding_boxObject



61
62
63
# File 'lib/algolia/models/search/browse_params_object.rb', line 61

def inside_bounding_box
  @inside_bounding_box
end

#inside_polygonObject



64
65
66
# File 'lib/algolia/models/search/browse_params_object.rb', line 64

def inside_polygon
  @inside_polygon
end

#keep_diacritics_on_charactersObject



157
158
159
# File 'lib/algolia/models/search/browse_params_object.rb', line 157

def keep_diacritics_on_characters
  @keep_diacritics_on_characters
end

#lengthObject

Sets the number of hits to retrieve (for use with ‘offset`). > Note: Using `page` and `hitsPerPage` is the recommended method for [paging results](www.algolia.com/doc/guides/building-search-ui/ui-and-ux-patterns/pagination/js/). However, you can use `offset` and `length` to implement [an alternative approach to paging](www.algolia.com/doc/guides/building-search-ui/ui-and-ux-patterns/pagination/js/#retrieving-a-subset-of-records-with-offset-and-length).



45
46
47
# File 'lib/algolia/models/search/browse_params_object.rb', line 45

def length
  @length
end

#max_facet_hitsObject

Maximum number of facet hits to return when [searching for facet values](www.algolia.com/doc/guides/managing-results/refine-results/faceting/#search-for-facet-values).



208
209
210
# File 'lib/algolia/models/search/browse_params_object.rb', line 208

def max_facet_hits
  @max_facet_hits
end

#max_values_per_facetObject

Maximum number of facet values to return for each facet.



211
212
213
# File 'lib/algolia/models/search/browse_params_object.rb', line 211

def max_values_per_facet
  @max_values_per_facet
end

#min_proximityObject



202
203
204
# File 'lib/algolia/models/search/browse_params_object.rb', line 202

def min_proximity
  @min_proximity
end

#min_word_sizefor1_typoObject

Minimum number of characters a word in the query string must contain to accept matches with [one typo](www.algolia.com/doc/guides/managing-results/optimize-search-results/typo-tolerance/in-depth/configuring-typo-tolerance/#configuring-word-length-for-typos).



139
140
141
# File 'lib/algolia/models/search/browse_params_object.rb', line 139

def min_word_sizefor1_typo
  @min_word_sizefor1_typo
end

#min_word_sizefor2_typosObject

Minimum number of characters a word in the query string must contain to accept matches with [two typos](www.algolia.com/doc/guides/managing-results/optimize-search-results/typo-tolerance/in-depth/configuring-typo-tolerance/#configuring-word-length-for-typos).



142
143
144
# File 'lib/algolia/models/search/browse_params_object.rb', line 142

def min_word_sizefor2_typos
  @min_word_sizefor2_typos
end

#minimum_around_radiusObject

Minimum radius (in meters) used for a geographical search when ‘aroundRadius` isn’t set.



58
59
60
# File 'lib/algolia/models/search/browse_params_object.rb', line 58

def minimum_around_radius
  @minimum_around_radius
end

#modeObject

Returns the value of attribute mode.



175
176
177
# File 'lib/algolia/models/search/browse_params_object.rb', line 175

def mode
  @mode
end

#natural_languagesObject

Changes the default values of parameters that work best for a natural language query, such as ‘ignorePlurals`, `removeStopWords`, `removeWordsIfNoResults`, `analyticsTags`, and `ruleContexts`. These parameters work well together when the query consists of fuller natural language strings instead of keywords, for example when processing voice search queries.



67
68
69
# File 'lib/algolia/models/search/browse_params_object.rb', line 67

def natural_languages
  @natural_languages
end

#numeric_filtersObject

Returns the value of attribute numeric_filters.



22
23
24
# File 'lib/algolia/models/search/browse_params_object.rb', line 22

def numeric_filters
  @numeric_filters
end

#offsetObject

Specifies the offset of the first hit to return. > Note: Using ‘page` and `hitsPerPage` is the recommended method for [paging results](www.algolia.com/doc/guides/building-search-ui/ui-and-ux-patterns/pagination/js/). However, you can use `offset` and `length` to implement [an alternative approach to paging](www.algolia.com/doc/guides/building-search-ui/ui-and-ux-patterns/pagination/js/#retrieving-a-subset-of-records-with-offset-and-length).



42
43
44
# File 'lib/algolia/models/search/browse_params_object.rb', line 42

def offset
  @offset
end

#optional_filtersObject

Returns the value of attribute optional_filters.



20
21
22
# File 'lib/algolia/models/search/browse_params_object.rb', line 20

def optional_filters
  @optional_filters
end

#optional_wordsObject



183
184
185
# File 'lib/algolia/models/search/browse_params_object.rb', line 183

def optional_words
  @optional_words
end

#pageObject

Page to retrieve (the first page is ‘0`, not `1`).



39
40
41
# File 'lib/algolia/models/search/browse_params_object.rb', line 39

def page
  @page
end

#percentile_computationObject

Whether to include or exclude a query from the processing-time percentile computation.



97
98
99
# File 'lib/algolia/models/search/browse_params_object.rb', line 97

def percentile_computation
  @percentile_computation
end

#personalization_impactObject



73
74
75
# File 'lib/algolia/models/search/browse_params_object.rb', line 73

def personalization_impact
  @personalization_impact
end

#queryObject

Text to search for in an index.



10
11
12
# File 'lib/algolia/models/search/browse_params_object.rb', line 10

def query
  @query
end

#query_languagesObject

Sets your user’s search language. This adjusts language-specific settings and features such as ‘ignorePlurals`, `removeStopWords`, and [CJK](www.algolia.com/doc/guides/managing-results/optimize-search-results/handling-natural-languages-nlp/in-depth/normalization/#normalization-for-logogram-based-languages-cjk) word detection.



160
161
162
# File 'lib/algolia/models/search/browse_params_object.rb', line 160

def query_languages
  @query_languages
end

#query_typeObject

Returns the value of attribute query_type.



171
172
173
# File 'lib/algolia/models/search/browse_params_object.rb', line 171

def query_type
  @query_type
end

#rankingObject

Determines the order in which Algolia [returns your results](www.algolia.com/doc/guides/managing-results/relevance-overview/in-depth/ranking-criteria/).



109
110
111
# File 'lib/algolia/models/search/browse_params_object.rb', line 109

def ranking
  @ranking
end

#re_ranking_apply_filterObject

Returns the value of attribute re_ranking_apply_filter.



224
225
226
# File 'lib/algolia/models/search/browse_params_object.rb', line 224

def re_ranking_apply_filter
  @re_ranking_apply_filter
end

#relevancy_strictnessObject

Relevancy threshold below which less relevant results aren’t included in the results.



115
116
117
# File 'lib/algolia/models/search/browse_params_object.rb', line 115

def relevancy_strictness
  @relevancy_strictness
end

#remove_stop_wordsObject

Returns the value of attribute remove_stop_words.



154
155
156
# File 'lib/algolia/models/search/browse_params_object.rb', line 154

def remove_stop_words
  @remove_stop_words
end

#remove_words_if_no_resultsObject

Returns the value of attribute remove_words_if_no_results.



173
174
175
# File 'lib/algolia/models/search/browse_params_object.rb', line 173

def remove_words_if_no_results
  @remove_words_if_no_results
end

#rendering_contentObject

Returns the value of attribute rendering_content.



219
220
221
# File 'lib/algolia/models/search/browse_params_object.rb', line 219

def rendering_content
  @rendering_content
end

#replace_synonyms_in_highlightObject

Whether to highlight and snippet the original word that matches the synonym or the synonym itself.



199
200
201
# File 'lib/algolia/models/search/browse_params_object.rb', line 199

def replace_synonyms_in_highlight
  @replace_synonyms_in_highlight
end

#response_fieldsObject

Attributes to include in the API response for search and browse queries.



205
206
207
# File 'lib/algolia/models/search/browse_params_object.rb', line 205

def response_fields
  @response_fields
end

#restrict_highlight_and_snippet_arraysObject

Restrict highlighting and snippeting to items that matched the query.



133
134
135
# File 'lib/algolia/models/search/browse_params_object.rb', line 133

def restrict_highlight_and_snippet_arrays
  @restrict_highlight_and_snippet_arrays
end

#restrict_searchable_attributesObject

Restricts a query to only look at a subset of your [searchable attributes](www.algolia.com/doc/guides/managing-results/must-do/searchable-attributes/).



30
31
32
# File 'lib/algolia/models/search/browse_params_object.rb', line 30

def restrict_searchable_attributes
  @restrict_searchable_attributes
end

#rule_contextsObject



70
71
72
# File 'lib/algolia/models/search/browse_params_object.rb', line 70

def rule_contexts
  @rule_contexts
end

#semantic_searchObject

Returns the value of attribute semantic_search.



177
178
179
# File 'lib/algolia/models/search/browse_params_object.rb', line 177

def semantic_search
  @semantic_search
end

#similar_queryObject

Overrides the query parameter and performs a more generic search.



13
14
15
# File 'lib/algolia/models/search/browse_params_object.rb', line 13

def similar_query
  @similar_query
end

#snippet_ellipsis_textObject

String used as an ellipsis indicator when a snippet is truncated.



130
131
132
# File 'lib/algolia/models/search/browse_params_object.rb', line 130

def snippet_ellipsis_text
  @snippet_ellipsis_text
end

#sort_facet_values_byObject

Controls how facet values are fetched.



214
215
216
# File 'lib/algolia/models/search/browse_params_object.rb', line 214

def sort_facet_values_by
  @sort_facet_values_by
end

#sum_or_filters_scoresObject

Determines how to calculate [filter scores](www.algolia.com/doc/guides/managing-results/refine-results/filtering/in-depth/filter-scoring/#accumulating-scores-with-sumorfiltersscores). If ‘false`, maximum score is kept. If `true`, score is summed.



27
28
29
# File 'lib/algolia/models/search/browse_params_object.rb', line 27

def sum_or_filters_scores
  @sum_or_filters_scores
end

#synonymsObject

Whether to take into account an index’s synonyms for a particular search.



85
86
87
# File 'lib/algolia/models/search/browse_params_object.rb', line 85

def synonyms
  @synonyms
end

#tag_filtersObject

Returns the value of attribute tag_filters.



24
25
26
# File 'lib/algolia/models/search/browse_params_object.rb', line 24

def tag_filters
  @tag_filters
end

#typo_toleranceObject

Returns the value of attribute typo_tolerance.



144
145
146
# File 'lib/algolia/models/search/browse_params_object.rb', line 144

def typo_tolerance
  @typo_tolerance
end

#user_tokenObject

Associates a [user token](www.algolia.com/doc/guides/sending-events/concepts/usertoken/) with the current search.



76
77
78
# File 'lib/algolia/models/search/browse_params_object.rb', line 76

def user_token
  @user_token
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
# File 'lib/algolia/models/search/browse_params_object.rb', line 1027

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Search.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



337
338
339
# File 'lib/algolia/models/search/browse_params_object.rb', line 337

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/algolia/models/search/browse_params_object.rb', line 252

def self.attribute_map
  {
    :query => :query,
    :similar_query => :similarQuery,
    :filters => :filters,
    :facet_filters => :facetFilters,
    :optional_filters => :optionalFilters,
    :numeric_filters => :numericFilters,
    :tag_filters => :tagFilters,
    :sum_or_filters_scores => :sumOrFiltersScores,
    :restrict_searchable_attributes => :restrictSearchableAttributes,
    :facets => :facets,
    :faceting_after_distinct => :facetingAfterDistinct,
    :page => :page,
    :offset => :offset,
    :length => :length,
    :around_lat_lng => :aroundLatLng,
    :around_lat_lng_via_ip => :aroundLatLngViaIP,
    :around_radius => :aroundRadius,
    :around_precision => :aroundPrecision,
    :minimum_around_radius => :minimumAroundRadius,
    :inside_bounding_box => :insideBoundingBox,
    :inside_polygon => :insidePolygon,
    :natural_languages => :naturalLanguages,
    :rule_contexts => :ruleContexts,
    :personalization_impact => :personalizationImpact,
    :user_token => :userToken,
    :get_ranking_info => :getRankingInfo,
    :explain => :explain,
    :synonyms => :synonyms,
    :click_analytics => :clickAnalytics,
    :analytics => :analytics,
    :analytics_tags => :analyticsTags,
    :percentile_computation => :percentileComputation,
    :enable_ab_test => :enableABTest,
    :attributes_for_faceting => :attributesForFaceting,
    :attributes_to_retrieve => :attributesToRetrieve,
    :ranking => :ranking,
    :custom_ranking => :customRanking,
    :relevancy_strictness => :relevancyStrictness,
    :attributes_to_highlight => :attributesToHighlight,
    :attributes_to_snippet => :attributesToSnippet,
    :highlight_pre_tag => :highlightPreTag,
    :highlight_post_tag => :highlightPostTag,
    :snippet_ellipsis_text => :snippetEllipsisText,
    :restrict_highlight_and_snippet_arrays => :restrictHighlightAndSnippetArrays,
    :hits_per_page => :hitsPerPage,
    :min_word_sizefor1_typo => :minWordSizefor1Typo,
    :min_word_sizefor2_typos => :minWordSizefor2Typos,
    :typo_tolerance => :typoTolerance,
    :allow_typos_on_numeric_tokens => :allowTyposOnNumericTokens,
    :disable_typo_tolerance_on_attributes => :disableTypoToleranceOnAttributes,
    :ignore_plurals => :ignorePlurals,
    :remove_stop_words => :removeStopWords,
    :keep_diacritics_on_characters => :keepDiacriticsOnCharacters,
    :query_languages => :queryLanguages,
    :decompound_query => :decompoundQuery,
    :enable_rules => :enableRules,
    :enable_personalization => :enablePersonalization,
    :query_type => :queryType,
    :remove_words_if_no_results => :removeWordsIfNoResults,
    :mode => :mode,
    :semantic_search => :semanticSearch,
    :advanced_syntax => :advancedSyntax,
    :optional_words => :optionalWords,
    :disable_exact_on_attributes => :disableExactOnAttributes,
    :exact_on_single_word_query => :exactOnSingleWordQuery,
    :alternatives_as_exact => :alternativesAsExact,
    :advanced_syntax_features => :advancedSyntaxFeatures,
    :distinct => :distinct,
    :replace_synonyms_in_highlight => :replaceSynonymsInHighlight,
    :min_proximity => :minProximity,
    :response_fields => :responseFields,
    :max_facet_hits => :maxFacetHits,
    :max_values_per_facet => :maxValuesPerFacet,
    :sort_facet_values_by => :sortFacetValuesBy,
    :attribute_criteria_computed_by_min_proximity => :attributeCriteriaComputedByMinProximity,
    :rendering_content => :renderingContent,
    :enable_re_ranking => :enableReRanking,
    :re_ranking_apply_filter => :reRankingApplyFilter,
    :cursor => :cursor
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
# File 'lib/algolia/models/search/browse_params_object.rb', line 1002

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_s] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_s] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_s] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



434
435
436
437
438
439
# File 'lib/algolia/models/search/browse_params_object.rb', line 434

def self.openapi_all_of
  [
    :Cursor,
    :SearchParamsObject
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



427
428
429
430
431
# File 'lib/algolia/models/search/browse_params_object.rb', line 427

def self.openapi_nullable
  Set.new([
            :re_ranking_apply_filter
          ])
end

.types_mappingObject

Attribute type mapping.



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/algolia/models/search/browse_params_object.rb', line 342

def self.types_mapping
  {
    :query => :String,
    :similar_query => :String,
    :filters => :String,
    :facet_filters => :FacetFilters,
    :optional_filters => :OptionalFilters,
    :numeric_filters => :NumericFilters,
    :tag_filters => :TagFilters,
    :sum_or_filters_scores => :Boolean,
    :restrict_searchable_attributes => :'Array<String>',
    :facets => :'Array<String>',
    :faceting_after_distinct => :Boolean,
    :page => :Integer,
    :offset => :Integer,
    :length => :Integer,
    :around_lat_lng => :String,
    :around_lat_lng_via_ip => :Boolean,
    :around_radius => :AroundRadius,
    :around_precision => :AroundPrecision,
    :minimum_around_radius => :Integer,
    :inside_bounding_box => :'Array<Array<Float>>',
    :inside_polygon => :'Array<Array<Float>>',
    :natural_languages => :'Array<String>',
    :rule_contexts => :'Array<String>',
    :personalization_impact => :Integer,
    :user_token => :String,
    :get_ranking_info => :Boolean,
    :explain => :'Array<String>',
    :synonyms => :Boolean,
    :click_analytics => :Boolean,
    :analytics => :Boolean,
    :analytics_tags => :'Array<String>',
    :percentile_computation => :Boolean,
    :enable_ab_test => :Boolean,
    :attributes_for_faceting => :'Array<String>',
    :attributes_to_retrieve => :'Array<String>',
    :ranking => :'Array<String>',
    :custom_ranking => :'Array<String>',
    :relevancy_strictness => :Integer,
    :attributes_to_highlight => :'Array<String>',
    :attributes_to_snippet => :'Array<String>',
    :highlight_pre_tag => :String,
    :highlight_post_tag => :String,
    :snippet_ellipsis_text => :String,
    :restrict_highlight_and_snippet_arrays => :Boolean,
    :hits_per_page => :Integer,
    :min_word_sizefor1_typo => :Integer,
    :min_word_sizefor2_typos => :Integer,
    :typo_tolerance => :TypoTolerance,
    :allow_typos_on_numeric_tokens => :Boolean,
    :disable_typo_tolerance_on_attributes => :'Array<String>',
    :ignore_plurals => :IgnorePlurals,
    :remove_stop_words => :RemoveStopWords,
    :keep_diacritics_on_characters => :String,
    :query_languages => :'Array<String>',
    :decompound_query => :Boolean,
    :enable_rules => :Boolean,
    :enable_personalization => :Boolean,
    :query_type => :QueryType,
    :remove_words_if_no_results => :RemoveWordsIfNoResults,
    :mode => :Mode,
    :semantic_search => :SemanticSearch,
    :advanced_syntax => :Boolean,
    :optional_words => :'Array<String>',
    :disable_exact_on_attributes => :'Array<String>',
    :exact_on_single_word_query => :ExactOnSingleWordQuery,
    :alternatives_as_exact => :'Array<AlternativesAsExact>',
    :advanced_syntax_features => :'Array<AdvancedSyntaxFeatures>',
    :distinct => :Distinct,
    :replace_synonyms_in_highlight => :Boolean,
    :min_proximity => :Integer,
    :response_fields => :'Array<String>',
    :max_facet_hits => :Integer,
    :max_values_per_facet => :Integer,
    :sort_facet_values_by => :String,
    :attribute_criteria_computed_by_min_proximity => :Boolean,
    :rendering_content => :RenderingContent,
    :enable_re_ranking => :Boolean,
    :re_ranking_apply_filter => :ReRankingApplyFilter,
    :cursor => :String
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
# File 'lib/algolia/models/search/browse_params_object.rb', line 901

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    query == other.query &&
    similar_query == other.similar_query &&
    filters == other.filters &&
    facet_filters == other.facet_filters &&
    optional_filters == other.optional_filters &&
    numeric_filters == other.numeric_filters &&
    tag_filters == other.tag_filters &&
    sum_or_filters_scores == other.sum_or_filters_scores &&
    restrict_searchable_attributes == other.restrict_searchable_attributes &&
    facets == other.facets &&
    faceting_after_distinct == other.faceting_after_distinct &&
    page == other.page &&
    offset == other.offset &&
    length == other.length &&
    around_lat_lng == other.around_lat_lng &&
    around_lat_lng_via_ip == other.around_lat_lng_via_ip &&
    around_radius == other.around_radius &&
    around_precision == other.around_precision &&
    minimum_around_radius == other.minimum_around_radius &&
    inside_bounding_box == other.inside_bounding_box &&
    inside_polygon == other.inside_polygon &&
    natural_languages == other.natural_languages &&
    rule_contexts == other.rule_contexts &&
    personalization_impact == other.personalization_impact &&
    user_token == other.user_token &&
    get_ranking_info == other.get_ranking_info &&
    explain == other.explain &&
    synonyms == other.synonyms &&
    click_analytics == other.click_analytics &&
    analytics == other.analytics &&
    analytics_tags == other.analytics_tags &&
    percentile_computation == other.percentile_computation &&
    enable_ab_test == other.enable_ab_test &&
    attributes_for_faceting == other.attributes_for_faceting &&
    attributes_to_retrieve == other.attributes_to_retrieve &&
    ranking == other.ranking &&
    custom_ranking == other.custom_ranking &&
    relevancy_strictness == other.relevancy_strictness &&
    attributes_to_highlight == other.attributes_to_highlight &&
    attributes_to_snippet == other.attributes_to_snippet &&
    highlight_pre_tag == other.highlight_pre_tag &&
     == other. &&
    snippet_ellipsis_text == other.snippet_ellipsis_text &&
    restrict_highlight_and_snippet_arrays == other.restrict_highlight_and_snippet_arrays &&
    hits_per_page == other.hits_per_page &&
    min_word_sizefor1_typo == other.min_word_sizefor1_typo &&
    min_word_sizefor2_typos == other.min_word_sizefor2_typos &&
    typo_tolerance == other.typo_tolerance &&
    allow_typos_on_numeric_tokens == other.allow_typos_on_numeric_tokens &&
    disable_typo_tolerance_on_attributes == other.disable_typo_tolerance_on_attributes &&
    ignore_plurals == other.ignore_plurals &&
    remove_stop_words == other.remove_stop_words &&
    keep_diacritics_on_characters == other.keep_diacritics_on_characters &&
    query_languages == other.query_languages &&
    decompound_query == other.decompound_query &&
    enable_rules == other.enable_rules &&
    enable_personalization == other.enable_personalization &&
    query_type == other.query_type &&
    remove_words_if_no_results == other.remove_words_if_no_results &&
    mode == other.mode &&
    semantic_search == other.semantic_search &&
    advanced_syntax == other.advanced_syntax &&
    optional_words == other.optional_words &&
    disable_exact_on_attributes == other.disable_exact_on_attributes &&
    exact_on_single_word_query == other.exact_on_single_word_query &&
    alternatives_as_exact == other.alternatives_as_exact &&
    advanced_syntax_features == other.advanced_syntax_features &&
    distinct == other.distinct &&
    replace_synonyms_in_highlight == other.replace_synonyms_in_highlight &&
    min_proximity == other.min_proximity &&
    response_fields == other.response_fields &&
    max_facet_hits == other.max_facet_hits &&
    max_values_per_facet == other.max_values_per_facet &&
    sort_facet_values_by == other.sort_facet_values_by &&
    attribute_criteria_computed_by_min_proximity == other.attribute_criteria_computed_by_min_proximity &&
    rendering_content == other.rendering_content &&
    enable_re_ranking == other.enable_re_ranking &&
    re_ranking_apply_filter == other.re_ranking_apply_filter &&
    cursor == other.cursor
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
# File 'lib/algolia/models/search/browse_params_object.rb', line 1098

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


988
989
990
# File 'lib/algolia/models/search/browse_params_object.rb', line 988

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



994
995
996
997
# File 'lib/algolia/models/search/browse_params_object.rb', line 994

def hash
  [query, similar_query, filters, facet_filters, optional_filters, numeric_filters, tag_filters, sum_or_filters_scores, restrict_searchable_attributes, facets,
   faceting_after_distinct, page, offset, length, around_lat_lng, around_lat_lng_via_ip, around_radius, around_precision, minimum_around_radius, inside_bounding_box, inside_polygon, natural_languages, rule_contexts, personalization_impact, user_token, get_ranking_info, explain, synonyms, click_analytics, analytics, analytics_tags, percentile_computation, enable_ab_test, attributes_for_faceting, attributes_to_retrieve, ranking, custom_ranking, relevancy_strictness, attributes_to_highlight, attributes_to_snippet, highlight_pre_tag, , snippet_ellipsis_text, restrict_highlight_and_snippet_arrays, hits_per_page, min_word_sizefor1_typo, min_word_sizefor2_typos, typo_tolerance, allow_typos_on_numeric_tokens, disable_typo_tolerance_on_attributes, ignore_plurals, remove_stop_words, keep_diacritics_on_characters, query_languages, decompound_query, enable_rules, enable_personalization, query_type, remove_words_if_no_results, mode, semantic_search, advanced_syntax, optional_words, disable_exact_on_attributes, exact_on_single_word_query, alternatives_as_exact, advanced_syntax_features, distinct, replace_synonyms_in_highlight, min_proximity, response_fields, max_facet_hits, max_values_per_facet, sort_facet_values_by, attribute_criteria_computed_by_min_proximity, rendering_content, enable_re_ranking, re_ranking_apply_filter, cursor].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



1074
1075
1076
# File 'lib/algolia/models/search/browse_params_object.rb', line 1074

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
# File 'lib/algolia/models/search/browse_params_object.rb', line 1080

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



1068
1069
1070
# File 'lib/algolia/models/search/browse_params_object.rb', line 1068

def to_s
  to_hash.to_s
end