Class: Algolia::Search::Consequence
- Inherits:
-
Object
- Object
- Algolia::Search::Consequence
- Defined in:
- lib/algolia/models/search/consequence.rb
Overview
Effect of the rule. For more information, see [Consequences](www.algolia.com/doc/guides/managing-results/rules/rules-overview/#consequences).
Instance Attribute Summary collapse
-
#filter_promotes ⇒ Object
Determines whether promoted records must also match active filters for the consequence to apply.
-
#hide ⇒ Object
Records you want to hide from the search results.
-
#params ⇒ Object
Returns the value of attribute params.
-
#promote ⇒ Object
Records you want to pin to a specific position in the search results.
-
#redirect ⇒ Object
Returns the value of attribute redirect.
-
#user_data ⇒ Object
A JSON object with custom data that will be appended to the
userDataarray in the response.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Consequence
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Consequence
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/algolia/models/search/consequence.rb', line 61 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise( ArgumentError, "The input argument (attributes) must be a hash in `Algolia::Consequence` initialize method" ) end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) raise( ArgumentError, "`#{k}` is not a valid attribute in `Algolia::Consequence`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect ) end h[k.to_sym] = v } if attributes.key?(:params) self.params = attributes[:params] end if attributes.key?(:promote) if (value = attributes[:promote]).is_a?(Array) self.promote = value end end if attributes.key?(:filter_promotes) self.filter_promotes = attributes[:filter_promotes] end if attributes.key?(:hide) if (value = attributes[:hide]).is_a?(Array) self.hide = value end end if attributes.key?(:redirect) self.redirect = attributes[:redirect] end if attributes.key?(:user_data) self.user_data = attributes[:user_data] end end |
Instance Attribute Details
#filter_promotes ⇒ Object
Determines whether promoted records must also match active filters for the consequence to apply. This ensures user-applied filters take priority and irrelevant matches aren’t shown. For example, if you promote a record with ‘color: red` but the user filters for `color: blue`, the "red" record won’t be shown. > In the Algolia dashboard, when you use the **Pin an item** consequence, filterPromotes appears as the checkbox: **Pinned items must match active filters to be displayed.** For examples, see [Promote results with rules](www.algolia.com/doc/guides/managing-results/rules/merchandising-and-promoting/how-to/promote-hits/#promote-results-matching-active-filters).
18 19 20 |
# File 'lib/algolia/models/search/consequence.rb', line 18 def filter_promotes @filter_promotes end |
#hide ⇒ Object
Records you want to hide from the search results.
21 22 23 |
# File 'lib/algolia/models/search/consequence.rb', line 21 def hide @hide end |
#params ⇒ Object
Returns the value of attribute params.
12 13 14 |
# File 'lib/algolia/models/search/consequence.rb', line 12 def params @params end |
#promote ⇒ Object
Records you want to pin to a specific position in the search results. You can promote up to 300 records, either individually, or as groups of up to 100 records each.
15 16 17 |
# File 'lib/algolia/models/search/consequence.rb', line 15 def promote @promote end |
#redirect ⇒ Object
Returns the value of attribute redirect.
23 24 25 |
# File 'lib/algolia/models/search/consequence.rb', line 23 def redirect @redirect end |
#user_data ⇒ Object
A JSON object with custom data that will be appended to the userData array in the response. This object isn’t interpreted by the API and is limited to 1 kB of minified JSON.
26 27 28 |
# File 'lib/algolia/models/search/consequence.rb', line 26 def user_data @user_data end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/algolia/models/search/consequence.rb', line 166 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end # model else # models (e.g. Pet) or oneOf klass = Algolia::Search.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass .build_from_hash(value) end end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 37 38 |
# File 'lib/algolia/models/search/consequence.rb', line 29 def self.attribute_map { :params => :params, :promote => :promote, :filter_promotes => :filterPromotes, :hide => :hide, :redirect => :redirect, :user_data => :userData } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/algolia/models/search/consequence.rb', line 139 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
53 54 55 56 57 |
# File 'lib/algolia/models/search/consequence.rb', line 53 def self.openapi_nullable Set.new( [] ) end |
.types_mapping ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/algolia/models/search/consequence.rb', line 41 def self.types_mapping { :params => :"ConsequenceParams", :promote => :"Array<Promote>", :filter_promotes => :"Boolean", :hide => :"Array<ConsequenceHide>", :redirect => :"ConsequenceRedirect", :user_data => :"Object" } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
113 114 115 116 117 118 119 120 121 122 |
# File 'lib/algolia/models/search/consequence.rb', line 113 def ==(other) return true if self.equal?(other) self.class == other.class && params == other.params && promote == other.promote && filter_promotes == other.filter_promotes && hide == other.hide && redirect == other.redirect && user_data == other.user_data end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/algolia/models/search/consequence.rb', line 245 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to?(:to_hash) value.to_hash else value end end |
#eql?(other) ⇒ Boolean
126 127 128 |
# File 'lib/algolia/models/search/consequence.rb', line 126 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
132 133 134 |
# File 'lib/algolia/models/search/consequence.rb', line 132 def hash [params, promote, filter_promotes, hide, redirect, user_data].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
216 217 218 |
# File 'lib/algolia/models/search/consequence.rb', line 216 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/algolia/models/search/consequence.rb', line 226 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
220 221 222 |
# File 'lib/algolia/models/search/consequence.rb', line 220 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/algolia/models/search/consequence.rb', line 210 def to_s to_hash.to_s end |