Class: Algolia::Search::CreatedAtResponse
- Inherits:
-
Object
- Object
- Algolia::Search::CreatedAtResponse
- Defined in:
- lib/algolia/models/search/created_at_response.rb
Overview
Response and creation timestamp.
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Timestamp of creation in [ISO-8601](wikipedia.org/wiki/ISO_8601) format.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatedAtResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CreatedAtResponse
Initializes the object
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/algolia/models/search/created_at_response.rb', line 39 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::CreatedAtResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::CreatedAtResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:created_at) self.created_at = attributes[:created_at] else self.created_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Timestamp of creation in [ISO-8601](wikipedia.org/wiki/ISO_8601) format.
11 12 13 |
# File 'lib/algolia/models/search/created_at_response.rb', line 11 def created_at @created_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/algolia/models/search/created_at_response.rb', line 110 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Search.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
21 22 23 |
# File 'lib/algolia/models/search/created_at_response.rb', line 21 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
14 15 16 17 18 |
# File 'lib/algolia/models/search/created_at_response.rb', line 14 def self.attribute_map { :created_at => :createdAt } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/algolia/models/search/created_at_response.rb', line 85 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_s] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
33 34 35 |
# File 'lib/algolia/models/search/created_at_response.rb', line 33 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
26 27 28 29 30 |
# File 'lib/algolia/models/search/created_at_response.rb', line 26 def self.types_mapping { :created_at => :String } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
63 64 65 66 67 68 |
# File 'lib/algolia/models/search/created_at_response.rb', line 63 def ==(other) return true if equal?(other) self.class == other.class && created_at == other.created_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/algolia/models/search/created_at_response.rb', line 181 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
72 73 74 |
# File 'lib/algolia/models/search/created_at_response.rb', line 72 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
78 79 80 |
# File 'lib/algolia/models/search/created_at_response.rb', line 78 def hash [created_at].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
157 158 159 |
# File 'lib/algolia/models/search/created_at_response.rb', line 157 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/algolia/models/search/created_at_response.rb', line 163 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
151 152 153 |
# File 'lib/algolia/models/search/created_at_response.rb', line 151 def to_s to_hash.to_s end |