Class: Algolia::Search::DeleteByParams

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/search/delete_by_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DeleteByParams

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/algolia/models/search/delete_by_params.rb', line 69

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::DeleteByParams` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::DeleteByParams`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:facet_filters)
    self.facet_filters = attributes[:facet_filters]
  end

  if attributes.key?(:filters)
    self.filters = attributes[:filters]
  end

  if attributes.key?(:numeric_filters)
    self.numeric_filters = attributes[:numeric_filters]
  end

  if attributes.key?(:tag_filters)
    self.tag_filters = attributes[:tag_filters]
  end

  if attributes.key?(:around_lat_lng)
    self.around_lat_lng = attributes[:around_lat_lng]
  end

  if attributes.key?(:around_radius)
    self.around_radius = attributes[:around_radius]
  end

  if attributes.key?(:inside_bounding_box)
    if (value = attributes[:inside_bounding_box]).is_a?(Array)
      self.inside_bounding_box = value
    end
  end

  if attributes.key?(:inside_polygon)
    if (value = attributes[:inside_polygon]).is_a?(Array)
      self.inside_polygon = value
    end
  end
end

Instance Attribute Details

#around_lat_lngObject

Search for entries [around a central location](www.algolia.com/doc/guides/managing-results/refine-results/geolocation/#filter-around-a-central-point), enabling a geographical search within a circular area.



19
20
21
# File 'lib/algolia/models/search/delete_by_params.rb', line 19

def around_lat_lng
  @around_lat_lng
end

#around_radiusObject

Returns the value of attribute around_radius.



21
22
23
# File 'lib/algolia/models/search/delete_by_params.rb', line 21

def around_radius
  @around_radius
end

#facet_filtersObject

Returns the value of attribute facet_filters.



9
10
11
# File 'lib/algolia/models/search/delete_by_params.rb', line 9

def facet_filters
  @facet_filters
end

#filtersObject

[Filter](www.algolia.com/doc/guides/managing-results/refine-results/filtering/) the query with numeric, facet, or tag filters.



12
13
14
# File 'lib/algolia/models/search/delete_by_params.rb', line 12

def filters
  @filters
end

#inside_bounding_boxObject



24
25
26
# File 'lib/algolia/models/search/delete_by_params.rb', line 24

def inside_bounding_box
  @inside_bounding_box
end

#inside_polygonObject



27
28
29
# File 'lib/algolia/models/search/delete_by_params.rb', line 27

def inside_polygon
  @inside_polygon
end

#numeric_filtersObject

Returns the value of attribute numeric_filters.



14
15
16
# File 'lib/algolia/models/search/delete_by_params.rb', line 14

def numeric_filters
  @numeric_filters
end

#tag_filtersObject

Returns the value of attribute tag_filters.



16
17
18
# File 'lib/algolia/models/search/delete_by_params.rb', line 16

def tag_filters
  @tag_filters
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/algolia/models/search/delete_by_params.rb', line 177

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Search.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



44
45
46
# File 'lib/algolia/models/search/delete_by_params.rb', line 44

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
38
39
40
41
# File 'lib/algolia/models/search/delete_by_params.rb', line 30

def self.attribute_map
  {
    :facet_filters => :facetFilters,
    :filters => :filters,
    :numeric_filters => :numericFilters,
    :tag_filters => :tagFilters,
    :around_lat_lng => :aroundLatLng,
    :around_radius => :aroundRadius,
    :inside_bounding_box => :insideBoundingBox,
    :inside_polygon => :insidePolygon
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/algolia/models/search/delete_by_params.rb', line 152

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
# File 'lib/algolia/models/search/delete_by_params.rb', line 63

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/algolia/models/search/delete_by_params.rb', line 49

def self.types_mapping
  {
    :facet_filters => :FacetFilters,
    :filters => :String,
    :numeric_filters => :NumericFilters,
    :tag_filters => :TagFilters,
    :around_lat_lng => :String,
    :around_radius => :AroundRadius,
    :inside_bounding_box => :'Array<Array<Float>>',
    :inside_polygon => :'Array<Array<Float>>'
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/algolia/models/search/delete_by_params.rb', line 123

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    facet_filters == other.facet_filters &&
    filters == other.filters &&
    numeric_filters == other.numeric_filters &&
    tag_filters == other.tag_filters &&
    around_lat_lng == other.around_lat_lng &&
    around_radius == other.around_radius &&
    inside_bounding_box == other.inside_bounding_box &&
    inside_polygon == other.inside_polygon
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/algolia/models/search/delete_by_params.rb', line 252

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


139
140
141
# File 'lib/algolia/models/search/delete_by_params.rb', line 139

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



145
146
147
# File 'lib/algolia/models/search/delete_by_params.rb', line 145

def hash
  [facet_filters, filters, numeric_filters, tag_filters, around_lat_lng, around_radius, inside_bounding_box, inside_polygon].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



224
225
226
# File 'lib/algolia/models/search/delete_by_params.rb', line 224

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/algolia/models/search/delete_by_params.rb', line 234

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*_args) ⇒ Object



228
229
230
# File 'lib/algolia/models/search/delete_by_params.rb', line 228

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



218
219
220
# File 'lib/algolia/models/search/delete_by_params.rb', line 218

def to_s
  to_hash.to_s
end