Class: Algolia::Search::DeletedAtResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/search/deleted_at_response.rb

Overview

Response, taskID, and deletion timestamp.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DeletedAtResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/algolia/models/search/deleted_at_response.rb', line 44

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::DeletedAtResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::DeletedAtResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:task_id)
    self.task_id = attributes[:task_id]
  else
    self.task_id = nil
  end

  if attributes.key?(:deleted_at)
    self.deleted_at = attributes[:deleted_at]
  else
    self.deleted_at = nil
  end
end

Instance Attribute Details

#deleted_atObject

Date and time when the object was deleted, in RFC 3339 format.



14
15
16
# File 'lib/algolia/models/search/deleted_at_response.rb', line 14

def deleted_at
  @deleted_at
end

#task_idObject

Unique identifier of a task. A successful API response means that a task was added to a queue. It might not run immediately. You can check the task’s progress with the [‘task` operation](#tag/Indices/operation/getTask) and this `taskID`.



11
12
13
# File 'lib/algolia/models/search/deleted_at_response.rb', line 11

def task_id
  @task_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/algolia/models/search/deleted_at_response.rb', line 122

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Search.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



25
26
27
# File 'lib/algolia/models/search/deleted_at_response.rb', line 25

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



17
18
19
20
21
22
# File 'lib/algolia/models/search/deleted_at_response.rb', line 17

def self.attribute_map
  {
    :task_id => :taskID,
    :deleted_at => :deletedAt
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/algolia/models/search/deleted_at_response.rb', line 97

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



38
39
40
# File 'lib/algolia/models/search/deleted_at_response.rb', line 38

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



30
31
32
33
34
35
# File 'lib/algolia/models/search/deleted_at_response.rb', line 30

def self.types_mapping
  {
    :task_id => :Integer,
    :deleted_at => :String
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



74
75
76
77
78
79
80
# File 'lib/algolia/models/search/deleted_at_response.rb', line 74

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    task_id == other.task_id &&
    deleted_at == other.deleted_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/algolia/models/search/deleted_at_response.rb', line 197

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


84
85
86
# File 'lib/algolia/models/search/deleted_at_response.rb', line 84

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



90
91
92
# File 'lib/algolia/models/search/deleted_at_response.rb', line 90

def hash
  [task_id, deleted_at].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



169
170
171
# File 'lib/algolia/models/search/deleted_at_response.rb', line 169

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/algolia/models/search/deleted_at_response.rb', line 179

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*_args) ⇒ Object



173
174
175
# File 'lib/algolia/models/search/deleted_at_response.rb', line 173

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



163
164
165
# File 'lib/algolia/models/search/deleted_at_response.rb', line 163

def to_s
  to_hash.to_s
end