Class: Algolia::Search::OperationIndexParams

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/search/operation_index_params.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OperationIndexParams

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/algolia/models/search/operation_index_params.rb', line 69

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::OperationIndexParams` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::OperationIndexParams`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:operation)
    self.operation = attributes[:operation]
  else
    self.operation = nil
  end

  if attributes.key?(:destination)
    self.destination = attributes[:destination]
  else
    self.destination = nil
  end

  if attributes.key?(:scope)
    if (value = attributes[:scope]).is_a?(Array)
      self.scope = value
    end
  end
end

Instance Attribute Details

#destinationObject

Algolia index name.



12
13
14
# File 'lib/algolia/models/search/operation_index_params.rb', line 12

def destination
  @destination
end

#operationObject

Returns the value of attribute operation.



9
10
11
# File 'lib/algolia/models/search/operation_index_params.rb', line 9

def operation
  @operation
end

#scopeObject

**This only applies to the copy operation.** If you omit ‘scope`, the copy command copies all records, settings, synonyms, and rules. If you specify `scope`, only the specified scopes are copied.



15
16
17
# File 'lib/algolia/models/search/operation_index_params.rb', line 15

def scope
  @scope
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/algolia/models/search/operation_index_params.rb', line 154

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Search.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/algolia/models/search/operation_index_params.rb', line 49

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
# File 'lib/algolia/models/search/operation_index_params.rb', line 40

def self.attribute_map
  {
    :operation => :operation,
    :destination => :destination,
    :scope => :scope
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/algolia/models/search/operation_index_params.rb', line 129

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
# File 'lib/algolia/models/search/operation_index_params.rb', line 63

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



54
55
56
57
58
59
60
# File 'lib/algolia/models/search/operation_index_params.rb', line 54

def self.types_mapping
  {
    :operation => :OperationType,
    :destination => :String,
    :scope => :'Array<ScopeType>'
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



105
106
107
108
109
110
111
112
# File 'lib/algolia/models/search/operation_index_params.rb', line 105

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    operation == other.operation &&
    destination == other.destination &&
    scope == other.scope
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/algolia/models/search/operation_index_params.rb', line 229

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


116
117
118
# File 'lib/algolia/models/search/operation_index_params.rb', line 116

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



122
123
124
# File 'lib/algolia/models/search/operation_index_params.rb', line 122

def hash
  [operation, destination, scope].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



201
202
203
# File 'lib/algolia/models/search/operation_index_params.rb', line 201

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/algolia/models/search/operation_index_params.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*_args) ⇒ Object



205
206
207
# File 'lib/algolia/models/search/operation_index_params.rb', line 205

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



195
196
197
# File 'lib/algolia/models/search/operation_index_params.rb', line 195

def to_s
  to_hash.to_s
end