Module: Algolia::Search::RemoveStopWords

Defined in:
lib/algolia/models/search/remove_stop_words.rb

Overview

Removes stop (common) words from the query before executing it. ‘removeStopWords` is used in conjunction with the `queryLanguages` setting. list: language ISO codes for which stop words should be enabled. This list will override any values that you may have set in `queryLanguages`. true: enables the stop words feature, ensuring that stop words are removed from consideration in a search. The languages supported here are either [every language](www.algolia.com/doc/guides/managing-results/optimize-search-results/handling-natural-languages-nlp/in-depth/supported-languages/) (this is the default) or those set by `queryLanguages`. false: turns off the stop words feature, allowing stop words to be taken into account in a search.

Class Method Summary collapse

Class Method Details

.build(data) ⇒ Object

Builds the object

Parameters:

  • Data (Mixed)

    to be matched against the list of oneOf items

Returns:

  • (Object)

    Returns the model or the data itself



22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'lib/algolia/models/search/remove_stop_words.rb', line 22

def build(data)
  # Go through the list of oneOf items and attempt to identify the appropriate one.
  # Note:
  # - We do not attempt to check whether exactly one item matches.
  # - No advanced validation of types in some cases (e.g. "x: { type: string }" will happily match { x: 123 })
  #   due to the way the deserialization is made in the base_object template (it just casts without verifying).
  # - TODO: scalar values are de facto behaving as if they were nullable.
  # - TODO: logging when debugging is set.
  openapi_one_of.each do |klass|
    next if klass == :AnyType # "nullable: true"

    typed_data = find_and_cast_into_type(klass, data)
    return typed_data if typed_data
  rescue # rescue all errors so we keep iterating even if the current item lookup raises
  end

  openapi_one_of.include?(:AnyType) ? data : nil
end

.openapi_one_ofObject

List of class defined in oneOf (OpenAPI v3)



12
13
14
15
16
17
# File 'lib/algolia/models/search/remove_stop_words.rb', line 12

def openapi_one_of
  [
    :'Array<String>',
    :Boolean
  ]
end