Method: Algolia::Search::SettingsResponse#replicas
- Defined in:
- lib/algolia/models/search/settings_response.rb
#replicas ⇒ Object
Creates [replica indices](www.algolia.com/doc/guides/managing-results/refine-results/sorting/in-depth/replicas). Replicas are copies of a primary index with the same records but different settings, synonyms, or rules. If you want to offer a different ranking or sorting of your search results, you’ll use replica indices. All index operations on a primary index are automatically forwarded to its replicas. To add a replica index, you must provide the complete set of replicas to this parameter. If you omit a replica from this list, the replica turns into a regular, standalone index that will no longer be synced with the primary index. Modifier - ‘virtual("REPLICA")`. Create a virtual replica, Virtual replicas don’t increase the number of records and are optimized for [Relevant sorting](www.algolia.com/doc/guides/managing-results/refine-results/sorting/in-depth/relevant-sort).
15 16 17 |
# File 'lib/algolia/models/search/settings_response.rb', line 15 def replicas @replicas end |