Class: Algolia::Search::UserHit

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/search/user_hit.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UserHit

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/algolia/models/search/user_hit.rb', line 62

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::UserHit` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::UserHit`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:user_id)
    self.user_id = attributes[:user_id]
  else
    self.user_id = nil
  end

  if attributes.key?(:cluster_name)
    self.cluster_name = attributes[:cluster_name]
  else
    self.cluster_name = nil
  end

  if attributes.key?(:nb_records)
    self.nb_records = attributes[:nb_records]
  else
    self.nb_records = nil
  end

  if attributes.key?(:data_size)
    self.data_size = attributes[:data_size]
  else
    self.data_size = nil
  end

  if attributes.key?(:object_id)
    self.object_id = attributes[:object_id]
  else
    self.object_id = nil
  end

  if attributes.key?(:_highlight_result)
    self._highlight_result = attributes[:_highlight_result]
  else
    self._highlight_result = nil
  end
end

Instance Attribute Details

#_highlight_resultObject

Returns the value of attribute _highlight_result.



24
25
26
# File 'lib/algolia/models/search/user_hit.rb', line 24

def _highlight_result
  @_highlight_result
end

#cluster_nameObject

Cluster name.



13
14
15
# File 'lib/algolia/models/search/user_hit.rb', line 13

def cluster_name
  @cluster_name
end

#data_sizeObject

Data size taken by all the users assigned to the cluster.



19
20
21
# File 'lib/algolia/models/search/user_hit.rb', line 19

def data_size
  @data_size
end

#nb_recordsObject

Number of records in the cluster.



16
17
18
# File 'lib/algolia/models/search/user_hit.rb', line 16

def nb_records
  @nb_records
end

#object_idObject

userID of the requested user. Same as userID.



22
23
24
# File 'lib/algolia/models/search/user_hit.rb', line 22

def object_id
  @object_id
end

#user_idObject

Unique identifier of the user who makes the search request.



10
11
12
# File 'lib/algolia/models/search/user_hit.rb', line 10

def user_id
  @user_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/algolia/models/search/user_hit.rb', line 183

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Search.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/algolia/models/search/user_hit.rb', line 39

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
35
36
# File 'lib/algolia/models/search/user_hit.rb', line 27

def self.attribute_map
  {
    :user_id => :userID,
    :cluster_name => :clusterName,
    :nb_records => :nbRecords,
    :data_size => :dataSize,
    :object_id => :objectID,
    :_highlight_result => :_highlightResult
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/algolia/models/search/user_hit.rb', line 158

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
# File 'lib/algolia/models/search/user_hit.rb', line 56

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



44
45
46
47
48
49
50
51
52
53
# File 'lib/algolia/models/search/user_hit.rb', line 44

def self.types_mapping
  {
    :user_id => :String,
    :cluster_name => :String,
    :nb_records => :Integer,
    :data_size => :Integer,
    :object_id => :String,
    :_highlight_result => :UserHighlightResult
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



131
132
133
134
135
136
137
138
139
140
141
# File 'lib/algolia/models/search/user_hit.rb', line 131

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    user_id == other.user_id &&
    cluster_name == other.cluster_name &&
    nb_records == other.nb_records &&
    data_size == other.data_size &&
    object_id == other.object_id &&
    _highlight_result == other._highlight_result
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/algolia/models/search/user_hit.rb', line 258

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


145
146
147
# File 'lib/algolia/models/search/user_hit.rb', line 145

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



151
152
153
# File 'lib/algolia/models/search/user_hit.rb', line 151

def hash
  [user_id, cluster_name, nb_records, data_size, object_id, _highlight_result].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
# File 'lib/algolia/models/search/user_hit.rb', line 230

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/algolia/models/search/user_hit.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*_args) ⇒ Object



234
235
236
# File 'lib/algolia/models/search/user_hit.rb', line 234

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



224
225
226
# File 'lib/algolia/models/search/user_hit.rb', line 224

def to_s
  to_hash.to_s
end