Class: Algolia::Search::UserId
- Inherits:
-
Object
- Object
- Algolia::Search::UserId
- Defined in:
- lib/algolia/models/search/user_id.rb
Overview
Unique user ID.
Instance Attribute Summary collapse
-
#cluster_name ⇒ Object
Cluster to which the user is assigned.
-
#data_size ⇒ Object
Data size used by the user.
-
#nb_records ⇒ Object
Number of records belonging to the user.
-
#user_id ⇒ Object
User ID.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserId
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ UserId
Initializes the object
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/algolia/models/search/user_id.rb', line 54 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::UserId` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::UserId`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:user_id) self.user_id = attributes[:user_id] else self.user_id = nil end if attributes.key?(:cluster_name) self.cluster_name = attributes[:cluster_name] else self.cluster_name = nil end if attributes.key?(:nb_records) self.nb_records = attributes[:nb_records] else self.nb_records = nil end if attributes.key?(:data_size) self.data_size = attributes[:data_size] else self.data_size = nil end end |
Instance Attribute Details
#cluster_name ⇒ Object
Cluster to which the user is assigned.
14 15 16 |
# File 'lib/algolia/models/search/user_id.rb', line 14 def cluster_name @cluster_name end |
#data_size ⇒ Object
Data size used by the user.
20 21 22 |
# File 'lib/algolia/models/search/user_id.rb', line 20 def data_size @data_size end |
#nb_records ⇒ Object
Number of records belonging to the user.
17 18 19 |
# File 'lib/algolia/models/search/user_id.rb', line 17 def nb_records @nb_records end |
#user_id ⇒ Object
User ID.
11 12 13 |
# File 'lib/algolia/models/search/user_id.rb', line 11 def user_id @user_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/algolia/models/search/user_id.rb', line 161 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Search.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
33 34 35 |
# File 'lib/algolia/models/search/user_id.rb', line 33 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 29 30 |
# File 'lib/algolia/models/search/user_id.rb', line 23 def self.attribute_map { :user_id => :userID, :cluster_name => :clusterName, :nb_records => :nbRecords, :data_size => :dataSize } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/algolia/models/search/user_id.rb', line 136 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
48 49 50 |
# File 'lib/algolia/models/search/user_id.rb', line 48 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
38 39 40 41 42 43 44 45 |
# File 'lib/algolia/models/search/user_id.rb', line 38 def self.types_mapping { :user_id => :String, :cluster_name => :String, :nb_records => :Integer, :data_size => :Integer } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 |
# File 'lib/algolia/models/search/user_id.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && user_id == other.user_id && cluster_name == other.cluster_name && nb_records == other.nb_records && data_size == other.data_size end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/algolia/models/search/user_id.rb', line 236 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
123 124 125 |
# File 'lib/algolia/models/search/user_id.rb', line 123 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
129 130 131 |
# File 'lib/algolia/models/search/user_id.rb', line 129 def hash [user_id, cluster_name, nb_records, data_size].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
208 209 210 |
# File 'lib/algolia/models/search/user_id.rb', line 208 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/algolia/models/search/user_id.rb', line 218 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
212 213 214 |
# File 'lib/algolia/models/search/user_id.rb', line 212 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
202 203 204 |
# File 'lib/algolia/models/search/user_id.rb', line 202 def to_s to_hash.to_s end |