Method: Algolia::SearchClient#search_rules

Defined in:
lib/algolia/api/search_client.rb

#search_rules(index_name, search_rules_params = nil, request_options = {}) ⇒ SearchRulesResponse

Searches for rules in your index.

Required API Key ACLs:

- settings

Parameters:

  • index_name (String)

    Name of the index on which to perform the operation. (required)

  • search_rules_params (SearchRulesParams) (defaults to: nil)
  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (SearchRulesResponse)


2791
2792
2793
2794
# File 'lib/algolia/api/search_client.rb', line 2791

def search_rules(index_name, search_rules_params = nil, request_options = {})
  response = search_rules_with_http_info(index_name, search_rules_params, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "Search::SearchRulesResponse")
end