Class: Algolia::AbtestingClient
- Inherits:
-
Object
- Object
- Algolia::AbtestingClient
- Defined in:
- lib/algolia/api/abtesting_client.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Class Method Summary collapse
Instance Method Summary collapse
-
#add_ab_tests(add_ab_tests_request, request_options = {}) ⇒ ABTestResponse
Creates a new A/B test.
-
#add_ab_tests_with_http_info(add_ab_tests_request, request_options = {}) ⇒ Http::Response
Creates a new A/B test.
- #custom_delete(path, parameters = nil, request_options = {}) ⇒ Object
-
#custom_delete_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
The response.
- #custom_get(path, parameters = nil, request_options = {}) ⇒ Object
-
#custom_get_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
The response.
- #custom_post(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
-
#custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
The response.
- #custom_put(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
-
#custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
The response.
-
#delete_ab_test(id, request_options = {}) ⇒ ABTestResponse
Deletes an A/B test by its ID.
-
#delete_ab_test_with_http_info(id, request_options = {}) ⇒ Http::Response
Deletes an A/B test by its ID.
-
#get_ab_test(id, request_options = {}) ⇒ ABTest
Retrieves the details for an A/B test by its ID.
-
#get_ab_test_with_http_info(id, request_options = {}) ⇒ Http::Response
Retrieves the details for an A/B test by its ID.
-
#initialize(config = nil) ⇒ AbtestingClient
constructor
A new instance of AbtestingClient.
-
#list_ab_tests(offset = nil, limit = nil, index_prefix = nil, index_suffix = nil, request_options = {}) ⇒ ListABTestsResponse
Lists all A/B tests you configured for this application.
-
#list_ab_tests_with_http_info(offset = nil, limit = nil, index_prefix = nil, index_suffix = nil, request_options = {}) ⇒ Http::Response
Lists all A/B tests you configured for this application.
-
#schedule_ab_test(schedule_ab_tests_request, request_options = {}) ⇒ ScheduleABTestResponse
Schedule an A/B test to be started at a later time.
-
#schedule_ab_test_with_http_info(schedule_ab_tests_request, request_options = {}) ⇒ Http::Response
Schedule an A/B test to be started at a later time.
-
#set_client_api_key(api_key) ⇒ void
Helper method to switch the API key used to authenticate the requests.
-
#stop_ab_test(id, request_options = {}) ⇒ ABTestResponse
Stops an A/B test by its ID.
-
#stop_ab_test_with_http_info(id, request_options = {}) ⇒ Http::Response
Stops an A/B test by its ID.
Constructor Details
#initialize(config = nil) ⇒ AbtestingClient
Returns a new instance of AbtestingClient.
7 8 9 10 11 12 13 |
# File 'lib/algolia/api/abtesting_client.rb', line 7 def initialize(config = nil) raise "`config` is missing." if config.nil? raise "`app_id` is missing." if config.app_id.nil? || config.app_id == "" raise "`api_key` is missing." if config.api_key.nil? || config.api_key == "" @api_client = Algolia::ApiClient.new(config) end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
5 6 7 |
# File 'lib/algolia/api/abtesting_client.rb', line 5 def api_client @api_client end |
Class Method Details
.create(app_id, api_key, region = nil, opts = {}) ⇒ Object
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/algolia/api/abtesting_client.rb', line 15 def self.create(app_id, api_key, region = nil, opts = {}) hosts = [] regions = ["de", "us"] if region.is_a?(Hash) && (opts.nil? || opts.empty?) opts = region region = nil end if !region.nil? && (!region.is_a?(String) || !regions.include?(region)) raise "`region` must be one of the following: #{regions.join(", ")}" end hosts << Transport::StatefulHost.new( region.nil? ? "analytics.algolia.com" : "analytics.{region}.algolia.com".sub!("{region}", region), accept: CallType::READ | CallType::WRITE ) config = Algolia::Configuration.new(app_id, api_key, hosts, "Abtesting", opts) create_with_config(config) end |
.create_with_config(config) ⇒ Object
38 39 40 |
# File 'lib/algolia/api/abtesting_client.rb', line 38 def self.create_with_config(config) new(config) end |
Instance Method Details
#add_ab_tests(add_ab_tests_request, request_options = {}) ⇒ ABTestResponse
Creates a new A/B test.
Required API Key ACLs:
- editSettings
89 90 91 92 |
# File 'lib/algolia/api/abtesting_client.rb', line 89 def add_ab_tests(add_ab_tests_request, = {}) response = add_ab_tests_with_http_info(add_ab_tests_request, ) @api_client.deserialize(response.body, [:debug_return_type] || "Abtesting::ABTestResponse") end |
#add_ab_tests_with_http_info(add_ab_tests_request, request_options = {}) ⇒ Http::Response
Creates a new A/B test.
Required API Key ACLs:
- editSettings
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/algolia/api/abtesting_client.rb', line 57 def add_ab_tests_with_http_info(add_ab_tests_request, = {}) # verify the required parameter 'add_ab_tests_request' is set if @api_client.config.client_side_validation && add_ab_tests_request.nil? raise ArgumentError, "Parameter `add_ab_tests_request` is required when calling `add_ab_tests`." end path = "/2/abtests" query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(add_ab_tests_request) = .merge( :operation => :"AbtestingClient.add_ab_tests", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:POST, path, ) end |
#custom_delete(path, parameters = nil, request_options = {}) ⇒ Object
132 133 134 135 |
# File 'lib/algolia/api/abtesting_client.rb', line 132 def custom_delete(path, parameters = nil, = {}) response = custom_delete_with_http_info(path, parameters, ) @api_client.deserialize(response.body, [:debug_return_type] || "Object") end |
#custom_delete_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
Returns the response.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/algolia/api/abtesting_client.rb', line 100 def custom_delete_with_http_info(path, parameters = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_delete`." end path = "/{path}".sub("{" + "path" + "}", path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :"AbtestingClient.custom_delete", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:DELETE, path, ) end |
#custom_get(path, parameters = nil, request_options = {}) ⇒ Object
175 176 177 178 |
# File 'lib/algolia/api/abtesting_client.rb', line 175 def custom_get(path, parameters = nil, = {}) response = custom_get_with_http_info(path, parameters, ) @api_client.deserialize(response.body, [:debug_return_type] || "Object") end |
#custom_get_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
Returns the response.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/algolia/api/abtesting_client.rb', line 143 def custom_get_with_http_info(path, parameters = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_get`." end path = "/{path}".sub("{" + "path" + "}", path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :"AbtestingClient.custom_get", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#custom_post(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
220 221 222 223 |
# File 'lib/algolia/api/abtesting_client.rb', line 220 def custom_post(path, parameters = nil, body = nil, = {}) response = custom_post_with_http_info(path, parameters, body, ) @api_client.deserialize(response.body, [:debug_return_type] || "Object") end |
#custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
Returns the response.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/algolia/api/abtesting_client.rb', line 187 def custom_post_with_http_info(path, parameters = nil, body = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_post`." end path = "/{path}".sub("{" + "path" + "}", path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(body) = .merge( :operation => :"AbtestingClient.custom_post", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:POST, path, ) end |
#custom_put(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
265 266 267 268 |
# File 'lib/algolia/api/abtesting_client.rb', line 265 def custom_put(path, parameters = nil, body = nil, = {}) response = custom_put_with_http_info(path, parameters, body, ) @api_client.deserialize(response.body, [:debug_return_type] || "Object") end |
#custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
Returns the response.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/algolia/api/abtesting_client.rb', line 232 def custom_put_with_http_info(path, parameters = nil, body = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_put`." end path = "/{path}".sub("{" + "path" + "}", path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(body) = .merge( :operation => :"AbtestingClient.custom_put", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:PUT, path, ) end |
#delete_ab_test(id, request_options = {}) ⇒ ABTestResponse
Deletes an A/B test by its ID.
Required API Key ACLs:
- editSettings
309 310 311 312 |
# File 'lib/algolia/api/abtesting_client.rb', line 309 def delete_ab_test(id, = {}) response = delete_ab_test_with_http_info(id, ) @api_client.deserialize(response.body, [:debug_return_type] || "Abtesting::ABTestResponse") end |
#delete_ab_test_with_http_info(id, request_options = {}) ⇒ Http::Response
Deletes an A/B test by its ID.
Required API Key ACLs:
- editSettings
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/algolia/api/abtesting_client.rb', line 277 def delete_ab_test_with_http_info(id, = {}) # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? raise ArgumentError, "Parameter `id` is required when calling `delete_ab_test`." end path = "/2/abtests/{id}".sub("{" + "id" + "}", Transport.encode_uri(id.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :"AbtestingClient.delete_ab_test", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:DELETE, path, ) end |
#get_ab_test(id, request_options = {}) ⇒ ABTest
Retrieves the details for an A/B test by its ID.
Required API Key ACLs:
- analytics
353 354 355 356 |
# File 'lib/algolia/api/abtesting_client.rb', line 353 def get_ab_test(id, = {}) response = get_ab_test_with_http_info(id, ) @api_client.deserialize(response.body, [:debug_return_type] || "Abtesting::ABTest") end |
#get_ab_test_with_http_info(id, request_options = {}) ⇒ Http::Response
Retrieves the details for an A/B test by its ID.
Required API Key ACLs:
- analytics
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/algolia/api/abtesting_client.rb', line 321 def get_ab_test_with_http_info(id, = {}) # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? raise ArgumentError, "Parameter `id` is required when calling `get_ab_test`." end path = "/2/abtests/{id}".sub("{" + "id" + "}", Transport.encode_uri(id.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :"AbtestingClient.get_ab_test", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#list_ab_tests(offset = nil, limit = nil, index_prefix = nil, index_suffix = nil, request_options = {}) ⇒ ListABTestsResponse
Lists all A/B tests you configured for this application.
Required API Key ACLs:
- analytics
415 416 417 418 |
# File 'lib/algolia/api/abtesting_client.rb', line 415 def list_ab_tests(offset = nil, limit = nil, index_prefix = nil, index_suffix = nil, = {}) response = list_ab_tests_with_http_info(offset, limit, index_prefix, index_suffix, ) @api_client.deserialize(response.body, [:debug_return_type] || "Abtesting::ListABTestsResponse") end |
#list_ab_tests_with_http_info(offset = nil, limit = nil, index_prefix = nil, index_suffix = nil, request_options = {}) ⇒ Http::Response
Lists all A/B tests you configured for this application.
Required API Key ACLs:
- analytics
368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/algolia/api/abtesting_client.rb', line 368 def list_ab_tests_with_http_info( offset = nil, limit = nil, index_prefix = nil, index_suffix = nil, = {} ) if @api_client.config.client_side_validation && !offset.nil? && offset < 0 raise( ArgumentError, "invalid value for \"\"offset\"\" when calling AbtestingClient.list_ab_tests, must be greater than or equal to 0." ) end path = "/2/abtests" query_params = {} query_params[:offset] = offset unless offset.nil? query_params[:limit] = limit unless limit.nil? query_params[:indexPrefix] = index_prefix unless index_prefix.nil? query_params[:indexSuffix] = index_suffix unless index_suffix.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :"AbtestingClient.list_ab_tests", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#schedule_ab_test(schedule_ab_tests_request, request_options = {}) ⇒ ScheduleABTestResponse
Schedule an A/B test to be started at a later time.
Required API Key ACLs:
- editSettings
459 460 461 462 |
# File 'lib/algolia/api/abtesting_client.rb', line 459 def schedule_ab_test(schedule_ab_tests_request, = {}) response = schedule_ab_test_with_http_info(schedule_ab_tests_request, ) @api_client.deserialize(response.body, [:debug_return_type] || "Abtesting::ScheduleABTestResponse") end |
#schedule_ab_test_with_http_info(schedule_ab_tests_request, request_options = {}) ⇒ Http::Response
Schedule an A/B test to be started at a later time.
Required API Key ACLs:
- editSettings
427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/algolia/api/abtesting_client.rb', line 427 def schedule_ab_test_with_http_info(schedule_ab_tests_request, = {}) # verify the required parameter 'schedule_ab_tests_request' is set if @api_client.config.client_side_validation && schedule_ab_tests_request.nil? raise ArgumentError, "Parameter `schedule_ab_tests_request` is required when calling `schedule_ab_test`." end path = "/2/abtests/schedule" query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(schedule_ab_tests_request) = .merge( :operation => :"AbtestingClient.schedule_ab_test", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:POST, path, ) end |
#set_client_api_key(api_key) ⇒ void
This method returns an undefined value.
Helper method to switch the API key used to authenticate the requests.
46 47 48 |
# File 'lib/algolia/api/abtesting_client.rb', line 46 def set_client_api_key(api_key) @api_client.set_client_api_key(api_key) end |
#stop_ab_test(id, request_options = {}) ⇒ ABTestResponse
Stops an A/B test by its ID. You can’t restart stopped A/B tests.
Required API Key ACLs:
- editSettings
503 504 505 506 |
# File 'lib/algolia/api/abtesting_client.rb', line 503 def stop_ab_test(id, = {}) response = stop_ab_test_with_http_info(id, ) @api_client.deserialize(response.body, [:debug_return_type] || "Abtesting::ABTestResponse") end |
#stop_ab_test_with_http_info(id, request_options = {}) ⇒ Http::Response
Stops an A/B test by its ID. You can't restart stopped A/B tests.
Required API Key ACLs:
- editSettings
471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 |
# File 'lib/algolia/api/abtesting_client.rb', line 471 def stop_ab_test_with_http_info(id, = {}) # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? raise ArgumentError, "Parameter `id` is required when calling `stop_ab_test`." end path = "/2/abtests/{id}/stop".sub("{" + "id" + "}", Transport.encode_uri(id.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :"AbtestingClient.stop_ab_test", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:POST, path, ) end |