Class: Algolia::AgentStudio::AgentWithVersionResponse
- Inherits:
-
Object
- Object
- Algolia::AgentStudio::AgentWithVersionResponse
- Defined in:
- lib/algolia/models/agent-studio/agent_with_version_response.rb
Instance Attribute Summary collapse
-
#config ⇒ Object
Returns the value of attribute config.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
Returns the value of attribute description.
-
#id ⇒ Object
Returns the value of attribute id.
-
#instructions ⇒ Object
Returns the value of attribute instructions.
-
#last_used_at ⇒ Object
Returns the value of attribute last_used_at.
-
#model ⇒ Object
Returns the value of attribute model.
-
#name ⇒ Object
Returns the value of attribute name.
-
#provider_id ⇒ Object
Returns the value of attribute provider_id.
-
#status ⇒ Object
Returns the value of attribute status.
-
#system_prompt ⇒ Object
Returns the value of attribute system_prompt.
-
#template_type ⇒ Object
Returns the value of attribute template_type.
-
#tools ⇒ Object
Returns the value of attribute tools.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AgentWithVersionResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ AgentWithVersionResponse
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) raise( ArgumentError, "The input argument (attributes) must be a hash in `Algolia::AgentWithVersionResponse` initialize method" ) end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) raise( ArgumentError, "`#{k}` is not a valid attribute in `Algolia::AgentWithVersionResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect ) end h[k.to_sym] = v } if attributes.key?(:id) self.id = attributes[:id] else self.id = nil end if attributes.key?(:name) self.name = attributes[:name] else self.name = nil end if attributes.key?(:description) self.description = attributes[:description] else self.description = nil end if attributes.key?(:status) self.status = attributes[:status] else self.status = nil end if attributes.key?(:provider_id) self.provider_id = attributes[:provider_id] else self.provider_id = nil end if attributes.key?(:model) self.model = attributes[:model] end if attributes.key?(:instructions) self.instructions = attributes[:instructions] else self.instructions = nil end if attributes.key?(:system_prompt) self.system_prompt = attributes[:system_prompt] end if attributes.key?(:config) if (value = attributes[:config]).is_a?(Hash) self.config = value end else self.config = nil end if attributes.key?(:tools) if (value = attributes[:tools]).is_a?(Array) self.tools = value end end if attributes.key?(:template_type) self.template_type = attributes[:template_type] end if attributes.key?(:created_at) self.created_at = attributes[:created_at] else self.created_at = nil end if attributes.key?(:updated_at) self.updated_at = attributes[:updated_at] else self.updated_at = nil end if attributes.key?(:last_used_at) self.last_used_at = attributes[:last_used_at] else self.last_used_at = nil end end |
Instance Attribute Details
#config ⇒ Object
Returns the value of attribute config.
27 28 29 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 27 def config @config end |
#created_at ⇒ Object
Returns the value of attribute created_at.
33 34 35 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 33 def created_at @created_at end |
#description ⇒ Object
Returns the value of attribute description.
15 16 17 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 15 def description @description end |
#id ⇒ Object
Returns the value of attribute id.
11 12 13 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 11 def id @id end |
#instructions ⇒ Object
Returns the value of attribute instructions.
23 24 25 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 23 def instructions @instructions end |
#last_used_at ⇒ Object
Returns the value of attribute last_used_at.
37 38 39 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 37 def last_used_at @last_used_at end |
#model ⇒ Object
Returns the value of attribute model.
21 22 23 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 21 def model @model end |
#name ⇒ Object
Returns the value of attribute name.
13 14 15 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 13 def name @name end |
#provider_id ⇒ Object
Returns the value of attribute provider_id.
19 20 21 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 19 def provider_id @provider_id end |
#status ⇒ Object
Returns the value of attribute status.
17 18 19 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 17 def status @status end |
#system_prompt ⇒ Object
Returns the value of attribute system_prompt.
25 26 27 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 25 def system_prompt @system_prompt end |
#template_type ⇒ Object
Returns the value of attribute template_type.
31 32 33 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 31 def template_type @template_type end |
#tools ⇒ Object
Returns the value of attribute tools.
29 30 31 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 29 def tools @tools end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
35 36 37 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 35 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 276 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end # model else # models (e.g. Pet) or oneOf klass = Algolia::AgentStudio.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass .build_from_hash(value) end end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 40 def self.attribute_map { :id => :id, :name => :name, :description => :description, :status => :status, :provider_id => :providerId, :model => :model, :instructions => :instructions, :system_prompt => :systemPrompt, :config => :config, :tools => :tools, :template_type => :templateType, :created_at => :createdAt, :updated_at => :updatedAt, :last_used_at => :lastUsedAt } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 249 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 80 def self.openapi_nullable Set.new( [ :description, :provider_id, :model, :system_prompt, :template_type, :updated_at, :last_used_at ] ) end |
.types_mapping ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 60 def self.types_mapping { :id => :"String", :name => :"String", :description => :"String", :status => :"AgentStatus", :provider_id => :"String", :model => :"String", :instructions => :"String", :system_prompt => :"String", :config => :"Hash<String, Object>", :tools => :"Array<ToolConfigInput>", :template_type => :"String", :created_at => :"String", :updated_at => :"String", :last_used_at => :"String" } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 200 def ==(other) return true if self.equal?(other) self.class == other.class && id == other.id && name == other.name && description == other.description && status == other.status && provider_id == other.provider_id && model == other.model && instructions == other.instructions && system_prompt == other.system_prompt && config == other.config && tools == other.tools && template_type == other.template_type && created_at == other.created_at && updated_at == other.updated_at && last_used_at == other.last_used_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 355 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to?(:to_hash) value.to_hash else value end end |
#eql?(other) ⇒ Boolean
221 222 223 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 221 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 227 def hash [ id, name, description, status, provider_id, model, instructions, system_prompt, config, tools, template_type, created_at, updated_at, last_used_at ].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
326 327 328 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 326 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 336 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
330 331 332 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 330 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
320 321 322 |
# File 'lib/algolia/models/agent-studio/agent_with_version_response.rb', line 320 def to_s to_hash.to_s end |