Class: Algolia::Ingestion::SourceDocker
- Inherits:
-
Object
- Object
- Algolia::Ingestion::SourceDocker
- Defined in:
- lib/algolia/models/ingestion/source_docker.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#configuration ⇒ Object
The configuration of the spec.
-
#image ⇒ Object
The name of the image to pull.
-
#image_type ⇒ Object
Returns the value of attribute image_type.
-
#registry ⇒ Object
Returns the value of attribute registry.
-
#version ⇒ Object
The version of the image, defaults to ‘latest`.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SourceDocker
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SourceDocker
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 78 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::SourceDocker` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::SourceDocker`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:image_type) self.image_type = attributes[:image_type] else self.image_type = nil end if attributes.key?(:registry) self.registry = attributes[:registry] else self.registry = nil end if attributes.key?(:image) self.image = attributes[:image] else self.image = nil end if attributes.key?(:version) self.version = attributes[:version] end if attributes.key?(:configuration) self.configuration = attributes[:configuration] else self.configuration = nil end end |
Instance Attribute Details
#configuration ⇒ Object
The configuration of the spec.
20 21 22 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 20 def configuration @configuration end |
#image ⇒ Object
The name of the image to pull.
14 15 16 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 14 def image @image end |
#image_type ⇒ Object
Returns the value of attribute image_type.
9 10 11 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 9 def image_type @image_type end |
#registry ⇒ Object
Returns the value of attribute registry.
11 12 13 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 11 def registry @registry end |
#version ⇒ Object
The version of the image, defaults to ‘latest`.
17 18 19 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 17 def version @version end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 175 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Ingestion.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
56 57 58 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 56 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 45 def self.attribute_map { :image_type => :imageType, :registry => :registry, :image => :image, :version => :version, :configuration => :configuration } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 150 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_s] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 72 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 61 def self.types_mapping { :image_type => :DockerImageType, :registry => :DockerRegistry, :image => :String, :version => :String, :configuration => :Object } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 132 133 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 124 def ==(other) return true if equal?(other) self.class == other.class && image_type == other.image_type && registry == other.registry && image == other.image && version == other.version && configuration == other.configuration end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 246 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
137 138 139 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 137 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 143 def hash [image_type, registry, image, version, configuration].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
222 223 224 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 222 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 228 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
216 217 218 |
# File 'lib/algolia/models/ingestion/source_docker.rb', line 216 def to_s to_hash.to_s end |