Class: Algolia::Monitoring::Server

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/monitoring/server.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Server

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/algolia/models/monitoring/server.rb', line 87

def initialize(attributes = {})
  unless attributes.is_a?(Hash)
    raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::Server` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) do |(k, v), h|
    unless self.class.attribute_map.key?(k.to_sym)
      raise ArgumentError,
            "`#{k}` is not a valid attribute in `Algolia::Server`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end

    h[k.to_sym] = v
  end

  if attributes.key?(:name)
    self.name = attributes[:name]
  end

  if attributes.key?(:region)
    self.region = attributes[:region]
  end

  if attributes.key?(:is_slave)
    self.is_slave = attributes[:is_slave]
  end

  if attributes.key?(:is_replica)
    self.is_replica = attributes[:is_replica]
  end

  if attributes.key?(:cluster)
    self.cluster = attributes[:cluster]
  end

  if attributes.key?(:status)
    self.status = attributes[:status]
  end

  if attributes.key?(:type)
    self.type = attributes[:type]
  end
end

Instance Attribute Details

#clusterObject

Name of the cluster to which this server belongs.



21
22
23
# File 'lib/algolia/models/monitoring/server.rb', line 21

def cluster
  @cluster
end

#is_replicaObject

Indicates whether this server is a replica of another server.



18
19
20
# File 'lib/algolia/models/monitoring/server.rb', line 18

def is_replica
  @is_replica
end

#is_slaveObject

Included to support legacy applications. Do not rely on this attribute being present in the response. Use ‘is_replica` instead.



15
16
17
# File 'lib/algolia/models/monitoring/server.rb', line 15

def is_slave
  @is_slave
end

#nameObject

Server name.



10
11
12
# File 'lib/algolia/models/monitoring/server.rb', line 10

def name
  @name
end

#regionObject

Returns the value of attribute region.



12
13
14
# File 'lib/algolia/models/monitoring/server.rb', line 12

def region
  @region
end

#statusObject

Returns the value of attribute status.



23
24
25
# File 'lib/algolia/models/monitoring/server.rb', line 23

def status
  @status
end

#typeObject

Returns the value of attribute type.



25
26
27
# File 'lib/algolia/models/monitoring/server.rb', line 25

def type
  @type
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/algolia/models/monitoring/server.rb', line 186

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Algolia::Monitoring.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/algolia/models/monitoring/server.rb', line 63

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
# File 'lib/algolia/models/monitoring/server.rb', line 50

def self.attribute_map
  {
    :name => :name,
    :region => :region,
    :is_slave => :is_slave,
    :is_replica => :is_replica,
    :cluster => :cluster,
    :status => :status,
    :type => :type
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/algolia/models/monitoring/server.rb', line 161

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)

  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
# File 'lib/algolia/models/monitoring/server.rb', line 81

def self.openapi_nullable
  Set.new([])
end

.types_mappingObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
# File 'lib/algolia/models/monitoring/server.rb', line 68

def self.types_mapping
  {
    :name => :String,
    :region => :Region,
    :is_slave => :Boolean,
    :is_replica => :Boolean,
    :cluster => :String,
    :status => :ServerStatus,
    :type => :Type
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/algolia/models/monitoring/server.rb', line 133

def ==(other)
  return true if equal?(other)

  self.class == other.class &&
    name == other.name &&
    region == other.region &&
    is_slave == other.is_slave &&
    is_replica == other.is_replica &&
    cluster == other.cluster &&
    status == other.status &&
    type == other.type
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/algolia/models/monitoring/server.rb', line 261

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


148
149
150
# File 'lib/algolia/models/monitoring/server.rb', line 148

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



154
155
156
# File 'lib/algolia/models/monitoring/server.rb', line 154

def hash
  [name, region, is_slave, is_replica, cluster, status, type].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
# File 'lib/algolia/models/monitoring/server.rb', line 233

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/algolia/models/monitoring/server.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*_args) ⇒ Object



237
238
239
# File 'lib/algolia/models/monitoring/server.rb', line 237

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



227
228
229
# File 'lib/algolia/models/monitoring/server.rb', line 227

def to_s
  to_hash.to_s
end