Class: Algolia::MonitoringClient

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/api/monitoring_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config = nil) ⇒ MonitoringClient

Returns a new instance of MonitoringClient.



7
8
9
10
11
12
13
# File 'lib/algolia/api/monitoring_client.rb', line 7

def initialize(config = nil)
  raise '`config` is missing.' if config.nil?
  raise '`app_id` is missing.' if config.app_id.nil? || config.app_id == ''
  raise '`api_key` is missing.' if config.api_key.nil? || config.api_key == ''

  @api_client = Algolia::ApiClient.new(config)
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



5
6
7
# File 'lib/algolia/api/monitoring_client.rb', line 5

def api_client
  @api_client
end

Class Method Details

.create(app_id, api_key, opts = {}) ⇒ Object



15
16
17
18
19
20
21
22
23
24
25
26
27
# File 'lib/algolia/api/monitoring_client.rb', line 15

def self.create(app_id, api_key, opts = {})
  hosts = []

  hosts << Transport::StatefulHost.new("#{app_id}-dsn.algolia.net", accept: CallType::READ)
  hosts << Transport::StatefulHost.new("#{app_id}.algolia.net", accept: CallType::WRITE)

  hosts += 1.upto(3).map do |i|
    Transport::StatefulHost.new("#{app_id}-#{i}.algolianet.com", accept: CallType::READ | CallType::WRITE)
  end.shuffle

  config = Algolia::Configuration.new(app_id, api_key, hosts, 'Monitoring', opts)
  create_with_config(config)
end

.create_with_config(config) ⇒ Object



29
30
31
# File 'lib/algolia/api/monitoring_client.rb', line 29

def self.create_with_config(config)
  new(config)
end

Instance Method Details

#custom_delete(path, parameters = nil, request_options = {}) ⇒ Object

Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (Object)


71
72
73
74
# File 'lib/algolia/api/monitoring_client.rb', line 71

def custom_delete(path, parameters = nil, request_options = {})
  response = custom_delete_with_http_info(path, parameters, request_options)
  deserialize(response.body, request_options[:debug_return_type] || 'Object')
end

#custom_delete_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response

Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/algolia/api/monitoring_client.rb', line 39

def custom_delete_with_http_info(path, parameters = nil, request_options = {})
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    raise ArgumentError, "Parameter `path` is required when calling `custom_delete`."
  end

  path = '/1{path}'.sub('{' + 'path' + '}', path.to_s)
  query_params = {}
  query_params = query_params.merge(parameters) unless parameters.nil?
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :'MonitoringClient.custom_delete',
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:DELETE, path, new_options)
end

#custom_get(path, parameters = nil, request_options = {}) ⇒ Object

Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (Object)


114
115
116
117
# File 'lib/algolia/api/monitoring_client.rb', line 114

def custom_get(path, parameters = nil, request_options = {})
  response = custom_get_with_http_info(path, parameters, request_options)
  deserialize(response.body, request_options[:debug_return_type] || 'Object')
end

#custom_get_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response

Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/algolia/api/monitoring_client.rb', line 82

def custom_get_with_http_info(path, parameters = nil, request_options = {})
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    raise ArgumentError, "Parameter `path` is required when calling `custom_get`."
  end

  path = '/1{path}'.sub('{' + 'path' + '}', path.to_s)
  query_params = {}
  query_params = query_params.merge(parameters) unless parameters.nil?
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :'MonitoringClient.custom_get',
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#custom_post(path, parameters = nil, body = nil, request_options = {}) ⇒ Object

Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • body (Object) (defaults to: nil)

    Parameters to send with the custom request.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (Object)


159
160
161
162
# File 'lib/algolia/api/monitoring_client.rb', line 159

def custom_post(path, parameters = nil, body = nil, request_options = {})
  response = custom_post_with_http_info(path, parameters, body, request_options)
  deserialize(response.body, request_options[:debug_return_type] || 'Object')
end

#custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response

Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • body (Object) (defaults to: nil)

    Parameters to send with the custom request.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/algolia/api/monitoring_client.rb', line 126

def custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {})
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    raise ArgumentError, "Parameter `path` is required when calling `custom_post`."
  end

  path = '/1{path}'.sub('{' + 'path' + '}', path.to_s)
  query_params = {}
  query_params = query_params.merge(parameters) unless parameters.nil?
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body] || @api_client.object_to_http_body(body)

  new_options = request_options.merge(
    :operation => :'MonitoringClient.custom_post',
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:POST, path, new_options)
end

#custom_put(path, parameters = nil, body = nil, request_options = {}) ⇒ Object

Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • body (Object) (defaults to: nil)

    Parameters to send with the custom request.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (Object)


204
205
206
207
# File 'lib/algolia/api/monitoring_client.rb', line 204

def custom_put(path, parameters = nil, body = nil, request_options = {})
  response = custom_put_with_http_info(path, parameters, body, request_options)
  deserialize(response.body, request_options[:debug_return_type] || 'Object')
end

#custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response

Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • body (Object) (defaults to: nil)

    Parameters to send with the custom request.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/algolia/api/monitoring_client.rb', line 171

def custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {})
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    raise ArgumentError, "Parameter `path` is required when calling `custom_put`."
  end

  path = '/1{path}'.sub('{' + 'path' + '}', path.to_s)
  query_params = {}
  query_params = query_params.merge(parameters) unless parameters.nil?
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body] || @api_client.object_to_http_body(body)

  new_options = request_options.merge(
    :operation => :'MonitoringClient.custom_put',
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:PUT, path, new_options)
end

#get_cluster_incidents(clusters, request_options = {}) ⇒ IncidentsResponse

List incidents for selected clusters. List known incidents for selected clusters.

Parameters:

  • clusters (String)

    Subset of clusters, separated by comma. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (IncidentsResponse)


244
245
246
247
# File 'lib/algolia/api/monitoring_client.rb', line 244

def get_cluster_incidents(clusters, request_options = {})
  response = get_cluster_incidents_with_http_info(clusters, request_options)
  deserialize(response.body, request_options[:debug_return_type] || 'Monitoring::IncidentsResponse')
end

#get_cluster_incidents_with_http_info(clusters, request_options = {}) ⇒ Http::Response

List incidents for selected clusters. List known incidents for selected clusters.

Parameters:

  • clusters (String)

    Subset of clusters, separated by comma. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/algolia/api/monitoring_client.rb', line 214

def get_cluster_incidents_with_http_info(clusters, request_options = {})
  # verify the required parameter 'clusters' is set
  if @api_client.config.client_side_validation && clusters.nil?
    raise ArgumentError, "Parameter `clusters` is required when calling `get_cluster_incidents`."
  end

  path = '/1/incidents/{clusters}'.sub('{' + 'clusters' + '}', @api_client.encode_uri(clusters.to_s))
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :'MonitoringClient.get_cluster_incidents',
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#get_cluster_status(clusters, request_options = {}) ⇒ StatusResponse

List statuses of selected clusters. Report whether a cluster is operational.

Parameters:

  • clusters (String)

    Subset of clusters, separated by comma. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (StatusResponse)


284
285
286
287
# File 'lib/algolia/api/monitoring_client.rb', line 284

def get_cluster_status(clusters, request_options = {})
  response = get_cluster_status_with_http_info(clusters, request_options)
  deserialize(response.body, request_options[:debug_return_type] || 'Monitoring::StatusResponse')
end

#get_cluster_status_with_http_info(clusters, request_options = {}) ⇒ Http::Response

List statuses of selected clusters. Report whether a cluster is operational.

Parameters:

  • clusters (String)

    Subset of clusters, separated by comma. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/algolia/api/monitoring_client.rb', line 254

def get_cluster_status_with_http_info(clusters, request_options = {})
  # verify the required parameter 'clusters' is set
  if @api_client.config.client_side_validation && clusters.nil?
    raise ArgumentError, "Parameter `clusters` is required when calling `get_cluster_status`."
  end

  path = '/1/status/{clusters}'.sub('{' + 'clusters' + '}', @api_client.encode_uri(clusters.to_s))
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :'MonitoringClient.get_cluster_status',
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#get_incidents(request_options = {}) ⇒ IncidentsResponse

List incidents. List known incidents for all clusters.

Parameters:

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (IncidentsResponse)


317
318
319
320
# File 'lib/algolia/api/monitoring_client.rb', line 317

def get_incidents(request_options = {})
  response = get_incidents_with_http_info(request_options)
  deserialize(response.body, request_options[:debug_return_type] || 'Monitoring::IncidentsResponse')
end

#get_incidents_with_http_info(request_options = {}) ⇒ Http::Response

List incidents. List known incidents for all clusters.

Parameters:

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/algolia/api/monitoring_client.rb', line 293

def get_incidents_with_http_info(request_options = {})
  path = '/1/incidents'
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :'MonitoringClient.get_incidents',
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#get_indexing_time(clusters, request_options = {}) ⇒ IndexingTimeResponse

Get indexing times. List the average times for indexing operations for selected clusters.

Parameters:

  • clusters (String)

    Subset of clusters, separated by comma. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (IndexingTimeResponse)


357
358
359
360
# File 'lib/algolia/api/monitoring_client.rb', line 357

def get_indexing_time(clusters, request_options = {})
  response = get_indexing_time_with_http_info(clusters, request_options)
  deserialize(response.body, request_options[:debug_return_type] || 'Monitoring::IndexingTimeResponse')
end

#get_indexing_time_with_http_info(clusters, request_options = {}) ⇒ Http::Response

Get indexing times. List the average times for indexing operations for selected clusters.

Parameters:

  • clusters (String)

    Subset of clusters, separated by comma. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/algolia/api/monitoring_client.rb', line 327

def get_indexing_time_with_http_info(clusters, request_options = {})
  # verify the required parameter 'clusters' is set
  if @api_client.config.client_side_validation && clusters.nil?
    raise ArgumentError, "Parameter `clusters` is required when calling `get_indexing_time`."
  end

  path = '/1/indexing/{clusters}'.sub('{' + 'clusters' + '}', @api_client.encode_uri(clusters.to_s))
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :'MonitoringClient.get_indexing_time',
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#get_inventory(request_options = {}) ⇒ InventoryResponse

List servers. List the servers belonging to clusters. The response depends on whether you authenticate your API request: - With authentication, the response lists the servers assigned to your Algolia application’s cluster. - Without authentication, the response lists the servers for all Algolia clusters.

Parameters:

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (InventoryResponse)


390
391
392
393
# File 'lib/algolia/api/monitoring_client.rb', line 390

def get_inventory(request_options = {})
  response = get_inventory_with_http_info(request_options)
  deserialize(response.body, request_options[:debug_return_type] || 'Monitoring::InventoryResponse')
end

#get_inventory_with_http_info(request_options = {}) ⇒ Http::Response

List servers. List the servers belonging to clusters. The response depends on whether you authenticate your API request: - With authentication, the response lists the servers assigned to your Algolia application&#39;s cluster. - Without authentication, the response lists the servers for all Algolia clusters.

Parameters:

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/algolia/api/monitoring_client.rb', line 366

def get_inventory_with_http_info(request_options = {})
  path = '/1/inventory/servers'
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :'MonitoringClient.get_inventory',
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#get_latency(clusters, request_options = {}) ⇒ LatencyResponse

Get search latency times. List the average latency for search requests for selected clusters.

Parameters:

  • clusters (String)

    Subset of clusters, separated by comma. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (LatencyResponse)


430
431
432
433
# File 'lib/algolia/api/monitoring_client.rb', line 430

def get_latency(clusters, request_options = {})
  response = get_latency_with_http_info(clusters, request_options)
  deserialize(response.body, request_options[:debug_return_type] || 'Monitoring::LatencyResponse')
end

#get_latency_with_http_info(clusters, request_options = {}) ⇒ Http::Response

Get search latency times. List the average latency for search requests for selected clusters.

Parameters:

  • clusters (String)

    Subset of clusters, separated by comma. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/algolia/api/monitoring_client.rb', line 400

def get_latency_with_http_info(clusters, request_options = {})
  # verify the required parameter 'clusters' is set
  if @api_client.config.client_side_validation && clusters.nil?
    raise ArgumentError, "Parameter `clusters` is required when calling `get_latency`."
  end

  path = '/1/latency/{clusters}'.sub('{' + 'clusters' + '}', @api_client.encode_uri(clusters.to_s))
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :'MonitoringClient.get_latency',
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#get_metrics(metric, period, request_options = {}) ⇒ InfrastructureResponse

Get metrics for a given period. Report the aggregate value of a metric for a selected period of time.

Parameters:

  • metric (Metric)

    Metric to report. For more information about the individual metrics, see the response. To include all metrics, use &#x60;*&#x60; as the parameter. (required)

  • period (Period)

    Period over which to aggregate the metrics: - &#x60;minute&#x60;. Aggregate the last minute. 1 data point per 10 seconds. - &#x60;hour&#x60;. Aggregate the last hour. 1 data point per minute. - &#x60;day&#x60;. Aggregate the last day. 1 data point per 10 minutes. - &#x60;week&#x60;. Aggregate the last week. 1 data point per hour. - &#x60;month&#x60;. Aggregate the last month. 1 data point per day. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (InfrastructureResponse)


477
478
479
480
# File 'lib/algolia/api/monitoring_client.rb', line 477

def get_metrics(metric, period, request_options = {})
  response = get_metrics_with_http_info(metric, period, request_options)
  deserialize(response.body, request_options[:debug_return_type] || 'Monitoring::InfrastructureResponse')
end

#get_metrics_with_http_info(metric, period, request_options = {}) ⇒ Http::Response

Get metrics for a given period. Report the aggregate value of a metric for a selected period of time.

Parameters:

  • metric (Metric)

    Metric to report. For more information about the individual metrics, see the response. To include all metrics, use &#x60;*&#x60; as the parameter. (required)

  • period (Period)

    Period over which to aggregate the metrics: - &#x60;minute&#x60;. Aggregate the last minute. 1 data point per 10 seconds. - &#x60;hour&#x60;. Aggregate the last hour. 1 data point per minute. - &#x60;day&#x60;. Aggregate the last day. 1 data point per 10 minutes. - &#x60;week&#x60;. Aggregate the last week. 1 data point per hour. - &#x60;month&#x60;. Aggregate the last month. 1 data point per day. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/algolia/api/monitoring_client.rb', line 441

def get_metrics_with_http_info(metric, period, request_options = {})
  # verify the required parameter 'metric' is set
  if @api_client.config.client_side_validation && metric.nil?
    raise ArgumentError, "Parameter `metric` is required when calling `get_metrics`."
  end
  # verify the required parameter 'period' is set
  if @api_client.config.client_side_validation && period.nil?
    raise ArgumentError, "Parameter `period` is required when calling `get_metrics`."
  end

  path = '/1/infrastructure/{metric}/period/{period}'.sub('{' + 'metric' + '}', @api_client.encode_uri(metric.to_s)).sub('{' + 'period' + '}',
                                                                                                                         @api_client.encode_uri(period.to_s))
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :'MonitoringClient.get_metrics',
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#get_reachability(clusters, request_options = {}) ⇒ Hash<String, Hash>

Test the reachability of clusters. Test whether clusters are reachable or not.

Parameters:

  • clusters (String)

    Subset of clusters, separated by comma. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (Hash<String, Hash>)


517
518
519
520
# File 'lib/algolia/api/monitoring_client.rb', line 517

def get_reachability(clusters, request_options = {})
  response = get_reachability_with_http_info(clusters, request_options)
  deserialize(response.body, request_options[:debug_return_type] || 'Monitoring::Hash<String, Hash>')
end

#get_reachability_with_http_info(clusters, request_options = {}) ⇒ Http::Response

Test the reachability of clusters. Test whether clusters are reachable or not.

Parameters:

  • clusters (String)

    Subset of clusters, separated by comma. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
# File 'lib/algolia/api/monitoring_client.rb', line 487

def get_reachability_with_http_info(clusters, request_options = {})
  # verify the required parameter 'clusters' is set
  if @api_client.config.client_side_validation && clusters.nil?
    raise ArgumentError, "Parameter `clusters` is required when calling `get_reachability`."
  end

  path = '/1/reachability/{clusters}/probes'.sub('{' + 'clusters' + '}', @api_client.encode_uri(clusters.to_s))
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :'MonitoringClient.get_reachability',
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#get_status(request_options = {}) ⇒ StatusResponse

List cluster statuses. Report whether clusters are operational. The response depends on whether you authenticate your API request. - With authentication, the response includes the status of the cluster assigned to your Algolia application. - Without authentication, the response lists the statuses of all public Algolia clusters.

Parameters:

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (StatusResponse)


550
551
552
553
# File 'lib/algolia/api/monitoring_client.rb', line 550

def get_status(request_options = {})
  response = get_status_with_http_info(request_options)
  deserialize(response.body, request_options[:debug_return_type] || 'Monitoring::StatusResponse')
end

#get_status_with_http_info(request_options = {}) ⇒ Http::Response

List cluster statuses. Report whether clusters are operational. The response depends on whether you authenticate your API request. - With authentication, the response includes the status of the cluster assigned to your Algolia application. - Without authentication, the response lists the statuses of all public Algolia clusters.

Parameters:

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
# File 'lib/algolia/api/monitoring_client.rb', line 526

def get_status_with_http_info(request_options = {})
  path = '/1/status'
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :'MonitoringClient.get_status',
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end