Class: Algolia::PersonalizationClient
- Inherits:
-
Object
- Object
- Algolia::PersonalizationClient
- Defined in:
- lib/algolia/api/personalization_client.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Class Method Summary collapse
Instance Method Summary collapse
- #custom_delete(path, parameters = nil, request_options = {}) ⇒ Object
-
#custom_delete_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
The response.
- #custom_get(path, parameters = nil, request_options = {}) ⇒ Object
-
#custom_get_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
The response.
- #custom_post(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
-
#custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
The response.
- #custom_put(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
-
#custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
The response.
-
#delete_user_profile(user_token, request_options = {}) ⇒ DeleteUserProfileResponse
Deletes a user profile.
-
#delete_user_profile_with_http_info(user_token, request_options = {}) ⇒ Http::Response
Deletes a user profile.
-
#get_personalization_strategy(request_options = {}) ⇒ PersonalizationStrategyParams
Retrieves the current personalization strategy.
-
#get_personalization_strategy_with_http_info(request_options = {}) ⇒ Http::Response
Retrieves the current personalization strategy.
-
#get_user_token_profile(user_token, request_options = {}) ⇒ GetUserTokenResponse
Retrieves a user profile and their affinities for different facets.
-
#get_user_token_profile_with_http_info(user_token, request_options = {}) ⇒ Http::Response
Retrieves a user profile and their affinities for different facets.
-
#initialize(config = nil) ⇒ PersonalizationClient
constructor
A new instance of PersonalizationClient.
-
#set_personalization_strategy(personalization_strategy_params, request_options = {}) ⇒ SetPersonalizationStrategyResponse
Creates a new personalization strategy.
-
#set_personalization_strategy_with_http_info(personalization_strategy_params, request_options = {}) ⇒ Http::Response
Creates a new personalization strategy.
Constructor Details
#initialize(config = nil) ⇒ PersonalizationClient
Returns a new instance of PersonalizationClient.
7 8 9 10 11 12 13 |
# File 'lib/algolia/api/personalization_client.rb', line 7 def initialize(config = nil) raise '`config` is missing.' if config.nil? raise '`app_id` is missing.' if config.app_id.nil? || config.app_id == '' raise '`api_key` is missing.' if config.api_key.nil? || config.api_key == '' @api_client = Algolia::ApiClient.new(config) end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
5 6 7 |
# File 'lib/algolia/api/personalization_client.rb', line 5 def api_client @api_client end |
Class Method Details
.create(app_id, api_key, region = nil, opts = {}) ⇒ Object
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/algolia/api/personalization_client.rb', line 15 def self.create(app_id, api_key, region = nil, opts = {}) hosts = [] regions = ['eu', 'us'] if region.is_a?(Hash) && (opts.nil? || opts.empty?) opts = region region = nil end raise "`region` is required and must be one of the following: #{regions.join(', ')}" if region.nil? || !region.is_a?(String) || !regions.include?(region) hosts << Transport::StatefulHost.new('personalization.{region}.algolia.com'.sub!('{region}', region), accept: CallType::READ | CallType::WRITE) config = Algolia::Configuration.new(app_id, api_key, hosts, 'Personalization', opts) create_with_config(config) end |
.create_with_config(config) ⇒ Object
32 33 34 |
# File 'lib/algolia/api/personalization_client.rb', line 32 def self.create_with_config(config) new(config) end |
Instance Method Details
#custom_delete(path, parameters = nil, request_options = {}) ⇒ Object
74 75 76 77 |
# File 'lib/algolia/api/personalization_client.rb', line 74 def custom_delete(path, parameters = nil, = {}) response = custom_delete_with_http_info(path, parameters, ) @api_client.deserialize(response.body, [:debug_return_type] || 'Object') end |
#custom_delete_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
Returns the response.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/algolia/api/personalization_client.rb', line 42 def custom_delete_with_http_info(path, parameters = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_delete`." end path = '/{path}'.sub('{' + 'path' + '}', path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :'PersonalizationClient.custom_delete', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:DELETE, path, ) end |
#custom_get(path, parameters = nil, request_options = {}) ⇒ Object
117 118 119 120 |
# File 'lib/algolia/api/personalization_client.rb', line 117 def custom_get(path, parameters = nil, = {}) response = custom_get_with_http_info(path, parameters, ) @api_client.deserialize(response.body, [:debug_return_type] || 'Object') end |
#custom_get_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
Returns the response.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/algolia/api/personalization_client.rb', line 85 def custom_get_with_http_info(path, parameters = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_get`." end path = '/{path}'.sub('{' + 'path' + '}', path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :'PersonalizationClient.custom_get', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#custom_post(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
162 163 164 165 |
# File 'lib/algolia/api/personalization_client.rb', line 162 def custom_post(path, parameters = nil, body = nil, = {}) response = custom_post_with_http_info(path, parameters, body, ) @api_client.deserialize(response.body, [:debug_return_type] || 'Object') end |
#custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
Returns the response.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/algolia/api/personalization_client.rb', line 129 def custom_post_with_http_info(path, parameters = nil, body = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_post`." end path = '/{path}'.sub('{' + 'path' + '}', path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(body) = .merge( :operation => :'PersonalizationClient.custom_post', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:POST, path, ) end |
#custom_put(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
207 208 209 210 |
# File 'lib/algolia/api/personalization_client.rb', line 207 def custom_put(path, parameters = nil, body = nil, = {}) response = custom_put_with_http_info(path, parameters, body, ) @api_client.deserialize(response.body, [:debug_return_type] || 'Object') end |
#custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
Returns the response.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/algolia/api/personalization_client.rb', line 174 def custom_put_with_http_info(path, parameters = nil, body = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_put`." end path = '/{path}'.sub('{' + 'path' + '}', path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(body) = .merge( :operation => :'PersonalizationClient.custom_put', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:PUT, path, ) end |
#delete_user_profile(user_token, request_options = {}) ⇒ DeleteUserProfileResponse
Deletes a user profile. The response includes a date and time when the user profile can safely be considered deleted.
Required API Key ACLs:
- recommendation
251 252 253 254 |
# File 'lib/algolia/api/personalization_client.rb', line 251 def delete_user_profile(user_token, = {}) response = delete_user_profile_with_http_info(user_token, ) @api_client.deserialize(response.body, [:debug_return_type] || 'Personalization::DeleteUserProfileResponse') end |
#delete_user_profile_with_http_info(user_token, request_options = {}) ⇒ Http::Response
Deletes a user profile. The response includes a date and time when the user profile can safely be considered deleted.
Required API Key ACLs:
- recommendation
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/algolia/api/personalization_client.rb', line 219 def delete_user_profile_with_http_info(user_token, = {}) # verify the required parameter 'user_token' is set if @api_client.config.client_side_validation && user_token.nil? raise ArgumentError, "Parameter `user_token` is required when calling `delete_user_profile`." end path = '/1/profiles/{userToken}'.sub('{' + 'userToken' + '}', Transport.encode_uri(user_token.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :'PersonalizationClient.delete_user_profile', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:DELETE, path, ) end |
#get_personalization_strategy(request_options = {}) ⇒ PersonalizationStrategyParams
Retrieves the current personalization strategy.
Required API Key ACLs:
- recommendation
288 289 290 291 |
# File 'lib/algolia/api/personalization_client.rb', line 288 def get_personalization_strategy( = {}) response = get_personalization_strategy_with_http_info() @api_client.deserialize(response.body, [:debug_return_type] || 'Personalization::PersonalizationStrategyParams') end |
#get_personalization_strategy_with_http_info(request_options = {}) ⇒ Http::Response
Retrieves the current personalization strategy.
Required API Key ACLs:
- recommendation
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/algolia/api/personalization_client.rb', line 262 def get_personalization_strategy_with_http_info( = {}) path = '/1/strategies/personalization' query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :'PersonalizationClient.get_personalization_strategy', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#get_user_token_profile(user_token, request_options = {}) ⇒ GetUserTokenResponse
Retrieves a user profile and their affinities for different facets.
Required API Key ACLs:
- recommendation
332 333 334 335 |
# File 'lib/algolia/api/personalization_client.rb', line 332 def get_user_token_profile(user_token, = {}) response = get_user_token_profile_with_http_info(user_token, ) @api_client.deserialize(response.body, [:debug_return_type] || 'Personalization::GetUserTokenResponse') end |
#get_user_token_profile_with_http_info(user_token, request_options = {}) ⇒ Http::Response
Retrieves a user profile and their affinities for different facets.
Required API Key ACLs:
- recommendation
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/algolia/api/personalization_client.rb', line 300 def get_user_token_profile_with_http_info(user_token, = {}) # verify the required parameter 'user_token' is set if @api_client.config.client_side_validation && user_token.nil? raise ArgumentError, "Parameter `user_token` is required when calling `get_user_token_profile`." end path = '/1/profiles/personalization/{userToken}'.sub('{' + 'userToken' + '}', Transport.encode_uri(user_token.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :'PersonalizationClient.get_user_token_profile', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#set_personalization_strategy(personalization_strategy_params, request_options = {}) ⇒ SetPersonalizationStrategyResponse
Creates a new personalization strategy.
Required API Key ACLs:
- recommendation
376 377 378 379 |
# File 'lib/algolia/api/personalization_client.rb', line 376 def set_personalization_strategy(personalization_strategy_params, = {}) response = set_personalization_strategy_with_http_info(personalization_strategy_params, ) @api_client.deserialize(response.body, [:debug_return_type] || 'Personalization::SetPersonalizationStrategyResponse') end |
#set_personalization_strategy_with_http_info(personalization_strategy_params, request_options = {}) ⇒ Http::Response
Creates a new personalization strategy.
Required API Key ACLs:
- recommendation
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/algolia/api/personalization_client.rb', line 344 def set_personalization_strategy_with_http_info(personalization_strategy_params, = {}) # verify the required parameter 'personalization_strategy_params' is set if @api_client.config.client_side_validation && personalization_strategy_params.nil? raise ArgumentError, "Parameter `personalization_strategy_params` is required when calling `set_personalization_strategy`." end path = '/1/strategies/personalization' query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(personalization_strategy_params) = .merge( :operation => :'PersonalizationClient.set_personalization_strategy', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:POST, path, ) end |