Class: Algolia::PersonalizationClient

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/api/personalization_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config = nil) ⇒ PersonalizationClient



7
8
9
10
11
12
13
# File 'lib/algolia/api/personalization_client.rb', line 7

def initialize(config = nil)
  raise "`config` is missing." if config.nil?
  raise "`app_id` is missing." if config.app_id.nil? || config.app_id == ""
  raise "`api_key` is missing." if config.api_key.nil? || config.api_key == ""

  @api_client = Algolia::ApiClient.new(config)
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



5
6
7
# File 'lib/algolia/api/personalization_client.rb', line 5

def api_client
  @api_client
end

Class Method Details

.create(app_id, api_key, region = nil, opts = {}) ⇒ Object



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/algolia/api/personalization_client.rb', line 15

def self.create(app_id, api_key, region = nil, opts = {})
  hosts = []
  regions = ["eu", "us"]

  if region.is_a?(Hash) && (opts.nil? || opts.empty?)
    opts = region
    region = nil
  end

  if opts.nil? || opts[:connect_timeout].nil?
    opts[:connect_timeout] = 2000
  end

  if opts.nil? || opts[:read_timeout].nil?
    opts[:read_timeout] = 5000
  end

  if opts.nil? || opts[:write_timeout].nil?
    opts[:write_timeout] = 30000
  end

  if region.nil? || !region.is_a?(String) || !regions.include?(region)
    raise "`region` is required and must be one of the following: #{regions.join(", ")}"
  end

  hosts <<
    Transport::StatefulHost.new(
      "personalization.{region}.algolia.com".sub!("{region}", region),
      accept: CallType::READ | CallType::WRITE
    )

  config = Algolia::Configuration.new(app_id, api_key, hosts, "Personalization", opts)
  create_with_config(config)
end

.create_with_config(config) ⇒ Object



50
51
52
# File 'lib/algolia/api/personalization_client.rb', line 50

def self.create_with_config(config)
  new(config)
end

Instance Method Details

#add_user_agent_segment(segment, version = nil) ⇒ Object



64
65
66
67
68
# File 'lib/algolia/api/personalization_client.rb', line 64

def add_user_agent_segment(segment, version = nil)
  @api_client.config.add_user_agent_segment(segment, version)

  self
end

#custom_delete(path, parameters = nil, request_options = {}) ⇒ Object



108
109
110
111
# File 'lib/algolia/api/personalization_client.rb', line 108

def custom_delete(path, parameters = nil, request_options = {})
  response = custom_delete_with_http_info(path, parameters, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "Object")
end

#custom_delete_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/algolia/api/personalization_client.rb', line 76

def custom_delete_with_http_info(path, parameters = nil, request_options = {})
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    raise ArgumentError, "Parameter `path` is required when calling `custom_delete`."
  end

  path = "/{path}".sub("{" + "path" + "}", path.to_s)
  query_params = {}
  query_params = query_params.merge(parameters) unless parameters.nil?
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :"PersonalizationClient.custom_delete",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:DELETE, path, new_options)
end

#custom_get(path, parameters = nil, request_options = {}) ⇒ Object



151
152
153
154
# File 'lib/algolia/api/personalization_client.rb', line 151

def custom_get(path, parameters = nil, request_options = {})
  response = custom_get_with_http_info(path, parameters, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "Object")
end

#custom_get_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/algolia/api/personalization_client.rb', line 119

def custom_get_with_http_info(path, parameters = nil, request_options = {})
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    raise ArgumentError, "Parameter `path` is required when calling `custom_get`."
  end

  path = "/{path}".sub("{" + "path" + "}", path.to_s)
  query_params = {}
  query_params = query_params.merge(parameters) unless parameters.nil?
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :"PersonalizationClient.custom_get",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#custom_post(path, parameters = nil, body = nil, request_options = {}) ⇒ Object



196
197
198
199
# File 'lib/algolia/api/personalization_client.rb', line 196

def custom_post(path, parameters = nil, body = nil, request_options = {})
  response = custom_post_with_http_info(path, parameters, body, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "Object")
end

#custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/algolia/api/personalization_client.rb', line 163

def custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {})
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    raise ArgumentError, "Parameter `path` is required when calling `custom_post`."
  end

  path = "/{path}".sub("{" + "path" + "}", path.to_s)
  query_params = {}
  query_params = query_params.merge(parameters) unless parameters.nil?
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body] || @api_client.object_to_http_body(body)

  new_options = request_options.merge(
    :operation => :"PersonalizationClient.custom_post",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:POST, path, new_options)
end

#custom_put(path, parameters = nil, body = nil, request_options = {}) ⇒ Object



241
242
243
244
# File 'lib/algolia/api/personalization_client.rb', line 241

def custom_put(path, parameters = nil, body = nil, request_options = {})
  response = custom_put_with_http_info(path, parameters, body, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "Object")
end

#custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/algolia/api/personalization_client.rb', line 208

def custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {})
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    raise ArgumentError, "Parameter `path` is required when calling `custom_put`."
  end

  path = "/{path}".sub("{" + "path" + "}", path.to_s)
  query_params = {}
  query_params = query_params.merge(parameters) unless parameters.nil?
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body] || @api_client.object_to_http_body(body)

  new_options = request_options.merge(
    :operation => :"PersonalizationClient.custom_put",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:PUT, path, new_options)
end

#delete_user_profile(user_token, request_options = {}) ⇒ DeleteUserProfileResponse

Deletes a user profile. The response includes a date and time when the user profile can safely be considered deleted.

Required API Key ACLs:

- recommendation


285
286
287
288
289
290
291
# File 'lib/algolia/api/personalization_client.rb', line 285

def (user_token, request_options = {})
  response = (user_token, request_options)
  @api_client.deserialize(
    response.body,
    request_options[:debug_return_type] || "Personalization::DeleteUserProfileResponse"
  )
end

#delete_user_profile_with_http_info(user_token, request_options = {}) ⇒ Http::Response

Deletes a user profile. The response includes a date and time when the user profile can safely be considered deleted.

Required API Key ACLs:

- recommendation


253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/algolia/api/personalization_client.rb', line 253

def (user_token, request_options = {})
  # verify the required parameter 'user_token' is set
  if @api_client.config.client_side_validation && user_token.nil?
    raise ArgumentError, "Parameter `user_token` is required when calling `delete_user_profile`."
  end

  path = "/1/profiles/{userToken}".sub("{" + "userToken" + "}", Transport.encode_uri(user_token.to_s))
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :"PersonalizationClient.delete_user_profile",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:DELETE, path, new_options)
end

#get_personalization_strategy(request_options = {}) ⇒ PersonalizationStrategyParams

Retrieves the current personalization strategy.

Required API Key ACLs:

- recommendation


325
326
327
328
329
330
331
# File 'lib/algolia/api/personalization_client.rb', line 325

def get_personalization_strategy(request_options = {})
  response = get_personalization_strategy_with_http_info(request_options)
  @api_client.deserialize(
    response.body,
    request_options[:debug_return_type] || "Personalization::PersonalizationStrategyParams"
  )
end

#get_personalization_strategy_with_http_info(request_options = {}) ⇒ Http::Response

Retrieves the current personalization strategy.

Required API Key ACLs:

- recommendation


299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/algolia/api/personalization_client.rb', line 299

def get_personalization_strategy_with_http_info(request_options = {})
  path = "/1/strategies/personalization"
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :"PersonalizationClient.get_personalization_strategy",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#get_user_token_profile(user_token, request_options = {}) ⇒ GetUserTokenResponse

Retrieves a user profile and their affinities for different facets.

Required API Key ACLs:

- recommendation


375
376
377
378
379
380
381
# File 'lib/algolia/api/personalization_client.rb', line 375

def get_user_token_profile(user_token, request_options = {})
  response = get_user_token_profile_with_http_info(user_token, request_options)
  @api_client.deserialize(
    response.body,
    request_options[:debug_return_type] || "Personalization::GetUserTokenResponse"
  )
end

#get_user_token_profile_with_http_info(user_token, request_options = {}) ⇒ Http::Response

Retrieves a user profile and their affinities for different facets.

Required API Key ACLs:

- recommendation


340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/algolia/api/personalization_client.rb', line 340

def get_user_token_profile_with_http_info(user_token, request_options = {})
  # verify the required parameter 'user_token' is set
  if @api_client.config.client_side_validation && user_token.nil?
    raise ArgumentError, "Parameter `user_token` is required when calling `get_user_token_profile`."
  end

  path = "/1/profiles/personalization/{userToken}".sub(
    "{" + "userToken" + "}",
    Transport.encode_uri(user_token.to_s)
  )
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :"PersonalizationClient.get_user_token_profile",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#set_client_api_key(api_key) ⇒ void

This method returns an undefined value.

Helper method to switch the API key used to authenticate the requests.



58
59
60
61
62
# File 'lib/algolia/api/personalization_client.rb', line 58

def set_client_api_key(api_key)
  @api_client.set_client_api_key(api_key)

  self
end

#set_personalization_strategy(personalization_strategy_params, request_options = {}) ⇒ SetPersonalizationStrategyResponse

Creates a new personalization strategy.

Required API Key ACLs:

- recommendation


425
426
427
428
429
430
431
# File 'lib/algolia/api/personalization_client.rb', line 425

def set_personalization_strategy(personalization_strategy_params, request_options = {})
  response = set_personalization_strategy_with_http_info(personalization_strategy_params, request_options)
  @api_client.deserialize(
    response.body,
    request_options[:debug_return_type] || "Personalization::SetPersonalizationStrategyResponse"
  )
end

#set_personalization_strategy_with_http_info(personalization_strategy_params, request_options = {}) ⇒ Http::Response

Creates a new personalization strategy.

Required API Key ACLs:

- recommendation


390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/algolia/api/personalization_client.rb', line 390

def set_personalization_strategy_with_http_info(personalization_strategy_params, request_options = {})
  # verify the required parameter 'personalization_strategy_params' is set
  if @api_client.config.client_side_validation && personalization_strategy_params.nil?
    raise(
      ArgumentError,
      "Parameter `personalization_strategy_params` is required when calling `set_personalization_strategy`."
    )
  end

  path = "/1/strategies/personalization"
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body] || @api_client.object_to_http_body(personalization_strategy_params)

  new_options = request_options.merge(
    :operation => :"PersonalizationClient.set_personalization_strategy",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:POST, path, new_options)
end