Class: Algolia::QuerySuggestions::QuerySuggestionsConfigurationResponse
- Inherits:
-
Object
- Object
- Algolia::QuerySuggestions::QuerySuggestionsConfigurationResponse
- Defined in:
- lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb
Instance Attribute Summary collapse
-
#allow_special_characters ⇒ Object
Allow suggestions with special characters.
-
#enable_personalization ⇒ Object
Turn on personalized query suggestions.
-
#exclude ⇒ Object
Patterns to exclude from query suggestions.
-
#external_indices_api_key ⇒ Object
API key used to read from external Algolia indices.
-
#index_name ⇒ Object
Query Suggestions index name.
-
#languages ⇒ Object
Returns the value of attribute languages.
-
#source_indices ⇒ Object
Algolia indices from which to get the popular searches for query suggestions.
-
#source_indices_api_key ⇒ Object
API key used to read from your source index.
-
#suggestions_indices_api_key ⇒ Object
API key used to write and configure your Query Suggestions index.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ QuerySuggestionsConfigurationResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ QuerySuggestionsConfigurationResponse
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 87 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::QuerySuggestionsConfigurationResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::QuerySuggestionsConfigurationResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:source_indices_api_key) self.source_indices_api_key = attributes[:source_indices_api_key] end if attributes.key?(:suggestions_indices_api_key) self.suggestions_indices_api_key = attributes[:suggestions_indices_api_key] end if attributes.key?(:external_indices_api_key) self.external_indices_api_key = attributes[:external_indices_api_key] end if attributes.key?(:index_name) self.index_name = attributes[:index_name] else self.index_name = nil end if attributes.key?(:source_indices) if (value = attributes[:source_indices]).is_a?(Array) self.source_indices = value end else self.source_indices = nil end if attributes.key?(:languages) self.languages = attributes[:languages] end if attributes.key?(:exclude) if (value = attributes[:exclude]).is_a?(Array) self.exclude = value end end if attributes.key?(:enable_personalization) self.enable_personalization = attributes[:enable_personalization] end if attributes.key?(:allow_special_characters) self.allow_special_characters = attributes[:allow_special_characters] end end |
Instance Attribute Details
#allow_special_characters ⇒ Object
Allow suggestions with special characters.
33 34 35 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 33 def allow_special_characters @allow_special_characters end |
#enable_personalization ⇒ Object
Turn on personalized query suggestions.
30 31 32 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 30 def enable_personalization @enable_personalization end |
#exclude ⇒ Object
Patterns to exclude from query suggestions.
27 28 29 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 27 def exclude @exclude end |
#external_indices_api_key ⇒ Object
API key used to read from external Algolia indices.
16 17 18 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 16 def external_indices_api_key @external_indices_api_key end |
#index_name ⇒ Object
Query Suggestions index name.
19 20 21 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 19 def index_name @index_name end |
#languages ⇒ Object
Returns the value of attribute languages.
24 25 26 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 24 def languages @languages end |
#source_indices ⇒ Object
Algolia indices from which to get the popular searches for query suggestions.
22 23 24 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 22 def source_indices @source_indices end |
#source_indices_api_key ⇒ Object
API key used to read from your source index.
10 11 12 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 10 def source_indices_api_key @source_indices_api_key end |
#suggestions_indices_api_key ⇒ Object
API key used to write and configure your Query Suggestions index.
13 14 15 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 13 def suggestions_indices_api_key @suggestions_indices_api_key end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 219 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::QuerySuggestions.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 51 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 36 def self.attribute_map { :source_indices_api_key => :sourceIndicesAPIKey, :suggestions_indices_api_key => :suggestionsIndicesAPIKey, :external_indices_api_key => :externalIndicesAPIKey, :index_name => :indexName, :source_indices => :sourceIndices, :languages => :languages, :exclude => :exclude, :enable_personalization => :enablePersonalization, :allow_special_characters => :allowSpecialCharacters } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
78 79 80 81 82 83 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 78 def self.openapi_all_of [ :BaseQuerySuggestionsConfigurationResponse, :QuerySuggestionsConfigurationWithIndex ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 75 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 71 def self.openapi_nullable Set.new([ :exclude ]) end |
.types_mapping ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 56 def self.types_mapping { :source_indices_api_key => :String, :suggestions_indices_api_key => :String, :external_indices_api_key => :String, :index_name => :String, :source_indices => :'Array<SourceIndex>', :languages => :Languages, :exclude => :'Array<String>', :enable_personalization => :Boolean, :allow_special_characters => :Boolean } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 163 def ==(other) return true if equal?(other) self.class == other.class && source_indices_api_key == other.source_indices_api_key && suggestions_indices_api_key == other.suggestions_indices_api_key && external_indices_api_key == other.external_indices_api_key && index_name == other.index_name && source_indices == other.source_indices && languages == other.languages && exclude == other.exclude && enable_personalization == other.enable_personalization && allow_special_characters == other.allow_special_characters end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 294 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
180 181 182 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 180 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
186 187 188 189 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 186 def hash [source_indices_api_key, suggestions_indices_api_key, external_indices_api_key, index_name, source_indices, languages, exclude, enable_personalization, allow_special_characters].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
266 267 268 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 266 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 276 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
270 271 272 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 270 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
260 261 262 |
# File 'lib/algolia/models/query-suggestions/query_suggestions_configuration_response.rb', line 260 def to_s to_hash.to_s end |