Class: Algolia::QuerySuggestionsClient
- Inherits:
-
Object
- Object
- Algolia::QuerySuggestionsClient
- Defined in:
- lib/algolia/api/query_suggestions_client.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Class Method Summary collapse
Instance Method Summary collapse
-
#create_config(configuration_with_index, request_options = {}) ⇒ BaseResponse
Creates a new Query Suggestions configuration.
-
#create_config_with_http_info(configuration_with_index, request_options = {}) ⇒ Http::Response
Creates a new Query Suggestions configuration.
- #custom_delete(path, parameters = nil, request_options = {}) ⇒ Object
-
#custom_delete_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
The response.
- #custom_get(path, parameters = nil, request_options = {}) ⇒ Object
-
#custom_get_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
The response.
- #custom_post(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
-
#custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
The response.
- #custom_put(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
-
#custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
The response.
-
#delete_config(index_name, request_options = {}) ⇒ BaseResponse
Deletes a Query Suggestions configuration.
-
#delete_config_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Deletes a Query Suggestions configuration.
-
#get_all_configs(request_options = {}) ⇒ Array<ConfigurationResponse>
Retrieves all Query Suggestions configurations of your Algolia application.
-
#get_all_configs_with_http_info(request_options = {}) ⇒ Http::Response
Retrieves all Query Suggestions configurations of your Algolia application.
-
#get_config(index_name, request_options = {}) ⇒ ConfigurationResponse
Retrieves a single Query Suggestions configuration by its index name.
-
#get_config_status(index_name, request_options = {}) ⇒ ConfigStatus
Reports the status of a Query Suggestions index.
-
#get_config_status_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Reports the status of a Query Suggestions index.
-
#get_config_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Retrieves a single Query Suggestions configuration by its index name.
-
#get_log_file(index_name, request_options = {}) ⇒ LogFile
Retrieves the logs for a single Query Suggestions index.
-
#get_log_file_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Retrieves the logs for a single Query Suggestions index.
-
#initialize(config = nil) ⇒ QuerySuggestionsClient
constructor
A new instance of QuerySuggestionsClient.
-
#set_client_api_key(api_key) ⇒ void
Helper method to switch the API key used to authenticate the requests.
-
#update_config(index_name, configuration, request_options = {}) ⇒ BaseResponse
Updates a QuerySuggestions configuration.
-
#update_config_with_http_info(index_name, configuration, request_options = {}) ⇒ Http::Response
Updates a QuerySuggestions configuration.
Constructor Details
#initialize(config = nil) ⇒ QuerySuggestionsClient
Returns a new instance of QuerySuggestionsClient.
7 8 9 10 11 12 13 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 7 def initialize(config = nil) raise "`config` is missing." if config.nil? raise "`app_id` is missing." if config.app_id.nil? || config.app_id == "" raise "`api_key` is missing." if config.api_key.nil? || config.api_key == "" @api_client = Algolia::ApiClient.new(config) end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
5 6 7 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 5 def api_client @api_client end |
Class Method Details
.create(app_id, api_key, region = nil, opts = {}) ⇒ Object
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 15 def self.create(app_id, api_key, region = nil, opts = {}) hosts = [] regions = ["eu", "us"] if region.is_a?(Hash) && (opts.nil? || opts.empty?) opts = region region = nil end if region.nil? || !region.is_a?(String) || !regions.include?(region) raise "`region` is required and must be one of the following: #{regions.join(", ")}" end hosts << Transport::StatefulHost.new( "query-suggestions.{region}.algolia.com".sub!("{region}", region), accept: CallType::READ | CallType::WRITE ) config = Algolia::Configuration.new(app_id, api_key, hosts, "QuerySuggestions", opts) create_with_config(config) end |
.create_with_config(config) ⇒ Object
38 39 40 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 38 def self.create_with_config(config) new(config) end |
Instance Method Details
#create_config(configuration_with_index, request_options = {}) ⇒ BaseResponse
Creates a new Query Suggestions configuration. You can have up to 100 configurations per Algolia application.
Required API Key ACLs:
- editSettings
89 90 91 92 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 89 def create_config(configuration_with_index, = {}) response = create_config_with_http_info(configuration_with_index, ) @api_client.deserialize(response.body, [:debug_return_type] || "QuerySuggestions::BaseResponse") end |
#create_config_with_http_info(configuration_with_index, request_options = {}) ⇒ Http::Response
Creates a new Query Suggestions configuration. You can have up to 100 configurations per Algolia application.
Required API Key ACLs:
- editSettings
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 57 def create_config_with_http_info(configuration_with_index, = {}) # verify the required parameter 'configuration_with_index' is set if @api_client.config.client_side_validation && configuration_with_index.nil? raise ArgumentError, "Parameter `configuration_with_index` is required when calling `create_config`." end path = "/1/configs" query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(configuration_with_index) = .merge( :operation => :"QuerySuggestionsClient.create_config", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:POST, path, ) end |
#custom_delete(path, parameters = nil, request_options = {}) ⇒ Object
132 133 134 135 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 132 def custom_delete(path, parameters = nil, = {}) response = custom_delete_with_http_info(path, parameters, ) @api_client.deserialize(response.body, [:debug_return_type] || "Object") end |
#custom_delete_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
Returns the response.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 100 def custom_delete_with_http_info(path, parameters = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_delete`." end path = "/{path}".sub("{" + "path" + "}", path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :"QuerySuggestionsClient.custom_delete", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:DELETE, path, ) end |
#custom_get(path, parameters = nil, request_options = {}) ⇒ Object
175 176 177 178 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 175 def custom_get(path, parameters = nil, = {}) response = custom_get_with_http_info(path, parameters, ) @api_client.deserialize(response.body, [:debug_return_type] || "Object") end |
#custom_get_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
Returns the response.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 143 def custom_get_with_http_info(path, parameters = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_get`." end path = "/{path}".sub("{" + "path" + "}", path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :"QuerySuggestionsClient.custom_get", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#custom_post(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
220 221 222 223 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 220 def custom_post(path, parameters = nil, body = nil, = {}) response = custom_post_with_http_info(path, parameters, body, ) @api_client.deserialize(response.body, [:debug_return_type] || "Object") end |
#custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
Returns the response.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 187 def custom_post_with_http_info(path, parameters = nil, body = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_post`." end path = "/{path}".sub("{" + "path" + "}", path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(body) = .merge( :operation => :"QuerySuggestionsClient.custom_post", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:POST, path, ) end |
#custom_put(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
265 266 267 268 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 265 def custom_put(path, parameters = nil, body = nil, = {}) response = custom_put_with_http_info(path, parameters, body, ) @api_client.deserialize(response.body, [:debug_return_type] || "Object") end |
#custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
Returns the response.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 232 def custom_put_with_http_info(path, parameters = nil, body = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_put`." end path = "/{path}".sub("{" + "path" + "}", path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(body) = .merge( :operation => :"QuerySuggestionsClient.custom_put", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:PUT, path, ) end |
#delete_config(index_name, request_options = {}) ⇒ BaseResponse
Deletes a Query Suggestions configuration. Deleting only removes the configuration and stops updates to the Query Suggestions index. To delete the Query Suggestions index itself, use the Search API and the ‘Delete an index` operation.
Required API Key ACLs:
- editSettings
309 310 311 312 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 309 def delete_config(index_name, = {}) response = delete_config_with_http_info(index_name, ) @api_client.deserialize(response.body, [:debug_return_type] || "QuerySuggestions::BaseResponse") end |
#delete_config_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Deletes a Query Suggestions configuration. Deleting only removes the configuration and stops updates to the Query Suggestions index. To delete the Query Suggestions index itself, use the Search API and the `Delete an index` operation.
Required API Key ACLs:
- editSettings
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 277 def delete_config_with_http_info(index_name, = {}) # verify the required parameter 'index_name' is set if @api_client.config.client_side_validation && index_name.nil? raise ArgumentError, "Parameter `index_name` is required when calling `delete_config`." end path = "/1/configs/{indexName}".sub("{" + "indexName" + "}", Transport.encode_uri(index_name.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :"QuerySuggestionsClient.delete_config", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:DELETE, path, ) end |
#get_all_configs(request_options = {}) ⇒ Array<ConfigurationResponse>
Retrieves all Query Suggestions configurations of your Algolia application.
Required API Key ACLs:
- settings
346 347 348 349 350 351 352 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 346 def get_all_configs( = {}) response = get_all_configs_with_http_info() @api_client.deserialize( response.body, [:debug_return_type] || "Array<QuerySuggestions::ConfigurationResponse>" ) end |
#get_all_configs_with_http_info(request_options = {}) ⇒ Http::Response
Retrieves all Query Suggestions configurations of your Algolia application.
Required API Key ACLs:
- settings
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 320 def get_all_configs_with_http_info( = {}) path = "/1/configs" query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :"QuerySuggestionsClient.get_all_configs", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#get_config(index_name, request_options = {}) ⇒ ConfigurationResponse
Retrieves a single Query Suggestions configuration by its index name.
Required API Key ACLs:
- settings
393 394 395 396 397 398 399 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 393 def get_config(index_name, = {}) response = get_config_with_http_info(index_name, ) @api_client.deserialize( response.body, [:debug_return_type] || "QuerySuggestions::ConfigurationResponse" ) end |
#get_config_status(index_name, request_options = {}) ⇒ ConfigStatus
Reports the status of a Query Suggestions index.
Required API Key ACLs:
- settings
440 441 442 443 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 440 def get_config_status(index_name, = {}) response = get_config_status_with_http_info(index_name, ) @api_client.deserialize(response.body, [:debug_return_type] || "QuerySuggestions::ConfigStatus") end |
#get_config_status_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Reports the status of a Query Suggestions index.
Required API Key ACLs:
- settings
408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 408 def get_config_status_with_http_info(index_name, = {}) # verify the required parameter 'index_name' is set if @api_client.config.client_side_validation && index_name.nil? raise ArgumentError, "Parameter `index_name` is required when calling `get_config_status`." end path = "/1/configs/{indexName}/status".sub("{" + "indexName" + "}", Transport.encode_uri(index_name.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :"QuerySuggestionsClient.get_config_status", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#get_config_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Retrieves a single Query Suggestions configuration by its index name.
Required API Key ACLs:
- settings
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 361 def get_config_with_http_info(index_name, = {}) # verify the required parameter 'index_name' is set if @api_client.config.client_side_validation && index_name.nil? raise ArgumentError, "Parameter `index_name` is required when calling `get_config`." end path = "/1/configs/{indexName}".sub("{" + "indexName" + "}", Transport.encode_uri(index_name.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :"QuerySuggestionsClient.get_config", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#get_log_file(index_name, request_options = {}) ⇒ LogFile
Retrieves the logs for a single Query Suggestions index.
Required API Key ACLs:
- settings
484 485 486 487 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 484 def get_log_file(index_name, = {}) response = get_log_file_with_http_info(index_name, ) @api_client.deserialize(response.body, [:debug_return_type] || "QuerySuggestions::LogFile") end |
#get_log_file_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Retrieves the logs for a single Query Suggestions index.
Required API Key ACLs:
- settings
452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 452 def get_log_file_with_http_info(index_name, = {}) # verify the required parameter 'index_name' is set if @api_client.config.client_side_validation && index_name.nil? raise ArgumentError, "Parameter `index_name` is required when calling `get_log_file`." end path = "/1/logs/{indexName}".sub("{" + "indexName" + "}", Transport.encode_uri(index_name.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :"QuerySuggestionsClient.get_log_file", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#set_client_api_key(api_key) ⇒ void
This method returns an undefined value.
Helper method to switch the API key used to authenticate the requests.
46 47 48 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 46 def set_client_api_key(api_key) @api_client.set_client_api_key(api_key) end |
#update_config(index_name, configuration, request_options = {}) ⇒ BaseResponse
Updates a QuerySuggestions configuration.
Required API Key ACLs:
- editSettings
534 535 536 537 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 534 def update_config(index_name, configuration, = {}) response = update_config_with_http_info(index_name, configuration, ) @api_client.deserialize(response.body, [:debug_return_type] || "QuerySuggestions::BaseResponse") end |
#update_config_with_http_info(index_name, configuration, request_options = {}) ⇒ Http::Response
Updates a QuerySuggestions configuration.
Required API Key ACLs:
- editSettings
497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 497 def update_config_with_http_info(index_name, configuration, = {}) # verify the required parameter 'index_name' is set if @api_client.config.client_side_validation && index_name.nil? raise ArgumentError, "Parameter `index_name` is required when calling `update_config`." end # verify the required parameter 'configuration' is set if @api_client.config.client_side_validation && configuration.nil? raise ArgumentError, "Parameter `configuration` is required when calling `update_config`." end path = "/1/configs/{indexName}".sub("{" + "indexName" + "}", Transport.encode_uri(index_name.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(configuration) = .merge( :operation => :"QuerySuggestionsClient.update_config", :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:PUT, path, ) end |