Class: Algolia::QuerySuggestionsClient

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/api/query_suggestions_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config = nil) ⇒ QuerySuggestionsClient

Returns a new instance of QuerySuggestionsClient.



7
8
9
10
11
12
13
# File 'lib/algolia/api/query_suggestions_client.rb', line 7

def initialize(config = nil)
  raise "`config` is missing." if config.nil?
  raise "`app_id` is missing." if config.app_id.nil? || config.app_id == ""
  raise "`api_key` is missing." if config.api_key.nil? || config.api_key == ""

  @api_client = Algolia::ApiClient.new(config)
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



5
6
7
# File 'lib/algolia/api/query_suggestions_client.rb', line 5

def api_client
  @api_client
end

Class Method Details

.create(app_id, api_key, region = nil, opts = {}) ⇒ Object



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/algolia/api/query_suggestions_client.rb', line 15

def self.create(app_id, api_key, region = nil, opts = {})
  hosts = []
  regions = ["eu", "us"]

  if region.is_a?(Hash) && (opts.nil? || opts.empty?)
    opts = region
    region = nil
  end

  if region.nil? || !region.is_a?(String) || !regions.include?(region)
    raise "`region` is required and must be one of the following: #{regions.join(", ")}"
  end

  hosts <<
    Transport::StatefulHost.new(
      "query-suggestions.{region}.algolia.com".sub!("{region}", region),
      accept: CallType::READ | CallType::WRITE
    )

  config = Algolia::Configuration.new(app_id, api_key, hosts, "QuerySuggestions", opts)
  create_with_config(config)
end

.create_with_config(config) ⇒ Object



38
39
40
# File 'lib/algolia/api/query_suggestions_client.rb', line 38

def self.create_with_config(config)
  new(config)
end

Instance Method Details

#create_config(configuration_with_index, request_options = {}) ⇒ BaseResponse

Creates a new Query Suggestions configuration. You can have up to 100 configurations per Algolia application.

Required API Key ACLs:

- editSettings

Parameters:

  • configuration_with_index (ConfigurationWithIndex)

    (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (BaseResponse)


81
82
83
84
# File 'lib/algolia/api/query_suggestions_client.rb', line 81

def create_config(configuration_with_index, request_options = {})
  response = create_config_with_http_info(configuration_with_index, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "QuerySuggestions::BaseResponse")
end

#create_config_with_http_info(configuration_with_index, request_options = {}) ⇒ Http::Response

Creates a new Query Suggestions configuration. You can have up to 100 configurations per Algolia application.

Required API Key ACLs:

- editSettings

Parameters:

  • configuration_with_index (ConfigurationWithIndex)

    (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/algolia/api/query_suggestions_client.rb', line 49

def create_config_with_http_info(configuration_with_index, request_options = {})
  # verify the required parameter 'configuration_with_index' is set
  if @api_client.config.client_side_validation && configuration_with_index.nil?
    raise ArgumentError, "Parameter `configuration_with_index` is required when calling `create_config`."
  end

  path = "/1/configs"
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body] || @api_client.object_to_http_body(configuration_with_index)

  new_options = request_options.merge(
    :operation => :"QuerySuggestionsClient.create_config",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:POST, path, new_options)
end

#custom_delete(path, parameters = nil, request_options = {}) ⇒ Object

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (Object)


124
125
126
127
# File 'lib/algolia/api/query_suggestions_client.rb', line 124

def custom_delete(path, parameters = nil, request_options = {})
  response = custom_delete_with_http_info(path, parameters, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "Object")
end

#custom_delete_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response

Returns the response.

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/algolia/api/query_suggestions_client.rb', line 92

def custom_delete_with_http_info(path, parameters = nil, request_options = {})
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    raise ArgumentError, "Parameter `path` is required when calling `custom_delete`."
  end

  path = "/{path}".sub("{" + "path" + "}", path.to_s)
  query_params = {}
  query_params = query_params.merge(parameters) unless parameters.nil?
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :"QuerySuggestionsClient.custom_delete",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:DELETE, path, new_options)
end

#custom_get(path, parameters = nil, request_options = {}) ⇒ Object

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (Object)


167
168
169
170
# File 'lib/algolia/api/query_suggestions_client.rb', line 167

def custom_get(path, parameters = nil, request_options = {})
  response = custom_get_with_http_info(path, parameters, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "Object")
end

#custom_get_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response

Returns the response.

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/algolia/api/query_suggestions_client.rb', line 135

def custom_get_with_http_info(path, parameters = nil, request_options = {})
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    raise ArgumentError, "Parameter `path` is required when calling `custom_get`."
  end

  path = "/{path}".sub("{" + "path" + "}", path.to_s)
  query_params = {}
  query_params = query_params.merge(parameters) unless parameters.nil?
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :"QuerySuggestionsClient.custom_get",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#custom_post(path, parameters = nil, body = nil, request_options = {}) ⇒ Object

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • body (Object) (defaults to: nil)

    Parameters to send with the custom request.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (Object)


212
213
214
215
# File 'lib/algolia/api/query_suggestions_client.rb', line 212

def custom_post(path, parameters = nil, body = nil, request_options = {})
  response = custom_post_with_http_info(path, parameters, body, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "Object")
end

#custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response

Returns the response.

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • body (Object) (defaults to: nil)

    Parameters to send with the custom request.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/algolia/api/query_suggestions_client.rb', line 179

def custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {})
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    raise ArgumentError, "Parameter `path` is required when calling `custom_post`."
  end

  path = "/{path}".sub("{" + "path" + "}", path.to_s)
  query_params = {}
  query_params = query_params.merge(parameters) unless parameters.nil?
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body] || @api_client.object_to_http_body(body)

  new_options = request_options.merge(
    :operation => :"QuerySuggestionsClient.custom_post",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:POST, path, new_options)
end

#custom_put(path, parameters = nil, body = nil, request_options = {}) ⇒ Object

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • body (Object) (defaults to: nil)

    Parameters to send with the custom request.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (Object)


257
258
259
260
# File 'lib/algolia/api/query_suggestions_client.rb', line 257

def custom_put(path, parameters = nil, body = nil, request_options = {})
  response = custom_put_with_http_info(path, parameters, body, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "Object")
end

#custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response

Returns the response.

Parameters:

  • path (String)

    Path of the endpoint, anything after &quot;/1&quot; must be specified. (required)

  • parameters (Hash<String, Object>) (defaults to: nil)

    Query parameters to apply to the current query.

  • body (Object) (defaults to: nil)

    Parameters to send with the custom request.

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/algolia/api/query_suggestions_client.rb', line 224

def custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {})
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    raise ArgumentError, "Parameter `path` is required when calling `custom_put`."
  end

  path = "/{path}".sub("{" + "path" + "}", path.to_s)
  query_params = {}
  query_params = query_params.merge(parameters) unless parameters.nil?
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body] || @api_client.object_to_http_body(body)

  new_options = request_options.merge(
    :operation => :"QuerySuggestionsClient.custom_put",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:PUT, path, new_options)
end

#delete_config(index_name, request_options = {}) ⇒ BaseResponse

Deletes a Query Suggestions configuration. Deleting only removes the configuration and stops updates to the Query Suggestions index. To delete the Query Suggestions index itself, use the Search API and the ‘Delete an index` operation.

Required API Key ACLs:

- editSettings

Parameters:

  • index_name (String)

    Query Suggestions index name. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (BaseResponse)


301
302
303
304
# File 'lib/algolia/api/query_suggestions_client.rb', line 301

def delete_config(index_name, request_options = {})
  response = delete_config_with_http_info(index_name, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "QuerySuggestions::BaseResponse")
end

#delete_config_with_http_info(index_name, request_options = {}) ⇒ Http::Response

Deletes a Query Suggestions configuration. Deleting only removes the configuration and stops updates to the Query Suggestions index. To delete the Query Suggestions index itself, use the Search API and the &#x60;Delete an index&#x60; operation.

Required API Key ACLs:

- editSettings

Parameters:

  • index_name (String)

    Query Suggestions index name. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/algolia/api/query_suggestions_client.rb', line 269

def delete_config_with_http_info(index_name, request_options = {})
  # verify the required parameter 'index_name' is set
  if @api_client.config.client_side_validation && index_name.nil?
    raise ArgumentError, "Parameter `index_name` is required when calling `delete_config`."
  end

  path = "/1/configs/{indexName}".sub("{" + "indexName" + "}", Transport.encode_uri(index_name.to_s))
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :"QuerySuggestionsClient.delete_config",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:DELETE, path, new_options)
end

#get_all_configs(request_options = {}) ⇒ Array<ConfigurationResponse>

Retrieves all Query Suggestions configurations of your Algolia application.

Required API Key ACLs:

- settings

Parameters:

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (Array<ConfigurationResponse>)


338
339
340
341
342
343
344
# File 'lib/algolia/api/query_suggestions_client.rb', line 338

def get_all_configs(request_options = {})
  response = get_all_configs_with_http_info(request_options)
  @api_client.deserialize(
    response.body,
    request_options[:debug_return_type] || "Array<QuerySuggestions::ConfigurationResponse>"
  )
end

#get_all_configs_with_http_info(request_options = {}) ⇒ Http::Response

Retrieves all Query Suggestions configurations of your Algolia application.

Required API Key ACLs:

- settings

Parameters:

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/algolia/api/query_suggestions_client.rb', line 312

def get_all_configs_with_http_info(request_options = {})
  path = "/1/configs"
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :"QuerySuggestionsClient.get_all_configs",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#get_config(index_name, request_options = {}) ⇒ ConfigurationResponse

Retrieves a single Query Suggestions configuration by its index name.

Required API Key ACLs:

- settings

Parameters:

  • index_name (String)

    Query Suggestions index name. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (ConfigurationResponse)


385
386
387
388
389
390
391
# File 'lib/algolia/api/query_suggestions_client.rb', line 385

def get_config(index_name, request_options = {})
  response = get_config_with_http_info(index_name, request_options)
  @api_client.deserialize(
    response.body,
    request_options[:debug_return_type] || "QuerySuggestions::ConfigurationResponse"
  )
end

#get_config_status(index_name, request_options = {}) ⇒ ConfigStatus

Reports the status of a Query Suggestions index.

Required API Key ACLs:

- settings

Parameters:

  • index_name (String)

    Query Suggestions index name. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (ConfigStatus)


432
433
434
435
# File 'lib/algolia/api/query_suggestions_client.rb', line 432

def get_config_status(index_name, request_options = {})
  response = get_config_status_with_http_info(index_name, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "QuerySuggestions::ConfigStatus")
end

#get_config_status_with_http_info(index_name, request_options = {}) ⇒ Http::Response

Reports the status of a Query Suggestions index.

Required API Key ACLs:

- settings

Parameters:

  • index_name (String)

    Query Suggestions index name. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/algolia/api/query_suggestions_client.rb', line 400

def get_config_status_with_http_info(index_name, request_options = {})
  # verify the required parameter 'index_name' is set
  if @api_client.config.client_side_validation && index_name.nil?
    raise ArgumentError, "Parameter `index_name` is required when calling `get_config_status`."
  end

  path = "/1/configs/{indexName}/status".sub("{" + "indexName" + "}", Transport.encode_uri(index_name.to_s))
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :"QuerySuggestionsClient.get_config_status",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#get_config_with_http_info(index_name, request_options = {}) ⇒ Http::Response

Retrieves a single Query Suggestions configuration by its index name.

Required API Key ACLs:

- settings

Parameters:

  • index_name (String)

    Query Suggestions index name. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/algolia/api/query_suggestions_client.rb', line 353

def get_config_with_http_info(index_name, request_options = {})
  # verify the required parameter 'index_name' is set
  if @api_client.config.client_side_validation && index_name.nil?
    raise ArgumentError, "Parameter `index_name` is required when calling `get_config`."
  end

  path = "/1/configs/{indexName}".sub("{" + "indexName" + "}", Transport.encode_uri(index_name.to_s))
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :"QuerySuggestionsClient.get_config",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#get_log_file(index_name, request_options = {}) ⇒ LogFile

Retrieves the logs for a single Query Suggestions index.

Required API Key ACLs:

- settings

Parameters:

  • index_name (String)

    Query Suggestions index name. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (LogFile)


476
477
478
479
# File 'lib/algolia/api/query_suggestions_client.rb', line 476

def get_log_file(index_name, request_options = {})
  response = get_log_file_with_http_info(index_name, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "QuerySuggestions::LogFile")
end

#get_log_file_with_http_info(index_name, request_options = {}) ⇒ Http::Response

Retrieves the logs for a single Query Suggestions index.

Required API Key ACLs:

- settings

Parameters:

  • index_name (String)

    Query Suggestions index name. (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
# File 'lib/algolia/api/query_suggestions_client.rb', line 444

def get_log_file_with_http_info(index_name, request_options = {})
  # verify the required parameter 'index_name' is set
  if @api_client.config.client_side_validation && index_name.nil?
    raise ArgumentError, "Parameter `index_name` is required when calling `get_log_file`."
  end

  path = "/1/logs/{indexName}".sub("{" + "indexName" + "}", Transport.encode_uri(index_name.to_s))
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body]

  new_options = request_options.merge(
    :operation => :"QuerySuggestionsClient.get_log_file",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:GET, path, new_options)
end

#update_config(index_name, configuration, request_options = {}) ⇒ BaseResponse

Updates a QuerySuggestions configuration.

Required API Key ACLs:

- editSettings

Parameters:

  • index_name (String)

    Query Suggestions index name. (required)

  • configuration (Configuration)

    (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:

  • (BaseResponse)


526
527
528
529
# File 'lib/algolia/api/query_suggestions_client.rb', line 526

def update_config(index_name, configuration, request_options = {})
  response = update_config_with_http_info(index_name, configuration, request_options)
  @api_client.deserialize(response.body, request_options[:debug_return_type] || "QuerySuggestions::BaseResponse")
end

#update_config_with_http_info(index_name, configuration, request_options = {}) ⇒ Http::Response

Updates a QuerySuggestions configuration.

Required API Key ACLs:

- editSettings

Parameters:

  • index_name (String)

    Query Suggestions index name. (required)

  • configuration (Configuration)

    (required)

  • request_options:

    The request options to send along with the query, they will be merged with the transporter base parameters (headers, query params, timeouts, etc.). (optional)

Returns:



489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
# File 'lib/algolia/api/query_suggestions_client.rb', line 489

def update_config_with_http_info(index_name, configuration, request_options = {})
  # verify the required parameter 'index_name' is set
  if @api_client.config.client_side_validation && index_name.nil?
    raise ArgumentError, "Parameter `index_name` is required when calling `update_config`."
  end
  # verify the required parameter 'configuration' is set
  if @api_client.config.client_side_validation && configuration.nil?
    raise ArgumentError, "Parameter `configuration` is required when calling `update_config`."
  end

  path = "/1/configs/{indexName}".sub("{" + "indexName" + "}", Transport.encode_uri(index_name.to_s))
  query_params = {}
  query_params = query_params.merge(request_options[:query_params]) unless request_options[:query_params].nil?
  header_params = {}
  header_params = header_params.merge(request_options[:header_params]) unless request_options[:header_params].nil?

  post_body = request_options[:debug_body] || @api_client.object_to_http_body(configuration)

  new_options = request_options.merge(
    :operation => :"QuerySuggestionsClient.update_config",
    :header_params => header_params,
    :query_params => query_params,
    :body => post_body,
    :use_read_transporter => false
  )

  @api_client.call_api(:PUT, path, new_options)
end