Class: Algolia::QuerySuggestionsClient
- Inherits:
-
Object
- Object
- Algolia::QuerySuggestionsClient
- Defined in:
- lib/algolia/api/query_suggestions_client.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Class Method Summary collapse
Instance Method Summary collapse
-
#create_config(query_suggestions_configuration_with_index, request_options = {}) ⇒ BaseResponse
Create a configuration.
-
#create_config_with_http_info(query_suggestions_configuration_with_index, request_options = {}) ⇒ Http::Response
Create a configuration.
-
#custom_delete(path, parameters = nil, request_options = {}) ⇒ Object
Send requests to the Algolia REST API.
-
#custom_delete_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
Send requests to the Algolia REST API.
-
#custom_get(path, parameters = nil, request_options = {}) ⇒ Object
Send requests to the Algolia REST API.
-
#custom_get_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
Send requests to the Algolia REST API.
-
#custom_post(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
Send requests to the Algolia REST API.
-
#custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
Send requests to the Algolia REST API.
-
#custom_put(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
Send requests to the Algolia REST API.
-
#custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
Send requests to the Algolia REST API.
-
#delete_config(index_name, request_options = {}) ⇒ BaseResponse
Delete a configuration.
-
#delete_config_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Delete a configuration.
-
#get_all_configs(request_options = {}) ⇒ Array<QuerySuggestionsConfigurationResponse>
List configurations.
-
#get_all_configs_with_http_info(request_options = {}) ⇒ Http::Response
List configurations.
-
#get_config(index_name, request_options = {}) ⇒ QuerySuggestionsConfigurationResponse
Get a configuration.
-
#get_config_status(index_name, request_options = {}) ⇒ GetConfigStatus200Response
Get configuration status.
-
#get_config_status_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Get configuration status.
-
#get_config_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Get a configuration.
-
#get_log_file(index_name, request_options = {}) ⇒ GetLogFile200Response
Get logs.
-
#get_log_file_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Get logs.
-
#initialize(config = nil) ⇒ QuerySuggestionsClient
constructor
A new instance of QuerySuggestionsClient.
-
#update_config(index_name, query_suggestions_configuration, request_options = {}) ⇒ BaseResponse
Update a configuration.
-
#update_config_with_http_info(index_name, query_suggestions_configuration, request_options = {}) ⇒ Http::Response
Update a configuration.
Constructor Details
#initialize(config = nil) ⇒ QuerySuggestionsClient
Returns a new instance of QuerySuggestionsClient.
7 8 9 10 11 12 13 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 7 def initialize(config = nil) raise '`config` is missing.' if config.nil? raise '`app_id` is missing.' if config.app_id.nil? || config.app_id == '' raise '`api_key` is missing.' if config.api_key.nil? || config.api_key == '' @api_client = Algolia::ApiClient.new(config) end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
5 6 7 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 5 def api_client @api_client end |
Class Method Details
.create(app_id, api_key, region = nil, opts = {}) ⇒ Object
15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 15 def self.create(app_id, api_key, region = nil, opts = {}) hosts = [] regions = ['eu', 'us'] if region.is_a?(Hash) && (opts.nil? || opts.empty?) opts = region region = nil end raise "`region` is required and must be one of the following: #{regions.join(', ')}" if region.nil? || !region.is_a?(String) || !regions.include?(region) hosts << Transport::StatefulHost.new('query-suggestions.{region}.algolia.com'.sub!('{region}', region), accept: CallType::READ | CallType::WRITE) config = Algolia::Configuration.new(app_id, api_key, hosts, 'QuerySuggestions', opts) create_with_config(config) end |
.create_with_config(config) ⇒ Object
32 33 34 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 32 def self.create_with_config(config) new(config) end |
Instance Method Details
#create_config(query_suggestions_configuration_with_index, request_options = {}) ⇒ BaseResponse
Create a configuration. Create a new Query Suggestions configuration. You can have up to 100 configurations per Algolia application.
71 72 73 74 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 71 def create_config(query_suggestions_configuration_with_index, = {}) response = create_config_with_http_info(query_suggestions_configuration_with_index, ) deserialize(response.body, [:debug_return_type] || 'QuerySuggestions::BaseResponse') end |
#create_config_with_http_info(query_suggestions_configuration_with_index, request_options = {}) ⇒ Http::Response
Create a configuration. Create a new Query Suggestions configuration. You can have up to 100 configurations per Algolia application.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 41 def create_config_with_http_info(query_suggestions_configuration_with_index, = {}) # verify the required parameter 'query_suggestions_configuration_with_index' is set if @api_client.config.client_side_validation && query_suggestions_configuration_with_index.nil? raise ArgumentError, "Parameter `query_suggestions_configuration_with_index` is required when calling `create_config`." end path = '/1/configs' query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(query_suggestions_configuration_with_index) = .merge( :operation => :'QuerySuggestionsClient.create_config', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:POST, path, ) end |
#custom_delete(path, parameters = nil, request_options = {}) ⇒ Object
Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.
114 115 116 117 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 114 def custom_delete(path, parameters = nil, = {}) response = custom_delete_with_http_info(path, parameters, ) deserialize(response.body, [:debug_return_type] || 'Object') end |
#custom_delete_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 82 def custom_delete_with_http_info(path, parameters = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_delete`." end path = '/1{path}'.sub('{' + 'path' + '}', path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :'QuerySuggestionsClient.custom_delete', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:DELETE, path, ) end |
#custom_get(path, parameters = nil, request_options = {}) ⇒ Object
Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.
157 158 159 160 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 157 def custom_get(path, parameters = nil, = {}) response = custom_get_with_http_info(path, parameters, ) deserialize(response.body, [:debug_return_type] || 'Object') end |
#custom_get_with_http_info(path, parameters = nil, request_options = {}) ⇒ Http::Response
Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 125 def custom_get_with_http_info(path, parameters = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_get`." end path = '/1{path}'.sub('{' + 'path' + '}', path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :'QuerySuggestionsClient.custom_get', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#custom_post(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.
202 203 204 205 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 202 def custom_post(path, parameters = nil, body = nil, = {}) response = custom_post_with_http_info(path, parameters, body, ) deserialize(response.body, [:debug_return_type] || 'Object') end |
#custom_post_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 169 def custom_post_with_http_info(path, parameters = nil, body = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_post`." end path = '/1{path}'.sub('{' + 'path' + '}', path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(body) = .merge( :operation => :'QuerySuggestionsClient.custom_post', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:POST, path, ) end |
#custom_put(path, parameters = nil, body = nil, request_options = {}) ⇒ Object
Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.
247 248 249 250 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 247 def custom_put(path, parameters = nil, body = nil, = {}) response = custom_put_with_http_info(path, parameters, body, ) deserialize(response.body, [:debug_return_type] || 'Object') end |
#custom_put_with_http_info(path, parameters = nil, body = nil, request_options = {}) ⇒ Http::Response
Send requests to the Algolia REST API. This method allow you to send requests to the Algolia REST API.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 214 def custom_put_with_http_info(path, parameters = nil, body = nil, = {}) # verify the required parameter 'path' is set if @api_client.config.client_side_validation && path.nil? raise ArgumentError, "Parameter `path` is required when calling `custom_put`." end path = '/1{path}'.sub('{' + 'path' + '}', path.to_s) query_params = {} query_params = query_params.merge(parameters) unless parameters.nil? query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(body) = .merge( :operation => :'QuerySuggestionsClient.custom_put', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:PUT, path, ) end |
#delete_config(index_name, request_options = {}) ⇒ BaseResponse
Delete a configuration. Delete a Query Suggestions configuration. Deleting only removes the configuration and stops updates to the Query Suggestions index. The Query Suggestions index itself is not deleted.
287 288 289 290 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 287 def delete_config(index_name, = {}) response = delete_config_with_http_info(index_name, ) deserialize(response.body, [:debug_return_type] || 'QuerySuggestions::BaseResponse') end |
#delete_config_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Delete a configuration. Delete a Query Suggestions configuration. Deleting only removes the configuration and stops updates to the Query Suggestions index. The Query Suggestions index itself is not deleted.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 257 def delete_config_with_http_info(index_name, = {}) # verify the required parameter 'index_name' is set if @api_client.config.client_side_validation && index_name.nil? raise ArgumentError, "Parameter `index_name` is required when calling `delete_config`." end path = '/1/configs/{indexName}'.sub('{' + 'indexName' + '}', @api_client.encode_uri(index_name.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :'QuerySuggestionsClient.delete_config', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:DELETE, path, ) end |
#get_all_configs(request_options = {}) ⇒ Array<QuerySuggestionsConfigurationResponse>
List configurations. List all Query Suggestions configurations of your Algolia application.
320 321 322 323 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 320 def get_all_configs( = {}) response = get_all_configs_with_http_info() deserialize(response.body, [:debug_return_type] || 'Array<QuerySuggestions::QuerySuggestionsConfigurationResponse>') end |
#get_all_configs_with_http_info(request_options = {}) ⇒ Http::Response
List configurations. List all Query Suggestions configurations of your Algolia application.
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 296 def get_all_configs_with_http_info( = {}) path = '/1/configs' query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :'QuerySuggestionsClient.get_all_configs', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#get_config(index_name, request_options = {}) ⇒ QuerySuggestionsConfigurationResponse
Get a configuration. Get a single Query Suggestions configuration.
360 361 362 363 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 360 def get_config(index_name, = {}) response = get_config_with_http_info(index_name, ) deserialize(response.body, [:debug_return_type] || 'QuerySuggestions::QuerySuggestionsConfigurationResponse') end |
#get_config_status(index_name, request_options = {}) ⇒ GetConfigStatus200Response
Get configuration status. Report the status of a Query Suggestions index.
400 401 402 403 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 400 def get_config_status(index_name, = {}) response = get_config_status_with_http_info(index_name, ) deserialize(response.body, [:debug_return_type] || 'QuerySuggestions::GetConfigStatus200Response') end |
#get_config_status_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Get configuration status. Report the status of a Query Suggestions index.
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 370 def get_config_status_with_http_info(index_name, = {}) # verify the required parameter 'index_name' is set if @api_client.config.client_side_validation && index_name.nil? raise ArgumentError, "Parameter `index_name` is required when calling `get_config_status`." end path = '/1/configs/{indexName}/status'.sub('{' + 'indexName' + '}', @api_client.encode_uri(index_name.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :'QuerySuggestionsClient.get_config_status', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#get_config_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Get a configuration. Get a single Query Suggestions configuration.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 330 def get_config_with_http_info(index_name, = {}) # verify the required parameter 'index_name' is set if @api_client.config.client_side_validation && index_name.nil? raise ArgumentError, "Parameter `index_name` is required when calling `get_config`." end path = '/1/configs/{indexName}'.sub('{' + 'indexName' + '}', @api_client.encode_uri(index_name.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :'QuerySuggestionsClient.get_config', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#get_log_file(index_name, request_options = {}) ⇒ GetLogFile200Response
Get logs. Get the logs for a single Query Suggestions index.
440 441 442 443 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 440 def get_log_file(index_name, = {}) response = get_log_file_with_http_info(index_name, ) deserialize(response.body, [:debug_return_type] || 'QuerySuggestions::GetLogFile200Response') end |
#get_log_file_with_http_info(index_name, request_options = {}) ⇒ Http::Response
Get logs. Get the logs for a single Query Suggestions index.
410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 410 def get_log_file_with_http_info(index_name, = {}) # verify the required parameter 'index_name' is set if @api_client.config.client_side_validation && index_name.nil? raise ArgumentError, "Parameter `index_name` is required when calling `get_log_file`." end path = '/1/logs/{indexName}'.sub('{' + 'indexName' + '}', @api_client.encode_uri(index_name.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] = .merge( :operation => :'QuerySuggestionsClient.get_log_file', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:GET, path, ) end |
#update_config(index_name, query_suggestions_configuration, request_options = {}) ⇒ BaseResponse
Update a configuration. Update a QuerySuggestions configuration.
486 487 488 489 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 486 def update_config(index_name, query_suggestions_configuration, = {}) response = update_config_with_http_info(index_name, query_suggestions_configuration, ) deserialize(response.body, [:debug_return_type] || 'QuerySuggestions::BaseResponse') end |
#update_config_with_http_info(index_name, query_suggestions_configuration, request_options = {}) ⇒ Http::Response
Update a configuration. Update a QuerySuggestions configuration.
451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'lib/algolia/api/query_suggestions_client.rb', line 451 def update_config_with_http_info(index_name, query_suggestions_configuration, = {}) # verify the required parameter 'index_name' is set if @api_client.config.client_side_validation && index_name.nil? raise ArgumentError, "Parameter `index_name` is required when calling `update_config`." end # verify the required parameter 'query_suggestions_configuration' is set if @api_client.config.client_side_validation && query_suggestions_configuration.nil? raise ArgumentError, "Parameter `query_suggestions_configuration` is required when calling `update_config`." end path = '/1/configs/{indexName}'.sub('{' + 'indexName' + '}', @api_client.encode_uri(index_name.to_s)) query_params = {} query_params = query_params.merge([:query_params]) unless [:query_params].nil? header_params = {} header_params = header_params.merge([:header_params]) unless [:header_params].nil? post_body = [:debug_body] || @api_client.object_to_http_body(query_suggestions_configuration) = .merge( :operation => :'QuerySuggestionsClient.update_config', :header_params => header_params, :query_params => query_params, :body => post_body, :use_read_transporter => false ) @api_client.call_api(:PUT, path, ) end |