Class: Algolia::Recommend::IndexSettingsAsSearchParams
- Inherits:
-
Object
- Object
- Algolia::Recommend::IndexSettingsAsSearchParams
- Defined in:
- lib/algolia/models/recommend/index_settings_as_search_params.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#advanced_syntax ⇒ Object
Enables the [advanced query syntax](www.algolia.com/doc/guides/managing-results/optimize-search-results/override-search-engine-defaults/#advanced-syntax).
-
#advanced_syntax_features ⇒ Object
Allows you to specify which advanced syntax features are active when ‘advancedSyntax` is enabled.
-
#allow_typos_on_numeric_tokens ⇒ Object
Whether to allow typos on numbers ("numeric tokens") in the query string.
-
#alternatives_as_exact ⇒ Object
Alternatives that should be considered an exact match by [the exact ranking criterion](www.algolia.com/doc/guides/managing-results/optimize-search-results/override-search-engine-defaults/in-depth/adjust-exact-settings/#turn-off-exact-for-some-attributes).
-
#attribute_criteria_computed_by_min_proximity ⇒ Object
When the [Attribute criterion is ranked above Proximity](www.algolia.com/doc/guides/managing-results/relevance-overview/in-depth/ranking-criteria/#attribute-and-proximity-combinations) in your ranking formula, Proximity is used to select which searchable attribute is matched in the Attribute ranking stage.
-
#attributes_for_faceting ⇒ Object
Attributes used for [faceting](www.algolia.com/doc/guides/managing-results/refine-results/faceting/) and the [modifiers](www.algolia.com/doc/api-reference/api-parameters/attributesForFaceting/#modifiers) that can be applied: ‘filterOnly`, `searchable`, and `afterDistinct`.
-
#attributes_to_highlight ⇒ Object
Attributes to highlight.
-
#attributes_to_retrieve ⇒ Object
Attributes to include in the API response.
-
#attributes_to_snippet ⇒ Object
Attributes to snippet.
-
#custom_ranking ⇒ Object
Specifies the [Custom ranking criterion](www.algolia.com/doc/guides/managing-results/must-do/custom-ranking/).
-
#decompound_query ⇒ Object
[Splits compound words](www.algolia.com/doc/guides/managing-results/optimize-search-results/handling-natural-languages-nlp/in-depth/language-specific-configurations/#splitting-compound-words) into their component word parts in the query.
-
#disable_exact_on_attributes ⇒ Object
Attributes for which you want to [turn off the exact ranking criterion](www.algolia.com/doc/guides/managing-results/optimize-search-results/override-search-engine-defaults/in-depth/adjust-exact-settings/#turn-off-exact-for-some-attributes).
-
#disable_typo_tolerance_on_attributes ⇒ Object
Attributes for which you want to turn off [typo tolerance](www.algolia.com/doc/guides/managing-results/optimize-search-results/typo-tolerance/).
-
#distinct ⇒ Object
Returns the value of attribute distinct.
-
#enable_personalization ⇒ Object
Incidates whether [Personalization](www.algolia.com/doc/guides/personalization/what-is-personalization/) is enabled.
-
#enable_re_ranking ⇒ Object
Indicates whether this search will use [Dynamic Re-Ranking](www.algolia.com/doc/guides/algolia-ai/re-ranking/).
-
#enable_rules ⇒ Object
Incidates whether [Rules](www.algolia.com/doc/guides/managing-results/rules/rules-overview/) are enabled.
-
#exact_on_single_word_query ⇒ Object
Returns the value of attribute exact_on_single_word_query.
-
#highlight_post_tag ⇒ Object
HTML string to insert after the highlighted parts in all highlight and snippet results.
-
#highlight_pre_tag ⇒ Object
HTML string to insert before the highlighted parts in all highlight and snippet results.
-
#hits_per_page ⇒ Object
Number of hits per page.
-
#ignore_plurals ⇒ Object
Returns the value of attribute ignore_plurals.
-
#keep_diacritics_on_characters ⇒ Object
Characters that the engine shouldn’t automatically [normalize](www.algolia.com/doc/guides/managing-results/optimize-search-results/handling-natural-languages-nlp/in-depth/normalization/).
-
#max_facet_hits ⇒ Object
Maximum number of facet hits to return when [searching for facet values](www.algolia.com/doc/guides/managing-results/refine-results/faceting/#search-for-facet-values).
-
#max_values_per_facet ⇒ Object
Maximum number of facet values to return for each facet.
-
#min_proximity ⇒ Object
Precision of the [proximity ranking criterion](www.algolia.com/doc/guides/managing-results/relevance-overview/in-depth/ranking-criteria/#proximity).
-
#min_word_sizefor1_typo ⇒ Object
Minimum number of characters a word in the query string must contain to accept matches with [one typo](www.algolia.com/doc/guides/managing-results/optimize-search-results/typo-tolerance/in-depth/configuring-typo-tolerance/#configuring-word-length-for-typos).
-
#min_word_sizefor2_typos ⇒ Object
Minimum number of characters a word in the query string must contain to accept matches with [two typos](www.algolia.com/doc/guides/managing-results/optimize-search-results/typo-tolerance/in-depth/configuring-typo-tolerance/#configuring-word-length-for-typos).
-
#mode ⇒ Object
Returns the value of attribute mode.
-
#optional_words ⇒ Object
Words which should be considered [optional](www.algolia.com/doc/guides/managing-results/optimize-search-results/empty-or-insufficient-results/#creating-a-list-of-optional-words) when found in a query.
-
#query_languages ⇒ Object
Sets your user’s search language.
-
#query_type ⇒ Object
Returns the value of attribute query_type.
-
#ranking ⇒ Object
Determines the order in which Algolia [returns your results](www.algolia.com/doc/guides/managing-results/relevance-overview/in-depth/ranking-criteria/).
-
#re_ranking_apply_filter ⇒ Object
Returns the value of attribute re_ranking_apply_filter.
-
#relevancy_strictness ⇒ Object
Relevancy threshold below which less relevant results aren’t included in the results.
-
#remove_stop_words ⇒ Object
Returns the value of attribute remove_stop_words.
-
#remove_words_if_no_results ⇒ Object
Returns the value of attribute remove_words_if_no_results.
-
#rendering_content ⇒ Object
Returns the value of attribute rendering_content.
-
#replace_synonyms_in_highlight ⇒ Object
Whether to highlight and snippet the original word that matches the synonym or the synonym itself.
-
#response_fields ⇒ Object
Attributes to include in the API response for search and browse queries.
-
#restrict_highlight_and_snippet_arrays ⇒ Object
Restrict highlighting and snippeting to items that matched the query.
-
#semantic_search ⇒ Object
Returns the value of attribute semantic_search.
-
#snippet_ellipsis_text ⇒ Object
String used as an ellipsis indicator when a snippet is truncated.
-
#sort_facet_values_by ⇒ Object
Controls how facet values are fetched.
-
#typo_tolerance ⇒ Object
Returns the value of attribute typo_tolerance.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IndexSettingsAsSearchParams
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ IndexSettingsAsSearchParams
Initializes the object
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 271 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::IndexSettingsAsSearchParams` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::IndexSettingsAsSearchParams`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:attributes_for_faceting) if (value = attributes[:attributes_for_faceting]).is_a?(Array) self.attributes_for_faceting = value end end if attributes.key?(:attributes_to_retrieve) if (value = attributes[:attributes_to_retrieve]).is_a?(Array) self.attributes_to_retrieve = value end end if attributes.key?(:ranking) if (value = attributes[:ranking]).is_a?(Array) self.ranking = value end end if attributes.key?(:custom_ranking) if (value = attributes[:custom_ranking]).is_a?(Array) self.custom_ranking = value end end if attributes.key?(:relevancy_strictness) self.relevancy_strictness = attributes[:relevancy_strictness] end if attributes.key?(:attributes_to_highlight) if (value = attributes[:attributes_to_highlight]).is_a?(Array) self.attributes_to_highlight = value end end if attributes.key?(:attributes_to_snippet) if (value = attributes[:attributes_to_snippet]).is_a?(Array) self.attributes_to_snippet = value end end if attributes.key?(:highlight_pre_tag) self.highlight_pre_tag = attributes[:highlight_pre_tag] end if attributes.key?(:highlight_post_tag) self.highlight_post_tag = attributes[:highlight_post_tag] end if attributes.key?(:snippet_ellipsis_text) self.snippet_ellipsis_text = attributes[:snippet_ellipsis_text] end if attributes.key?(:restrict_highlight_and_snippet_arrays) self.restrict_highlight_and_snippet_arrays = attributes[:restrict_highlight_and_snippet_arrays] end if attributes.key?(:hits_per_page) self.hits_per_page = attributes[:hits_per_page] end if attributes.key?(:min_word_sizefor1_typo) self.min_word_sizefor1_typo = attributes[:min_word_sizefor1_typo] end if attributes.key?(:min_word_sizefor2_typos) self.min_word_sizefor2_typos = attributes[:min_word_sizefor2_typos] end if attributes.key?(:typo_tolerance) self.typo_tolerance = attributes[:typo_tolerance] end if attributes.key?(:allow_typos_on_numeric_tokens) self.allow_typos_on_numeric_tokens = attributes[:allow_typos_on_numeric_tokens] end if attributes.key?(:disable_typo_tolerance_on_attributes) if (value = attributes[:disable_typo_tolerance_on_attributes]).is_a?(Array) self.disable_typo_tolerance_on_attributes = value end end if attributes.key?(:ignore_plurals) self.ignore_plurals = attributes[:ignore_plurals] end if attributes.key?(:remove_stop_words) self.remove_stop_words = attributes[:remove_stop_words] end if attributes.key?(:keep_diacritics_on_characters) self.keep_diacritics_on_characters = attributes[:keep_diacritics_on_characters] end if attributes.key?(:query_languages) if (value = attributes[:query_languages]).is_a?(Array) self.query_languages = value end end if attributes.key?(:decompound_query) self.decompound_query = attributes[:decompound_query] end if attributes.key?(:enable_rules) self.enable_rules = attributes[:enable_rules] end if attributes.key?(:enable_personalization) self.enable_personalization = attributes[:enable_personalization] end if attributes.key?(:query_type) self.query_type = attributes[:query_type] end if attributes.key?(:remove_words_if_no_results) self.remove_words_if_no_results = attributes[:remove_words_if_no_results] end if attributes.key?(:mode) self.mode = attributes[:mode] end if attributes.key?(:semantic_search) self.semantic_search = attributes[:semantic_search] end if attributes.key?(:advanced_syntax) self.advanced_syntax = attributes[:advanced_syntax] end if attributes.key?(:optional_words) if (value = attributes[:optional_words]).is_a?(Array) self.optional_words = value end end if attributes.key?(:disable_exact_on_attributes) if (value = attributes[:disable_exact_on_attributes]).is_a?(Array) self.disable_exact_on_attributes = value end end if attributes.key?(:exact_on_single_word_query) self.exact_on_single_word_query = attributes[:exact_on_single_word_query] end if attributes.key?(:alternatives_as_exact) if (value = attributes[:alternatives_as_exact]).is_a?(Array) self.alternatives_as_exact = value end end if attributes.key?(:advanced_syntax_features) if (value = attributes[:advanced_syntax_features]).is_a?(Array) self.advanced_syntax_features = value end end if attributes.key?(:distinct) self.distinct = attributes[:distinct] end if attributes.key?(:replace_synonyms_in_highlight) self.replace_synonyms_in_highlight = attributes[:replace_synonyms_in_highlight] end if attributes.key?(:min_proximity) self.min_proximity = attributes[:min_proximity] end if attributes.key?(:response_fields) if (value = attributes[:response_fields]).is_a?(Array) self.response_fields = value end end if attributes.key?(:max_facet_hits) self.max_facet_hits = attributes[:max_facet_hits] end if attributes.key?(:max_values_per_facet) self.max_values_per_facet = attributes[:max_values_per_facet] end if attributes.key?(:sort_facet_values_by) self.sort_facet_values_by = attributes[:sort_facet_values_by] end if attributes.key?(:attribute_criteria_computed_by_min_proximity) self.attribute_criteria_computed_by_min_proximity = attributes[:attribute_criteria_computed_by_min_proximity] end if attributes.key?(:rendering_content) self.rendering_content = attributes[:rendering_content] end if attributes.key?(:enable_re_ranking) self.enable_re_ranking = attributes[:enable_re_ranking] end if attributes.key?(:re_ranking_apply_filter) self.re_ranking_apply_filter = attributes[:re_ranking_apply_filter] end end |
Instance Attribute Details
#advanced_syntax ⇒ Object
Enables the [advanced query syntax](www.algolia.com/doc/guides/managing-results/optimize-search-results/override-search-engine-defaults/#advanced-syntax).
87 88 89 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 87 def advanced_syntax @advanced_syntax end |
#advanced_syntax_features ⇒ Object
Allows you to specify which advanced syntax features are active when ‘advancedSyntax` is enabled.
101 102 103 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 101 def advanced_syntax_features @advanced_syntax_features end |
#allow_typos_on_numeric_tokens ⇒ Object
Whether to allow typos on numbers ("numeric tokens") in the query string.
54 55 56 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 54 def allow_typos_on_numeric_tokens @allow_typos_on_numeric_tokens end |
#alternatives_as_exact ⇒ Object
Alternatives that should be considered an exact match by [the exact ranking criterion](www.algolia.com/doc/guides/managing-results/optimize-search-results/override-search-engine-defaults/in-depth/adjust-exact-settings/#turn-off-exact-for-some-attributes).
98 99 100 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 98 def alternatives_as_exact @alternatives_as_exact end |
#attribute_criteria_computed_by_min_proximity ⇒ Object
When the [Attribute criterion is ranked above Proximity](www.algolia.com/doc/guides/managing-results/relevance-overview/in-depth/ranking-criteria/#attribute-and-proximity-combinations) in your ranking formula, Proximity is used to select which searchable attribute is matched in the Attribute ranking stage.
124 125 126 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 124 def attribute_criteria_computed_by_min_proximity @attribute_criteria_computed_by_min_proximity end |
#attributes_for_faceting ⇒ Object
Attributes used for [faceting](www.algolia.com/doc/guides/managing-results/refine-results/faceting/) and the [modifiers](www.algolia.com/doc/api-reference/api-parameters/attributesForFaceting/#modifiers) that can be applied: ‘filterOnly`, `searchable`, and `afterDistinct`.
10 11 12 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 10 def attributes_for_faceting @attributes_for_faceting end |
#attributes_to_highlight ⇒ Object
Attributes to highlight. Strings that match the search query in the attributes are highlighted by surrounding them with HTML tags (‘highlightPreTag` and `highlightPostTag`).
25 26 27 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 25 def attributes_to_highlight @attributes_to_highlight end |
#attributes_to_retrieve ⇒ Object
Attributes to include in the API response. To reduce the size of your response, you can retrieve only some of the attributes. By default, the response includes all attributes.
13 14 15 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 13 def attributes_to_retrieve @attributes_to_retrieve end |
#attributes_to_snippet ⇒ Object
Attributes to snippet. ‘Snippeting’ is shortening the attribute to a certain number of words. If not specified, the attribute is shortened to the 10 words around the matching string but you can specify the number. For example: ‘body:20`.
28 29 30 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 28 def attributes_to_snippet @attributes_to_snippet end |
#custom_ranking ⇒ Object
Specifies the [Custom ranking criterion](www.algolia.com/doc/guides/managing-results/must-do/custom-ranking/). Use the ‘asc` and `desc` modifiers to specify the ranking order: ascending or descending.
19 20 21 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 19 def custom_ranking @custom_ranking end |
#decompound_query ⇒ Object
[Splits compound words](www.algolia.com/doc/guides/managing-results/optimize-search-results/handling-natural-languages-nlp/in-depth/language-specific-configurations/#splitting-compound-words) into their component word parts in the query.
70 71 72 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 70 def decompound_query @decompound_query end |
#disable_exact_on_attributes ⇒ Object
Attributes for which you want to [turn off the exact ranking criterion](www.algolia.com/doc/guides/managing-results/optimize-search-results/override-search-engine-defaults/in-depth/adjust-exact-settings/#turn-off-exact-for-some-attributes).
93 94 95 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 93 def disable_exact_on_attributes @disable_exact_on_attributes end |
#disable_typo_tolerance_on_attributes ⇒ Object
Attributes for which you want to turn off [typo tolerance](www.algolia.com/doc/guides/managing-results/optimize-search-results/typo-tolerance/).
57 58 59 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 57 def disable_typo_tolerance_on_attributes @disable_typo_tolerance_on_attributes end |
#distinct ⇒ Object
Returns the value of attribute distinct.
103 104 105 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 103 def distinct @distinct end |
#enable_personalization ⇒ Object
Incidates whether [Personalization](www.algolia.com/doc/guides/personalization/what-is-personalization/) is enabled.
76 77 78 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 76 def enable_personalization @enable_personalization end |
#enable_re_ranking ⇒ Object
Indicates whether this search will use [Dynamic Re-Ranking](www.algolia.com/doc/guides/algolia-ai/re-ranking/).
129 130 131 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 129 def enable_re_ranking @enable_re_ranking end |
#enable_rules ⇒ Object
Incidates whether [Rules](www.algolia.com/doc/guides/managing-results/rules/rules-overview/) are enabled.
73 74 75 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 73 def enable_rules @enable_rules end |
#exact_on_single_word_query ⇒ Object
Returns the value of attribute exact_on_single_word_query.
95 96 97 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 95 def exact_on_single_word_query @exact_on_single_word_query end |
#highlight_post_tag ⇒ Object
HTML string to insert after the highlighted parts in all highlight and snippet results.
34 35 36 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 34 def highlight_post_tag @highlight_post_tag end |
#highlight_pre_tag ⇒ Object
HTML string to insert before the highlighted parts in all highlight and snippet results.
31 32 33 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 31 def highlight_pre_tag @highlight_pre_tag end |
#hits_per_page ⇒ Object
Number of hits per page.
43 44 45 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 43 def hits_per_page @hits_per_page end |
#ignore_plurals ⇒ Object
Returns the value of attribute ignore_plurals.
59 60 61 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 59 def ignore_plurals @ignore_plurals end |
#keep_diacritics_on_characters ⇒ Object
Characters that the engine shouldn’t automatically [normalize](www.algolia.com/doc/guides/managing-results/optimize-search-results/handling-natural-languages-nlp/in-depth/normalization/).
64 65 66 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 64 def keep_diacritics_on_characters @keep_diacritics_on_characters end |
#max_facet_hits ⇒ Object
Maximum number of facet hits to return when [searching for facet values](www.algolia.com/doc/guides/managing-results/refine-results/faceting/#search-for-facet-values).
115 116 117 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 115 def max_facet_hits @max_facet_hits end |
#max_values_per_facet ⇒ Object
Maximum number of facet values to return for each facet.
118 119 120 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 118 def max_values_per_facet @max_values_per_facet end |
#min_proximity ⇒ Object
Precision of the [proximity ranking criterion](www.algolia.com/doc/guides/managing-results/relevance-overview/in-depth/ranking-criteria/#proximity).
109 110 111 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 109 def min_proximity @min_proximity end |
#min_word_sizefor1_typo ⇒ Object
Minimum number of characters a word in the query string must contain to accept matches with [one typo](www.algolia.com/doc/guides/managing-results/optimize-search-results/typo-tolerance/in-depth/configuring-typo-tolerance/#configuring-word-length-for-typos).
46 47 48 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 46 def min_word_sizefor1_typo @min_word_sizefor1_typo end |
#min_word_sizefor2_typos ⇒ Object
Minimum number of characters a word in the query string must contain to accept matches with [two typos](www.algolia.com/doc/guides/managing-results/optimize-search-results/typo-tolerance/in-depth/configuring-typo-tolerance/#configuring-word-length-for-typos).
49 50 51 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 49 def min_word_sizefor2_typos @min_word_sizefor2_typos end |
#mode ⇒ Object
Returns the value of attribute mode.
82 83 84 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 82 def mode @mode end |
#optional_words ⇒ Object
Words which should be considered [optional](www.algolia.com/doc/guides/managing-results/optimize-search-results/empty-or-insufficient-results/#creating-a-list-of-optional-words) when found in a query.
90 91 92 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 90 def optional_words @optional_words end |
#query_languages ⇒ Object
Sets your user’s search language. This adjusts language-specific settings and features such as ‘ignorePlurals`, `removeStopWords`, and [CJK](www.algolia.com/doc/guides/managing-results/optimize-search-results/handling-natural-languages-nlp/in-depth/normalization/#normalization-for-logogram-based-languages-cjk) word detection.
67 68 69 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 67 def query_languages @query_languages end |
#query_type ⇒ Object
Returns the value of attribute query_type.
78 79 80 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 78 def query_type @query_type end |
#ranking ⇒ Object
Determines the order in which Algolia [returns your results](www.algolia.com/doc/guides/managing-results/relevance-overview/in-depth/ranking-criteria/).
16 17 18 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 16 def ranking @ranking end |
#re_ranking_apply_filter ⇒ Object
Returns the value of attribute re_ranking_apply_filter.
131 132 133 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 131 def re_ranking_apply_filter @re_ranking_apply_filter end |
#relevancy_strictness ⇒ Object
Relevancy threshold below which less relevant results aren’t included in the results.
22 23 24 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 22 def relevancy_strictness @relevancy_strictness end |
#remove_stop_words ⇒ Object
Returns the value of attribute remove_stop_words.
61 62 63 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 61 def remove_stop_words @remove_stop_words end |
#remove_words_if_no_results ⇒ Object
Returns the value of attribute remove_words_if_no_results.
80 81 82 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 80 def remove_words_if_no_results @remove_words_if_no_results end |
#rendering_content ⇒ Object
Returns the value of attribute rendering_content.
126 127 128 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 126 def rendering_content @rendering_content end |
#replace_synonyms_in_highlight ⇒ Object
Whether to highlight and snippet the original word that matches the synonym or the synonym itself.
106 107 108 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 106 def replace_synonyms_in_highlight @replace_synonyms_in_highlight end |
#response_fields ⇒ Object
Attributes to include in the API response for search and browse queries.
112 113 114 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 112 def response_fields @response_fields end |
#restrict_highlight_and_snippet_arrays ⇒ Object
Restrict highlighting and snippeting to items that matched the query.
40 41 42 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 40 def restrict_highlight_and_snippet_arrays @restrict_highlight_and_snippet_arrays end |
#semantic_search ⇒ Object
Returns the value of attribute semantic_search.
84 85 86 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 84 def semantic_search @semantic_search end |
#snippet_ellipsis_text ⇒ Object
String used as an ellipsis indicator when a snippet is truncated.
37 38 39 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 37 def snippet_ellipsis_text @snippet_ellipsis_text end |
#sort_facet_values_by ⇒ Object
Controls how facet values are fetched.
121 122 123 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 121 def sort_facet_values_by @sort_facet_values_by end |
#typo_tolerance ⇒ Object
Returns the value of attribute typo_tolerance.
51 52 53 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 51 def typo_tolerance @typo_tolerance end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 637 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Recommend.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
207 208 209 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 207 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 156 def self.attribute_map { :attributes_for_faceting => :attributesForFaceting, :attributes_to_retrieve => :attributesToRetrieve, :ranking => :ranking, :custom_ranking => :customRanking, :relevancy_strictness => :relevancyStrictness, :attributes_to_highlight => :attributesToHighlight, :attributes_to_snippet => :attributesToSnippet, :highlight_pre_tag => :highlightPreTag, :highlight_post_tag => :highlightPostTag, :snippet_ellipsis_text => :snippetEllipsisText, :restrict_highlight_and_snippet_arrays => :restrictHighlightAndSnippetArrays, :hits_per_page => :hitsPerPage, :min_word_sizefor1_typo => :minWordSizefor1Typo, :min_word_sizefor2_typos => :minWordSizefor2Typos, :typo_tolerance => :typoTolerance, :allow_typos_on_numeric_tokens => :allowTyposOnNumericTokens, :disable_typo_tolerance_on_attributes => :disableTypoToleranceOnAttributes, :ignore_plurals => :ignorePlurals, :remove_stop_words => :removeStopWords, :keep_diacritics_on_characters => :keepDiacriticsOnCharacters, :query_languages => :queryLanguages, :decompound_query => :decompoundQuery, :enable_rules => :enableRules, :enable_personalization => :enablePersonalization, :query_type => :queryType, :remove_words_if_no_results => :removeWordsIfNoResults, :mode => :mode, :semantic_search => :semanticSearch, :advanced_syntax => :advancedSyntax, :optional_words => :optionalWords, :disable_exact_on_attributes => :disableExactOnAttributes, :exact_on_single_word_query => :exactOnSingleWordQuery, :alternatives_as_exact => :alternativesAsExact, :advanced_syntax_features => :advancedSyntaxFeatures, :distinct => :distinct, :replace_synonyms_in_highlight => :replaceSynonymsInHighlight, :min_proximity => :minProximity, :response_fields => :responseFields, :max_facet_hits => :maxFacetHits, :max_values_per_facet => :maxValuesPerFacet, :sort_facet_values_by => :sortFacetValuesBy, :attribute_criteria_computed_by_min_proximity => :attributeCriteriaComputedByMinProximity, :rendering_content => :renderingContent, :enable_re_ranking => :enableReRanking, :re_ranking_apply_filter => :reRankingApplyFilter } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 612 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
263 264 265 266 267 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 263 def self.openapi_nullable Set.new([ :re_ranking_apply_filter ]) end |
.types_mapping ⇒ Object
Attribute type mapping.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 212 def self.types_mapping { :attributes_for_faceting => :'Array<String>', :attributes_to_retrieve => :'Array<String>', :ranking => :'Array<String>', :custom_ranking => :'Array<String>', :relevancy_strictness => :Integer, :attributes_to_highlight => :'Array<String>', :attributes_to_snippet => :'Array<String>', :highlight_pre_tag => :String, :highlight_post_tag => :String, :snippet_ellipsis_text => :String, :restrict_highlight_and_snippet_arrays => :Boolean, :hits_per_page => :Integer, :min_word_sizefor1_typo => :Integer, :min_word_sizefor2_typos => :Integer, :typo_tolerance => :TypoTolerance, :allow_typos_on_numeric_tokens => :Boolean, :disable_typo_tolerance_on_attributes => :'Array<String>', :ignore_plurals => :IgnorePlurals, :remove_stop_words => :RemoveStopWords, :keep_diacritics_on_characters => :String, :query_languages => :'Array<String>', :decompound_query => :Boolean, :enable_rules => :Boolean, :enable_personalization => :Boolean, :query_type => :QueryType, :remove_words_if_no_results => :RemoveWordsIfNoResults, :mode => :Mode, :semantic_search => :SemanticSearch, :advanced_syntax => :Boolean, :optional_words => :'Array<String>', :disable_exact_on_attributes => :'Array<String>', :exact_on_single_word_query => :ExactOnSingleWordQuery, :alternatives_as_exact => :'Array<AlternativesAsExact>', :advanced_syntax_features => :'Array<AdvancedSyntaxFeatures>', :distinct => :Distinct, :replace_synonyms_in_highlight => :Boolean, :min_proximity => :Integer, :response_fields => :'Array<String>', :max_facet_hits => :Integer, :max_values_per_facet => :Integer, :sort_facet_values_by => :String, :attribute_criteria_computed_by_min_proximity => :Boolean, :rendering_content => :RenderingContent, :enable_re_ranking => :Boolean, :re_ranking_apply_filter => :ReRankingApplyFilter } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 545 def ==(other) return true if equal?(other) self.class == other.class && attributes_for_faceting == other.attributes_for_faceting && attributes_to_retrieve == other.attributes_to_retrieve && ranking == other.ranking && custom_ranking == other.custom_ranking && relevancy_strictness == other.relevancy_strictness && attributes_to_highlight == other.attributes_to_highlight && attributes_to_snippet == other.attributes_to_snippet && highlight_pre_tag == other.highlight_pre_tag && highlight_post_tag == other.highlight_post_tag && snippet_ellipsis_text == other.snippet_ellipsis_text && restrict_highlight_and_snippet_arrays == other.restrict_highlight_and_snippet_arrays && hits_per_page == other.hits_per_page && min_word_sizefor1_typo == other.min_word_sizefor1_typo && min_word_sizefor2_typos == other.min_word_sizefor2_typos && typo_tolerance == other.typo_tolerance && allow_typos_on_numeric_tokens == other.allow_typos_on_numeric_tokens && disable_typo_tolerance_on_attributes == other.disable_typo_tolerance_on_attributes && ignore_plurals == other.ignore_plurals && remove_stop_words == other.remove_stop_words && keep_diacritics_on_characters == other.keep_diacritics_on_characters && query_languages == other.query_languages && decompound_query == other.decompound_query && enable_rules == other.enable_rules && enable_personalization == other.enable_personalization && query_type == other.query_type && remove_words_if_no_results == other.remove_words_if_no_results && mode == other.mode && semantic_search == other.semantic_search && advanced_syntax == other.advanced_syntax && optional_words == other.optional_words && disable_exact_on_attributes == other.disable_exact_on_attributes && exact_on_single_word_query == other.exact_on_single_word_query && alternatives_as_exact == other.alternatives_as_exact && advanced_syntax_features == other.advanced_syntax_features && distinct == other.distinct && replace_synonyms_in_highlight == other.replace_synonyms_in_highlight && min_proximity == other.min_proximity && response_fields == other.response_fields && max_facet_hits == other.max_facet_hits && max_values_per_facet == other.max_values_per_facet && sort_facet_values_by == other.sort_facet_values_by && attribute_criteria_computed_by_min_proximity == other.attribute_criteria_computed_by_min_proximity && rendering_content == other.rendering_content && enable_re_ranking == other.enable_re_ranking && re_ranking_apply_filter == other.re_ranking_apply_filter end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
712 713 714 715 716 717 718 719 720 721 722 723 724 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 712 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
598 599 600 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 598 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
604 605 606 607 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 604 def hash [attributes_for_faceting, attributes_to_retrieve, ranking, custom_ranking, relevancy_strictness, attributes_to_highlight, attributes_to_snippet, highlight_pre_tag, highlight_post_tag, snippet_ellipsis_text, restrict_highlight_and_snippet_arrays, hits_per_page, min_word_sizefor1_typo, min_word_sizefor2_typos, typo_tolerance, allow_typos_on_numeric_tokens, disable_typo_tolerance_on_attributes, ignore_plurals, remove_stop_words, keep_diacritics_on_characters, query_languages, decompound_query, enable_rules, enable_personalization, query_type, remove_words_if_no_results, mode, semantic_search, advanced_syntax, optional_words, disable_exact_on_attributes, exact_on_single_word_query, alternatives_as_exact, advanced_syntax_features, distinct, replace_synonyms_in_highlight, min_proximity, response_fields, max_facet_hits, max_values_per_facet, sort_facet_values_by, attribute_criteria_computed_by_min_proximity, rendering_content, enable_re_ranking, re_ranking_apply_filter].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
684 685 686 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 684 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
694 695 696 697 698 699 700 701 702 703 704 705 706 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 694 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
688 689 690 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 688 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
678 679 680 |
# File 'lib/algolia/models/recommend/index_settings_as_search_params.rb', line 678 def to_s to_hash.to_s end |