Class: Algolia::Search::DictionaryEntry

Inherits:
Object
  • Object
show all
Defined in:
lib/algolia/models/search/dictionary_entry.rb

Overview

Dictionary entry.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DictionaryEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/algolia/models/search/dictionary_entry.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    raise(
      ArgumentError,
      "The input argument (attributes) must be a hash in `Algolia::DictionaryEntry` initialize method"
    )
  end

  if attributes.key?(:object_id)
    self.object_id = attributes[:object_id]
  else
    self.object_id = nil
  end

  if attributes.key?(:language)
    self.language = attributes[:language]
  else
    self.language = nil
  end

  if attributes.key?(:word)
    self.word = attributes[:word]
  end

  if attributes.key?(:words)
    if (value = attributes[:words]).is_a?(Array)
      self.words = value
    end
  end

  if attributes.key?(:decomposition)
    if (value = attributes[:decomposition]).is_a?(Array)
      self.decomposition = value
    end
  end

  if attributes.key?(:state)
    self.state = attributes[:state]
  end

  # add extra attribute to additional_properties
  self.additional_properties ||= {}
  self.additional_properties.merge!(attributes.reject { |k, _| self.class.attribute_map.key?(k.to_sym) })
end

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



26
27
28
# File 'lib/algolia/models/search/dictionary_entry.rb', line 26

def additional_properties
  @additional_properties
end

#decompositionObject

Invividual components of a compound word in the ‘compounds` dictionary.



22
23
24
# File 'lib/algolia/models/search/dictionary_entry.rb', line 22

def decomposition
  @decomposition
end

#languageObject

Returns the value of attribute language.



13
14
15
# File 'lib/algolia/models/search/dictionary_entry.rb', line 13

def language
  @language
end

#object_idObject

Unique identifier for the dictionary entry.



11
12
13
# File 'lib/algolia/models/search/dictionary_entry.rb', line 11

def object_id
  @object_id
end

#stateObject

Returns the value of attribute state.



24
25
26
# File 'lib/algolia/models/search/dictionary_entry.rb', line 24

def state
  @state
end

#wordObject

Matching dictionary word for ‘stopwords` and `compounds` dictionaries.



16
17
18
# File 'lib/algolia/models/search/dictionary_entry.rb', line 16

def word
  @word
end

#wordsObject

Matching words in the ‘plurals` dictionary including declensions.



19
20
21
# File 'lib/algolia/models/search/dictionary_entry.rb', line 19

def words
  @words
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/algolia/models/search/dictionary_entry.rb', line 190

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end

  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
    # model
  else
    # models (e.g. Pet) or oneOf
    klass = Algolia::Search.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass
      .build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/algolia/models/search/dictionary_entry.rb', line 63

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
60
# File 'lib/algolia/models/search/dictionary_entry.rb', line 51

def self.attribute_map
  {
    :object_id => :objectID,
    :language => :language,
    :word => :word,
    :words => :words,
    :decomposition => :decomposition,
    :state => :state
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/algolia/models/search/dictionary_entry.rb', line 161

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  types_mapping.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v|
          _deserialize(::Regexp.last_match(1), v)
        }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]])
    end
  end

  # add extra attribute to transformed_hash
  transformed_hash.merge!(attributes.reject { |k, _| attribute_map.key?(k.to_sym) })
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
84
# File 'lib/algolia/models/search/dictionary_entry.rb', line 80

def self.openapi_nullable
  Set.new(
    []
  )
end

.types_mappingObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
# File 'lib/algolia/models/search/dictionary_entry.rb', line 68

def self.types_mapping
  {
    :object_id => :"String",
    :language => :"SupportedLanguage",
    :word => :"String",
    :words => :"Array<String>",
    :decomposition => :"Array<String>",
    :state => :"DictionaryEntryState"
  }
end

Instance Method Details

#==(other) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



135
136
137
138
139
140
141
142
143
144
# File 'lib/algolia/models/search/dictionary_entry.rb', line 135

def ==(other)
  return true if self.equal?(other)
  self.class == other.class &&
    object_id == other.object_id &&
    language == other.language &&
    word == other.word &&
    words == other.words &&
    decomposition == other.decomposition &&
    state == other.state
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/algolia/models/search/dictionary_entry.rb', line 274

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to?(:to_hash)
    value.to_hash
  else
    value
  end
end

#eql?(other) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


148
149
150
# File 'lib/algolia/models/search/dictionary_entry.rb', line 148

def eql?(other)
  self == other
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



154
155
156
# File 'lib/algolia/models/search/dictionary_entry.rb', line 154

def hash
  [object_id, language, word, words, decomposition, state].hash
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
# File 'lib/algolia/models/search/dictionary_entry.rb', line 240

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/algolia/models/search/dictionary_entry.rb', line 250

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end

  # also add attributes from additional_properties to hash
  self.additional_properties&.each_pair do |k, v|
    hash[k.to_sym] = _to_hash(v)
  end

  hash
end

#to_json(*_args) ⇒ Object



244
245
246
# File 'lib/algolia/models/search/dictionary_entry.rb', line 244

def to_json(*_args)
  to_hash.to_json
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



234
235
236
# File 'lib/algolia/models/search/dictionary_entry.rb', line 234

def to_s
  to_hash.to_s
end