Class: Algolia::Search::Log
- Inherits:
-
Object
- Object
- Algolia::Search::Log
- Defined in:
- lib/algolia/models/search/log.rb
Instance Attribute Summary collapse
-
#_query_params ⇒ Object
Query parameters sent with the request.
-
#answer ⇒ Object
Answer body.
-
#answer_code ⇒ Object
HTTP response code.
-
#index ⇒ Object
Index targeted by the query.
-
#inner_queries ⇒ Object
Performed queries for the given request.
-
#ip ⇒ Object
IP address of the client that performed the request.
-
#method ⇒ Object
HTTP method of the performed request.
-
#nb_api_calls ⇒ Object
Number of API calls.
-
#processing_time_ms ⇒ Object
Processing time for the query.
-
#query_body ⇒ Object
Request body.
-
#query_headers ⇒ Object
Request headers (API key is obfuscated).
-
#query_nb_hits ⇒ Object
Number of hits returned for the query.
-
#sha1 ⇒ Object
SHA1 signature of the log entry.
-
#timestamp ⇒ Object
Timestamp in [ISO 8601](wikipedia.org/wiki/ISO_8601) format.
-
#url ⇒ Object
Request URL.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Log
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Log
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/algolia/models/search/log.rb', line 108 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::Log` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::Log`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:timestamp) self. = attributes[:timestamp] else self. = nil end if attributes.key?(:method) self.method = attributes[:method] else self.method = nil end if attributes.key?(:answer_code) self.answer_code = attributes[:answer_code] else self.answer_code = nil end if attributes.key?(:query_body) self.query_body = attributes[:query_body] else self.query_body = nil end if attributes.key?(:answer) self.answer = attributes[:answer] else self.answer = nil end if attributes.key?(:url) self.url = attributes[:url] else self.url = nil end if attributes.key?(:ip) self.ip = attributes[:ip] else self.ip = nil end if attributes.key?(:query_headers) self.query_headers = attributes[:query_headers] else self.query_headers = nil end if attributes.key?(:sha1) self.sha1 = attributes[:sha1] else self.sha1 = nil end if attributes.key?(:nb_api_calls) self.nb_api_calls = attributes[:nb_api_calls] else self.nb_api_calls = nil end if attributes.key?(:processing_time_ms) self.processing_time_ms = attributes[:processing_time_ms] else self.processing_time_ms = nil end if attributes.key?(:index) self.index = attributes[:index] end if attributes.key?(:_query_params) self._query_params = attributes[:_query_params] end if attributes.key?(:query_nb_hits) self.query_nb_hits = attributes[:query_nb_hits] end if attributes.key?(:inner_queries) if (value = attributes[:inner_queries]).is_a?(Array) self.inner_queries = value end end end |
Instance Attribute Details
#_query_params ⇒ Object
Query parameters sent with the request.
46 47 48 |
# File 'lib/algolia/models/search/log.rb', line 46 def _query_params @_query_params end |
#answer ⇒ Object
Answer body. Truncated after 1,000 characters.
22 23 24 |
# File 'lib/algolia/models/search/log.rb', line 22 def answer @answer end |
#answer_code ⇒ Object
HTTP response code.
16 17 18 |
# File 'lib/algolia/models/search/log.rb', line 16 def answer_code @answer_code end |
#index ⇒ Object
Index targeted by the query.
43 44 45 |
# File 'lib/algolia/models/search/log.rb', line 43 def index @index end |
#inner_queries ⇒ Object
Performed queries for the given request.
52 53 54 |
# File 'lib/algolia/models/search/log.rb', line 52 def inner_queries @inner_queries end |
#ip ⇒ Object
IP address of the client that performed the request.
28 29 30 |
# File 'lib/algolia/models/search/log.rb', line 28 def ip @ip end |
#method ⇒ Object
HTTP method of the performed request.
13 14 15 |
# File 'lib/algolia/models/search/log.rb', line 13 def method @method end |
#nb_api_calls ⇒ Object
Number of API calls.
37 38 39 |
# File 'lib/algolia/models/search/log.rb', line 37 def nb_api_calls @nb_api_calls end |
#processing_time_ms ⇒ Object
Processing time for the query. Doesn’t include network time.
40 41 42 |
# File 'lib/algolia/models/search/log.rb', line 40 def processing_time_ms @processing_time_ms end |
#query_body ⇒ Object
Request body. Truncated after 1,000 characters.
19 20 21 |
# File 'lib/algolia/models/search/log.rb', line 19 def query_body @query_body end |
#query_headers ⇒ Object
Request headers (API key is obfuscated).
31 32 33 |
# File 'lib/algolia/models/search/log.rb', line 31 def query_headers @query_headers end |
#query_nb_hits ⇒ Object
Number of hits returned for the query.
49 50 51 |
# File 'lib/algolia/models/search/log.rb', line 49 def query_nb_hits @query_nb_hits end |
#sha1 ⇒ Object
SHA1 signature of the log entry.
34 35 36 |
# File 'lib/algolia/models/search/log.rb', line 34 def sha1 @sha1 end |
#timestamp ⇒ Object
Timestamp in [ISO 8601](wikipedia.org/wiki/ISO_8601) format.
10 11 12 |
# File 'lib/algolia/models/search/log.rb', line 10 def @timestamp end |
#url ⇒ Object
Request URL.
25 26 27 |
# File 'lib/algolia/models/search/log.rb', line 25 def url @url end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/algolia/models/search/log.rb', line 272 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Search.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/algolia/models/search/log.rb', line 76 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/algolia/models/search/log.rb', line 55 def self.attribute_map { :timestamp => :timestamp, :method => :method, :answer_code => :answer_code, :query_body => :query_body, :answer => :answer, :url => :url, :ip => :ip, :query_headers => :query_headers, :sha1 => :sha1, :nb_api_calls => :nb_api_calls, :processing_time_ms => :processing_time_ms, :index => :index, :_query_params => :query_params, :query_nb_hits => :query_nb_hits, :inner_queries => :inner_queries } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/algolia/models/search/log.rb', line 247 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_s] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_s] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 |
# File 'lib/algolia/models/search/log.rb', line 102 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/algolia/models/search/log.rb', line 81 def self.types_mapping { :timestamp => :String, :method => :String, :answer_code => :String, :query_body => :String, :answer => :String, :url => :String, :ip => :String, :query_headers => :String, :sha1 => :String, :nb_api_calls => :String, :processing_time_ms => :String, :index => :String, :_query_params => :String, :query_nb_hits => :String, :inner_queries => :'Array<LogQuery>' } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/algolia/models/search/log.rb', line 210 def ==(other) return true if equal?(other) self.class == other.class && == other. && method == other.method && answer_code == other.answer_code && query_body == other.query_body && answer == other.answer && url == other.url && ip == other.ip && query_headers == other.query_headers && sha1 == other.sha1 && nb_api_calls == other.nb_api_calls && processing_time_ms == other.processing_time_ms && index == other.index && _query_params == other._query_params && query_nb_hits == other.query_nb_hits && inner_queries == other.inner_queries end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/algolia/models/search/log.rb', line 343 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
233 234 235 |
# File 'lib/algolia/models/search/log.rb', line 233 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
239 240 241 242 |
# File 'lib/algolia/models/search/log.rb', line 239 def hash [, method, answer_code, query_body, answer, url, ip, query_headers, sha1, nb_api_calls, processing_time_ms, index, _query_params, query_nb_hits, inner_queries].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
319 320 321 |
# File 'lib/algolia/models/search/log.rb', line 319 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/algolia/models/search/log.rb', line 325 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
313 314 315 |
# File 'lib/algolia/models/search/log.rb', line 313 def to_s to_hash.to_s end |