Class: Algolia::Search::Rule
- Inherits:
-
Object
- Object
- Algolia::Search::Rule
- Defined in:
- lib/algolia/models/search/rule.rb
Overview
Rule object.
Instance Attribute Summary collapse
-
#conditions ⇒ Object
[Conditions](www.algolia.com/doc/guides/managing-results/rules/rules-overview/#conditions) required to activate a rule.
-
#consequence ⇒ Object
Returns the value of attribute consequence.
-
#description ⇒ Object
Description of the rule’s purpose.
-
#enabled ⇒ Object
Indicates whether to enable the rule.
-
#object_id ⇒ Object
Unique identifier for a rule object.
-
#validity ⇒ Object
If you specify a validity period, the rule only applies only during that period.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Rule
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ Rule
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/algolia/models/search/rule.rb', line 63 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::Rule` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::Rule`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:object_id) self.object_id = attributes[:object_id] else self.object_id = nil end if attributes.key?(:conditions) if (value = attributes[:conditions]).is_a?(Array) self.conditions = value end end if attributes.key?(:consequence) self.consequence = attributes[:consequence] end if attributes.key?(:description) self.description = attributes[:description] end if attributes.key?(:enabled) self.enabled = attributes[:enabled] end if attributes.key?(:validity) if (value = attributes[:validity]).is_a?(Array) self.validity = value end end end |
Instance Attribute Details
#conditions ⇒ Object
[Conditions](www.algolia.com/doc/guides/managing-results/rules/rules-overview/#conditions) required to activate a rule. You can use up to 25 conditions per rule.
14 15 16 |
# File 'lib/algolia/models/search/rule.rb', line 14 def conditions @conditions end |
#consequence ⇒ Object
Returns the value of attribute consequence.
16 17 18 |
# File 'lib/algolia/models/search/rule.rb', line 16 def consequence @consequence end |
#description ⇒ Object
Description of the rule’s purpose. This can be helpful for display in the Algolia dashboard.
19 20 21 |
# File 'lib/algolia/models/search/rule.rb', line 19 def description @description end |
#enabled ⇒ Object
Indicates whether to enable the rule. If it isn’t enabled, it isn’t applied at query time.
22 23 24 |
# File 'lib/algolia/models/search/rule.rb', line 22 def enabled @enabled end |
#object_id ⇒ Object
Unique identifier for a rule object.
11 12 13 |
# File 'lib/algolia/models/search/rule.rb', line 11 def object_id @object_id end |
#validity ⇒ Object
If you specify a validity period, the rule only applies only during that period. If specified, the array must not be empty.
25 26 27 |
# File 'lib/algolia/models/search/rule.rb', line 25 def validity @validity end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/algolia/models/search/rule.rb', line 163 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Search.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/algolia/models/search/rule.rb', line 40 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 36 37 |
# File 'lib/algolia/models/search/rule.rb', line 28 def self.attribute_map { :object_id => :objectID, :conditions => :conditions, :consequence => :consequence, :description => :description, :enabled => :enabled, :validity => :validity } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/algolia/models/search/rule.rb', line 138 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 |
# File 'lib/algolia/models/search/rule.rb', line 57 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 52 53 54 |
# File 'lib/algolia/models/search/rule.rb', line 45 def self.types_mapping { :object_id => :String, :conditions => :'Array<Condition>', :consequence => :Consequence, :description => :String, :enabled => :Boolean, :validity => :'Array<TimeRange>' } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/algolia/models/search/rule.rb', line 111 def ==(other) return true if equal?(other) self.class == other.class && object_id == other.object_id && conditions == other.conditions && consequence == other.consequence && description == other.description && enabled == other.enabled && validity == other.validity end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/algolia/models/search/rule.rb', line 238 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
125 126 127 |
# File 'lib/algolia/models/search/rule.rb', line 125 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
131 132 133 |
# File 'lib/algolia/models/search/rule.rb', line 131 def hash [object_id, conditions, consequence, description, enabled, validity].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
210 211 212 |
# File 'lib/algolia/models/search/rule.rb', line 210 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/algolia/models/search/rule.rb', line 220 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
214 215 216 |
# File 'lib/algolia/models/search/rule.rb', line 214 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
204 205 206 |
# File 'lib/algolia/models/search/rule.rb', line 204 def to_s to_hash.to_s end |