Method: Algolia::Search::SearchForHits#inside_polygon
- Defined in:
- lib/algolia/models/search/search_for_hits.rb
#inside_polygon ⇒ Object
Coordinates of a polygon in which to search. Polygons are defined by 3 to 10,000 points. Each point is represented by its latitude and longitude. Provide multiple polygons as nested arrays. For more information, see [filtering inside polygons](www.algolia.com/doc/guides/managing-results/refine-results/geolocation/#filtering-inside-rectangular-or-polygonal-areas). This parameter is ignored if you also specify insideBoundingBox.
68 69 70 |
# File 'lib/algolia/models/search/search_for_hits.rb', line 68 def inside_polygon @inside_polygon end |