Class: Algolia::Search::SearchSynonymsResponse
- Inherits:
-
Object
- Object
- Algolia::Search::SearchSynonymsResponse
- Defined in:
- lib/algolia/models/search/search_synonyms_response.rb
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#hits ⇒ Object
Matching synonyms.
-
#nb_hits ⇒ Object
Number of results (hits).
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SearchSynonymsResponse
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SearchSynonymsResponse
Initializes the object
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 45 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::SearchSynonymsResponse` initialize method" end if attributes.key?(:hits) if (value = attributes[:hits]).is_a?(Array) self.hits = value end else self.hits = nil end if attributes.key?(:nb_hits) self.nb_hits = attributes[:nb_hits] else self.nb_hits = nil end # add extra attribute to additional_properties self.additional_properties ||= {} self.additional_properties.merge!(attributes.reject { |k, _| self.class.attribute_map.key?(k.to_sym) }) end |
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
15 16 17 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 15 def additional_properties @additional_properties end |
#hits ⇒ Object
Matching synonyms.
10 11 12 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 10 def hits @hits end |
#nb_hits ⇒ Object
Number of results (hits).
13 14 15 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 13 def nb_hits @nb_hits end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 122 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Search.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
26 27 28 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 26 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
18 19 20 21 22 23 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 18 def self.attribute_map { :hits => :hits, :nb_hits => :nbHits } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 94 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end # add extra attribute to transformed_hash transformed_hash.merge!(attributes.reject { |k, _| attribute_map.key?(k.to_sym) }) new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
39 40 41 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 39 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
31 32 33 34 35 36 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 31 def self.types_mapping { :hits => :'Array<SynonymHit>', :nb_hits => :Integer } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
71 72 73 74 75 76 77 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 71 def ==(other) return true if equal?(other) self.class == other.class && hits == other.hits && nb_hits == other.nb_hits end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 202 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
81 82 83 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 81 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
87 88 89 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 87 def hash [hits, nb_hits].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
169 170 171 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 169 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 179 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end # also add attributes from additional_properties to hash self.additional_properties&.each_pair do |k, v| hash[k.to_sym] = _to_hash(v) end hash end |
#to_json(*_args) ⇒ Object
173 174 175 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 173 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
163 164 165 |
# File 'lib/algolia/models/search/search_synonyms_response.rb', line 163 def to_s to_hash.to_s end |