Class: Algolia::Search::SecuredAPIKeyRestrictions
- Inherits:
-
Object
- Object
- Algolia::Search::SecuredAPIKeyRestrictions
- Defined in:
- lib/algolia/models/search/secured_api_key_restrictions.rb
Instance Attribute Summary collapse
-
#filters ⇒ Object
Filters that apply to every search made with the secured API key.
-
#restrict_indices ⇒ Object
Index names that can be queried.
-
#restrict_sources ⇒ Object
IPv4 network allowed to use the generated key.
-
#search_params ⇒ Object
Returns the value of attribute search_params.
-
#user_token ⇒ Object
Unique user IP address.
-
#valid_until ⇒ Object
Unix timestamp used to set the expiration date of the API key.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.types_mapping ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SecuredAPIKeyRestrictions
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*_args) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ SecuredAPIKeyRestrictions
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 62 def initialize(attributes = {}) unless attributes.is_a?(Hash) raise ArgumentError, "The input argument (attributes) must be a hash in `Algolia::SecuredAPIKeyRestrictions` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) do |(k, v), h| unless self.class.attribute_map.key?(k.to_sym) raise ArgumentError, "`#{k}` is not a valid attribute in `Algolia::SecuredAPIKeyRestrictions`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v end if attributes.key?(:search_params) self.search_params = attributes[:search_params] end if attributes.key?(:filters) self.filters = attributes[:filters] end if attributes.key?(:valid_until) self.valid_until = attributes[:valid_until] end if attributes.key?(:restrict_indices) if (value = attributes[:restrict_indices]).is_a?(Array) self.restrict_indices = value end end if attributes.key?(:restrict_sources) self.restrict_sources = attributes[:restrict_sources] end if attributes.key?(:user_token) self.user_token = attributes[:user_token] end end |
Instance Attribute Details
#filters ⇒ Object
Filters that apply to every search made with the secured API key. You can add extra filters at search time with the filters query parameter. For example, if you set the filter group:admin on your generated API key, and you add groups:press OR groups:visitors with the filters query parameter, your final search filter is equivalent to groups:admin AND (groups:press OR groups:visitors).
12 13 14 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 12 def filters @filters end |
#restrict_indices ⇒ Object
Index names that can be queried.
18 19 20 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 18 def restrict_indices @restrict_indices end |
#restrict_sources ⇒ Object
IPv4 network allowed to use the generated key. Use this to protect against API key leaking and reuse. You can only provide a single source, but you can specify a range of IPs (for example, 192.168.1.0/24).
21 22 23 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 21 def restrict_sources @restrict_sources end |
#search_params ⇒ Object
Returns the value of attribute search_params.
9 10 11 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 9 def search_params @search_params end |
#user_token ⇒ Object
Unique user IP address. This can be useful when you want to impose a rate limit on specific users. By default, rate limits are set based on the IP address. This can become an issue when several users search from the same IP address. To avoid this, you can set a unique userToken for each user when generating their API key. This lets you restrict each user to a maximum number of API calls per hour, even if they share their IP with another user. Specifying the userToken in a secured API key is also a good security practice as it ensures users don’t change it. Many features like Analytics, Personalization, and Dynamic Re-ranking rely on the authenticity of user identifiers. Setting the userToken at the API key level ensures that downstream services work as expected and prevents abuse.
24 25 26 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 24 def user_token @user_token end |
#valid_until ⇒ Object
Unix timestamp used to set the expiration date of the API key.
15 16 17 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 15 def valid_until @valid_until end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 158 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Algolia::Search.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 39 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 27 def self.attribute_map { :search_params => :searchParams, :filters => :filters, :valid_until => :validUntil, :restrict_indices => :restrictIndices, :restrict_sources => :restrictSources, :user_token => :userToken } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 133 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} types_mapping.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash[key.to_sym] = attributes[attribute_map[key]].map { |v| _deserialize(::Regexp.last_match(1), v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash[key.to_sym] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 56 def self.openapi_nullable Set.new([]) end |
.types_mapping ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 50 51 52 53 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 44 def self.types_mapping { :search_params => :SearchParamsObject, :filters => :String, :valid_until => :Integer, :restrict_indices => :'Array<String>', :restrict_sources => :String, :user_token => :String } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 106 def ==(other) return true if equal?(other) self.class == other.class && search_params == other.search_params && filters == other.filters && valid_until == other.valid_until && restrict_indices == other.restrict_indices && restrict_sources == other.restrict_sources && user_token == other.user_token end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 233 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(other) ⇒ Boolean
120 121 122 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 120 def eql?(other) self == other end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
126 127 128 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 126 def hash [search_params, filters, valid_until, restrict_indices, restrict_sources, user_token].hash end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
205 206 207 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 205 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 215 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_json(*_args) ⇒ Object
209 210 211 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 209 def to_json(*_args) to_hash.to_json end |
#to_s ⇒ String
Returns the string representation of the object
199 200 201 |
# File 'lib/algolia/models/search/secured_api_key_restrictions.rb', line 199 def to_s to_hash.to_s end |